# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: otg.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\totg.proto\x12\x03otg\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x91\x02\n\x06\x43onfig\x12\x18\n\x05ports\x18\x01 \x03(\x0b\x32\t.otg.Port\x12\x16\n\x04lags\x18\x02 \x03(\x0b\x32\x08.otg.Lag\x12\x1b\n\x06layer1\x18\x03 \x03(\x0b\x32\x0b.otg.Layer1\x12\x1e\n\x08\x63\x61ptures\x18\x04 \x03(\x0b\x32\x0c.otg.Capture\x12\x1c\n\x07\x64\x65vices\x18\x05 \x03(\x0b\x32\x0b.otg.Device\x12\x18\n\x05\x66lows\x18\x06 \x03(\x0b\x32\t.otg.Flow\x12\x1f\n\x06\x65vents\x18\x07 \x01(\x0b\x32\n.otg.EventH\x00\x88\x01\x01\x12(\n\x07options\x18\x08 \x01(\x0b\x32\x12.otg.ConfigOptionsH\x01\x88\x01\x01\x42\t\n\x07_eventsB\n\n\x08_options\"M\n\rConfigOptions\x12+\n\x0cport_options\x18\x01 \x01(\x0b\x32\x10.otg.PortOptionsH\x00\x88\x01\x01\x42\x0f\n\r_port_options\"8\n\x04Port\x12\x15\n\x08location\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\tB\x0b\n\t_location\"G\n\x0bPortOptions\x12 \n\x13location_preemption\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x16\n\x14_location_preemption\"0\n\x03Lag\x12\x1b\n\x05ports\x18\x01 \x03(\x0b\x32\x0c.otg.LagPort\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n\x07LagPort\x12\x11\n\tport_name\x18\x01 \x01(\t\x12\"\n\x08protocol\x18\x02 \x01(\x0b\x32\x10.otg.LagProtocol\x12)\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x17.otg.DeviceEthernetBase\"\xde\x01\n\x0bLagProtocol\x12\x31\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1c.otg.LagProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x1f\n\x04lacp\x18\x02 \x01(\x0b\x32\x0c.otg.LagLacpH\x01\x88\x01\x01\x12#\n\x06static\x18\x03 \x01(\x0b\x32\x0e.otg.LagStaticH\x02\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04lacp\x10\x01\x12\n\n\x06static\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_lacpB\t\n\x07_static\"+\n\tLagStatic\x12\x13\n\x06lag_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\t\n\x07_lag_id\"\xa1\x04\n\x07LagLacp\x12\x16\n\tactor_key\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x11\x61\x63tor_port_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12 \n\x13\x61\x63tor_port_priority\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0f\x61\x63tor_system_id\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\"\n\x15\x61\x63tor_system_priority\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1dlacpdu_periodic_time_interval\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x1b\n\x0elacpdu_timeout\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12<\n\x0e\x61\x63tor_activity\x18\x08 \x01(\x0e\x32\x1f.otg.LagLacp.ActorActivity.EnumH\x07\x88\x01\x01\x1a\x41\n\rActorActivity\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07passive\x10\x01\x12\n\n\x06\x61\x63tive\x10\x02\x42\x0c\n\n_actor_keyB\x14\n\x12_actor_port_numberB\x16\n\x14_actor_port_priorityB\x12\n\x10_actor_system_idB\x18\n\x16_actor_system_priorityB \n\x1e_lacpdu_periodic_time_intervalB\x11\n\x0f_lacpdu_timeoutB\x11\n\x0f_actor_activity\"i\n\x12\x44\x65viceEthernetBase\x12\x0b\n\x03mac\x18\x01 \x01(\t\x12\x10\n\x03mtu\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x05vlans\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x0c\n\x04name\x18\x04 \x01(\tB\x06\n\x04_mtu\"\xca\x01\n\x0e\x44\x65viceEthernet\x12\x11\n\tport_name\x18\x01 \x01(\t\x12\'\n\x0eipv4_addresses\x18\x02 \x03(\x0b\x32\x0f.otg.DeviceIpv4\x12\'\n\x0eipv6_addresses\x18\x03 \x03(\x0b\x32\x0f.otg.DeviceIpv6\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x10\n\x03mtu\x18\x05 \x01(\x05H\x00\x88\x01\x01\x12\x1e\n\x05vlans\x18\x06 \x03(\x0b\x32\x0f.otg.DeviceVlan\x12\x0c\n\x04name\x18\x07 \x01(\tB\x06\n\x04_mtu\"\xe5\x01\n\nDeviceVlan\x12,\n\x04tpid\x18\x01 \x01(\x0e\x32\x19.otg.DeviceVlan.Tpid.EnumH\x00\x88\x01\x01\x12\x15\n\x08priority\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0f\n\x02id\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\t\x1aV\n\x04Tpid\"N\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05x8100\x10\x01\x12\t\n\x05x88a8\x10\x02\x12\t\n\x05x9100\x10\x03\x12\t\n\x05x9200\x10\x04\x12\t\n\x05x9300\x10\x05\x42\x07\n\x05_tpidB\x0b\n\t_priorityB\x05\n\x03_id\"\\\n\nDeviceIpv4\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x13\n\x06prefix\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\tB\t\n\x07_prefix\"V\n\x12\x44\x65viceIpv4Loopback\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\tB\n\n\x08_address\"\\\n\nDeviceIpv6\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x13\n\x06prefix\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x04 \x01(\tB\t\n\x07_prefix\"V\n\x12\x44\x65viceIpv6Loopback\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x14\n\x07\x61\x64\x64ress\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x03 \x01(\tB\n\n\x08_address\"\xb4\x06\n\x06Layer1\x12\x12\n\nport_names\x18\x01 \x03(\t\x12*\n\x05speed\x18\x02 \x01(\x0e\x32\x16.otg.Layer1.Speed.EnumH\x00\x88\x01\x01\x12*\n\x05media\x18\x03 \x01(\x0e\x32\x16.otg.Layer1.Media.EnumH\x01\x88\x01\x01\x12\x18\n\x0bpromiscuous\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03mtu\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12 \n\x13ieee_media_defaults\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12\x1b\n\x0e\x61uto_negotiate\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x39\n\x10\x61uto_negotiation\x18\x08 \x01(\x0b\x32\x1a.otg.Layer1AutoNegotiationH\x06\x88\x01\x01\x12\x31\n\x0c\x66low_control\x18\t \x01(\x0b\x32\x16.otg.Layer1FlowControlH\x07\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a\x95\x02\n\x05Speed\"\x8b\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10speed_10_fd_mbps\x10\x01\x12\x14\n\x10speed_10_hd_mbps\x10\x02\x12\x15\n\x11speed_100_fd_mbps\x10\x03\x12\x15\n\x11speed_100_hd_mbps\x10\x04\x12\x10\n\x0cspeed_1_gbps\x10\x05\x12\x11\n\rspeed_10_gbps\x10\x06\x12\x11\n\rspeed_25_gbps\x10\x07\x12\x11\n\rspeed_40_gbps\x10\x08\x12\x11\n\rspeed_50_gbps\x10\t\x12\x12\n\x0espeed_100_gbps\x10\n\x12\x12\n\x0espeed_200_gbps\x10\x0b\x12\x12\n\x0espeed_400_gbps\x10\x0c\x1a\x42\n\x05Media\"9\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63opper\x10\x01\x12\t\n\x05\x66iber\x10\x02\x12\t\n\x05sgmii\x10\x03\x42\x08\n\x06_speedB\x08\n\x06_mediaB\x0e\n\x0c_promiscuousB\x06\n\x04_mtuB\x16\n\x14_ieee_media_defaultsB\x11\n\x0f_auto_negotiateB\x13\n\x11_auto_negotiationB\x0f\n\r_flow_control\"\x93\x03\n\x15Layer1AutoNegotiation\x12 \n\x13\x61\x64vertise_1000_mbps\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_fd_mbps\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15\x61\x64vertise_100_hd_mbps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_fd_mbps\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12!\n\x14\x61\x64vertise_10_hd_mbps\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rlink_training\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06rs_fec\x18\x07 \x01(\x08H\x06\x88\x01\x01\x42\x16\n\x14_advertise_1000_mbpsB\x18\n\x16_advertise_100_fd_mbpsB\x18\n\x16_advertise_100_hd_mbpsB\x17\n\x15_advertise_10_fd_mbpsB\x17\n\x15_advertise_10_hd_mbpsB\x10\n\x0e_link_trainingB\t\n\x07_rs_fec\"\xd8\x02\n\x11Layer1FlowControl\x12\x1d\n\x10\x64irected_address\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x37\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\".otg.Layer1FlowControl.Choice.EnumH\x01\x88\x01\x01\x12\x32\n\rieee_802_1qbb\x18\x03 \x01(\x0b\x32\x16.otg.Layer1Ieee8021qbbH\x02\x88\x01\x01\x12.\n\x0bieee_802_3x\x18\x04 \x01(\x0b\x32\x14.otg.Layer1Ieee8023xH\x03\x88\x01\x01\x1a\x45\n\x06\x43hoice\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rieee_802_1qbb\x10\x01\x12\x0f\n\x0bieee_802_3x\x10\x02\x42\x13\n\x11_directed_addressB\t\n\x07_choiceB\x10\n\x0e_ieee_802_1qbbB\x0e\n\x0c_ieee_802_3x\"\x11\n\x0fLayer1Ieee8023x\"\x89\x03\n\x11Layer1Ieee8021qbb\x12\x16\n\tpfc_delay\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpfc_class_0\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0bpfc_class_1\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x18\n\x0bpfc_class_2\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x18\n\x0bpfc_class_3\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x18\n\x0bpfc_class_4\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x18\n\x0bpfc_class_5\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x18\n\x0bpfc_class_6\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x18\n\x0bpfc_class_7\x18\t \x01(\x05H\x08\x88\x01\x01\x42\x0c\n\n_pfc_delayB\x0e\n\x0c_pfc_class_0B\x0e\n\x0c_pfc_class_1B\x0e\n\x0c_pfc_class_2B\x0e\n\x0c_pfc_class_3B\x0e\n\x0c_pfc_class_4B\x0e\n\x0c_pfc_class_5B\x0e\n\x0c_pfc_class_6B\x0e\n\x0c_pfc_class_7\"\x93\x02\n\x07\x43\x61pture\x12\x12\n\nport_names\x18\x01 \x03(\t\x12#\n\x07\x66ilters\x18\x02 \x03(\x0b\x32\x12.otg.CaptureFilter\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bpacket_size\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12-\n\x06\x66ormat\x18\x05 \x01(\x0e\x32\x18.otg.Capture.Format.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x37\n\x06\x46ormat\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04pcap\x10\x01\x12\n\n\x06pcapng\x10\x02\x42\x0c\n\n_overwriteB\x0e\n\x0c_packet_sizeB\t\n\x07_format\"\xa2\x03\n\rCaptureFilter\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.CaptureFilter.Choice.EnumH\x00\x88\x01\x01\x12\'\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x12.otg.CaptureCustomH\x01\x88\x01\x01\x12+\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x14.otg.CaptureEthernetH\x02\x88\x01\x01\x12#\n\x04vlan\x18\x04 \x01(\x0b\x32\x10.otg.CaptureVlanH\x03\x88\x01\x01\x12#\n\x04ipv4\x18\x05 \x01(\x0b\x32\x10.otg.CaptureIpv4H\x04\x88\x01\x01\x12#\n\x04ipv6\x18\x06 \x01(\x0b\x32\x10.otg.CaptureIpv6H\x05\x88\x01\x01\x1aY\n\x06\x43hoice\"O\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\x08\n\x04ipv4\x10\x04\x12\x08\n\x04ipv6\x10\x05\x42\t\n\x07_choiceB\t\n\x07_customB\x0b\n\t_ethernetB\x07\n\x05_vlanB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"\xb1\x01\n\rCaptureCustom\x12\x13\n\x06offset\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x17\n\nbit_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04mask\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06negate\x18\x05 \x01(\x08H\x04\x88\x01\x01\x42\t\n\x07_offsetB\r\n\x0b_bit_lengthB\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"h\n\x0c\x43\x61ptureField\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04mask\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06negate\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_valueB\x07\n\x05_maskB\t\n\x07_negate\"\xdf\x01\n\x0f\x43\x61ptureEthernet\x12#\n\x03src\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12#\n\x03\x64st\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12*\n\nether_type\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12)\n\tpfc_queue\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x42\x06\n\x04_srcB\x06\n\x04_dstB\r\n\x0b_ether_typeB\x0c\n\n_pfc_queue\"\xd3\x01\n\x0b\x43\x61ptureVlan\x12(\n\x08priority\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12#\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12\"\n\x02id\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12(\n\x08protocol\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x42\x0b\n\t_priorityB\x06\n\x04_cfiB\x05\n\x03_idB\x0b\n\t_protocol\"\xd1\x06\n\x0b\x43\x61ptureIpv4\x12\'\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12-\n\rheader_length\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12(\n\x08priority\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12,\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x12.\n\x0eidentification\x18\x05 \x01(\x0b\x32\x11.otg.CaptureFieldH\x04\x88\x01\x01\x12(\n\x08reserved\x18\x06 \x01(\x0b\x32\x11.otg.CaptureFieldH\x05\x88\x01\x01\x12-\n\rdont_fragment\x18\x07 \x01(\x0b\x32\x11.otg.CaptureFieldH\x06\x88\x01\x01\x12.\n\x0emore_fragments\x18\x08 \x01(\x0b\x32\x11.otg.CaptureFieldH\x07\x88\x01\x01\x12/\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\x11.otg.CaptureFieldH\x08\x88\x01\x01\x12,\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x11.otg.CaptureFieldH\t\x88\x01\x01\x12(\n\x08protocol\x18\x0b \x01(\x0b\x32\x11.otg.CaptureFieldH\n\x88\x01\x01\x12/\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\x11.otg.CaptureFieldH\x0b\x88\x01\x01\x12#\n\x03src\x18\r \x01(\x0b\x32\x11.otg.CaptureFieldH\x0c\x88\x01\x01\x12#\n\x03\x64st\x18\x0e \x01(\x0b\x32\x11.otg.CaptureFieldH\r\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_header_lengthB\x0b\n\t_priorityB\x0f\n\r_total_lengthB\x11\n\x0f_identificationB\x0b\n\t_reservedB\x10\n\x0e_dont_fragmentB\x11\n\x0f_more_fragmentsB\x12\n\x10_fragment_offsetB\x0f\n\r_time_to_liveB\x0b\n\t_protocolB\x12\n\x10_header_checksumB\x06\n\x04_srcB\x06\n\x04_dst\"\xd1\x03\n\x0b\x43\x61ptureIpv6\x12\'\n\x07version\x18\x01 \x01(\x0b\x32\x11.otg.CaptureFieldH\x00\x88\x01\x01\x12-\n\rtraffic_class\x18\x02 \x01(\x0b\x32\x11.otg.CaptureFieldH\x01\x88\x01\x01\x12*\n\nflow_label\x18\x03 \x01(\x0b\x32\x11.otg.CaptureFieldH\x02\x88\x01\x01\x12.\n\x0epayload_length\x18\x04 \x01(\x0b\x32\x11.otg.CaptureFieldH\x03\x88\x01\x01\x12+\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x11.otg.CaptureFieldH\x04\x88\x01\x01\x12)\n\thop_limit\x18\x06 \x01(\x0b\x32\x11.otg.CaptureFieldH\x05\x88\x01\x01\x12#\n\x03src\x18\x07 \x01(\x0b\x32\x11.otg.CaptureFieldH\x06\x88\x01\x01\x12#\n\x03\x64st\x18\x08 \x01(\x0b\x32\x11.otg.CaptureFieldH\x07\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_traffic_classB\r\n\x0b_flow_labelB\x11\n\x0f_payload_lengthB\x0e\n\x0c_next_headerB\x0c\n\n_hop_limitB\x06\n\x04_srcB\x06\n\x04_dst\"\x83\x02\n\x06\x44\x65vice\x12&\n\tethernets\x18\x01 \x03(\x0b\x32\x13.otg.DeviceEthernet\x12/\n\x0eipv4_loopbacks\x18\x02 \x03(\x0b\x32\x17.otg.DeviceIpv4Loopback\x12/\n\x0eipv6_loopbacks\x18\x03 \x03(\x0b\x32\x17.otg.DeviceIpv6Loopback\x12(\n\x04isis\x18\x04 \x01(\x0b\x32\x15.otg.DeviceIsisRouterH\x00\x88\x01\x01\x12&\n\x03\x62gp\x18\x05 \x01(\x0b\x32\x14.otg.DeviceBgpRouterH\x01\x88\x01\x01\x12\x0c\n\x04name\x18\x06 \x01(\tB\x07\n\x05_isisB\x06\n\x04_bgp\"\x99\x03\n\x10\x44\x65viceIsisRouter\x12\x33\n\x08instance\x18\x01 \x01(\x0b\x32\x1c.otg.DeviceIsisMultiInstanceH\x00\x88\x01\x01\x12\x11\n\tsystem_id\x18\x02 \x01(\t\x12&\n\ninterfaces\x18\x03 \x03(\x0b\x32\x12.otg.IsisInterface\x12\"\n\x05\x62\x61sic\x18\x04 \x01(\x0b\x32\x0e.otg.IsisBasicH\x01\x88\x01\x01\x12(\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x11.otg.IsisAdvancedH\x02\x88\x01\x01\x12\x31\n\x0brouter_auth\x18\x06 \x01(\x0b\x32\x17.otg.IsisAuthenticationH\x03\x88\x01\x01\x12(\n\tv4_routes\x18\x07 \x03(\x0b\x32\x15.otg.IsisV4RouteRange\x12(\n\tv6_routes\x18\x08 \x03(\x0b\x32\x15.otg.IsisV6RouteRange\x12\x0c\n\x04name\x18\t \x01(\tB\x0b\n\t_instanceB\x08\n\x06_basicB\x0b\n\t_advancedB\x0e\n\x0c_router_auth\"B\n\x17\x44\x65viceIsisMultiInstance\x12\x10\n\x03iid\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\r\n\x05itids\x18\x02 \x03(\x05\x42\x06\n\x04_iid\"\xde\x06\n\rIsisInterface\x12\x10\n\x08\x65th_name\x18\x01 \x01(\t\x12\x13\n\x06metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12>\n\x0cnetwork_type\x18\x03 \x01(\x0e\x32#.otg.IsisInterface.NetworkType.EnumH\x01\x88\x01\x01\x12:\n\nlevel_type\x18\x04 \x01(\x0e\x32!.otg.IsisInterface.LevelType.EnumH\x02\x88\x01\x01\x12\x31\n\x0bl1_settings\x18\x05 \x01(\x0b\x32\x17.otg.IsisInterfaceLevelH\x03\x88\x01\x01\x12\x31\n\x0bl2_settings\x18\x06 \x01(\x0b\x32\x17.otg.IsisInterfaceLevelH\x04\x88\x01\x01\x12\'\n\x12multi_topology_ids\x18\x07 \x03(\x0b\x32\x0b.otg.IsisMT\x12-\n\x13traffic_engineering\x18\x08 \x03(\x0b\x32\x10.otg.LinkStateTE\x12=\n\x0e\x61uthentication\x18\t \x01(\x0b\x32 .otg.IsisInterfaceAuthenticationH\x05\x88\x01\x01\x12\x31\n\x08\x61\x64vanced\x18\n \x01(\x0b\x32\x1a.otg.IsisInterfaceAdvancedH\x06\x88\x01\x01\x12>\n\x0flink_protection\x18\x0b \x01(\x0b\x32 .otg.IsisInterfaceLinkProtectionH\x07\x88\x01\x01\x12\x13\n\x0bsrlg_values\x18\x0c \x03(\x05\x12\x0c\n\x04name\x18\r \x01(\t\x1aI\n\x0bNetworkType\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tbroadcast\x10\x01\x12\x12\n\x0epoint_to_point\x10\x02\x1aM\n\tLevelType\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07level_1\x10\x01\x12\x0b\n\x07level_2\x10\x02\x12\r\n\tlevel_1_2\x10\x03\x42\t\n\x07_metricB\x0f\n\r_network_typeB\r\n\x0b_level_typeB\x0e\n\x0c_l1_settingsB\x0e\n\x0c_l2_settingsB\x11\n\x0f_authenticationB\x0b\n\t_advancedB\x12\n\x10_link_protection\"\x96\x01\n\x12IsisInterfaceLevel\x12\x15\n\x08priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1b\n\x0ehello_interval\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\rdead_interval\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0b\n\t_priorityB\x11\n\x0f_hello_intervalB\x10\n\x0e_dead_interval\"P\n\x06IsisMT\x12\x12\n\x05mt_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x08\n\x06_mt_idB\x0e\n\x0c_link_metric\"\xc1\x02\n\x0bLinkStateTE\x12!\n\x14\x61\x64ministrative_group\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cmetric_level\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x19\n\x0cmax_bandwith\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12%\n\x18max_reservable_bandwidth\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x42\n\x13priority_bandwidths\x18\x05 \x01(\x0b\x32 .otg.LinkStatepriorityBandwidthsH\x04\x88\x01\x01\x42\x17\n\x15_administrative_groupB\x0f\n\r_metric_levelB\x0f\n\r_max_bandwithB\x1b\n\x19_max_reservable_bandwidthB\x16\n\x14_priority_bandwidths\"\xed\x01\n\x1bLinkStatepriorityBandwidths\x12\x10\n\x03pb0\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x10\n\x03pb1\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03pb2\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x10\n\x03pb3\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x10\n\x03pb4\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x10\n\x03pb5\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x10\n\x03pb6\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x10\n\x03pb7\x18\x08 \x01(\x03H\x07\x88\x01\x01\x42\x06\n\x04_pb0B\x06\n\x04_pb1B\x06\n\x04_pb2B\x06\n\x04_pb3B\x06\n\x04_pb4B\x06\n\x04_pb5B\x06\n\x04_pb6B\x06\n\x04_pb7\"\xda\x01\n\x1bIsisInterfaceAuthentication\x12\x41\n\tauth_type\x18\x01 \x01(\x0e\x32..otg.IsisInterfaceAuthentication.AuthType.Enum\x12\x10\n\x03md5\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x06\n\x04_md5B\x0b\n\t_password\"\x8d\x02\n\x15IsisInterfaceAdvanced\x12\x1c\n\x0f\x61uto_adjust_mtu\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1d\n\x10\x61uto_adjust_area\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12,\n\x1f\x61uto_adjust_supported_protocols\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\"\n\x15\x65nable_3way_handshake\x18\x04 \x01(\x08H\x03\x88\x01\x01\x42\x12\n\x10_auto_adjust_mtuB\x13\n\x11_auto_adjust_areaB\"\n _auto_adjust_supported_protocolsB\x18\n\x16_enable_3way_handshake\"\xf9\x02\n\x1bIsisInterfaceLinkProtection\x12\x1a\n\rextra_traffic\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0bunprotected\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x13\n\x06shared\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x10\x64\x65\x64icated_1_to_1\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x1f\n\x12\x64\x65\x64icated_1_plus_1\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x15\n\x08\x65nhanced\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0breserved_40\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x18\n\x0breserved_80\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x10\n\x0e_extra_trafficB\x0e\n\x0c_unprotectedB\t\n\x07_sharedB\x13\n\x11_dedicated_1_to_1B\x15\n\x13_dedicated_1_plus_1B\x0b\n\t_enhancedB\x0e\n\x0c_reserved_40B\x0e\n\x0c_reserved_80\"\x9d\x01\n\tIsisBasic\x12\x1e\n\x11ipv4_te_router_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08hostname\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12\x65nable_wide_metric\x18\x03 \x01(\x08H\x02\x88\x01\x01\x42\x14\n\x12_ipv4_te_router_idB\x0b\n\t_hostnameB\x15\n\x13_enable_wide_metric\"\x8a\x04\n\x0cIsisAdvanced\x12!\n\x14\x65nable_hello_padding\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1f\n\x12max_area_addresses\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\x0e\x61rea_addresses\x18\x03 \x03(\t\x12\x1d\n\x10lsp_refresh_rate\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0clsp_lifetime\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12\x1a\n\rpsnp_interval\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12\x1a\n\rcsnp_interval\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12\x19\n\x0cmax_lsp_size\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12*\n\x1dlsp_mgroup_min_trans_interval\x18\t \x01(\x05H\x07\x88\x01\x01\x12 \n\x13\x65nable_attached_bit\x18\n \x01(\x08H\x08\x88\x01\x01\x42\x17\n\x15_enable_hello_paddingB\x15\n\x13_max_area_addressesB\x13\n\x11_lsp_refresh_rateB\x0f\n\r_lsp_lifetimeB\x10\n\x0e_psnp_intervalB\x10\n\x0e_csnp_intervalB\x0f\n\r_max_lsp_sizeB \n\x1e_lsp_mgroup_min_trans_intervalB\x16\n\x14_enable_attached_bit\"\xd6\x01\n\x12IsisAuthentication\x12\x1f\n\x12ignore_receive_md5\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x33\n\tarea_auth\x18\x02 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseH\x01\x88\x01\x01\x12\x35\n\x0b\x64omain_auth\x18\x03 \x01(\x0b\x32\x1b.otg.IsisAuthenticationBaseH\x02\x88\x01\x01\x42\x15\n\x13_ignore_receive_md5B\x0c\n\n_area_authB\x0e\n\x0c_domain_auth\"\xd0\x01\n\x16IsisAuthenticationBase\x12<\n\tauth_type\x18\x01 \x01(\x0e\x32).otg.IsisAuthenticationBase.AuthType.Enum\x12\x10\n\x03md5\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x1a:\n\x08\x41uthType\".\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03md5\x10\x01\x12\x0c\n\x08password\x10\x02\x42\x06\n\x04_md5B\x0b\n\t_password\"\xca\x04\n\x10IsisV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV4RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV4RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x06\x88\x01\x01\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"{\n\x0eV4RouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"{\n\x0eV6RouteAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x13\n\x06prefix\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x04 \x01(\x05H\x02\x88\x01\x01\x42\t\n\x07_prefixB\x08\n\x06_countB\x07\n\x05_step\"\xca\x04\n\x10IsisV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x18\n\x0blink_metric\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12?\n\x0borigin_type\x18\x03 \x01(\x0e\x32%.otg.IsisV6RouteRange.OriginType.EnumH\x01\x88\x01\x01\x12O\n\x13redistribution_type\x18\x04 \x01(\x0e\x32-.otg.IsisV6RouteRange.RedistributionType.EnumH\x02\x88\x01\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12 \n\x13prefix_attr_enabled\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06x_flag\x18\x07 \x01(\x08H\x04\x88\x01\x01\x12\x13\n\x06r_flag\x18\x08 \x01(\x08H\x05\x88\x01\x01\x12\x13\n\x06n_flag\x18\t \x01(\x08H\x06\x88\x01\x01\x1a\x41\n\nOriginType\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08internal\x10\x01\x12\x0c\n\x08\x65xternal\x10\x02\x1a?\n\x12RedistributionType\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x0e\n\x0c_link_metricB\x0e\n\x0c_origin_typeB\x16\n\x14_redistribution_typeB\x16\n\x14_prefix_attr_enabledB\t\n\x07_x_flagB\t\n\x07_r_flagB\t\n\x07_n_flag\"\x80\x01\n\x0f\x44\x65viceBgpRouter\x12\x11\n\trouter_id\x18\x01 \x01(\t\x12,\n\x0fipv4_interfaces\x18\x02 \x03(\x0b\x32\x13.otg.BgpV4Interface\x12,\n\x0fipv6_interfaces\x18\x03 \x03(\x0b\x32\x13.otg.BgpV6Interface\"\xdc\x04\n\tBgpV4Peer\x12\x14\n\x0cpeer_address\x18\x01 \x01(\t\x12+\n\x07\x61s_type\x18\x02 \x01(\x0e\x32\x1a.otg.BgpV4Peer.AsType.Enum\x12\x11\n\tas_number\x18\x03 \x01(\x05\x12?\n\x0f\x61s_number_width\x18\x04 \x01(\x0e\x32!.otg.BgpV4Peer.AsNumberWidth.EnumH\x00\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x05 \x01(\x0b\x32\x10.otg.BgpAdvancedH\x01\x88\x01\x01\x12+\n\ncapability\x18\x06 \x01(\x0b\x32\x12.otg.BgpCapabilityH\x02\x88\x01\x01\x12\'\n\tv4_routes\x18\x07 \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\x08 \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\t \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\n \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x0c\n\x04name\x18\x0b \x01(\t\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x12\n\x10_as_number_widthB\x0b\n\t_advancedB\r\n\x0b_capability\"B\n\x0e\x42gpV4Interface\x12\x11\n\tipv4_name\x18\x01 \x01(\t\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV4Peer\"\xff\x01\n\x0b\x42gpAdvanced\x12\x1f\n\x12hold_time_interval\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12 \n\x13keep_alive_interval\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fupdate_interval\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07md5_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x15\n\x13_hold_time_intervalB\x16\n\x14_keep_alive_intervalB\x12\n\x10_update_intervalB\x0f\n\r_time_to_liveB\n\n\x08_md5_key\"\x91\n\n\rBgpCapability\x12\x19\n\x0cipv4_unicast\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0eipv4_multicast\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x19\n\x0cipv6_unicast\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1b\n\x0eipv6_multicast\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x11\n\x04vpls\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x1a\n\rroute_refresh\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1d\n\x10route_constraint\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12link_state_non_vpn\x18\x08 \x01(\x08H\x07\x88\x01\x01\x12\x1b\n\x0elink_state_vpn\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x11\n\x04\x65vpn\x18\n \x01(\x08H\t\x88\x01\x01\x12\'\n\x1a\x65xtended_next_hop_encoding\x18\x0b \x01(\x08H\n\x88\x01\x01\x12\x1f\n\x12ipv4_multicast_vpn\x18\x0c \x01(\x08H\x0b\x88\x01\x01\x12\x1a\n\ripv4_mpls_vpn\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\x15\n\x08ipv4_mdt\x18\x0e \x01(\x08H\r\x88\x01\x01\x12$\n\x17ipv4_multicast_mpls_vpn\x18\x0f \x01(\x08H\x0e\x88\x01\x01\x12#\n\x16ipv4_unicast_flow_spec\x18\x10 \x01(\x08H\x0f\x88\x01\x01\x12\x1e\n\x11ipv4_sr_te_policy\x18\x11 \x01(\x08H\x10\x88\x01\x01\x12\"\n\x15ipv4_unicast_add_path\x18\x12 \x01(\x08H\x11\x88\x01\x01\x12\x1f\n\x12ipv6_multicast_vpn\x18\x13 \x01(\x08H\x12\x88\x01\x01\x12\x1a\n\ripv6_mpls_vpn\x18\x14 \x01(\x08H\x13\x88\x01\x01\x12\x15\n\x08ipv6_mdt\x18\x15 \x01(\x08H\x14\x88\x01\x01\x12$\n\x17ipv6_multicast_mpls_vpn\x18\x16 \x01(\x08H\x15\x88\x01\x01\x12#\n\x16ipv6_unicast_flow_spec\x18\x17 \x01(\x08H\x16\x88\x01\x01\x12\x1e\n\x11ipv6_sr_te_policy\x18\x18 \x01(\x08H\x17\x88\x01\x01\x12\"\n\x15ipv6_unicast_add_path\x18\x19 \x01(\x08H\x18\x88\x01\x01\x42\x0f\n\r_ipv4_unicastB\x11\n\x0f_ipv4_multicastB\x0f\n\r_ipv6_unicastB\x11\n\x0f_ipv6_multicastB\x07\n\x05_vplsB\x10\n\x0e_route_refreshB\x13\n\x11_route_constraintB\x15\n\x13_link_state_non_vpnB\x11\n\x0f_link_state_vpnB\x07\n\x05_evpnB\x1d\n\x1b_extended_next_hop_encodingB\x15\n\x13_ipv4_multicast_vpnB\x10\n\x0e_ipv4_mpls_vpnB\x0b\n\t_ipv4_mdtB\x1a\n\x18_ipv4_multicast_mpls_vpnB\x19\n\x17_ipv4_unicast_flow_specB\x14\n\x12_ipv4_sr_te_policyB\x18\n\x16_ipv4_unicast_add_pathB\x15\n\x13_ipv6_multicast_vpnB\x10\n\x0e_ipv6_mpls_vpnB\x0b\n\t_ipv6_mdtB\x1a\n\x18_ipv6_multicast_mpls_vpnB\x19\n\x17_ipv6_unicast_flow_specB\x14\n\x12_ipv6_sr_te_policyB\x18\n\x16_ipv6_unicast_add_path\"\xd3\x05\n\x0f\x42gpV4RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V4RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV4RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV4RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12$\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x06\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\n\n\x08_as_pathB\x0b\n\t_add_path\"\xce\x01\n\x10\x42gpRouteAdvanced\x12%\n\x18multi_exit_discriminator\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x36\n\x06origin\x18\x02 \x01(\x0e\x32!.otg.BgpRouteAdvanced.Origin.EnumH\x01\x88\x01\x01\x1a\x33\n\x06Origin\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03igp\x10\x01\x12\x07\n\x03\x65gp\x10\x02\x42\x1b\n\x19_multi_exit_discriminatorB\t\n\x07_origin\"\xa4\x02\n\x0c\x42gpCommunity\x12.\n\x04type\x18\x01 \x01(\x0e\x32\x1b.otg.BgpCommunity.Type.EnumH\x00\x88\x01\x01\x12\x16\n\tas_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x16\n\tas_custom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a\x8e\x01\n\x04Type\"\x85\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x14\n\x10manual_as_number\x10\x01\x12\r\n\tno_export\x10\x02\x12\x11\n\rno_advertised\x10\x03\x12\x17\n\x13no_export_subconfed\x10\x04\x12\x0e\n\nllgr_stale\x10\x05\x12\x0b\n\x07no_llgr\x10\x06\x42\x07\n\x05_typeB\x0c\n\n_as_numberB\x0c\n\n_as_custom\"\xbe\x02\n\tBgpAsPath\x12\x37\n\x0b\x61s_set_mode\x18\x01 \x01(\x0e\x32\x1d.otg.BgpAsPath.AsSetMode.EnumH\x00\x88\x01\x01\x12\'\n\x08segments\x18\x02 \x03(\x0b\x32\x15.otg.BgpAsPathSegment\x1a\xbe\x01\n\tAsSetMode\"\xb0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x64o_not_include_local_as\x10\x01\x12\x12\n\x0einclude_as_seq\x10\x02\x12\x12\n\x0einclude_as_set\x10\x03\x12\x19\n\x15include_as_confed_seq\x10\x04\x12\x19\n\x15include_as_confed_set\x10\x05\x12\x1c\n\x18prepend_to_first_segment\x10\x06\x42\x0e\n\x0c_as_set_mode\"\xc2\x01\n\x10\x42gpAsPathSegment\x12\x32\n\x04type\x18\x01 \x01(\x0e\x32\x1f.otg.BgpAsPathSegment.Type.EnumH\x00\x88\x01\x01\x12\x12\n\nas_numbers\x18\x02 \x03(\x03\x1a]\n\x04Type\"U\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x61s_seq\x10\x01\x12\n\n\x06\x61s_set\x10\x02\x12\x11\n\ras_confed_seq\x10\x03\x12\x11\n\ras_confed_set\x10\x04\x42\x07\n\x05_type\".\n\nBgpAddPath\x12\x14\n\x07path_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\n\n\x08_path_id\"\xd3\x05\n\x0f\x42gpV6RouteRange\x12&\n\taddresses\x18\x01 \x03(\x0b\x32\x13.otg.V6RouteAddress\x12\x41\n\rnext_hop_mode\x18\x02 \x01(\x0e\x32%.otg.BgpV6RouteRange.NextHopMode.EnumH\x00\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x03 \x01(\x0e\x32,.otg.BgpV6RouteRange.NextHopAddressType.EnumH\x01\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x05 \x01(\tH\x03\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x04\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x07 \x03(\x0b\x32\x11.otg.BgpCommunity\x12$\n\x07\x61s_path\x18\x08 \x01(\x0b\x32\x0e.otg.BgpAsPathH\x05\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x06\x88\x01\x01\x12\x0c\n\x04name\x18\n \x01(\t\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\n\n\x08_as_pathB\x0b\n\t_add_path\"\x8b\x07\n\x0f\x42gpSrteV4Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\ripv4_endpoint\x18\x03 \x01(\t\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV4Policy.NextHopMode.EnumH\x02\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV4Policy.NextHopAddressType.EnumH\x03\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x07\x88\x01\x01\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x08\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12-\n\x0f\x65xt_communities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV4TunnelTlv\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\t\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\x0b\n\t_add_pathB\n\n\x08_as_pathB\t\n\x07_active\"\xf9\x03\n\x0f\x42gpExtCommunity\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32\x1e.otg.BgpExtCommunity.Type.EnumH\x00\x88\x01\x01\x12\x37\n\x07subtype\x18\x02 \x01(\x0e\x32!.otg.BgpExtCommunity.Subtype.EnumH\x01\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x02\x88\x01\x01\x1a\xbc\x01\n\x04Type\"\xb3\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x1b\n\x17\x61\x64ministrator_as_2octet\x10\x01\x12\x1e\n\x1a\x61\x64ministrator_ipv4_address\x10\x02\x12\x1b\n\x17\x61\x64ministrator_as_4octet\x10\x03\x12\n\n\x06opaque\x10\x04\x12\x08\n\x04\x65vpn\x10\x05\x12*\n&administrator_as_2octet_link_bandwidth\x10\x06\x1a\x87\x01\n\x07Subtype\"|\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0croute_target\x10\x01\x12\n\n\x06origin\x10\x02\x12\x16\n\x12\x65xtended_bandwidth\x10\x03\x12\t\n\x05\x63olor\x10\x04\x12\x11\n\rencapsulation\x10\x05\x12\x0f\n\x0bmac_address\x10\x06\x42\x07\n\x05_typeB\n\n\x08_subtypeB\x08\n\x06_value\"\xff\x05\n\x12\x42gpSrteV4TunnelTlv\x12\x46\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlvH\x00\x88\x01\x01\x12\x33\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlvH\x01\x88\x01\x01\x12\x37\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlvH\x02\x88\x01\x01\x12=\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlvH\x03\x88\x01\x01\x12\x46\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlvH\x04\x88\x01\x01\x12>\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlvH\x05\x88\x01\x01\x12Z\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlvH\x06\x88\x01\x01\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x07\x88\x01\x01\x42\x1a\n\x18_remote_endpoint_sub_tlvB\x10\n\x0e_color_sub_tlvB\x12\n\x10_binding_sub_tlvB\x15\n\x13_preference_sub_tlvB\x1a\n\x18_policy_priority_sub_tlvB\x16\n\x14_policy_name_sub_tlvB%\n#_explicit_null_label_policy_sub_tlvB\t\n\x07_active\"\xbe\x02\n\x1b\x42gpSrteRemoteEndpointSubTlv\x12\x16\n\tas_number\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12P\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32\x33.otg.BgpSrteRemoteEndpointSubTlv.AddressFamily.EnumH\x01\x88\x01\x01\x12\x19\n\x0cipv4_address\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0cipv6_address\x18\x04 \x01(\tH\x03\x88\x01\x01\x1a<\n\rAddressFamily\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x0c\n\n_as_numberB\x11\n\x0f_address_familyB\x0f\n\r_ipv4_addressB\x0f\n\r_ipv6_address\"2\n\x12\x42gpSrteColorSubTlv\x12\x12\n\x05\x63olor\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_color\"\xea\x02\n\x14\x42gpSrteBindingSubTlv\x12L\n\x10\x62inding_sid_type\x18\x01 \x01(\x0e\x32-.otg.BgpSrteBindingSubTlv.BindingSidType.EnumH\x00\x88\x01\x01\x12\x1b\n\x0e\x66our_octet_sid\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x15\n\x08ipv6_sid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06s_flag\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06i_flag\x18\x05 \x01(\x08H\x04\x88\x01\x01\x1a[\n\x0e\x42indingSidType\"I\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0e\n\nno_binding\x10\x01\x12\x12\n\x0e\x66our_octet_sid\x10\x02\x12\x0c\n\x08ipv6_sid\x10\x03\x42\x13\n\x11_binding_sid_typeB\x11\n\x0f_four_octet_sidB\x0b\n\t_ipv6_sidB\t\n\x07_s_flagB\t\n\x07_i_flag\"A\n\x17\x42gpSrtePreferenceSubTlv\x12\x17\n\npreference\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\r\n\x0b_preference\"O\n\x1b\x42gpSrtePolicyPrioritySubTlv\x12\x1c\n\x0fpolicy_priority\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x12\n\x10_policy_priority\"C\n\x17\x42gpSrtePolicyNameSubTlv\x12\x18\n\x0bpolicy_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0e\n\x0c_policy_name\"\xd6\x02\n$BgpSrteExplicitNullLabelPolicySubTlv\x12o\n\x1a\x65xplicit_null_label_policy\x18\x01 \x01(\x0e\x32\x46.otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy.EnumH\x00\x88\x01\x01\x1a\x9d\x01\n\x17\x45xplicitNullLabelPolicy\"\x81\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rreserved_enlp\x10\x01\x12\x12\n\x0epush_ipv4_enlp\x10\x02\x12\x12\n\x0epush_ipv6_enlp\x10\x03\x12\x17\n\x13push_ipv4_ipv6_enlp\x10\x04\x12\x14\n\x10\x64o_not_push_enlp\x10\x05\x42\x1d\n\x1b_explicit_null_label_policy\"\x89\x01\n\x12\x42gpSrteSegmentList\x12\x13\n\x06weight\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12%\n\x08segments\x18\x02 \x03(\x0b\x32\x13.otg.BgpSrteSegment\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x04 \x01(\x08H\x01\x88\x01\x01\x42\t\n\x07_weightB\t\n\x07_active\"\xe8\x07\n\x0e\x42gpSrteSegment\x12:\n\x0csegment_type\x18\x01 \x01(\x0e\x32$.otg.BgpSrteSegment.SegmentType.Enum\x12\x33\n\x06type_a\x18\x02 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentATypeSubTlvH\x00\x88\x01\x01\x12\x33\n\x06type_b\x18\x03 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentBTypeSubTlvH\x01\x88\x01\x01\x12\x33\n\x06type_c\x18\x04 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentCTypeSubTlvH\x02\x88\x01\x01\x12\x33\n\x06type_d\x18\x05 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentDTypeSubTlvH\x03\x88\x01\x01\x12\x33\n\x06type_e\x18\x06 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentETypeSubTlvH\x04\x88\x01\x01\x12\x33\n\x06type_f\x18\x07 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentFTypeSubTlvH\x05\x88\x01\x01\x12\x33\n\x06type_g\x18\x08 \x01(\x0b\x32\x1e.otg.BgpSrteSegmentGTypeSubTlvH\x06\x88\x01\x01\x12\x33\n\x06type_h\x18\t \x01(\x0b\x32\x1e.otg.BgpSrteSegmentHTypeSubTlvH\x07\x88\x01\x01\x12\x33\n\x06type_i\x18\n \x01(\x0b\x32\x1e.otg.BgpSrteSegmentITypeSubTlvH\x08\x88\x01\x01\x12\x33\n\x06type_j\x18\x0b \x01(\x0b\x32\x1e.otg.BgpSrteSegmentJTypeSubTlvH\t\x88\x01\x01\x12\x33\n\x06type_k\x18\x0c \x01(\x0b\x32\x1e.otg.BgpSrteSegmentKTypeSubTlvH\n\x88\x01\x01\x12\x0c\n\x04name\x18\r \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0e \x01(\x08H\x0b\x88\x01\x01\x1a\xab\x01\n\x0bSegmentType\"\x9b\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06type_a\x10\x01\x12\n\n\x06type_b\x10\x02\x12\n\n\x06type_c\x10\x03\x12\n\n\x06type_d\x10\x04\x12\n\n\x06type_e\x10\x05\x12\n\n\x06type_f\x10\x06\x12\n\n\x06type_g\x10\x07\x12\n\n\x06type_h\x10\x08\x12\n\n\x06type_i\x10\t\x12\n\n\x06type_j\x10\n\x12\n\n\x06type_k\x10\x0b\x42\t\n\x07_type_aB\t\n\x07_type_bB\t\n\x07_type_cB\t\n\x07_type_dB\t\n\x07_type_eB\t\n\x07_type_fB\t\n\x07_type_gB\t\n\x07_type_hB\t\n\x07_type_iB\t\n\x07_type_jB\t\n\x07_type_kB\t\n\x07_active\"\x80\x01\n\x10\x42gpSrteSrMplsSid\x12\x12\n\x05label\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x0f\n\x02tc\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05s_bit\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x10\n\x03ttl\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xca\x01\n*BgpSrteSRv6SIDEndpointBehaviorAndStructure\x12\x16\n\tlb_length\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x16\n\tln_length\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x18\n\x0b\x66unc_length\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\narg_length\x18\x04 \x01(\x05H\x03\x88\x01\x01\x42\x0c\n\n_lb_lengthB\x0c\n\n_ln_lengthB\x0e\n\x0c_func_lengthB\r\n\x0b_arg_length\"\xa7\x01\n\x19\x42gpSrteSegmentATypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05label\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0f\n\x02tc\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x12\n\x05s_bit\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x10\n\x03ttl\x18\x05 \x01(\x05H\x04\x88\x01\x01\x42\x08\n\x06_flagsB\x08\n\x06_labelB\x05\n\x03_tcB\x08\n\x06_s_bitB\x06\n\x04_ttl\"\xc4\x01\n\x19\x42gpSrteSegmentBTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x08srv6_sid\x18\x02 \x01(\t\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x03 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xc1\x01\n\x19\x42gpSrteSegmentCTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv4_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0e\n\x0c_sr_mpls_sid\"\xc1\x01\n\x19\x42gpSrteSegmentDTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv6_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0e\n\x0c_sr_mpls_sid\"\xcd\x01\n\x19\x42gpSrteSegmentETypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x19\n\x11ipv4_node_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x0e\n\x0c_sr_mpls_sid\"\xb3\x01\n\x19\x42gpSrteSegmentFTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12local_ipv4_address\x18\x02 \x01(\t\x12\x1b\n\x13remote_ipv4_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x0e\n\x0c_sr_mpls_sid\"\xaf\x02\n\x19\x42gpSrteSegmentGTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x17local_ipv6_node_address\x18\x03 \x01(\t\x12 \n\x13remote_interface_id\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12 \n\x18remote_ipv6_node_address\x18\x05 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x06 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x15\n\x13_local_interface_idB\x16\n\x14_remote_interface_idB\x0e\n\x0c_sr_mpls_sid\"\xb3\x01\n\x19\x42gpSrteSegmentHTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\x12local_ipv6_address\x18\x02 \x01(\t\x12\x1b\n\x13remote_ipv6_address\x18\x03 \x01(\t\x12/\n\x0bsr_mpls_sid\x18\x04 \x01(\x0b\x32\x15.otg.BgpSrteSrMplsSidH\x01\x88\x01\x01\x42\x08\n\x06_flagsB\x0e\n\x0c_sr_mpls_sid\"\xf1\x01\n\x19\x42gpSrteSegmentITypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x11ipv6_node_address\x18\x02 \x01(\t\x12\x15\n\x08srv6_sid\x18\x03 \x01(\tH\x01\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x04 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x02\x88\x01\x01\x42\x08\n\x06_flagsB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xb7\x03\n\x19\x42gpSrteSegmentJTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x12local_interface_id\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1f\n\x17local_ipv6_node_address\x18\x04 \x01(\t\x12 \n\x13remote_interface_id\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12 \n\x18remote_ipv6_node_address\x18\x06 \x01(\t\x12\x15\n\x08srv6_sid\x18\x07 \x01(\tH\x04\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x08 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x05\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x15\n\x13_local_interface_idB\x16\n\x14_remote_interface_idB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\xbb\x02\n\x19\x42gpSrteSegmentKTypeSubTlv\x12\x12\n\x05\x66lags\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0csr_algorithm\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1a\n\x12local_ipv6_address\x18\x03 \x01(\t\x12\x1b\n\x13remote_ipv6_address\x18\x04 \x01(\t\x12\x15\n\x08srv6_sid\x18\x05 \x01(\tH\x02\x88\x01\x01\x12X\n\x1asrv6_sid_endpoint_behavior\x18\x06 \x01(\x0b\x32/.otg.BgpSrteSRv6SIDEndpointBehaviorAndStructureH\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x0f\n\r_sr_algorithmB\x0b\n\t_srv6_sidB\x1d\n\x1b_srv6_sid_endpoint_behavior\"\x8a\x07\n\x0f\x42gpSrteV6Policy\x12\x1a\n\rdistinguisher\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x15\n\ripv6_endpoint\x18\x03 \x01(\t\x12\x41\n\rnext_hop_mode\x18\x04 \x01(\x0e\x32%.otg.BgpSrteV6Policy.NextHopMode.EnumH\x02\x88\x01\x01\x12P\n\x15next_hop_address_type\x18\x05 \x01(\x0e\x32,.otg.BgpSrteV6Policy.NextHopAddressType.EnumH\x03\x88\x01\x01\x12\"\n\x15next_hop_ipv4_address\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\"\n\x15next_hop_ipv6_address\x18\x07 \x01(\tH\x05\x88\x01\x01\x12,\n\x08\x61\x64vanced\x18\x08 \x01(\x0b\x32\x15.otg.BgpRouteAdvancedH\x06\x88\x01\x01\x12&\n\x08\x61\x64\x64_path\x18\t \x01(\x0b\x32\x0f.otg.BgpAddPathH\x07\x88\x01\x01\x12$\n\x07\x61s_path\x18\n \x01(\x0b\x32\x0e.otg.BgpAsPathH\x08\x88\x01\x01\x12&\n\x0b\x63ommunities\x18\x0b \x03(\x0b\x32\x11.otg.BgpCommunity\x12,\n\x0e\x65xtcommunities\x18\x0c \x03(\x0b\x32\x14.otg.BgpExtCommunity\x12,\n\x0btunnel_tlvs\x18\r \x03(\x0b\x32\x17.otg.BgpSrteV6TunnelTlv\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x13\n\x06\x61\x63tive\x18\x0f \x01(\x08H\t\x88\x01\x01\x1a@\n\x0bNextHopMode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08local_ip\x10\x01\x12\n\n\x06manual\x10\x02\x1a\x41\n\x12NextHopAddressType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\x10\n\x0e_distinguisherB\x08\n\x06_colorB\x10\n\x0e_next_hop_modeB\x18\n\x16_next_hop_address_typeB\x18\n\x16_next_hop_ipv4_addressB\x18\n\x16_next_hop_ipv6_addressB\x0b\n\t_advancedB\x0b\n\t_add_pathB\n\n\x08_as_pathB\t\n\x07_active\"\xff\x05\n\x12\x42gpSrteV6TunnelTlv\x12\x46\n\x17remote_endpoint_sub_tlv\x18\x01 \x01(\x0b\x32 .otg.BgpSrteRemoteEndpointSubTlvH\x00\x88\x01\x01\x12\x33\n\rcolor_sub_tlv\x18\x02 \x01(\x0b\x32\x17.otg.BgpSrteColorSubTlvH\x01\x88\x01\x01\x12\x37\n\x0f\x62inding_sub_tlv\x18\x03 \x01(\x0b\x32\x19.otg.BgpSrteBindingSubTlvH\x02\x88\x01\x01\x12=\n\x12preference_sub_tlv\x18\x04 \x01(\x0b\x32\x1c.otg.BgpSrtePreferenceSubTlvH\x03\x88\x01\x01\x12\x46\n\x17policy_priority_sub_tlv\x18\x05 \x01(\x0b\x32 .otg.BgpSrtePolicyPrioritySubTlvH\x04\x88\x01\x01\x12>\n\x13policy_name_sub_tlv\x18\x06 \x01(\x0b\x32\x1c.otg.BgpSrtePolicyNameSubTlvH\x05\x88\x01\x01\x12Z\n\"explicit_null_label_policy_sub_tlv\x18\x07 \x01(\x0b\x32).otg.BgpSrteExplicitNullLabelPolicySubTlvH\x06\x88\x01\x01\x12.\n\rsegment_lists\x18\x08 \x03(\x0b\x32\x17.otg.BgpSrteSegmentList\x12\x0c\n\x04name\x18\t \x01(\t\x12\x13\n\x06\x61\x63tive\x18\n \x01(\x08H\x07\x88\x01\x01\x42\x1a\n\x18_remote_endpoint_sub_tlvB\x10\n\x0e_color_sub_tlvB\x12\n\x10_binding_sub_tlvB\x15\n\x13_preference_sub_tlvB\x1a\n\x18_policy_priority_sub_tlvB\x16\n\x14_policy_name_sub_tlvB%\n#_explicit_null_label_policy_sub_tlvB\t\n\x07_active\"\xa8\x05\n\tBgpV6Peer\x12\x14\n\x0cpeer_address\x18\x01 \x01(\t\x12\x36\n\x0fsegment_routing\x18\x02 \x01(\x0b\x32\x18.otg.BgpV6SegmentRoutingH\x00\x88\x01\x01\x12+\n\x07\x61s_type\x18\x03 \x01(\x0e\x32\x1a.otg.BgpV6Peer.AsType.Enum\x12\x11\n\tas_number\x18\x04 \x01(\x05\x12?\n\x0f\x61s_number_width\x18\x05 \x01(\x0e\x32!.otg.BgpV6Peer.AsNumberWidth.EnumH\x01\x88\x01\x01\x12\'\n\x08\x61\x64vanced\x18\x06 \x01(\x0b\x32\x10.otg.BgpAdvancedH\x02\x88\x01\x01\x12+\n\ncapability\x18\x07 \x01(\x0b\x32\x12.otg.BgpCapabilityH\x03\x88\x01\x01\x12\'\n\tv4_routes\x18\x08 \x03(\x0b\x32\x14.otg.BgpV4RouteRange\x12\'\n\tv6_routes\x18\t \x03(\x0b\x32\x14.otg.BgpV6RouteRange\x12.\n\x10v4_srte_policies\x18\n \x03(\x0b\x32\x14.otg.BgpSrteV4Policy\x12.\n\x10v6_srte_policies\x18\x0b \x03(\x0b\x32\x14.otg.BgpSrteV6Policy\x12\x0c\n\x04name\x18\x0c \x01(\t\x1a\x35\n\x06\x41sType\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ibgp\x10\x01\x12\x08\n\x04\x65\x62gp\x10\x02\x1a;\n\rAsNumberWidth\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03two\x10\x01\x12\x08\n\x04\x66our\x10\x02\x42\x12\n\x10_segment_routingB\x12\n\x10_as_number_widthB\x0b\n\t_advancedB\r\n\x0b_capability\"B\n\x0e\x42gpV6Interface\x12\x11\n\tipv6_name\x18\x01 \x01(\t\x12\x1d\n\x05peers\x18\x02 \x03(\x0b\x32\x0e.otg.BgpV6Peer\"\xf1\x03\n\x13\x42gpV6SegmentRouting\x12!\n\x14ingress_supports_vpn\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15reduced_encapsulation\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x1e\n\x11\x63opy_time_to_live\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x19\n\x0ctime_to_live\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1d\n\x10max_sids_per_srh\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12-\n auto_generate_segment_left_value\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x1f\n\x12segment_left_value\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12#\n\x16\x61\x64vertise_sr_te_policy\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\x17\n\x15_ingress_supports_vpnB\x18\n\x16_reduced_encapsulationB\x14\n\x12_copy_time_to_liveB\x0f\n\r_time_to_liveB\x13\n\x11_max_sids_per_srhB#\n!_auto_generate_segment_left_valueB\x15\n\x13_segment_left_valueB\x19\n\x17_advertise_sr_te_policy\"\x94\x02\n\x04\x46low\x12\x1c\n\x05tx_rx\x18\x01 \x01(\x0b\x32\r.otg.FlowTxRx\x12\x1f\n\x06packet\x18\x02 \x03(\x0b\x32\x0f.otg.FlowHeader\x12 \n\x04size\x18\x03 \x01(\x0b\x32\r.otg.FlowSizeH\x00\x88\x01\x01\x12 \n\x04rate\x18\x04 \x01(\x0b\x32\r.otg.FlowRateH\x01\x88\x01\x01\x12(\n\x08\x64uration\x18\x05 \x01(\x0b\x32\x11.otg.FlowDurationH\x02\x88\x01\x01\x12&\n\x07metrics\x18\x06 \x01(\x0b\x32\x10.otg.FlowMetricsH\x03\x88\x01\x01\x12\x0c\n\x04name\x18\x07 \x01(\tB\x07\n\x05_sizeB\x07\n\x05_rateB\x0b\n\t_durationB\n\n\x08_metrics\"\xda\x01\n\x08\x46lowTxRx\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowTxRx.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04port\x18\x02 \x01(\x0b\x32\r.otg.FlowPortH\x01\x88\x01\x01\x12$\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x0f.otg.FlowRouterH\x02\x88\x01\x01\x1a\x37\n\x06\x43hoice\"-\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\n\n\x06\x64\x65vice\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_portB\t\n\x07_device\"=\n\x08\x46lowPort\x12\x0f\n\x07tx_name\x18\x01 \x01(\t\x12\x14\n\x07rx_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_rx_name\"\xa2\x01\n\nFlowRouter\x12,\n\x04mode\x18\x01 \x01(\x0e\x32\x19.otg.FlowRouter.Mode.EnumH\x00\x88\x01\x01\x12\x10\n\x08tx_names\x18\x02 \x03(\t\x12\x10\n\x08rx_names\x18\x03 \x03(\t\x1a\x39\n\x04Mode\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04mesh\x10\x01\x12\x0e\n\none_to_one\x10\x02\x42\x07\n\x05_mode\"\xb1\t\n\nFlowHeader\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowHeader.Choice.EnumH\x00\x88\x01\x01\x12$\n\x06\x63ustom\x18\x02 \x01(\x0b\x32\x0f.otg.FlowCustomH\x01\x88\x01\x01\x12(\n\x08\x65thernet\x18\x03 \x01(\x0b\x32\x11.otg.FlowEthernetH\x02\x88\x01\x01\x12 \n\x04vlan\x18\x04 \x01(\x0b\x32\r.otg.FlowVlanH\x03\x88\x01\x01\x12\"\n\x05vxlan\x18\x05 \x01(\x0b\x32\x0e.otg.FlowVxlanH\x04\x88\x01\x01\x12 \n\x04ipv4\x18\x06 \x01(\x0b\x32\r.otg.FlowIpv4H\x05\x88\x01\x01\x12 \n\x04ipv6\x18\x07 \x01(\x0b\x32\r.otg.FlowIpv6H\x06\x88\x01\x01\x12(\n\x08pfcpause\x18\x08 \x01(\x0b\x32\x11.otg.FlowPfcPauseH\x07\x88\x01\x01\x12\x32\n\rethernetpause\x18\t \x01(\x0b\x32\x16.otg.FlowEthernetPauseH\x08\x88\x01\x01\x12\x1e\n\x03tcp\x18\n \x01(\x0b\x32\x0c.otg.FlowTcpH\t\x88\x01\x01\x12\x1e\n\x03udp\x18\x0b \x01(\x0b\x32\x0c.otg.FlowUdpH\n\x88\x01\x01\x12\x1e\n\x03gre\x18\x0c \x01(\x0b\x32\x0c.otg.FlowGreH\x0b\x88\x01\x01\x12\"\n\x05gtpv1\x18\r \x01(\x0b\x32\x0e.otg.FlowGtpv1H\x0c\x88\x01\x01\x12\"\n\x05gtpv2\x18\x0e \x01(\x0b\x32\x0e.otg.FlowGtpv2H\r\x88\x01\x01\x12\x1e\n\x03\x61rp\x18\x0f \x01(\x0b\x32\x0c.otg.FlowArpH\x0e\x88\x01\x01\x12 \n\x04icmp\x18\x10 \x01(\x0b\x32\r.otg.FlowIcmpH\x0f\x88\x01\x01\x12$\n\x06icmpv6\x18\x11 \x01(\x0b\x32\x0f.otg.FlowIcmpv6H\x10\x88\x01\x01\x12\x1e\n\x03ppp\x18\x12 \x01(\x0b\x32\x0c.otg.FlowPppH\x11\x88\x01\x01\x12$\n\x06igmpv1\x18\x13 \x01(\x0b\x32\x0f.otg.FlowIgmpv1H\x12\x88\x01\x01\x12 \n\x04mpls\x18\x14 \x01(\x0b\x32\r.otg.FlowMplsH\x13\x88\x01\x01\x1a\xf5\x01\n\x06\x43hoice\"\xea\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\n\n\x06\x63ustom\x10\x01\x12\x0c\n\x08\x65thernet\x10\x02\x12\x08\n\x04vlan\x10\x03\x12\t\n\x05vxlan\x10\x04\x12\x08\n\x04ipv4\x10\x05\x12\x08\n\x04ipv6\x10\x06\x12\x0c\n\x08pfcpause\x10\x07\x12\x11\n\rethernetpause\x10\x08\x12\x07\n\x03tcp\x10\t\x12\x07\n\x03udp\x10\n\x12\x07\n\x03gre\x10\x0b\x12\t\n\x05gtpv1\x10\x0c\x12\t\n\x05gtpv2\x10\r\x12\x07\n\x03\x61rp\x10\x0e\x12\x08\n\x04icmp\x10\x0f\x12\n\n\x06icmpv6\x10\x10\x12\x07\n\x03ppp\x10\x11\x12\n\n\x06igmpv1\x10\x12\x12\x08\n\x04mpls\x10\x13\x42\t\n\x07_choiceB\t\n\x07_customB\x0b\n\t_ethernetB\x07\n\x05_vlanB\x08\n\x06_vxlanB\x07\n\x05_ipv4B\x07\n\x05_ipv6B\x0b\n\t_pfcpauseB\x10\n\x0e_ethernetpauseB\x06\n\x04_tcpB\x06\n\x04_udpB\x06\n\x04_greB\x08\n\x06_gtpv1B\x08\n\x06_gtpv2B\x06\n\x04_arpB\x07\n\x05_icmpB\t\n\x07_icmpv6B\x06\n\x04_pppB\t\n\x07_igmpv1B\x07\n\x05_mpls\"\x1b\n\nFlowCustom\x12\r\n\x05\x62ytes\x18\x01 \x01(\t\"\x8f\x02\n\x0c\x46lowEthernet\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetDstH\x00\x88\x01\x01\x12-\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowEthernetSrcH\x01\x88\x01\x01\x12:\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowEthernetEtherTypeH\x02\x88\x01\x01\x12\x38\n\tpfc_queue\x18\x04 \x01(\x0b\x32 .otg.PatternFlowEthernetPfcQueueH\x03\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x0c\n\n_pfc_queue\"\xe5\x01\n\x08\x46lowVlan\x12\x33\n\x08priority\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowVlanPriorityH\x00\x88\x01\x01\x12)\n\x03\x63\x66i\x18\x02 \x01(\x0b\x32\x17.otg.PatternFlowVlanCfiH\x01\x88\x01\x01\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x16.otg.PatternFlowVlanIdH\x02\x88\x01\x01\x12+\n\x04tpid\x18\x04 \x01(\x0b\x32\x18.otg.PatternFlowVlanTpidH\x03\x88\x01\x01\x42\x0b\n\t_priorityB\x06\n\x04_cfiB\x05\n\x03_idB\x07\n\x05_tpid\"\x85\x02\n\tFlowVxlan\x12.\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowVxlanFlagsH\x00\x88\x01\x01\x12\x36\n\treserved0\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved0H\x01\x88\x01\x01\x12*\n\x03vni\x18\x03 \x01(\x0b\x32\x18.otg.PatternFlowVxlanVniH\x02\x88\x01\x01\x12\x36\n\treserved1\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowVxlanReserved1H\x03\x88\x01\x01\x42\x08\n\x06_flagsB\x0c\n\n_reserved0B\x06\n\x04_vniB\x0c\n\n_reserved1\"\xfa\x07\n\x08\x46lowIpv4\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4VersionH\x00\x88\x01\x01\x12<\n\rheader_length\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv4HeaderLengthH\x01\x88\x01\x01\x12,\n\x08priority\x18\x03 \x01(\x0b\x32\x15.otg.FlowIpv4PriorityH\x02\x88\x01\x01\x12:\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TotalLengthH\x03\x88\x01\x01\x12?\n\x0eidentification\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4IdentificationH\x04\x88\x01\x01\x12\x33\n\x08reserved\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4ReservedH\x05\x88\x01\x01\x12<\n\rdont_fragment\x18\x07 \x01(\x0b\x32 .otg.PatternFlowIpv4DontFragmentH\x06\x88\x01\x01\x12>\n\x0emore_fragments\x18\x08 \x01(\x0b\x32!.otg.PatternFlowIpv4MoreFragmentsH\x07\x88\x01\x01\x12@\n\x0f\x66ragment_offset\x18\t \x01(\x0b\x32\".otg.PatternFlowIpv4FragmentOffsetH\x08\x88\x01\x01\x12\x39\n\x0ctime_to_live\x18\n \x01(\x0b\x32\x1e.otg.PatternFlowIpv4TimeToLiveH\t\x88\x01\x01\x12\x33\n\x08protocol\x18\x0b \x01(\x0b\x32\x1c.otg.PatternFlowIpv4ProtocolH\n\x88\x01\x01\x12@\n\x0fheader_checksum\x18\x0c \x01(\x0b\x32\".otg.PatternFlowIpv4HeaderChecksumH\x0b\x88\x01\x01\x12)\n\x03src\x18\r \x01(\x0b\x32\x17.otg.PatternFlowIpv4SrcH\x0c\x88\x01\x01\x12)\n\x03\x64st\x18\x0e \x01(\x0b\x32\x17.otg.PatternFlowIpv4DstH\r\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_header_lengthB\x0b\n\t_priorityB\x0f\n\r_total_lengthB\x11\n\x0f_identificationB\x0b\n\t_reservedB\x10\n\x0e_dont_fragmentB\x11\n\x0f_more_fragmentsB\x12\n\x10_fragment_offsetB\x0f\n\r_time_to_liveB\x0b\n\t_protocolB\x12\n\x10_header_checksumB\x06\n\x04_srcB\x06\n\x04_dst\"\xaa\x02\n\x10\x46lowIpv4Priority\x12\x36\n\x06\x63hoice\x18\x01 \x01(\x0e\x32!.otg.FlowIpv4Priority.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\x03raw\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4PriorityRawH\x01\x88\x01\x01\x12\"\n\x03tos\x18\x03 \x01(\x0b\x32\x10.otg.FlowIpv4TosH\x02\x88\x01\x01\x12$\n\x04\x64scp\x18\x04 \x01(\x0b\x32\x11.otg.FlowIpv4DscpH\x03\x88\x01\x01\x1a=\n\x06\x43hoice\"3\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03raw\x10\x01\x12\x07\n\x03tos\x10\x02\x12\x08\n\x04\x64scp\x10\x03\x42\t\n\x07_choiceB\x06\n\x04_rawB\x06\n\x04_tosB\x07\n\x05_dscp\"|\n\x0c\x46lowIpv4Dscp\x12-\n\x03phb\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpPhbH\x00\x88\x01\x01\x12-\n\x03\x65\x63n\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowIpv4DscpEcnH\x01\x88\x01\x01\x42\x06\n\x04_phbB\x06\n\x04_ecn\"\xb1\x03\n\x0b\x46lowIpv4Tos\x12:\n\nprecedence\x18\x01 \x01(\x0b\x32!.otg.PatternFlowIpv4TosPrecedenceH\x00\x88\x01\x01\x12\x30\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIpv4TosDelayH\x01\x88\x01\x01\x12:\n\nthroughput\x18\x03 \x01(\x0b\x32!.otg.PatternFlowIpv4TosThroughputH\x02\x88\x01\x01\x12<\n\x0breliability\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIpv4TosReliabilityH\x03\x88\x01\x01\x12\x36\n\x08monetary\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowIpv4TosMonetaryH\x04\x88\x01\x01\x12\x32\n\x06unused\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowIpv4TosUnusedH\x05\x88\x01\x01\x42\r\n\x0b_precedenceB\x08\n\x06_delayB\r\n\x0b_throughputB\x0e\n\x0c_reliabilityB\x0b\n\t_monetaryB\t\n\x07_unused\"\xa7\x04\n\x08\x46lowIpv6\x12\x31\n\x07version\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowIpv6VersionH\x00\x88\x01\x01\x12<\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowIpv6TrafficClassH\x01\x88\x01\x01\x12\x36\n\nflow_label\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowIpv6FlowLabelH\x02\x88\x01\x01\x12>\n\x0epayload_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowIpv6PayloadLengthH\x03\x88\x01\x01\x12\x38\n\x0bnext_header\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6NextHeaderH\x04\x88\x01\x01\x12\x34\n\thop_limit\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowIpv6HopLimitH\x05\x88\x01\x01\x12)\n\x03src\x18\x07 \x01(\x0b\x32\x17.otg.PatternFlowIpv6SrcH\x06\x88\x01\x01\x12)\n\x03\x64st\x18\x08 \x01(\x0b\x32\x17.otg.PatternFlowIpv6DstH\x07\x88\x01\x01\x42\n\n\x08_versionB\x10\n\x0e_traffic_classB\r\n\x0b_flow_labelB\x11\n\x0f_payload_lengthB\x0e\n\x0c_next_headerB\x0c\n\n_hop_limitB\x06\n\x04_srcB\x06\n\x04_dst\"\x9d\x08\n\x0c\x46lowPfcPause\x12-\n\x03\x64st\x18\x01 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseDstH\x00\x88\x01\x01\x12-\n\x03src\x18\x02 \x01(\x0b\x32\x1b.otg.PatternFlowPfcPauseSrcH\x01\x88\x01\x01\x12:\n\nether_type\x18\x03 \x01(\x0b\x32!.otg.PatternFlowPfcPauseEtherTypeH\x02\x88\x01\x01\x12\x43\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32%.otg.PatternFlowPfcPauseControlOpCodeH\x03\x88\x01\x01\x12K\n\x13\x63lass_enable_vector\x18\x05 \x01(\x0b\x32).otg.PatternFlowPfcPauseClassEnableVectorH\x04\x88\x01\x01\x12?\n\rpause_class_0\x18\x06 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass0H\x05\x88\x01\x01\x12?\n\rpause_class_1\x18\x07 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass1H\x06\x88\x01\x01\x12?\n\rpause_class_2\x18\x08 \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass2H\x07\x88\x01\x01\x12?\n\rpause_class_3\x18\t \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass3H\x08\x88\x01\x01\x12?\n\rpause_class_4\x18\n \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass4H\t\x88\x01\x01\x12?\n\rpause_class_5\x18\x0b \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass5H\n\x88\x01\x01\x12?\n\rpause_class_6\x18\x0c \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass6H\x0b\x88\x01\x01\x12?\n\rpause_class_7\x18\r \x01(\x0b\x32#.otg.PatternFlowPfcPausePauseClass7H\x0c\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x12\n\x10_control_op_codeB\x16\n\x14_class_enable_vectorB\x10\n\x0e_pause_class_0B\x10\n\x0e_pause_class_1B\x10\n\x0e_pause_class_2B\x10\n\x0e_pause_class_3B\x10\n\x0e_pause_class_4B\x10\n\x0e_pause_class_5B\x10\n\x0e_pause_class_6B\x10\n\x0e_pause_class_7\"\xf8\x02\n\x11\x46lowEthernetPause\x12\x32\n\x03\x64st\x18\x01 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseDstH\x00\x88\x01\x01\x12\x32\n\x03src\x18\x02 \x01(\x0b\x32 .otg.PatternFlowEthernetPauseSrcH\x01\x88\x01\x01\x12?\n\nether_type\x18\x03 \x01(\x0b\x32&.otg.PatternFlowEthernetPauseEtherTypeH\x02\x88\x01\x01\x12H\n\x0f\x63ontrol_op_code\x18\x04 \x01(\x0b\x32*.otg.PatternFlowEthernetPauseControlOpCodeH\x03\x88\x01\x01\x12\x34\n\x04time\x18\x05 \x01(\x0b\x32!.otg.PatternFlowEthernetPauseTimeH\x04\x88\x01\x01\x42\x06\n\x04_dstB\x06\n\x04_srcB\r\n\x0b_ether_typeB\x12\n\x10_control_op_codeB\x07\n\x05_time\"\xac\x07\n\x07\x46lowTcp\x12\x31\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowTcpSrcPortH\x00\x88\x01\x01\x12\x31\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowTcpDstPortH\x01\x88\x01\x01\x12/\n\x07seq_num\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowTcpSeqNumH\x02\x88\x01\x01\x12/\n\x07\x61\x63k_num\x18\x04 \x01(\x0b\x32\x19.otg.PatternFlowTcpAckNumH\x03\x88\x01\x01\x12\x37\n\x0b\x64\x61ta_offset\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowTcpDataOffsetH\x04\x88\x01\x01\x12-\n\x06\x65\x63n_ns\x18\x06 \x01(\x0b\x32\x18.otg.PatternFlowTcpEcnNsH\x05\x88\x01\x01\x12/\n\x07\x65\x63n_cwr\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowTcpEcnCwrH\x06\x88\x01\x01\x12\x31\n\x08\x65\x63n_echo\x18\x08 \x01(\x0b\x32\x1a.otg.PatternFlowTcpEcnEchoH\x07\x88\x01\x01\x12/\n\x07\x63tl_urg\x18\t \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlUrgH\x08\x88\x01\x01\x12/\n\x07\x63tl_ack\x18\n \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlAckH\t\x88\x01\x01\x12/\n\x07\x63tl_psh\x18\x0b \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlPshH\n\x88\x01\x01\x12/\n\x07\x63tl_rst\x18\x0c \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlRstH\x0b\x88\x01\x01\x12/\n\x07\x63tl_syn\x18\r \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlSynH\x0c\x88\x01\x01\x12/\n\x07\x63tl_fin\x18\x0e \x01(\x0b\x32\x19.otg.PatternFlowTcpCtlFinH\r\x88\x01\x01\x12.\n\x06window\x18\x0f \x01(\x0b\x32\x19.otg.PatternFlowTcpWindowH\x0e\x88\x01\x01\x42\x0b\n\t_src_portB\x0b\n\t_dst_portB\n\n\x08_seq_numB\n\n\x08_ack_numB\x0e\n\x0c_data_offsetB\t\n\x07_ecn_nsB\n\n\x08_ecn_cwrB\x0b\n\t_ecn_echoB\n\n\x08_ctl_urgB\n\n\x08_ctl_ackB\n\n\x08_ctl_pshB\n\n\x08_ctl_rstB\n\n\x08_ctl_synB\n\n\x08_ctl_finB\t\n\x07_window\"\x85\x02\n\x07\x46lowUdp\x12\x31\n\x08src_port\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowUdpSrcPortH\x00\x88\x01\x01\x12\x31\n\x08\x64st_port\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowUdpDstPortH\x01\x88\x01\x01\x12.\n\x06length\x18\x03 \x01(\x0b\x32\x19.otg.PatternFlowUdpLengthH\x02\x88\x01\x01\x12\x32\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowUdpChecksumH\x03\x88\x01\x01\x42\x0b\n\t_src_portB\x0b\n\t_dst_portB\t\n\x07_lengthB\x0b\n\t_checksum\"\xa9\x03\n\x07\x46lowGre\x12\x41\n\x10\x63hecksum_present\x18\x01 \x01(\x0b\x32\".otg.PatternFlowGreChecksumPresentH\x00\x88\x01\x01\x12\x34\n\treserved0\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved0H\x01\x88\x01\x01\x12\x30\n\x07version\x18\x03 \x01(\x0b\x32\x1a.otg.PatternFlowGreVersionH\x02\x88\x01\x01\x12\x32\n\x08protocol\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGreProtocolH\x03\x88\x01\x01\x12\x32\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\x1b.otg.PatternFlowGreChecksumH\x04\x88\x01\x01\x12\x34\n\treserved1\x18\x06 \x01(\x0b\x32\x1c.otg.PatternFlowGreReserved1H\x05\x88\x01\x01\x42\x13\n\x11_checksum_presentB\x0c\n\n_reserved0B\n\n\x08_versionB\x0b\n\t_protocolB\x0b\n\t_checksumB\x0c\n\n_reserved1\"\xb8\x07\n\tFlowGtpv1\x12\x32\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv1VersionH\x00\x88\x01\x01\x12=\n\rprotocol_type\x18\x02 \x01(\x0b\x32!.otg.PatternFlowGtpv1ProtocolTypeH\x01\x88\x01\x01\x12\x34\n\x08reserved\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv1ReservedH\x02\x88\x01\x01\x12/\n\x06\x65_flag\x18\x04 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1EFlagH\x03\x88\x01\x01\x12/\n\x06s_flag\x18\x05 \x01(\x0b\x32\x1a.otg.PatternFlowGtpv1SFlagH\x04\x88\x01\x01\x12\x31\n\x07pn_flag\x18\x06 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv1PnFlagH\x05\x88\x01\x01\x12;\n\x0cmessage_type\x18\x07 \x01(\x0b\x32 .otg.PatternFlowGtpv1MessageTypeH\x06\x88\x01\x01\x12?\n\x0emessage_length\x18\x08 \x01(\x0b\x32\".otg.PatternFlowGtpv1MessageLengthH\x07\x88\x01\x01\x12,\n\x04teid\x18\t \x01(\x0b\x32\x19.otg.PatternFlowGtpv1TeidH\x08\x88\x01\x01\x12?\n\x0esquence_number\x18\n \x01(\x0b\x32\".otg.PatternFlowGtpv1SquenceNumberH\t\x88\x01\x01\x12:\n\x0cn_pdu_number\x18\x0b \x01(\x0b\x32\x1f.otg.PatternFlowGtpv1NPduNumberH\n\x88\x01\x01\x12U\n\x1anext_extension_header_type\x18\x0c \x01(\x0b\x32,.otg.PatternFlowGtpv1NextExtensionHeaderTypeH\x0b\x88\x01\x01\x12\x30\n\x11\x65xtension_headers\x18\r \x03(\x0b\x32\x15.otg.FlowGtpExtensionB\n\n\x08_versionB\x10\n\x0e_protocol_typeB\x0b\n\t_reservedB\t\n\x07_e_flagB\t\n\x07_s_flagB\n\n\x08_pn_flagB\x0f\n\r_message_typeB\x11\n\x0f_message_lengthB\x07\n\x05_teidB\x11\n\x0f_squence_numberB\x0f\n\r_n_pdu_numberB\x1d\n\x1b_next_extension_header_type\"\xac\x02\n\x10\x46lowGtpExtension\x12J\n\x10\x65xtension_length\x18\x01 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionExtensionLengthH\x00\x88\x01\x01\x12;\n\x08\x63ontents\x18\x02 \x01(\x0b\x32$.otg.PatternFlowGtpExtensionContentsH\x01\x88\x01\x01\x12S\n\x15next_extension_header\x18\x03 \x01(\x0b\x32/.otg.PatternFlowGtpExtensionNextExtensionHeaderH\x02\x88\x01\x01\x42\x13\n\x11_extension_lengthB\x0b\n\t_contentsB\x18\n\x16_next_extension_header\"\x97\x05\n\tFlowGtpv2\x12\x32\n\x07version\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowGtpv2VersionH\x00\x88\x01\x01\x12\x45\n\x11piggybacking_flag\x18\x02 \x01(\x0b\x32%.otg.PatternFlowGtpv2PiggybackingFlagH\x01\x88\x01\x01\x12\x35\n\tteid_flag\x18\x03 \x01(\x0b\x32\x1d.otg.PatternFlowGtpv2TeidFlagH\x02\x88\x01\x01\x12\x30\n\x06spare1\x18\x04 \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare1H\x03\x88\x01\x01\x12;\n\x0cmessage_type\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2MessageTypeH\x04\x88\x01\x01\x12?\n\x0emessage_length\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2MessageLengthH\x05\x88\x01\x01\x12,\n\x04teid\x18\x07 \x01(\x0b\x32\x19.otg.PatternFlowGtpv2TeidH\x06\x88\x01\x01\x12\x41\n\x0fsequence_number\x18\x08 \x01(\x0b\x32#.otg.PatternFlowGtpv2SequenceNumberH\x07\x88\x01\x01\x12\x30\n\x06spare2\x18\t \x01(\x0b\x32\x1b.otg.PatternFlowGtpv2Spare2H\x08\x88\x01\x01\x42\n\n\x08_versionB\x14\n\x12_piggybacking_flagB\x0c\n\n_teid_flagB\t\n\x07_spare1B\x0f\n\r_message_typeB\x11\n\x0f_message_lengthB\x07\n\x05_teidB\x12\n\x10_sequence_numberB\t\n\x07_spare2\"\xa1\x06\n\x07\x46lowArp\x12;\n\rhardware_type\x18\x01 \x01(\x0b\x32\x1f.otg.PatternFlowArpHardwareTypeH\x00\x88\x01\x01\x12;\n\rprotocol_type\x18\x02 \x01(\x0b\x32\x1f.otg.PatternFlowArpProtocolTypeH\x01\x88\x01\x01\x12?\n\x0fhardware_length\x18\x03 \x01(\x0b\x32!.otg.PatternFlowArpHardwareLengthH\x02\x88\x01\x01\x12?\n\x0fprotocol_length\x18\x04 \x01(\x0b\x32!.otg.PatternFlowArpProtocolLengthH\x03\x88\x01\x01\x12\x34\n\toperation\x18\x05 \x01(\x0b\x32\x1c.otg.PatternFlowArpOperationH\x04\x88\x01\x01\x12H\n\x14sender_hardware_addr\x18\x06 \x01(\x0b\x32%.otg.PatternFlowArpSenderHardwareAddrH\x05\x88\x01\x01\x12H\n\x14sender_protocol_addr\x18\x07 \x01(\x0b\x32%.otg.PatternFlowArpSenderProtocolAddrH\x06\x88\x01\x01\x12H\n\x14target_hardware_addr\x18\x08 \x01(\x0b\x32%.otg.PatternFlowArpTargetHardwareAddrH\x07\x88\x01\x01\x12H\n\x14target_protocol_addr\x18\t \x01(\x0b\x32%.otg.PatternFlowArpTargetProtocolAddrH\x08\x88\x01\x01\x42\x10\n\x0e_hardware_typeB\x10\n\x0e_protocol_typeB\x12\n\x10_hardware_lengthB\x12\n\x10_protocol_lengthB\x0c\n\n_operationB\x17\n\x15_sender_hardware_addrB\x17\n\x15_sender_protocol_addrB\x17\n\x15_target_hardware_addrB\x17\n\x15_target_protocol_addr\"\xa1\x01\n\x08\x46lowIcmp\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowIcmp.Choice.EnumH\x00\x88\x01\x01\x12$\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x11.otg.FlowIcmpEchoH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_echo\"\xee\x02\n\x0c\x46lowIcmpEcho\x12/\n\x04type\x18\x01 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoTypeH\x00\x88\x01\x01\x12/\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1c.otg.PatternFlowIcmpEchoCodeH\x01\x88\x01\x01\x12\x37\n\x08\x63hecksum\x18\x03 \x01(\x0b\x32 .otg.PatternFlowIcmpEchoChecksumH\x02\x88\x01\x01\x12;\n\nidentifier\x18\x04 \x01(\x0b\x32\".otg.PatternFlowIcmpEchoIdentifierH\x03\x88\x01\x01\x12\x44\n\x0fsequence_number\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIcmpEchoSequenceNumberH\x04\x88\x01\x01\x42\x07\n\x05_typeB\x07\n\x05_codeB\x0b\n\t_checksumB\r\n\x0b_identifierB\x12\n\x10_sequence_number\"\xa7\x01\n\nFlowIcmpv6\x12\x30\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1b.otg.FlowIcmpv6.Choice.EnumH\x00\x88\x01\x01\x12&\n\x04\x65\x63ho\x18\x02 \x01(\x0b\x32\x13.otg.FlowIcmpv6EchoH\x01\x88\x01\x01\x1a+\n\x06\x43hoice\"!\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04\x65\x63ho\x10\x01\x42\t\n\x07_choiceB\x07\n\x05_echo\"\xfa\x02\n\x0e\x46lowIcmpv6Echo\x12\x31\n\x04type\x18\x01 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoTypeH\x00\x88\x01\x01\x12\x31\n\x04\x63ode\x18\x02 \x01(\x0b\x32\x1e.otg.PatternFlowIcmpv6EchoCodeH\x01\x88\x01\x01\x12=\n\nidentifier\x18\x03 \x01(\x0b\x32$.otg.PatternFlowIcmpv6EchoIdentifierH\x02\x88\x01\x01\x12\x46\n\x0fsequence_number\x18\x04 \x01(\x0b\x32(.otg.PatternFlowIcmpv6EchoSequenceNumberH\x03\x88\x01\x01\x12\x39\n\x08\x63hecksum\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIcmpv6EchoChecksumH\x04\x88\x01\x01\x42\x07\n\x05_typeB\x07\n\x05_codeB\r\n\x0b_identifierB\x12\n\x10_sequence_numberB\x0b\n\t_checksum\"\xd4\x01\n\x07\x46lowPpp\x12\x30\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1a.otg.PatternFlowPppAddressH\x00\x88\x01\x01\x12\x30\n\x07\x63ontrol\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowPppControlH\x01\x88\x01\x01\x12;\n\rprotocol_type\x18\x03 \x01(\x0b\x32\x1f.otg.PatternFlowPppProtocolTypeH\x02\x88\x01\x01\x42\n\n\x08_addressB\n\n\x08_controlB\x10\n\x0e_protocol_type\"\xd9\x02\n\nFlowIgmpv1\x12\x33\n\x07version\x18\x01 \x01(\x0b\x32\x1d.otg.PatternFlowIgmpv1VersionH\x00\x88\x01\x01\x12-\n\x04type\x18\x02 \x01(\x0b\x32\x1a.otg.PatternFlowIgmpv1TypeH\x01\x88\x01\x01\x12\x31\n\x06unused\x18\x03 \x01(\x0b\x32\x1c.otg.PatternFlowIgmpv1UnusedH\x02\x88\x01\x01\x12\x35\n\x08\x63hecksum\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowIgmpv1ChecksumH\x03\x88\x01\x01\x12>\n\rgroup_address\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIgmpv1GroupAddressH\x04\x88\x01\x01\x42\n\n\x08_versionB\x07\n\x05_typeB\t\n\x07_unusedB\x0b\n\t_checksumB\x10\n\x0e_group_address\"\xb4\x02\n\x08\x46lowMpls\x12-\n\x05label\x18\x01 \x01(\x0b\x32\x19.otg.PatternFlowMplsLabelH\x00\x88\x01\x01\x12<\n\rtraffic_class\x18\x02 \x01(\x0b\x32 .otg.PatternFlowMplsTrafficClassH\x01\x88\x01\x01\x12?\n\x0f\x62ottom_of_stack\x18\x03 \x01(\x0b\x32!.otg.PatternFlowMplsBottomOfStackH\x02\x88\x01\x01\x12\x39\n\x0ctime_to_live\x18\x04 \x01(\x0b\x32\x1e.otg.PatternFlowMplsTimeToLiveH\x03\x88\x01\x01\x42\x08\n\x06_labelB\x10\n\x0e_traffic_classB\x12\n\x10_bottom_of_stackB\x0f\n\r_time_to_live\"\x9f\x02\n\x08\x46lowSize\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowSize.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x66ixed\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12.\n\tincrement\x18\x03 \x01(\x0b\x32\x16.otg.FlowSizeIncrementH\x02\x88\x01\x01\x12(\n\x06random\x18\x04 \x01(\x0b\x32\x13.otg.FlowSizeRandomH\x03\x88\x01\x01\x1aG\n\x06\x43hoice\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x66ixed\x10\x01\x12\r\n\tincrement\x10\x02\x12\n\n\x06random\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_fixedB\x0c\n\n_incrementB\t\n\x07_random\"g\n\x11\x46lowSizeIncrement\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03\x65nd\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x11\n\x04step\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x06\n\x04_endB\x07\n\x05_step\"D\n\x0e\x46lowSizeRandom\x12\x10\n\x03min\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x06\n\x04_minB\x06\n\x04_max\"\xd8\x02\n\x08\x46lowRate\x12.\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x19.otg.FlowRate.Choice.EnumH\x00\x88\x01\x01\x12\x10\n\x03pps\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x10\n\x03\x62ps\x18\x03 \x01(\x03H\x02\x88\x01\x01\x12\x11\n\x04kbps\x18\x04 \x01(\x03H\x03\x88\x01\x01\x12\x11\n\x04mbps\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x11\n\x04gbps\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12\x17\n\npercentage\x18\x07 \x01(\x02H\x06\x88\x01\x01\x1a\x61\n\x06\x43hoice\"W\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03pps\x10\x01\x12\x07\n\x03\x62ps\x10\x02\x12\x08\n\x04kbps\x10\x03\x12\x08\n\x04mbps\x10\x04\x12\x08\n\x04gbps\x10\x05\x12\x0e\n\npercentage\x10\x06\x42\t\n\x07_choiceB\x06\n\x04_ppsB\x06\n\x04_bpsB\x07\n\x05_kbpsB\x07\n\x05_mbpsB\x07\n\x05_gbpsB\r\n\x0b_percentage\"\xa6\x03\n\x0c\x46lowDuration\x12\x32\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1d.otg.FlowDuration.Choice.EnumH\x00\x88\x01\x01\x12\x31\n\rfixed_packets\x18\x02 \x01(\x0b\x32\x15.otg.FlowFixedPacketsH\x01\x88\x01\x01\x12\x31\n\rfixed_seconds\x18\x03 \x01(\x0b\x32\x15.otg.FlowFixedSecondsH\x02\x88\x01\x01\x12\"\n\x05\x62urst\x18\x04 \x01(\x0b\x32\x0e.otg.FlowBurstH\x03\x88\x01\x01\x12,\n\ncontinuous\x18\x05 \x01(\x0b\x32\x13.otg.FlowContinuousH\x04\x88\x01\x01\x1a\x62\n\x06\x43hoice\"X\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rfixed_packets\x10\x01\x12\x11\n\rfixed_seconds\x10\x02\x12\t\n\x05\x62urst\x10\x03\x12\x0e\n\ncontinuous\x10\x04\x42\t\n\x07_choiceB\x10\n\x0e_fixed_packetsB\x10\n\x0e_fixed_secondsB\x08\n\x06_burstB\r\n\x0b_continuous\"X\n\x0e\x46lowContinuous\x12\x10\n\x03gap\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x0e.otg.FlowDelayH\x01\x88\x01\x01\x42\x06\n\x04_gapB\x08\n\x06_delay\"\x8c\x02\n\tFlowDelay\x12/\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1a.otg.FlowDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x02H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"|\n\x10\x46lowFixedPackets\x12\x14\n\x07packets\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayH\x02\x88\x01\x01\x42\n\n\x08_packetsB\x06\n\x04_gapB\x08\n\x06_delay\"|\n\x10\x46lowFixedSeconds\x12\x14\n\x07seconds\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x10\n\x03gap\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\"\n\x05\x64\x65lay\x18\x03 \x01(\x0b\x32\x0e.otg.FlowDelayH\x02\x88\x01\x01\x42\n\n\x08_secondsB\x06\n\x04_gapB\x08\n\x06_delay\"\xb9\x01\n\tFlowBurst\x12\x13\n\x06\x62ursts\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07packets\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x10\n\x03gap\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12<\n\x0finter_burst_gap\x18\x04 \x01(\x0b\x32\x1e.otg.FlowDurationInterBurstGapH\x03\x88\x01\x01\x42\t\n\x07_burstsB\n\n\x08_packetsB\x06\n\x04_gapB\x12\n\x10_inter_burst_gap\"\xac\x02\n\x19\x46lowDurationInterBurstGap\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.FlowDurationInterBurstGap.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05\x62ytes\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x18\n\x0bnanoseconds\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x19\n\x0cmicroseconds\x18\x04 \x01(\x01H\x03\x88\x01\x01\x1aO\n\x06\x43hoice\"E\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05\x62ytes\x10\x01\x12\x0f\n\x0bnanoseconds\x10\x02\x12\x10\n\x0cmicroseconds\x10\x03\x42\t\n\x07_choiceB\x08\n\x06_bytesB\x0e\n\x0c_nanosecondsB\x0f\n\r_microseconds\"\xac\x01\n\x0b\x46lowMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x11\n\x04loss\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x17\n\ntimestamps\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12-\n\x07latency\x18\x04 \x01(\x0b\x32\x17.otg.FlowLatencyMetricsH\x03\x88\x01\x01\x42\t\n\x07_enableB\x07\n\x05_lossB\r\n\x0b_timestampsB\n\n\x08_latency\"\xb8\x01\n\x12\x46lowLatencyMetrics\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32!.otg.FlowLatencyMetrics.Mode.EnumH\x01\x88\x01\x01\x1a\x43\n\x04Mode\";\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rstore_forward\x10\x01\x12\x0f\n\x0b\x63ut_through\x10\x02\x42\t\n\x07_enableB\x07\n\x05_mode\"\x8a\x02\n\x05\x45vent\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12!\n\x04link\x18\x02 \x01(\x0b\x32\x0e.otg.EventLinkH\x01\x88\x01\x01\x12\x39\n\x11rx_rate_threshold\x18\x03 \x01(\x0b\x32\x19.otg.EventRxRateThresholdH\x02\x88\x01\x01\x12G\n\x18route_advertise_withdraw\x18\x04 \x01(\x0b\x32 .otg.EventRouteAdvertiseWithdrawH\x03\x88\x01\x01\x42\t\n\x07_enableB\x07\n\x05_linkB\x14\n\x12_rx_rate_thresholdB\x1b\n\x19_route_advertise_withdraw\"\\\n\x14\x45ventRxRateThreshold\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x16\n\tthreshold\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\t\n\x07_enableB\x0c\n\n_threshold\"+\n\tEventLink\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"=\n\x1b\x45ventRouteAdvertiseWithdraw\x12\x13\n\x06\x65nable\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_enable\"\xf5\x01\n\x0c\x45ventRequest\x12)\n\x04type\x18\x01 \x03(\x0e\x32\x1b.otg.EventRequest.Type.Enum\x12\x0e\n\x06source\x18\x02 \x03(\t\x1a\xa9\x01\n\x04Type\"\xa0\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tlink_down\x10\x01\x12\x0b\n\x07link_up\x10\x02\x12\x12\n\x0eroute_withdraw\x10\x03\x12\x13\n\x0froute_advertise\x10\x04\x12 \n\x1c\x66low_rx_rate_above_threshold\x10\x05\x12 \n\x1c\x66low_rx_rate_below_threshold\x10\x06\"p\n\x11\x45ventSubscription\x12&\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x11.otg.EventRequestH\x00\x88\x01\x01\x12\x18\n\x0b\x63\x61llbackurl\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_eventsB\x0e\n\x0c_callbackurl\"\x1f\n\rResponseError\x12\x0e\n\x06\x65rrors\x18\x01 \x03(\t\"#\n\x0fResponseWarning\x12\x10\n\x08warnings\x18\x01 \x03(\t\"}\n\tLinkState\x12\x12\n\nport_names\x18\x01 \x03(\t\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.otg.LinkState.State.Enum\x1a\x32\n\x05State\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\"\x93\x01\n\rTransmitState\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12,\n\x05state\x18\x02 \x01(\x0e\x32\x1d.otg.TransmitState.State.Enum\x1a@\n\x05State\"7\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\x12\t\n\x05pause\x10\x03\"\x86\x01\n\x0c\x43\x61ptureState\x12\x12\n\nport_names\x18\x01 \x03(\t\x12+\n\x05state\x18\x02 \x01(\x0e\x32\x1c.otg.CaptureState.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\xa2\x01\n\x0b\x46lowsUpdate\x12;\n\x0eproperty_names\x18\x01 \x03(\x0e\x32#.otg.FlowsUpdate.PropertyNames.Enum\x12\x18\n\x05\x66lows\x18\x02 \x03(\x0b\x32\t.otg.Flow\x1a<\n\rPropertyNames\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04rate\x10\x01\x12\x08\n\x04size\x10\x02\"\x85\x01\n\nRouteState\x12\r\n\x05names\x18\x01 \x03(\t\x12)\n\x05state\x18\x02 \x01(\x0e\x32\x1a.otg.RouteState.State.Enum\x1a=\n\x05State\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08withdraw\x10\x01\x12\r\n\tadvertise\x10\x02\"+\n\x0bPingRequest\x12\x1c\n\tendpoints\x18\x01 \x03(\x0b\x32\t.otg.Ping\"t\n\rProtocolState\x12,\n\x05state\x18\x01 \x01(\x0e\x32\x1d.otg.ProtocolState.State.Enum\x1a\x35\n\x05State\",\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05start\x10\x01\x12\x08\n\x04stop\x10\x02\"\xca\x01\n\x04Ping\x12*\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x15.otg.Ping.Choice.EnumH\x00\x88\x01\x01\x12 \n\x04ipv4\x18\x02 \x01(\x0b\x32\r.otg.PingIpv4H\x01\x88\x01\x01\x12 \n\x04ipv6\x18\x03 \x01(\x0b\x32\r.otg.PingIpv6H\x02\x88\x01\x01\x1a\x35\n\x06\x43hoice\"+\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ipv4\x10\x01\x12\x08\n\x04ipv6\x10\x02\x42\t\n\x07_choiceB\x07\n\x05_ipv4B\x07\n\x05_ipv6\"N\n\x08PingIpv4\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"N\n\x08PingIpv6\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_src_nameB\t\n\x07_dst_ip\"0\n\x0cPingResponse\x12 \n\tresponses\x18\x01 \x03(\x0b\x32\r.otg.Response\"\xc6\x01\n\x08Response\x12\x15\n\x08src_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x64st_ip\x18\x02 \x01(\tH\x01\x88\x01\x01\x12.\n\x06result\x18\x03 \x01(\x0e\x32\x19.otg.Response.Result.EnumH\x02\x88\x01\x01\x1a;\n\x06Result\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07success\x10\x01\x12\x0b\n\x07\x66\x61ilure\x10\x02\x42\x0b\n\t_src_nameB\t\n\x07_dst_ipB\t\n\x07_result\"\xb7\x03\n\x0eMetricsRequest\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.MetricsRequest.Choice.EnumH\x00\x88\x01\x01\x12*\n\x04port\x18\x02 \x01(\x0b\x32\x17.otg.PortMetricsRequestH\x01\x88\x01\x01\x12*\n\x04\x66low\x18\x03 \x01(\x0b\x32\x17.otg.FlowMetricsRequestH\x02\x88\x01\x01\x12,\n\x05\x62gpv4\x18\x04 \x01(\x0b\x32\x18.otg.Bgpv4MetricsRequestH\x03\x88\x01\x01\x12,\n\x05\x62gpv6\x18\x05 \x01(\x0b\x32\x18.otg.Bgpv6MetricsRequestH\x04\x88\x01\x01\x12*\n\x04isis\x18\x06 \x01(\x0b\x32\x17.otg.IsisMetricsRequestH\x05\x88\x01\x01\x1aU\n\x06\x43hoice\"K\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04port\x10\x01\x12\x08\n\x04\x66low\x10\x02\x12\t\n\x05\x62gpv4\x10\x03\x12\t\n\x05\x62gpv6\x10\x04\x12\x08\n\x04isis\x10\x05\x42\t\n\x07_choiceB\x07\n\x05_portB\x07\n\x05_flowB\x08\n\x06_bgpv4B\x08\n\x06_bgpv6B\x07\n\x05_isis\"\x99\x03\n\x0fMetricsResponse\x12\x35\n\x06\x63hoice\x18\x01 \x01(\x0e\x32 .otg.MetricsResponse.Choice.EnumH\x00\x88\x01\x01\x12%\n\x0cport_metrics\x18\x02 \x03(\x0b\x32\x0f.otg.PortMetric\x12%\n\x0c\x66low_metrics\x18\x03 \x03(\x0b\x32\x0f.otg.FlowMetric\x12\'\n\rbgpv4_metrics\x18\x04 \x03(\x0b\x32\x10.otg.Bgpv4Metric\x12\'\n\rbgpv6_metrics\x18\x05 \x03(\x0b\x32\x10.otg.Bgpv6Metric\x12%\n\x0cisis_metrics\x18\x06 \x03(\x0b\x32\x0f.otg.IsisMetric\x1a}\n\x06\x43hoice\"s\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0c\x66low_metrics\x10\x01\x12\x10\n\x0cport_metrics\x10\x02\x12\x11\n\rbgpv4_metrics\x10\x03\x12\x11\n\rbgpv6_metrics\x10\x04\x12\x10\n\x0cisis_metrics\x10\x05\x42\t\n\x07_choice\"\xcd\x02\n\x12PortMetricsRequest\x12\x12\n\nport_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.PortMetricsRequest.ColumnNames.Enum\x1a\xe2\x01\n\x0b\x43olumnNames\"\xd2\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\x0c\n\x08location\x10\x02\x12\x08\n\x04link\x10\x03\x12\x0b\n\x07\x63\x61pture\x10\x04\x12\r\n\tframes_tx\x10\x05\x12\r\n\tframes_rx\x10\x06\x12\x0c\n\x08\x62ytes_tx\x10\x07\x12\x0c\n\x08\x62ytes_rx\x10\x08\x12\x12\n\x0e\x66rames_tx_rate\x10\t\x12\x12\n\x0e\x66rames_rx_rate\x10\n\x12\x11\n\rbytes_tx_rate\x10\x0b\x12\x11\n\rbytes_rx_rate\x10\x0c\"\x84\x05\n\nPortMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08location\x18\x02 \x01(\tH\x01\x88\x01\x01\x12,\n\x04link\x18\x03 \x01(\x0e\x32\x19.otg.PortMetric.Link.EnumH\x02\x88\x01\x01\x12\x32\n\x07\x63\x61pture\x18\x04 \x01(\x0e\x32\x1c.otg.PortMetric.Capture.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x05 \x01(\x03H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x06 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x07 \x01(\x03H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\x08 \x01(\x03H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\t \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\n \x01(\x02H\t\x88\x01\x01\x12\x1a\n\rbytes_tx_rate\x18\x0b \x01(\x02H\n\x88\x01\x01\x12\x1a\n\rbytes_rx_rate\x18\x0c \x01(\x02H\x0b\x88\x01\x01\x1a\x31\n\x04Link\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x1a<\n\x07\x43\x61pture\"1\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x42\x07\n\x05_nameB\x0b\n\t_locationB\x07\n\x05_linkB\n\n\x08_captureB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x10\n\x0e_bytes_tx_rateB\x10\n\x0e_bytes_rx_rate\"\xcd\x02\n\x12\x46lowMetricsRequest\x12\x12\n\nflow_names\x18\x01 \x03(\t\x12\x37\n\rmetric_groups\x18\x02 \x01(\x0b\x32\x1b.otg.FlowMetricGroupRequestH\x00\x88\x01\x01\x12>\n\x0cmetric_names\x18\x03 \x03(\x0e\x32(.otg.FlowMetricsRequest.MetricNames.Enum\x1a\x97\x01\n\x0bMetricNames\"\x87\x01\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08transmit\x10\x01\x12\r\n\tframes_tx\x10\x02\x12\r\n\tframes_rx\x10\x03\x12\x0c\n\x08\x62ytes_tx\x10\x04\x12\x0c\n\x08\x62ytes_rx\x10\x05\x12\x12\n\x0e\x66rames_tx_rate\x10\x06\x12\x12\n\x0e\x66rames_rx_rate\x10\x07\x42\x10\n\x0e_metric_groups\"\xbe\x01\n\x16\x46lowMetricGroupRequest\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.FlowMetricGroupRequest.Choice.EnumH\x00\x88\x01\x01\x12\x0f\n\x07ingress\x18\x02 \x03(\t\x12\x0e\n\x06\x65gress\x18\x03 \x03(\t\x1a:\n\x06\x43hoice\"0\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07ingress\x10\x01\x12\n\n\x06\x65gress\x10\x02\x42\t\n\x07_choice\"\xab\x05\n\nFlowMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07port_tx\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07port_rx\x18\x03 \x01(\tH\x02\x88\x01\x01\x12+\n\rmetric_groups\x18\x04 \x03(\x0b\x32\x14.otg.FlowMetricGroup\x12\x34\n\x08transmit\x18\x05 \x01(\x0e\x32\x1d.otg.FlowMetric.Transmit.EnumH\x03\x88\x01\x01\x12\x16\n\tframes_tx\x18\x06 \x01(\x03H\x04\x88\x01\x01\x12\x16\n\tframes_rx\x18\x07 \x01(\x03H\x05\x88\x01\x01\x12\x15\n\x08\x62ytes_tx\x18\x08 \x01(\x03H\x06\x88\x01\x01\x12\x15\n\x08\x62ytes_rx\x18\t \x01(\x03H\x07\x88\x01\x01\x12\x1b\n\x0e\x66rames_tx_rate\x18\n \x01(\x02H\x08\x88\x01\x01\x12\x1b\n\x0e\x66rames_rx_rate\x18\x0b \x01(\x02H\t\x88\x01\x01\x12\x11\n\x04loss\x18\x0c \x01(\x02H\n\x88\x01\x01\x12-\n\ntimestamps\x18\r \x01(\x0b\x32\x14.otg.MetricTimestampH\x0b\x88\x01\x01\x12(\n\x07latency\x18\x0e \x01(\x0b\x32\x12.otg.MetricLatencyH\x0c\x88\x01\x01\x1aI\n\x08Transmit\"=\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\x0b\n\x07stopped\x10\x02\x12\n\n\x06paused\x10\x03\x42\x07\n\x05_nameB\n\n\x08_port_txB\n\n\x08_port_rxB\x0b\n\t_transmitB\x0c\n\n_frames_txB\x0c\n\n_frames_rxB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x11\n\x0f_frames_tx_rateB\x11\n\x0f_frames_rx_rateB\x07\n\x05_lossB\r\n\x0b_timestampsB\n\n\x08_latency\"K\n\x0f\x46lowMetricGroup\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"\x7f\n\x0fMetricTimestamp\x12\x1f\n\x12\x66irst_timestamp_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x1e\n\x11last_timestamp_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x42\x15\n\x13_first_timestamp_nsB\x14\n\x12_last_timestamp_ns\"\x87\x01\n\rMetricLatency\x12\x17\n\nminimum_ns\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x17\n\nmaximum_ns\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x17\n\naverage_ns\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\r\n\x0b_minimum_nsB\r\n\x0b_maximum_nsB\r\n\x0b_average_ns\"\xd1\x03\n\x13\x42gpv4MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv4MetricsRequest.ColumnNames.Enum\x1a\xe4\x02\n\x0b\x43olumnNames\"\xd4\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\"\xf2\x06\n\x0b\x42gpv4Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv4Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x05H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_received\"\xd1\x03\n\x13\x42gpv6MetricsRequest\x12\x12\n\npeer_names\x18\x01 \x03(\t\x12?\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32).otg.Bgpv6MetricsRequest.ColumnNames.Enum\x1a\xe4\x02\n\x0b\x43olumnNames\"\xd4\x02\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x11\n\rsession_state\x10\x01\x12\x16\n\x12session_flap_count\x10\x02\x12\x15\n\x11routes_advertised\x10\x03\x12\x13\n\x0froutes_received\x10\x04\x12\x18\n\x14route_withdraws_sent\x10\x05\x12\x1c\n\x18route_withdraws_received\x10\x06\x12\x10\n\x0cupdates_sent\x10\x07\x12\x14\n\x10updates_received\x10\x08\x12\x0e\n\nopens_sent\x10\t\x12\x12\n\x0eopens_received\x10\n\x12\x13\n\x0fkeepalives_sent\x10\x0b\x12\x17\n\x13keepalives_received\x10\x0c\x12\x16\n\x12notifications_sent\x10\r\x12\x1a\n\x16notifications_received\x10\x0e\"\xf2\x06\n\x0b\x42gpv6Metric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\rsession_state\x18\x02 \x01(\x0e\x32\".otg.Bgpv6Metric.SessionState.EnumH\x01\x88\x01\x01\x12\x1f\n\x12session_flap_count\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1e\n\x11routes_advertised\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0froutes_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12!\n\x14route_withdraws_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18route_withdraws_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x19\n\x0cupdates_sent\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x1d\n\x10updates_received\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x17\n\nopens_sent\x18\n \x01(\x05H\t\x88\x01\x01\x12\x1b\n\x0eopens_received\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1c\n\x0fkeepalives_sent\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12 \n\x13keepalives_received\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1f\n\x12notifications_sent\x18\x0e \x01(\x05H\r\x88\x01\x01\x12#\n\x16notifications_received\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x1a\x39\n\x0cSessionState\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x06\n\x02up\x10\x01\x12\x08\n\x04\x64own\x10\x02\x42\x07\n\x05_nameB\x10\n\x0e_session_stateB\x15\n\x13_session_flap_countB\x14\n\x12_routes_advertisedB\x12\n\x10_routes_receivedB\x17\n\x15_route_withdraws_sentB\x1b\n\x19_route_withdraws_receivedB\x0f\n\r_updates_sentB\x13\n\x11_updates_receivedB\r\n\x0b_opens_sentB\x11\n\x0f_opens_receivedB\x12\n\x10_keepalives_sentB\x16\n\x14_keepalives_receivedB\x15\n\x13_notifications_sentB\x19\n\x17_notifications_received\"\x92\x06\n\x12IsisMetricsRequest\x12\x14\n\x0crouter_names\x18\x01 \x03(\t\x12>\n\x0c\x63olumn_names\x18\x02 \x03(\x0e\x32(.otg.IsisMetricsRequest.ColumnNames.Enum\x1a\xa5\x05\n\x0b\x43olumnNames\"\x95\x05\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0el1_sessions_up\x10\x01\x12\x13\n\x0fl1_session_flap\x10\x02\x12\x14\n\x10l1_database_size\x10\x03\x12\x1c\n\x18l1_broadcast_hellos_sent\x10\x04\x12 \n\x1cl1_broadcast_hellos_received\x10\x05\x12!\n\x1dl1_point_to_point_hellos_sent\x10\x06\x12%\n!l1_point_to_point_hellos_received\x10\x07\x12\x10\n\x0cl1_psnp_sent\x10\x08\x12\x14\n\x10l1_psnp_received\x10\t\x12\x10\n\x0cl1_csnp_sent\x10\n\x12\x14\n\x10l1_csnp_received\x10\x0b\x12\x0f\n\x0bl1_lsp_sent\x10\x0c\x12\x13\n\x0fl1_lsp_received\x10\r\x12\x12\n\x0el2_sessions_up\x10\x0e\x12\x13\n\x0fl2_session_flap\x10\x0f\x12\x14\n\x10l2_database_size\x10\x10\x12\x1c\n\x18l2_broadcast_hellos_sent\x10\x11\x12 \n\x1cl2_broadcast_hellos_received\x10\x12\x12!\n\x1dl2_point_to_point_hellos_sent\x10\x13\x12%\n!l2_point_to_point_hellos_received\x10\x14\x12\x10\n\x0cl2_psnp_sent\x10\x15\x12\x14\n\x10l2_psnp_received\x10\x16\x12\x10\n\x0cl2_csnp_sent\x10\x17\x12\x14\n\x10l2_csnp_received\x10\x18\x12\x0f\n\x0bl2_lsp_sent\x10\x19\x12\x13\n\x0fl2_lsp_received\x10\x1a\"\xf4\x0b\n\nIsisMetric\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0el1_sessions_up\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1c\n\x0fl1_session_flap\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12%\n\x18l1_broadcast_hellos_sent\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12)\n\x1cl1_broadcast_hellos_received\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1dl1_point_to_point_hellos_sent\x18\x06 \x01(\x05H\x05\x88\x01\x01\x12.\n!l1_point_to_point_hellos_received\x18\x07 \x01(\x05H\x06\x88\x01\x01\x12\x1d\n\x10l1_database_size\x18\x08 \x01(\x05H\x07\x88\x01\x01\x12\x19\n\x0cl1_psnp_sent\x18\t \x01(\x05H\x08\x88\x01\x01\x12\x1d\n\x10l1_psnp_received\x18\n \x01(\x05H\t\x88\x01\x01\x12\x19\n\x0cl1_csnp_sent\x18\x0b \x01(\x05H\n\x88\x01\x01\x12\x1d\n\x10l1_csnp_received\x18\x0c \x01(\x05H\x0b\x88\x01\x01\x12\x18\n\x0bl1_lsp_sent\x18\r \x01(\x05H\x0c\x88\x01\x01\x12\x1c\n\x0fl1_lsp_received\x18\x0e \x01(\x05H\r\x88\x01\x01\x12\x1b\n\x0el2_sessions_up\x18\x0f \x01(\x05H\x0e\x88\x01\x01\x12\x1c\n\x0fl2_session_flap\x18\x10 \x01(\x05H\x0f\x88\x01\x01\x12%\n\x18l2_broadcast_hellos_sent\x18\x11 \x01(\x05H\x10\x88\x01\x01\x12)\n\x1cl2_broadcast_hellos_received\x18\x12 \x01(\x05H\x11\x88\x01\x01\x12*\n\x1dl2_point_to_point_hellos_sent\x18\x13 \x01(\x05H\x12\x88\x01\x01\x12.\n!l2_point_to_point_hellos_received\x18\x14 \x01(\x05H\x13\x88\x01\x01\x12\x1d\n\x10l2_database_size\x18\x15 \x01(\x05H\x14\x88\x01\x01\x12\x19\n\x0cl2_psnp_sent\x18\x16 \x01(\x05H\x15\x88\x01\x01\x12\x1d\n\x10l2_psnp_received\x18\x17 \x01(\x05H\x16\x88\x01\x01\x12\x19\n\x0cl2_csnp_sent\x18\x18 \x01(\x05H\x17\x88\x01\x01\x12\x1d\n\x10l2_csnp_received\x18\x19 \x01(\x05H\x18\x88\x01\x01\x12\x18\n\x0bl2_lsp_sent\x18\x1a \x01(\x05H\x19\x88\x01\x01\x12\x1c\n\x0fl2_lsp_received\x18\x1b \x01(\x05H\x1a\x88\x01\x01\x42\x07\n\x05_nameB\x11\n\x0f_l1_sessions_upB\x12\n\x10_l1_session_flapB\x1b\n\x19_l1_broadcast_hellos_sentB\x1f\n\x1d_l1_broadcast_hellos_receivedB \n\x1e_l1_point_to_point_hellos_sentB$\n\"_l1_point_to_point_hellos_receivedB\x13\n\x11_l1_database_sizeB\x0f\n\r_l1_psnp_sentB\x13\n\x11_l1_psnp_receivedB\x0f\n\r_l1_csnp_sentB\x13\n\x11_l1_csnp_receivedB\x0e\n\x0c_l1_lsp_sentB\x12\n\x10_l1_lsp_receivedB\x11\n\x0f_l2_sessions_upB\x12\n\x10_l2_session_flapB\x1b\n\x19_l2_broadcast_hellos_sentB\x1f\n\x1d_l2_broadcast_hellos_receivedB \n\x1e_l2_point_to_point_hellos_sentB$\n\"_l2_point_to_point_hellos_receivedB\x13\n\x11_l2_database_sizeB\x0f\n\r_l2_psnp_sentB\x13\n\x11_l2_psnp_receivedB\x0f\n\r_l2_csnp_sentB\x13\n\x11_l2_csnp_receivedB\x0e\n\x0c_l2_lsp_sentB\x12\n\x10_l2_lsp_received\"\xb8\x02\n\rStatesRequest\x12\x33\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1e.otg.StatesRequest.Choice.EnumH\x00\x88\x01\x01\x12:\n\x0eipv4_neighbors\x18\x02 \x01(\x0b\x32\x1d.otg.Neighborsv4StatesRequestH\x01\x88\x01\x01\x12:\n\x0eipv6_neighbors\x18\x03 \x01(\x0b\x32\x1d.otg.Neighborsv6StatesRequestH\x02\x88\x01\x01\x1aI\n\x06\x43hoice\"?\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x42\t\n\x07_choiceB\x11\n\x0f_ipv4_neighborsB\x11\n\x0f_ipv6_neighbors\"\xfa\x01\n\x0eStatesResponse\x12\x34\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x1f.otg.StatesResponse.Choice.EnumH\x00\x88\x01\x01\x12-\n\x0eipv4_neighbors\x18\x02 \x03(\x0b\x32\x15.otg.Neighborsv4State\x12-\n\x0eipv6_neighbors\x18\x03 \x03(\x0b\x32\x15.otg.Neighborsv6State\x1aI\n\x06\x43hoice\"?\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x12\n\x0eipv4_neighbors\x10\x01\x12\x12\n\x0eipv6_neighbors\x10\x02\x42\t\n\x07_choice\"2\n\x18Neighborsv4StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"w\n\x10Neighborsv4State\x12\x15\n\rethernet_name\x18\x01 \x01(\t\x12\x14\n\x0cipv4_address\x18\x02 \x01(\t\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_link_layer_address\"2\n\x18Neighborsv6StatesRequest\x12\x16\n\x0e\x65thernet_names\x18\x01 \x03(\t\"w\n\x10Neighborsv6State\x12\x15\n\rethernet_name\x18\x01 \x01(\t\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\x12\x1f\n\x12link_layer_address\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x15\n\x13_link_layer_address\"#\n\x0e\x43\x61ptureRequest\x12\x11\n\tport_name\x18\x01 \x01(\t\"w\n\x1dPatternFlowEthernetDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcd\x03\n\x16PatternFlowEthernetDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x11\n\x04\x61uto\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12:\n\tincrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounterH\x04\x88\x01\x01\x12:\n\tdecrement\x18\x07 \x01(\x0b\x32\".otg.PatternFlowEthernetDstCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowEthernetSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowEthernetSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowEthernetSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowEthernetSrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowEthernetEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n\x1cPatternFlowEthernetEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounterH\x04\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowEthernetEtherTypeCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPfcQueueCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowEthernetPfcQueue\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPfcQueue.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPfcQueueCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowVlanPriorityCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowVlanPriority\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowVlanPriority.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowVlanPriorityCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowVlanCfiCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowVlanCfi\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowVlanCfi.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowVlanCfiCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"r\n\x18PatternFlowVlanIdCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x93\x03\n\x11PatternFlowVlanId\x12\x37\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\".otg.PatternFlowVlanId.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x35\n\tincrement\x18\x05 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounterH\x03\x88\x01\x01\x12\x35\n\tdecrement\x18\x06 \x01(\x0b\x32\x1d.otg.PatternFlowVlanIdCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowVlanTpidCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9b\x03\n\x13PatternFlowVlanTpid\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVlanTpid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVlanTpidCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowVxlanFlagsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowVxlanFlags\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowVxlanFlags.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowVxlanFlagsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowVxlanReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowVxlanReserved0\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0CounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved0CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowVxlanVniCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9b\x03\n\x13PatternFlowVxlanVni\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowVxlanVni.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowVxlanVniCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowVxlanReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowVxlanReserved1\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowVxlanReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1CounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowVxlanReserved1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv4Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv4HeaderLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe1\x03\n\x1bPatternFlowIpv4HeaderLength\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4HeaderLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12?\n\tincrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounterH\x04\x88\x01\x01\x12?\n\tdecrement\x18\x07 \x01(\x0b\x32\'.otg.PatternFlowIpv4HeaderLengthCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4TotalLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdd\x03\n\x1aPatternFlowIpv4TotalLength\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TotalLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12>\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounterH\x04\x88\x01\x01\x12>\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowIpv4TotalLengthCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4IdentificationCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIpv4Identification\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4Identification.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4IdentificationCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIpv4Reserved\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ReservedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv4DontFragmentCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowIpv4DontFragment\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv4DontFragment.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv4DontFragmentCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4MoreFragmentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowIpv4MoreFragments\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4MoreFragments.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4MoreFragmentsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4FragmentOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIpv4FragmentOffset\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4FragmentOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4FragmentOffsetCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIpv4TimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIpv4TimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv4TimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv4TimeToLiveCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4ProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd1\x03\n\x17PatternFlowIpv4Protocol\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4Protocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12;\n\tincrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounterH\x04\x88\x01\x01\x12;\n\tdecrement\x18\x07 \x01(\x0b\x32#.otg.PatternFlowIpv4ProtocolCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIpv4HeaderChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4HeaderChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIpv4HeaderChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"s\n\x19PatternFlowIpv4SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv4Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4SrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv4DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv4Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv4Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv4DstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4PriorityRawCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowIpv4PriorityRaw\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4PriorityRaw.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4PriorityRawCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4DscpPhbCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv4DscpPhb\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpPhb.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpPhbCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv4DscpEcnCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv4DscpEcn\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv4DscpEcn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv4DscpEcnCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4TosPrecedenceCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowIpv4TosPrecedence\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosPrecedence.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosPrecedenceCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv4TosDelayCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIpv4TosDelay\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv4TosDelay.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv4TosDelayCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv4TosThroughputCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowIpv4TosThroughput\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv4TosThroughput.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv4TosThroughputCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowIpv4TosReliabilityCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIpv4TosReliability\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIpv4TosReliability.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIpv4TosReliabilityCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowIpv4TosMonetaryCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowIpv4TosMonetary\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowIpv4TosMonetary.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowIpv4TosMonetaryCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIpv4TosUnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowIpv4TosUnused\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv4TosUnused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv4TosUnusedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowIpv6VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowIpv6Version\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowIpv6Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowIpv6VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowIpv6TrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowIpv6TrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIpv6TrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowIpv6TrafficClassCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIpv6FlowLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowIpv6FlowLabel\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIpv6FlowLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIpv6FlowLabelCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowIpv6PayloadLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe5\x03\n\x1cPatternFlowIpv6PayloadLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowIpv6PayloadLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12@\n\tincrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounterH\x04\x88\x01\x01\x12@\n\tdecrement\x18\x07 \x01(\x0b\x32(.otg.PatternFlowIpv6PayloadLengthCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIpv6NextHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIpv6NextHeader\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIpv6NextHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIpv6NextHeaderCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIpv6HopLimitCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIpv6HopLimit\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIpv6HopLimit.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIpv6HopLimitCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv6SrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv6Src\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Src.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6SrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"s\n\x19PatternFlowIpv6DstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x97\x03\n\x12PatternFlowIpv6Dst\x12\x38\n\x06\x63hoice\x18\x01 \x01(\x0e\x32#.otg.PatternFlowIpv6Dst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x36\n\tincrement\x18\x05 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounterH\x03\x88\x01\x01\x12\x36\n\tdecrement\x18\x06 \x01(\x0b\x32\x1e.otg.PatternFlowIpv6DstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowPfcPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowPfcPauseDst\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseDstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowPfcPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowPfcPauseSrc\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowPfcPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowPfcPauseSrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowPfcPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowPfcPauseEtherType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowPfcPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowPfcPauseEtherTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowPfcPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowPfcPauseControlOpCode\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowPfcPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowPfcPauseControlOpCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x85\x01\n+PatternFlowPfcPauseClassEnableVectorCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdf\x03\n$PatternFlowPfcPauseClassEnableVector\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x35.otg.PatternFlowPfcPauseClassEnableVector.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12H\n\tincrement\x18\x05 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounterH\x03\x88\x01\x01\x12H\n\tdecrement\x18\x06 \x01(\x0b\x32\x30.otg.PatternFlowPfcPauseClassEnableVectorCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass0\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass0CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass1\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass2Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass2\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass2CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass3Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass3\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass3.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass3CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass4Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass4\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass4.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass4CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass5Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass5\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass5.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass5CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass6Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass6\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass6.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass6CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowPfcPausePauseClass7Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowPfcPausePauseClass7\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowPfcPausePauseClass7.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7CounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowPfcPausePauseClass7CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPauseDstCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowEthernetPauseDst\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseDst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseDstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowEthernetPauseSrcCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowEthernetPauseSrc\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowEthernetPauseSrc.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowEthernetPauseSrcCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x82\x01\n(PatternFlowEthernetPauseEtherTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd3\x03\n!PatternFlowEthernetPauseEtherType\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowEthernetPauseEtherType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounterH\x03\x88\x01\x01\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowEthernetPauseEtherTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x86\x01\n,PatternFlowEthernetPauseControlOpCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe3\x03\n%PatternFlowEthernetPauseControlOpCode\x12K\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x36.otg.PatternFlowEthernetPauseControlOpCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12I\n\tincrement\x18\x05 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounterH\x03\x88\x01\x01\x12I\n\tdecrement\x18\x06 \x01(\x0b\x32\x31.otg.PatternFlowEthernetPauseControlOpCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowEthernetPauseTimeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowEthernetPauseTime\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowEthernetPauseTime.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowEthernetPauseTimeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowTcpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpSrcPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowTcpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpDstPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpSeqNumCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpSeqNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpSeqNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpSeqNumCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpAckNumCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpAckNum\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpAckNum.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpAckNumCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowTcpDataOffsetCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowTcpDataOffset\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowTcpDataOffset.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowTcpDataOffsetCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"t\n\x1aPatternFlowTcpEcnNsCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9b\x03\n\x13PatternFlowTcpEcnNs\x12\x39\n\x06\x63hoice\x18\x01 \x01(\x0e\x32$.otg.PatternFlowTcpEcnNs.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x37\n\tincrement\x18\x05 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounterH\x03\x88\x01\x01\x12\x37\n\tdecrement\x18\x06 \x01(\x0b\x32\x1f.otg.PatternFlowTcpEcnNsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpEcnCwrCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpEcnCwr\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpEcnCwr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpEcnCwrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowTcpEcnEchoCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowTcpEcnEcho\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowTcpEcnEcho.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowTcpEcnEchoCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlUrgCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlUrg\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlUrg.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlUrgCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlAckCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlAck\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlAck.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlAckCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlPshCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlPsh\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlPsh.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlPshCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlRstCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlRst\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlRst.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlRstCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlSynCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlSyn\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlSyn.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlSynCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpCtlFinCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpCtlFin\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpCtlFin.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpCtlFinCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowTcpWindowCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowTcpWindow\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowTcpWindow.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowTcpWindowCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowUdpSrcPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowUdpSrcPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpSrcPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpSrcPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowUdpDstPortCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowUdpDstPort\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowUdpDstPort.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowUdpDstPortCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowUdpLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowUdpLength\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowUdpLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowUdpLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xca\x02\n\x16PatternFlowUdpChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowUdpChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowUdpChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowGreChecksumPresentCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGreChecksumPresent\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGreChecksumPresent.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGreChecksumPresentCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGreReserved0Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGreReserved0\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved0.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved0CounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved0CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGreVersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowGreVersion\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGreVersion.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGreVersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGreProtocolCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGreProtocol\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreProtocol.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGreProtocolCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xca\x02\n\x16PatternFlowGreChecksum\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGreChecksum.Choice.EnumH\x00\x88\x01\x01\x12\x42\n\tgenerated\x18\x02 \x01(\x0e\x32*.otg.PatternFlowGreChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"x\n\x1ePatternFlowGreReserved1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGreReserved1\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGreReserved1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGreReserved1CounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGreReserved1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGtpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGtpv1Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv1VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowGtpv1ProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowGtpv1ProtocolType\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowGtpv1ProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowGtpv1ProtocolTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowGtpv1ReservedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowGtpv1Reserved\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv1Reserved.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv1ReservedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGtpv1EFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowGtpv1EFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1EFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1EFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowGtpv1SFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowGtpv1SFlag\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowGtpv1SFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowGtpv1SFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv1PnFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGtpv1PnFlag\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv1PnFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv1PnFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowGtpv1MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowGtpv1MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv1MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv1MessageTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv1MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGtpv1MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1MessageLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowGtpv1TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowGtpv1Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv1Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv1TeidCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv1SquenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGtpv1SquenceNumber\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv1SquenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv1SquenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowGtpv1NPduNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowGtpv1NPduNumber\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowGtpv1NPduNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowGtpv1NPduNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x88\x01\n.PatternFlowGtpv1NextExtensionHeaderTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xeb\x03\n\'PatternFlowGtpv1NextExtensionHeaderType\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowGtpv1NextExtensionHeaderType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounterH\x03\x88\x01\x01\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowGtpv1NextExtensionHeaderTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x87\x01\n-PatternFlowGtpExtensionExtensionLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xe7\x03\n&PatternFlowGtpExtensionExtensionLength\x12L\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x37.otg.PatternFlowGtpExtensionExtensionLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12J\n\tincrement\x18\x05 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounterH\x03\x88\x01\x01\x12J\n\tdecrement\x18\x06 \x01(\x0b\x32\x32.otg.PatternFlowGtpExtensionExtensionLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x80\x01\n&PatternFlowGtpExtensionContentsCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcb\x03\n\x1fPatternFlowGtpExtensionContents\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowGtpExtensionContents.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounterH\x03\x88\x01\x01\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowGtpExtensionContentsCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x8b\x01\n1PatternFlowGtpExtensionNextExtensionHeaderCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xf7\x03\n*PatternFlowGtpExtensionNextExtensionHeader\x12P\n\x06\x63hoice\x18\x01 \x01(\x0e\x32;.otg.PatternFlowGtpExtensionNextExtensionHeader.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12N\n\tincrement\x18\x05 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounterH\x03\x88\x01\x01\x12N\n\tdecrement\x18\x06 \x01(\x0b\x32\x36.otg.PatternFlowGtpExtensionNextExtensionHeaderCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowGtpv2VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowGtpv2Version\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowGtpv2Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowGtpv2VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowGtpv2PiggybackingFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowGtpv2PiggybackingFlag\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowGtpv2PiggybackingFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowGtpv2PiggybackingFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowGtpv2TeidFlagCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowGtpv2TeidFlag\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowGtpv2TeidFlag.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowGtpv2TeidFlagCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv2Spare1Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGtpv2Spare1\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare1.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1CounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare1CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowGtpv2MessageTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowGtpv2MessageType\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowGtpv2MessageType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowGtpv2MessageTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"~\n$PatternFlowGtpv2MessageLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowGtpv2MessageLength\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowGtpv2MessageLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowGtpv2MessageLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowGtpv2TeidCounter\x12\x12\n\x05start\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\x9f\x03\n\x14PatternFlowGtpv2Teid\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowGtpv2Teid.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x03\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x38\n\tincrement\x18\x05 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounterH\x03\x88\x01\x01\x12\x38\n\tdecrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowGtpv2TeidCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x7f\n%PatternFlowGtpv2SequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc7\x03\n\x1ePatternFlowGtpv2SequenceNumber\x12\x44\n\x06\x63hoice\x18\x01 \x01(\x0e\x32/.otg.PatternFlowGtpv2SequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x42\n\tincrement\x18\x05 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounterH\x03\x88\x01\x01\x12\x42\n\tdecrement\x18\x06 \x01(\x0b\x32*.otg.PatternFlowGtpv2SequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"w\n\x1dPatternFlowGtpv2Spare2Counter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa7\x03\n\x16PatternFlowGtpv2Spare2\x12<\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\'.otg.PatternFlowGtpv2Spare2.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12:\n\tincrement\x18\x05 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2CounterH\x03\x88\x01\x01\x12:\n\tdecrement\x18\x06 \x01(\x0b\x32\".otg.PatternFlowGtpv2Spare2CounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowArpHardwareTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowArpHardwareType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpHardwareType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpHardwareTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowArpProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb7\x03\n\x1aPatternFlowArpProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowArpProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12>\n\tincrement\x18\x05 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounterH\x03\x88\x01\x01\x12>\n\tdecrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowArpProtocolTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowArpHardwareLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowArpHardwareLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpHardwareLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpHardwareLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowArpProtocolLengthCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowArpProtocolLength\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowArpProtocolLength.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowArpProtocolLengthCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowArpOperationCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowArpOperation\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowArpOperation.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowArpOperationCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpSenderHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpSenderHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderHardwareAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpSenderProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpSenderProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpSenderProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpSenderProtocolAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpTargetHardwareAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpTargetHardwareAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetHardwareAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetHardwareAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x81\x01\n\'PatternFlowArpTargetProtocolAddrCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcf\x03\n PatternFlowArpTargetProtocolAddr\x12\x46\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x31.otg.PatternFlowArpTargetProtocolAddr.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x44\n\tincrement\x18\x05 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounterH\x03\x88\x01\x01\x12\x44\n\tdecrement\x18\x06 \x01(\x0b\x32,.otg.PatternFlowArpTargetProtocolAddrCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIcmpEchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIcmpEchoType\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIcmpEchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIcmpEchoCode\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIcmpEchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIcmpEchoCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xd9\x02\n\x1bPatternFlowIcmpEchoChecksum\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowIcmpEchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12G\n\tgenerated\x18\x02 \x01(\x0e\x32/.otg.PatternFlowIcmpEchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIcmpEchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIcmpEchoIdentifier\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpEchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIcmpEchoIdentifierCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x82\x01\n(PatternFlowIcmpEchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xd3\x03\n!PatternFlowIcmpEchoSequenceNumber\x12G\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x32.otg.PatternFlowIcmpEchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x45\n\tincrement\x18\x05 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounterH\x03\x88\x01\x01\x12\x45\n\tdecrement\x18\x06 \x01(\x0b\x32-.otg.PatternFlowIcmpEchoSequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIcmpCommonChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpCommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpCommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\x84\x01\n*PatternFlowIcmpNextFieldsIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdb\x03\n#PatternFlowIcmpNextFieldsIdentifier\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpNextFieldsIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12G\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounterH\x03\x88\x01\x01\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpNextFieldsIdentifierCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x88\x01\n.PatternFlowIcmpNextFieldsSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xeb\x03\n\'PatternFlowIcmpNextFieldsSequenceNumber\x12M\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x38.otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12K\n\tincrement\x18\x05 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounterH\x03\x88\x01\x01\x12K\n\tdecrement\x18\x06 \x01(\x0b\x32\x33.otg.PatternFlowIcmpNextFieldsSequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIcmpv6EchoTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIcmpv6EchoType\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoTypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowIcmpv6EchoCodeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowIcmpv6EchoCode\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIcmpv6EchoCode.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowIcmpv6EchoCodeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x80\x01\n&PatternFlowIcmpv6EchoIdentifierCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xcb\x03\n\x1fPatternFlowIcmpv6EchoIdentifier\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6EchoIdentifier.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x43\n\tincrement\x18\x05 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounterH\x03\x88\x01\x01\x12\x43\n\tdecrement\x18\x06 \x01(\x0b\x32+.otg.PatternFlowIcmpv6EchoIdentifierCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\x84\x01\n*PatternFlowIcmpv6EchoSequenceNumberCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdb\x03\n#PatternFlowIcmpv6EchoSequenceNumber\x12I\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x34.otg.PatternFlowIcmpv6EchoSequenceNumber.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12G\n\tincrement\x18\x05 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounterH\x03\x88\x01\x01\x12G\n\tdecrement\x18\x06 \x01(\x0b\x32/.otg.PatternFlowIcmpv6EchoSequenceNumberCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xdf\x02\n\x1dPatternFlowIcmpv6EchoChecksum\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIcmpv6EchoChecksum.Choice.EnumH\x00\x88\x01\x01\x12I\n\tgenerated\x18\x02 \x01(\x0e\x32\x31.otg.PatternFlowIcmpv6EchoChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"\xe5\x02\n\x1fPatternFlowIcmpv6CommonChecksum\x12\x45\n\x06\x63hoice\x18\x01 \x01(\x0e\x32\x30.otg.PatternFlowIcmpv6CommonChecksum.Choice.EnumH\x00\x88\x01\x01\x12K\n\tgenerated\x18\x02 \x01(\x0e\x32\x33.otg.PatternFlowIcmpv6CommonChecksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"v\n\x1cPatternFlowPppAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowPppAddress\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppAddressCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowPppControlCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowPppControl\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowPppControl.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowPppControlCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowPppControlCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"{\n!PatternFlowPppProtocolTypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xdd\x03\n\x1aPatternFlowPppProtocolType\x12@\n\x06\x63hoice\x18\x01 \x01(\x0e\x32+.otg.PatternFlowPppProtocolType.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12>\n\tincrement\x18\x06 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounterH\x04\x88\x01\x01\x12>\n\tdecrement\x18\x07 \x01(\x0b\x32&.otg.PatternFlowPppProtocolTypeCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"y\n\x1fPatternFlowIgmpv1VersionCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xaf\x03\n\x18PatternFlowIgmpv1Version\x12>\n\x06\x63hoice\x18\x01 \x01(\x0e\x32).otg.PatternFlowIgmpv1Version.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12<\n\tincrement\x18\x05 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounterH\x03\x88\x01\x01\x12<\n\tdecrement\x18\x06 \x01(\x0b\x32$.otg.PatternFlowIgmpv1VersionCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"v\n\x1cPatternFlowIgmpv1TypeCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xa3\x03\n\x15PatternFlowIgmpv1Type\x12;\n\x06\x63hoice\x18\x01 \x01(\x0e\x32&.otg.PatternFlowIgmpv1Type.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x39\n\tincrement\x18\x05 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounterH\x03\x88\x01\x01\x12\x39\n\tdecrement\x18\x06 \x01(\x0b\x32!.otg.PatternFlowIgmpv1TypeCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"x\n\x1ePatternFlowIgmpv1UnusedCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xab\x03\n\x17PatternFlowIgmpv1Unused\x12=\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.otg.PatternFlowIgmpv1Unused.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12;\n\tincrement\x18\x05 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounterH\x03\x88\x01\x01\x12;\n\tdecrement\x18\x06 \x01(\x0b\x32#.otg.PatternFlowIgmpv1UnusedCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"\xd3\x02\n\x19PatternFlowIgmpv1Checksum\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowIgmpv1Checksum.Choice.EnumH\x00\x88\x01\x01\x12\x45\n\tgenerated\x18\x02 \x01(\x0e\x32-.otg.PatternFlowIgmpv1Checksum.Generated.EnumH\x01\x88\x01\x01\x12\x13\n\x06\x63ustom\x18\x03 \x01(\x05H\x02\x88\x01\x01\x1a<\n\x06\x43hoice\"2\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tgenerated\x10\x01\x12\n\n\x06\x63ustom\x10\x02\x1a\x37\n\tGenerated\"*\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04good\x10\x01\x12\x07\n\x03\x62\x61\x64\x10\x02\x42\t\n\x07_choiceB\x0c\n\n_generatedB\t\n\x07_custom\"~\n$PatternFlowIgmpv1GroupAddressCounter\x12\x12\n\x05start\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc3\x03\n\x1dPatternFlowIgmpv1GroupAddress\x12\x43\n\x06\x63hoice\x18\x01 \x01(\x0e\x32..otg.PatternFlowIgmpv1GroupAddress.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x41\n\tincrement\x18\x05 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounterH\x03\x88\x01\x01\x12\x41\n\tdecrement\x18\x06 \x01(\x0b\x32).otg.PatternFlowIgmpv1GroupAddressCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"u\n\x1bPatternFlowMplsLabelCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xc5\x03\n\x14PatternFlowMplsLabel\x12:\n\x06\x63hoice\x18\x01 \x01(\x0e\x32%.otg.PatternFlowMplsLabel.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x11\n\x04\x61uto\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x19\n\x0cmetric_group\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x38\n\tincrement\x18\x06 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounterH\x04\x88\x01\x01\x12\x38\n\tdecrement\x18\x07 \x01(\x0b\x32 .otg.PatternFlowMplsLabelCounterH\x05\x88\x01\x01\x1a`\n\x06\x43hoice\"V\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\x08\n\x04\x61uto\x10\x03\x12\r\n\tincrement\x10\x04\x12\r\n\tdecrement\x10\x05\x42\t\n\x07_choiceB\x08\n\x06_valueB\x07\n\x05_autoB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"|\n\"PatternFlowMplsTrafficClassCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbb\x03\n\x1bPatternFlowMplsTrafficClass\x12\x41\n\x06\x63hoice\x18\x01 \x01(\x0e\x32,.otg.PatternFlowMplsTrafficClass.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12?\n\tincrement\x18\x05 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounterH\x03\x88\x01\x01\x12?\n\tdecrement\x18\x06 \x01(\x0b\x32\'.otg.PatternFlowMplsTrafficClassCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"}\n#PatternFlowMplsBottomOfStackCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xbf\x03\n\x1cPatternFlowMplsBottomOfStack\x12\x42\n\x06\x63hoice\x18\x01 \x01(\x0e\x32-.otg.PatternFlowMplsBottomOfStack.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12@\n\tincrement\x18\x05 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounterH\x03\x88\x01\x01\x12@\n\tdecrement\x18\x06 \x01(\x0b\x32(.otg.PatternFlowMplsBottomOfStackCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"z\n PatternFlowMplsTimeToLiveCounter\x12\x12\n\x05start\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04step\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_startB\x07\n\x05_stepB\x08\n\x06_count\"\xb3\x03\n\x19PatternFlowMplsTimeToLive\x12?\n\x06\x63hoice\x18\x01 \x01(\x0e\x32*.otg.PatternFlowMplsTimeToLive.Choice.EnumH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x0e\n\x06values\x18\x03 \x03(\x05\x12\x19\n\x0cmetric_group\x18\x04 \x01(\tH\x02\x88\x01\x01\x12=\n\tincrement\x18\x05 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounterH\x03\x88\x01\x01\x12=\n\tdecrement\x18\x06 \x01(\x0b\x32%.otg.PatternFlowMplsTimeToLiveCounterH\x04\x88\x01\x01\x1aV\n\x06\x43hoice\"L\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\t\n\x05value\x10\x01\x12\n\n\x06values\x10\x02\x12\r\n\tincrement\x10\x03\x12\r\n\tdecrement\x10\x04\x42\t\n\x07_choiceB\x08\n\x06_valueB\x0f\n\r_metric_groupB\x0c\n\n_incrementB\x0c\n\n_decrement\"9\n\x07Success\x12.\n\x10response_warning\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarning\"8\n\nBadRequest\x12*\n\x0eresponse_error\x18\x01 \x01(\x0b\x32\x12.otg.ResponseError\"A\n\x13InternalServerError\x12*\n\x0eresponse_error\x18\x01 \x01(\x0b\x32\x12.otg.ResponseError\"/\n\x10SetConfigRequest\x12\x1b\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x0b.otg.Config\"\xe7\x01\n\x11SetConfigResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"\xde\x01\n\x11GetConfigResponse\x12)\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x0b.otg.ConfigH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"E\n\x17SetTransmitStateRequest\x12*\n\x0etransmit_state\x18\x01 \x01(\x0b\x32\x12.otg.TransmitState\"\xee\x01\n\x18SetTransmitStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"9\n\x13SetLinkStateRequest\x12\"\n\nlink_state\x18\x01 \x01(\x0b\x32\x0e.otg.LinkState\"\xea\x01\n\x14SetLinkStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"B\n\x16SetCaptureStateRequest\x12(\n\rcapture_state\x18\x01 \x01(\x0b\x32\x11.otg.CaptureState\"\xed\x01\n\x17SetCaptureStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"<\n\x12UpdateFlowsRequest\x12&\n\x0c\x66lows_update\x18\x01 \x01(\x0b\x32\x10.otg.FlowsUpdate\"\xe0\x01\n\x13UpdateFlowsResponse\x12)\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x0b.otg.ConfigH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"<\n\x14SetRouteStateRequest\x12$\n\x0broute_state\x18\x01 \x01(\x0b\x32\x0f.otg.RouteState\"\xeb\x01\n\x15SetRouteStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"9\n\x0fSendPingRequest\x12&\n\x0cping_request\x18\x01 \x01(\x0b\x32\x10.otg.PingRequest\"\xe3\x01\n\x10SendPingResponse\x12/\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x11.otg.PingResponseH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"E\n\x17SetProtocolStateRequest\x12*\n\x0eprotocol_state\x18\x01 \x01(\x0b\x32\x12.otg.ProtocolState\"\xee\x01\n\x18SetProtocolStateResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.ResponseWarningH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"A\n\x11GetMetricsRequest\x12,\n\x0fmetrics_request\x18\x01 \x01(\x0b\x32\x13.otg.MetricsRequest\"\xe8\x01\n\x12GetMetricsResponse\x12\x32\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x14.otg.MetricsResponseH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\">\n\x10GetStatesRequest\x12*\n\x0estates_request\x18\x01 \x01(\x0b\x32\x12.otg.StatesRequest\"\xe6\x01\n\x11GetStatesResponse\x12\x31\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x13.otg.StatesResponseH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"A\n\x11GetCaptureRequest\x12,\n\x0f\x63\x61pture_request\x18\x01 \x01(\x0b\x32\x13.otg.CaptureRequest\"\xd2\x01\n\x12GetCaptureResponse\x12\x1c\n\x0fstatus_code_200\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x12\x30\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x12.otg.ResponseErrorH\x01\x88\x01\x01\x12\x30\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x12.otg.ResponseErrorH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_5002\xb4\x06\n\x07Openapi\x12:\n\tSetConfig\x12\x15.otg.SetConfigRequest\x1a\x16.otg.SetConfigResponse\x12;\n\tGetConfig\x12\x16.google.protobuf.Empty\x1a\x16.otg.GetConfigResponse\x12O\n\x10SetTransmitState\x12\x1c.otg.SetTransmitStateRequest\x1a\x1d.otg.SetTransmitStateResponse\x12\x43\n\x0cSetLinkState\x12\x18.otg.SetLinkStateRequest\x1a\x19.otg.SetLinkStateResponse\x12L\n\x0fSetCaptureState\x12\x1b.otg.SetCaptureStateRequest\x1a\x1c.otg.SetCaptureStateResponse\x12@\n\x0bUpdateFlows\x12\x17.otg.UpdateFlowsRequest\x1a\x18.otg.UpdateFlowsResponse\x12\x46\n\rSetRouteState\x12\x19.otg.SetRouteStateRequest\x1a\x1a.otg.SetRouteStateResponse\x12\x37\n\x08SendPing\x12\x14.otg.SendPingRequest\x1a\x15.otg.SendPingResponse\x12O\n\x10SetProtocolState\x12\x1c.otg.SetProtocolStateRequest\x1a\x1d.otg.SetProtocolStateResponse\x12=\n\nGetMetrics\x12\x16.otg.GetMetricsRequest\x1a\x17.otg.GetMetricsResponse\x12:\n\tGetStates\x12\x15.otg.GetStatesRequest\x1a\x16.otg.GetStatesResponse\x12=\n\nGetCapture\x12\x16.otg.GetCaptureRequest\x1a\x17.otg.GetCaptureResponseb\x06proto3')



_CONFIG = DESCRIPTOR.message_types_by_name['Config']
_CONFIGOPTIONS = DESCRIPTOR.message_types_by_name['ConfigOptions']
_PORT = DESCRIPTOR.message_types_by_name['Port']
_PORTOPTIONS = DESCRIPTOR.message_types_by_name['PortOptions']
_LAG = DESCRIPTOR.message_types_by_name['Lag']
_LAGPORT = DESCRIPTOR.message_types_by_name['LagPort']
_LAGPROTOCOL = DESCRIPTOR.message_types_by_name['LagProtocol']
_LAGPROTOCOL_CHOICE = _LAGPROTOCOL.nested_types_by_name['Choice']
_LAGSTATIC = DESCRIPTOR.message_types_by_name['LagStatic']
_LAGLACP = DESCRIPTOR.message_types_by_name['LagLacp']
_LAGLACP_ACTORACTIVITY = _LAGLACP.nested_types_by_name['ActorActivity']
_DEVICEETHERNETBASE = DESCRIPTOR.message_types_by_name['DeviceEthernetBase']
_DEVICEETHERNET = DESCRIPTOR.message_types_by_name['DeviceEthernet']
_DEVICEVLAN = DESCRIPTOR.message_types_by_name['DeviceVlan']
_DEVICEVLAN_TPID = _DEVICEVLAN.nested_types_by_name['Tpid']
_DEVICEIPV4 = DESCRIPTOR.message_types_by_name['DeviceIpv4']
_DEVICEIPV4LOOPBACK = DESCRIPTOR.message_types_by_name['DeviceIpv4Loopback']
_DEVICEIPV6 = DESCRIPTOR.message_types_by_name['DeviceIpv6']
_DEVICEIPV6LOOPBACK = DESCRIPTOR.message_types_by_name['DeviceIpv6Loopback']
_LAYER1 = DESCRIPTOR.message_types_by_name['Layer1']
_LAYER1_SPEED = _LAYER1.nested_types_by_name['Speed']
_LAYER1_MEDIA = _LAYER1.nested_types_by_name['Media']
_LAYER1AUTONEGOTIATION = DESCRIPTOR.message_types_by_name['Layer1AutoNegotiation']
_LAYER1FLOWCONTROL = DESCRIPTOR.message_types_by_name['Layer1FlowControl']
_LAYER1FLOWCONTROL_CHOICE = _LAYER1FLOWCONTROL.nested_types_by_name['Choice']
_LAYER1IEEE8023X = DESCRIPTOR.message_types_by_name['Layer1Ieee8023x']
_LAYER1IEEE8021QBB = DESCRIPTOR.message_types_by_name['Layer1Ieee8021qbb']
_CAPTURE = DESCRIPTOR.message_types_by_name['Capture']
_CAPTURE_FORMAT = _CAPTURE.nested_types_by_name['Format']
_CAPTUREFILTER = DESCRIPTOR.message_types_by_name['CaptureFilter']
_CAPTUREFILTER_CHOICE = _CAPTUREFILTER.nested_types_by_name['Choice']
_CAPTURECUSTOM = DESCRIPTOR.message_types_by_name['CaptureCustom']
_CAPTUREFIELD = DESCRIPTOR.message_types_by_name['CaptureField']
_CAPTUREETHERNET = DESCRIPTOR.message_types_by_name['CaptureEthernet']
_CAPTUREVLAN = DESCRIPTOR.message_types_by_name['CaptureVlan']
_CAPTUREIPV4 = DESCRIPTOR.message_types_by_name['CaptureIpv4']
_CAPTUREIPV6 = DESCRIPTOR.message_types_by_name['CaptureIpv6']
_DEVICE = DESCRIPTOR.message_types_by_name['Device']
_DEVICEISISROUTER = DESCRIPTOR.message_types_by_name['DeviceIsisRouter']
_DEVICEISISMULTIINSTANCE = DESCRIPTOR.message_types_by_name['DeviceIsisMultiInstance']
_ISISINTERFACE = DESCRIPTOR.message_types_by_name['IsisInterface']
_ISISINTERFACE_NETWORKTYPE = _ISISINTERFACE.nested_types_by_name['NetworkType']
_ISISINTERFACE_LEVELTYPE = _ISISINTERFACE.nested_types_by_name['LevelType']
_ISISINTERFACELEVEL = DESCRIPTOR.message_types_by_name['IsisInterfaceLevel']
_ISISMT = DESCRIPTOR.message_types_by_name['IsisMT']
_LINKSTATETE = DESCRIPTOR.message_types_by_name['LinkStateTE']
_LINKSTATEPRIORITYBANDWIDTHS = DESCRIPTOR.message_types_by_name['LinkStatepriorityBandwidths']
_ISISINTERFACEAUTHENTICATION = DESCRIPTOR.message_types_by_name['IsisInterfaceAuthentication']
_ISISINTERFACEAUTHENTICATION_AUTHTYPE = _ISISINTERFACEAUTHENTICATION.nested_types_by_name['AuthType']
_ISISINTERFACEADVANCED = DESCRIPTOR.message_types_by_name['IsisInterfaceAdvanced']
_ISISINTERFACELINKPROTECTION = DESCRIPTOR.message_types_by_name['IsisInterfaceLinkProtection']
_ISISBASIC = DESCRIPTOR.message_types_by_name['IsisBasic']
_ISISADVANCED = DESCRIPTOR.message_types_by_name['IsisAdvanced']
_ISISAUTHENTICATION = DESCRIPTOR.message_types_by_name['IsisAuthentication']
_ISISAUTHENTICATIONBASE = DESCRIPTOR.message_types_by_name['IsisAuthenticationBase']
_ISISAUTHENTICATIONBASE_AUTHTYPE = _ISISAUTHENTICATIONBASE.nested_types_by_name['AuthType']
_ISISV4ROUTERANGE = DESCRIPTOR.message_types_by_name['IsisV4RouteRange']
_ISISV4ROUTERANGE_ORIGINTYPE = _ISISV4ROUTERANGE.nested_types_by_name['OriginType']
_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE = _ISISV4ROUTERANGE.nested_types_by_name['RedistributionType']
_V4ROUTEADDRESS = DESCRIPTOR.message_types_by_name['V4RouteAddress']
_V6ROUTEADDRESS = DESCRIPTOR.message_types_by_name['V6RouteAddress']
_ISISV6ROUTERANGE = DESCRIPTOR.message_types_by_name['IsisV6RouteRange']
_ISISV6ROUTERANGE_ORIGINTYPE = _ISISV6ROUTERANGE.nested_types_by_name['OriginType']
_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE = _ISISV6ROUTERANGE.nested_types_by_name['RedistributionType']
_DEVICEBGPROUTER = DESCRIPTOR.message_types_by_name['DeviceBgpRouter']
_BGPV4PEER = DESCRIPTOR.message_types_by_name['BgpV4Peer']
_BGPV4PEER_ASTYPE = _BGPV4PEER.nested_types_by_name['AsType']
_BGPV4PEER_ASNUMBERWIDTH = _BGPV4PEER.nested_types_by_name['AsNumberWidth']
_BGPV4INTERFACE = DESCRIPTOR.message_types_by_name['BgpV4Interface']
_BGPADVANCED = DESCRIPTOR.message_types_by_name['BgpAdvanced']
_BGPCAPABILITY = DESCRIPTOR.message_types_by_name['BgpCapability']
_BGPV4ROUTERANGE = DESCRIPTOR.message_types_by_name['BgpV4RouteRange']
_BGPV4ROUTERANGE_NEXTHOPMODE = _BGPV4ROUTERANGE.nested_types_by_name['NextHopMode']
_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE = _BGPV4ROUTERANGE.nested_types_by_name['NextHopAddressType']
_BGPROUTEADVANCED = DESCRIPTOR.message_types_by_name['BgpRouteAdvanced']
_BGPROUTEADVANCED_ORIGIN = _BGPROUTEADVANCED.nested_types_by_name['Origin']
_BGPCOMMUNITY = DESCRIPTOR.message_types_by_name['BgpCommunity']
_BGPCOMMUNITY_TYPE = _BGPCOMMUNITY.nested_types_by_name['Type']
_BGPASPATH = DESCRIPTOR.message_types_by_name['BgpAsPath']
_BGPASPATH_ASSETMODE = _BGPASPATH.nested_types_by_name['AsSetMode']
_BGPASPATHSEGMENT = DESCRIPTOR.message_types_by_name['BgpAsPathSegment']
_BGPASPATHSEGMENT_TYPE = _BGPASPATHSEGMENT.nested_types_by_name['Type']
_BGPADDPATH = DESCRIPTOR.message_types_by_name['BgpAddPath']
_BGPV6ROUTERANGE = DESCRIPTOR.message_types_by_name['BgpV6RouteRange']
_BGPV6ROUTERANGE_NEXTHOPMODE = _BGPV6ROUTERANGE.nested_types_by_name['NextHopMode']
_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE = _BGPV6ROUTERANGE.nested_types_by_name['NextHopAddressType']
_BGPSRTEV4POLICY = DESCRIPTOR.message_types_by_name['BgpSrteV4Policy']
_BGPSRTEV4POLICY_NEXTHOPMODE = _BGPSRTEV4POLICY.nested_types_by_name['NextHopMode']
_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE = _BGPSRTEV4POLICY.nested_types_by_name['NextHopAddressType']
_BGPEXTCOMMUNITY = DESCRIPTOR.message_types_by_name['BgpExtCommunity']
_BGPEXTCOMMUNITY_TYPE = _BGPEXTCOMMUNITY.nested_types_by_name['Type']
_BGPEXTCOMMUNITY_SUBTYPE = _BGPEXTCOMMUNITY.nested_types_by_name['Subtype']
_BGPSRTEV4TUNNELTLV = DESCRIPTOR.message_types_by_name['BgpSrteV4TunnelTlv']
_BGPSRTEREMOTEENDPOINTSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteRemoteEndpointSubTlv']
_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY = _BGPSRTEREMOTEENDPOINTSUBTLV.nested_types_by_name['AddressFamily']
_BGPSRTECOLORSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteColorSubTlv']
_BGPSRTEBINDINGSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteBindingSubTlv']
_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE = _BGPSRTEBINDINGSUBTLV.nested_types_by_name['BindingSidType']
_BGPSRTEPREFERENCESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrtePreferenceSubTlv']
_BGPSRTEPOLICYPRIORITYSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrtePolicyPrioritySubTlv']
_BGPSRTEPOLICYNAMESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrtePolicyNameSubTlv']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteExplicitNullLabelPolicySubTlv']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV.nested_types_by_name['ExplicitNullLabelPolicy']
_BGPSRTESEGMENTLIST = DESCRIPTOR.message_types_by_name['BgpSrteSegmentList']
_BGPSRTESEGMENT = DESCRIPTOR.message_types_by_name['BgpSrteSegment']
_BGPSRTESEGMENT_SEGMENTTYPE = _BGPSRTESEGMENT.nested_types_by_name['SegmentType']
_BGPSRTESRMPLSSID = DESCRIPTOR.message_types_by_name['BgpSrteSrMplsSid']
_BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE = DESCRIPTOR.message_types_by_name['BgpSrteSRv6SIDEndpointBehaviorAndStructure']
_BGPSRTESEGMENTATYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentATypeSubTlv']
_BGPSRTESEGMENTBTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentBTypeSubTlv']
_BGPSRTESEGMENTCTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentCTypeSubTlv']
_BGPSRTESEGMENTDTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentDTypeSubTlv']
_BGPSRTESEGMENTETYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentETypeSubTlv']
_BGPSRTESEGMENTFTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentFTypeSubTlv']
_BGPSRTESEGMENTGTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentGTypeSubTlv']
_BGPSRTESEGMENTHTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentHTypeSubTlv']
_BGPSRTESEGMENTITYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentITypeSubTlv']
_BGPSRTESEGMENTJTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentJTypeSubTlv']
_BGPSRTESEGMENTKTYPESUBTLV = DESCRIPTOR.message_types_by_name['BgpSrteSegmentKTypeSubTlv']
_BGPSRTEV6POLICY = DESCRIPTOR.message_types_by_name['BgpSrteV6Policy']
_BGPSRTEV6POLICY_NEXTHOPMODE = _BGPSRTEV6POLICY.nested_types_by_name['NextHopMode']
_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE = _BGPSRTEV6POLICY.nested_types_by_name['NextHopAddressType']
_BGPSRTEV6TUNNELTLV = DESCRIPTOR.message_types_by_name['BgpSrteV6TunnelTlv']
_BGPV6PEER = DESCRIPTOR.message_types_by_name['BgpV6Peer']
_BGPV6PEER_ASTYPE = _BGPV6PEER.nested_types_by_name['AsType']
_BGPV6PEER_ASNUMBERWIDTH = _BGPV6PEER.nested_types_by_name['AsNumberWidth']
_BGPV6INTERFACE = DESCRIPTOR.message_types_by_name['BgpV6Interface']
_BGPV6SEGMENTROUTING = DESCRIPTOR.message_types_by_name['BgpV6SegmentRouting']
_FLOW = DESCRIPTOR.message_types_by_name['Flow']
_FLOWTXRX = DESCRIPTOR.message_types_by_name['FlowTxRx']
_FLOWTXRX_CHOICE = _FLOWTXRX.nested_types_by_name['Choice']
_FLOWPORT = DESCRIPTOR.message_types_by_name['FlowPort']
_FLOWROUTER = DESCRIPTOR.message_types_by_name['FlowRouter']
_FLOWROUTER_MODE = _FLOWROUTER.nested_types_by_name['Mode']
_FLOWHEADER = DESCRIPTOR.message_types_by_name['FlowHeader']
_FLOWHEADER_CHOICE = _FLOWHEADER.nested_types_by_name['Choice']
_FLOWCUSTOM = DESCRIPTOR.message_types_by_name['FlowCustom']
_FLOWETHERNET = DESCRIPTOR.message_types_by_name['FlowEthernet']
_FLOWVLAN = DESCRIPTOR.message_types_by_name['FlowVlan']
_FLOWVXLAN = DESCRIPTOR.message_types_by_name['FlowVxlan']
_FLOWIPV4 = DESCRIPTOR.message_types_by_name['FlowIpv4']
_FLOWIPV4PRIORITY = DESCRIPTOR.message_types_by_name['FlowIpv4Priority']
_FLOWIPV4PRIORITY_CHOICE = _FLOWIPV4PRIORITY.nested_types_by_name['Choice']
_FLOWIPV4DSCP = DESCRIPTOR.message_types_by_name['FlowIpv4Dscp']
_FLOWIPV4TOS = DESCRIPTOR.message_types_by_name['FlowIpv4Tos']
_FLOWIPV6 = DESCRIPTOR.message_types_by_name['FlowIpv6']
_FLOWPFCPAUSE = DESCRIPTOR.message_types_by_name['FlowPfcPause']
_FLOWETHERNETPAUSE = DESCRIPTOR.message_types_by_name['FlowEthernetPause']
_FLOWTCP = DESCRIPTOR.message_types_by_name['FlowTcp']
_FLOWUDP = DESCRIPTOR.message_types_by_name['FlowUdp']
_FLOWGRE = DESCRIPTOR.message_types_by_name['FlowGre']
_FLOWGTPV1 = DESCRIPTOR.message_types_by_name['FlowGtpv1']
_FLOWGTPEXTENSION = DESCRIPTOR.message_types_by_name['FlowGtpExtension']
_FLOWGTPV2 = DESCRIPTOR.message_types_by_name['FlowGtpv2']
_FLOWARP = DESCRIPTOR.message_types_by_name['FlowArp']
_FLOWICMP = DESCRIPTOR.message_types_by_name['FlowIcmp']
_FLOWICMP_CHOICE = _FLOWICMP.nested_types_by_name['Choice']
_FLOWICMPECHO = DESCRIPTOR.message_types_by_name['FlowIcmpEcho']
_FLOWICMPV6 = DESCRIPTOR.message_types_by_name['FlowIcmpv6']
_FLOWICMPV6_CHOICE = _FLOWICMPV6.nested_types_by_name['Choice']
_FLOWICMPV6ECHO = DESCRIPTOR.message_types_by_name['FlowIcmpv6Echo']
_FLOWPPP = DESCRIPTOR.message_types_by_name['FlowPpp']
_FLOWIGMPV1 = DESCRIPTOR.message_types_by_name['FlowIgmpv1']
_FLOWMPLS = DESCRIPTOR.message_types_by_name['FlowMpls']
_FLOWSIZE = DESCRIPTOR.message_types_by_name['FlowSize']
_FLOWSIZE_CHOICE = _FLOWSIZE.nested_types_by_name['Choice']
_FLOWSIZEINCREMENT = DESCRIPTOR.message_types_by_name['FlowSizeIncrement']
_FLOWSIZERANDOM = DESCRIPTOR.message_types_by_name['FlowSizeRandom']
_FLOWRATE = DESCRIPTOR.message_types_by_name['FlowRate']
_FLOWRATE_CHOICE = _FLOWRATE.nested_types_by_name['Choice']
_FLOWDURATION = DESCRIPTOR.message_types_by_name['FlowDuration']
_FLOWDURATION_CHOICE = _FLOWDURATION.nested_types_by_name['Choice']
_FLOWCONTINUOUS = DESCRIPTOR.message_types_by_name['FlowContinuous']
_FLOWDELAY = DESCRIPTOR.message_types_by_name['FlowDelay']
_FLOWDELAY_CHOICE = _FLOWDELAY.nested_types_by_name['Choice']
_FLOWFIXEDPACKETS = DESCRIPTOR.message_types_by_name['FlowFixedPackets']
_FLOWFIXEDSECONDS = DESCRIPTOR.message_types_by_name['FlowFixedSeconds']
_FLOWBURST = DESCRIPTOR.message_types_by_name['FlowBurst']
_FLOWDURATIONINTERBURSTGAP = DESCRIPTOR.message_types_by_name['FlowDurationInterBurstGap']
_FLOWDURATIONINTERBURSTGAP_CHOICE = _FLOWDURATIONINTERBURSTGAP.nested_types_by_name['Choice']
_FLOWMETRICS = DESCRIPTOR.message_types_by_name['FlowMetrics']
_FLOWLATENCYMETRICS = DESCRIPTOR.message_types_by_name['FlowLatencyMetrics']
_FLOWLATENCYMETRICS_MODE = _FLOWLATENCYMETRICS.nested_types_by_name['Mode']
_EVENT = DESCRIPTOR.message_types_by_name['Event']
_EVENTRXRATETHRESHOLD = DESCRIPTOR.message_types_by_name['EventRxRateThreshold']
_EVENTLINK = DESCRIPTOR.message_types_by_name['EventLink']
_EVENTROUTEADVERTISEWITHDRAW = DESCRIPTOR.message_types_by_name['EventRouteAdvertiseWithdraw']
_EVENTREQUEST = DESCRIPTOR.message_types_by_name['EventRequest']
_EVENTREQUEST_TYPE = _EVENTREQUEST.nested_types_by_name['Type']
_EVENTSUBSCRIPTION = DESCRIPTOR.message_types_by_name['EventSubscription']
_RESPONSEERROR = DESCRIPTOR.message_types_by_name['ResponseError']
_RESPONSEWARNING = DESCRIPTOR.message_types_by_name['ResponseWarning']
_LINKSTATE = DESCRIPTOR.message_types_by_name['LinkState']
_LINKSTATE_STATE = _LINKSTATE.nested_types_by_name['State']
_TRANSMITSTATE = DESCRIPTOR.message_types_by_name['TransmitState']
_TRANSMITSTATE_STATE = _TRANSMITSTATE.nested_types_by_name['State']
_CAPTURESTATE = DESCRIPTOR.message_types_by_name['CaptureState']
_CAPTURESTATE_STATE = _CAPTURESTATE.nested_types_by_name['State']
_FLOWSUPDATE = DESCRIPTOR.message_types_by_name['FlowsUpdate']
_FLOWSUPDATE_PROPERTYNAMES = _FLOWSUPDATE.nested_types_by_name['PropertyNames']
_ROUTESTATE = DESCRIPTOR.message_types_by_name['RouteState']
_ROUTESTATE_STATE = _ROUTESTATE.nested_types_by_name['State']
_PINGREQUEST = DESCRIPTOR.message_types_by_name['PingRequest']
_PROTOCOLSTATE = DESCRIPTOR.message_types_by_name['ProtocolState']
_PROTOCOLSTATE_STATE = _PROTOCOLSTATE.nested_types_by_name['State']
_PING = DESCRIPTOR.message_types_by_name['Ping']
_PING_CHOICE = _PING.nested_types_by_name['Choice']
_PINGIPV4 = DESCRIPTOR.message_types_by_name['PingIpv4']
_PINGIPV6 = DESCRIPTOR.message_types_by_name['PingIpv6']
_PINGRESPONSE = DESCRIPTOR.message_types_by_name['PingResponse']
_RESPONSE = DESCRIPTOR.message_types_by_name['Response']
_RESPONSE_RESULT = _RESPONSE.nested_types_by_name['Result']
_METRICSREQUEST = DESCRIPTOR.message_types_by_name['MetricsRequest']
_METRICSREQUEST_CHOICE = _METRICSREQUEST.nested_types_by_name['Choice']
_METRICSRESPONSE = DESCRIPTOR.message_types_by_name['MetricsResponse']
_METRICSRESPONSE_CHOICE = _METRICSRESPONSE.nested_types_by_name['Choice']
_PORTMETRICSREQUEST = DESCRIPTOR.message_types_by_name['PortMetricsRequest']
_PORTMETRICSREQUEST_COLUMNNAMES = _PORTMETRICSREQUEST.nested_types_by_name['ColumnNames']
_PORTMETRIC = DESCRIPTOR.message_types_by_name['PortMetric']
_PORTMETRIC_LINK = _PORTMETRIC.nested_types_by_name['Link']
_PORTMETRIC_CAPTURE = _PORTMETRIC.nested_types_by_name['Capture']
_FLOWMETRICSREQUEST = DESCRIPTOR.message_types_by_name['FlowMetricsRequest']
_FLOWMETRICSREQUEST_METRICNAMES = _FLOWMETRICSREQUEST.nested_types_by_name['MetricNames']
_FLOWMETRICGROUPREQUEST = DESCRIPTOR.message_types_by_name['FlowMetricGroupRequest']
_FLOWMETRICGROUPREQUEST_CHOICE = _FLOWMETRICGROUPREQUEST.nested_types_by_name['Choice']
_FLOWMETRIC = DESCRIPTOR.message_types_by_name['FlowMetric']
_FLOWMETRIC_TRANSMIT = _FLOWMETRIC.nested_types_by_name['Transmit']
_FLOWMETRICGROUP = DESCRIPTOR.message_types_by_name['FlowMetricGroup']
_METRICTIMESTAMP = DESCRIPTOR.message_types_by_name['MetricTimestamp']
_METRICLATENCY = DESCRIPTOR.message_types_by_name['MetricLatency']
_BGPV4METRICSREQUEST = DESCRIPTOR.message_types_by_name['Bgpv4MetricsRequest']
_BGPV4METRICSREQUEST_COLUMNNAMES = _BGPV4METRICSREQUEST.nested_types_by_name['ColumnNames']
_BGPV4METRIC = DESCRIPTOR.message_types_by_name['Bgpv4Metric']
_BGPV4METRIC_SESSIONSTATE = _BGPV4METRIC.nested_types_by_name['SessionState']
_BGPV6METRICSREQUEST = DESCRIPTOR.message_types_by_name['Bgpv6MetricsRequest']
_BGPV6METRICSREQUEST_COLUMNNAMES = _BGPV6METRICSREQUEST.nested_types_by_name['ColumnNames']
_BGPV6METRIC = DESCRIPTOR.message_types_by_name['Bgpv6Metric']
_BGPV6METRIC_SESSIONSTATE = _BGPV6METRIC.nested_types_by_name['SessionState']
_ISISMETRICSREQUEST = DESCRIPTOR.message_types_by_name['IsisMetricsRequest']
_ISISMETRICSREQUEST_COLUMNNAMES = _ISISMETRICSREQUEST.nested_types_by_name['ColumnNames']
_ISISMETRIC = DESCRIPTOR.message_types_by_name['IsisMetric']
_STATESREQUEST = DESCRIPTOR.message_types_by_name['StatesRequest']
_STATESREQUEST_CHOICE = _STATESREQUEST.nested_types_by_name['Choice']
_STATESRESPONSE = DESCRIPTOR.message_types_by_name['StatesResponse']
_STATESRESPONSE_CHOICE = _STATESRESPONSE.nested_types_by_name['Choice']
_NEIGHBORSV4STATESREQUEST = DESCRIPTOR.message_types_by_name['Neighborsv4StatesRequest']
_NEIGHBORSV4STATE = DESCRIPTOR.message_types_by_name['Neighborsv4State']
_NEIGHBORSV6STATESREQUEST = DESCRIPTOR.message_types_by_name['Neighborsv6StatesRequest']
_NEIGHBORSV6STATE = DESCRIPTOR.message_types_by_name['Neighborsv6State']
_CAPTUREREQUEST = DESCRIPTOR.message_types_by_name['CaptureRequest']
_PATTERNFLOWETHERNETDSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetDstCounter']
_PATTERNFLOWETHERNETDST = DESCRIPTOR.message_types_by_name['PatternFlowEthernetDst']
_PATTERNFLOWETHERNETDST_CHOICE = _PATTERNFLOWETHERNETDST.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETSRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrcCounter']
_PATTERNFLOWETHERNETSRC = DESCRIPTOR.message_types_by_name['PatternFlowEthernetSrc']
_PATTERNFLOWETHERNETSRC_CHOICE = _PATTERNFLOWETHERNETSRC.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETETHERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherTypeCounter']
_PATTERNFLOWETHERNETETHERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetEtherType']
_PATTERNFLOWETHERNETETHERTYPE_CHOICE = _PATTERNFLOWETHERNETETHERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPFCQUEUECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueueCounter']
_PATTERNFLOWETHERNETPFCQUEUE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPfcQueue']
_PATTERNFLOWETHERNETPFCQUEUE_CHOICE = _PATTERNFLOWETHERNETPFCQUEUE.nested_types_by_name['Choice']
_PATTERNFLOWVLANPRIORITYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanPriorityCounter']
_PATTERNFLOWVLANPRIORITY = DESCRIPTOR.message_types_by_name['PatternFlowVlanPriority']
_PATTERNFLOWVLANPRIORITY_CHOICE = _PATTERNFLOWVLANPRIORITY.nested_types_by_name['Choice']
_PATTERNFLOWVLANCFICOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanCfiCounter']
_PATTERNFLOWVLANCFI = DESCRIPTOR.message_types_by_name['PatternFlowVlanCfi']
_PATTERNFLOWVLANCFI_CHOICE = _PATTERNFLOWVLANCFI.nested_types_by_name['Choice']
_PATTERNFLOWVLANIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanIdCounter']
_PATTERNFLOWVLANID = DESCRIPTOR.message_types_by_name['PatternFlowVlanId']
_PATTERNFLOWVLANID_CHOICE = _PATTERNFLOWVLANID.nested_types_by_name['Choice']
_PATTERNFLOWVLANTPIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVlanTpidCounter']
_PATTERNFLOWVLANTPID = DESCRIPTOR.message_types_by_name['PatternFlowVlanTpid']
_PATTERNFLOWVLANTPID_CHOICE = _PATTERNFLOWVLANTPID.nested_types_by_name['Choice']
_PATTERNFLOWVXLANFLAGSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlagsCounter']
_PATTERNFLOWVXLANFLAGS = DESCRIPTOR.message_types_by_name['PatternFlowVxlanFlags']
_PATTERNFLOWVXLANFLAGS_CHOICE = _PATTERNFLOWVXLANFLAGS.nested_types_by_name['Choice']
_PATTERNFLOWVXLANRESERVED0COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0Counter']
_PATTERNFLOWVXLANRESERVED0 = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved0']
_PATTERNFLOWVXLANRESERVED0_CHOICE = _PATTERNFLOWVXLANRESERVED0.nested_types_by_name['Choice']
_PATTERNFLOWVXLANVNICOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanVniCounter']
_PATTERNFLOWVXLANVNI = DESCRIPTOR.message_types_by_name['PatternFlowVxlanVni']
_PATTERNFLOWVXLANVNI_CHOICE = _PATTERNFLOWVXLANVNI.nested_types_by_name['Choice']
_PATTERNFLOWVXLANRESERVED1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1Counter']
_PATTERNFLOWVXLANRESERVED1 = DESCRIPTOR.message_types_by_name['PatternFlowVxlanReserved1']
_PATTERNFLOWVXLANRESERVED1_CHOICE = _PATTERNFLOWVXLANRESERVED1.nested_types_by_name['Choice']
_PATTERNFLOWIPV4VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4VersionCounter']
_PATTERNFLOWIPV4VERSION = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Version']
_PATTERNFLOWIPV4VERSION_CHOICE = _PATTERNFLOWIPV4VERSION.nested_types_by_name['Choice']
_PATTERNFLOWIPV4HEADERLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLengthCounter']
_PATTERNFLOWIPV4HEADERLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderLength']
_PATTERNFLOWIPV4HEADERLENGTH_CHOICE = _PATTERNFLOWIPV4HEADERLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOTALLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLengthCounter']
_PATTERNFLOWIPV4TOTALLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TotalLength']
_PATTERNFLOWIPV4TOTALLENGTH_CHOICE = _PATTERNFLOWIPV4TOTALLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWIPV4IDENTIFICATIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4IdentificationCounter']
_PATTERNFLOWIPV4IDENTIFICATION = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Identification']
_PATTERNFLOWIPV4IDENTIFICATION_CHOICE = _PATTERNFLOWIPV4IDENTIFICATION.nested_types_by_name['Choice']
_PATTERNFLOWIPV4RESERVEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4ReservedCounter']
_PATTERNFLOWIPV4RESERVED = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Reserved']
_PATTERNFLOWIPV4RESERVED_CHOICE = _PATTERNFLOWIPV4RESERVED.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DONTFRAGMENTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragmentCounter']
_PATTERNFLOWIPV4DONTFRAGMENT = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DontFragment']
_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE = _PATTERNFLOWIPV4DONTFRAGMENT.nested_types_by_name['Choice']
_PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragmentsCounter']
_PATTERNFLOWIPV4MOREFRAGMENTS = DESCRIPTOR.message_types_by_name['PatternFlowIpv4MoreFragments']
_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE = _PATTERNFLOWIPV4MOREFRAGMENTS.nested_types_by_name['Choice']
_PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffsetCounter']
_PATTERNFLOWIPV4FRAGMENTOFFSET = DESCRIPTOR.message_types_by_name['PatternFlowIpv4FragmentOffset']
_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE = _PATTERNFLOWIPV4FRAGMENTOFFSET.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TIMETOLIVECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLiveCounter']
_PATTERNFLOWIPV4TIMETOLIVE = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TimeToLive']
_PATTERNFLOWIPV4TIMETOLIVE_CHOICE = _PATTERNFLOWIPV4TIMETOLIVE.nested_types_by_name['Choice']
_PATTERNFLOWIPV4PROTOCOLCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4ProtocolCounter']
_PATTERNFLOWIPV4PROTOCOL = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Protocol']
_PATTERNFLOWIPV4PROTOCOL_CHOICE = _PATTERNFLOWIPV4PROTOCOL.nested_types_by_name['Choice']
_PATTERNFLOWIPV4HEADERCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIpv4HeaderChecksum']
_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE = _PATTERNFLOWIPV4HEADERCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED = _PATTERNFLOWIPV4HEADERCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWIPV4SRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4SrcCounter']
_PATTERNFLOWIPV4SRC = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Src']
_PATTERNFLOWIPV4SRC_CHOICE = _PATTERNFLOWIPV4SRC.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DstCounter']
_PATTERNFLOWIPV4DST = DESCRIPTOR.message_types_by_name['PatternFlowIpv4Dst']
_PATTERNFLOWIPV4DST_CHOICE = _PATTERNFLOWIPV4DST.nested_types_by_name['Choice']
_PATTERNFLOWIPV4PRIORITYRAWCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRawCounter']
_PATTERNFLOWIPV4PRIORITYRAW = DESCRIPTOR.message_types_by_name['PatternFlowIpv4PriorityRaw']
_PATTERNFLOWIPV4PRIORITYRAW_CHOICE = _PATTERNFLOWIPV4PRIORITYRAW.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DSCPPHBCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhbCounter']
_PATTERNFLOWIPV4DSCPPHB = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpPhb']
_PATTERNFLOWIPV4DSCPPHB_CHOICE = _PATTERNFLOWIPV4DSCPPHB.nested_types_by_name['Choice']
_PATTERNFLOWIPV4DSCPECNCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcnCounter']
_PATTERNFLOWIPV4DSCPECN = DESCRIPTOR.message_types_by_name['PatternFlowIpv4DscpEcn']
_PATTERNFLOWIPV4DSCPECN_CHOICE = _PATTERNFLOWIPV4DSCPECN.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSPRECEDENCECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedenceCounter']
_PATTERNFLOWIPV4TOSPRECEDENCE = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosPrecedence']
_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE = _PATTERNFLOWIPV4TOSPRECEDENCE.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSDELAYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelayCounter']
_PATTERNFLOWIPV4TOSDELAY = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosDelay']
_PATTERNFLOWIPV4TOSDELAY_CHOICE = _PATTERNFLOWIPV4TOSDELAY.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughputCounter']
_PATTERNFLOWIPV4TOSTHROUGHPUT = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosThroughput']
_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE = _PATTERNFLOWIPV4TOSTHROUGHPUT.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSRELIABILITYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliabilityCounter']
_PATTERNFLOWIPV4TOSRELIABILITY = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosReliability']
_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE = _PATTERNFLOWIPV4TOSRELIABILITY.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSMONETARYCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetaryCounter']
_PATTERNFLOWIPV4TOSMONETARY = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosMonetary']
_PATTERNFLOWIPV4TOSMONETARY_CHOICE = _PATTERNFLOWIPV4TOSMONETARY.nested_types_by_name['Choice']
_PATTERNFLOWIPV4TOSUNUSEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnusedCounter']
_PATTERNFLOWIPV4TOSUNUSED = DESCRIPTOR.message_types_by_name['PatternFlowIpv4TosUnused']
_PATTERNFLOWIPV4TOSUNUSED_CHOICE = _PATTERNFLOWIPV4TOSUNUSED.nested_types_by_name['Choice']
_PATTERNFLOWIPV6VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6VersionCounter']
_PATTERNFLOWIPV6VERSION = DESCRIPTOR.message_types_by_name['PatternFlowIpv6Version']
_PATTERNFLOWIPV6VERSION_CHOICE = _PATTERNFLOWIPV6VERSION.nested_types_by_name['Choice']
_PATTERNFLOWIPV6TRAFFICCLASSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClassCounter']
_PATTERNFLOWIPV6TRAFFICCLASS = DESCRIPTOR.message_types_by_name['PatternFlowIpv6TrafficClass']
_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE = _PATTERNFLOWIPV6TRAFFICCLASS.nested_types_by_name['Choice']
_PATTERNFLOWIPV6FLOWLABELCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabelCounter']
_PATTERNFLOWIPV6FLOWLABEL = DESCRIPTOR.message_types_by_name['PatternFlowIpv6FlowLabel']
_PATTERNFLOWIPV6FLOWLABEL_CHOICE = _PATTERNFLOWIPV6FLOWLABEL.nested_types_by_name['Choice']
_PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLengthCounter']
_PATTERNFLOWIPV6PAYLOADLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowIpv6PayloadLength']
_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE = _PATTERNFLOWIPV6PAYLOADLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWIPV6NEXTHEADERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeaderCounter']
_PATTERNFLOWIPV6NEXTHEADER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6NextHeader']
_PATTERNFLOWIPV6NEXTHEADER_CHOICE = _PATTERNFLOWIPV6NEXTHEADER.nested_types_by_name['Choice']
_PATTERNFLOWIPV6HOPLIMITCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimitCounter']
_PATTERNFLOWIPV6HOPLIMIT = DESCRIPTOR.message_types_by_name['PatternFlowIpv6HopLimit']
_PATTERNFLOWIPV6HOPLIMIT_CHOICE = _PATTERNFLOWIPV6HOPLIMIT.nested_types_by_name['Choice']
_PATTERNFLOWIPV6SRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6SrcCounter']
_PATTERNFLOWIPV6SRC = DESCRIPTOR.message_types_by_name['PatternFlowIpv6Src']
_PATTERNFLOWIPV6SRC_CHOICE = _PATTERNFLOWIPV6SRC.nested_types_by_name['Choice']
_PATTERNFLOWIPV6DSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIpv6DstCounter']
_PATTERNFLOWIPV6DST = DESCRIPTOR.message_types_by_name['PatternFlowIpv6Dst']
_PATTERNFLOWIPV6DST_CHOICE = _PATTERNFLOWIPV6DST.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEDSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDstCounter']
_PATTERNFLOWPFCPAUSEDST = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseDst']
_PATTERNFLOWPFCPAUSEDST_CHOICE = _PATTERNFLOWPFCPAUSEDST.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSESRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrcCounter']
_PATTERNFLOWPFCPAUSESRC = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseSrc']
_PATTERNFLOWPFCPAUSESRC_CHOICE = _PATTERNFLOWPFCPAUSESRC.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEETHERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherTypeCounter']
_PATTERNFLOWPFCPAUSEETHERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseEtherType']
_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE = _PATTERNFLOWPFCPAUSEETHERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCodeCounter']
_PATTERNFLOWPFCPAUSECONTROLOPCODE = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseControlOpCode']
_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE = _PATTERNFLOWPFCPAUSECONTROLOPCODE.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVectorCounter']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR = DESCRIPTOR.message_types_by_name['PatternFlowPfcPauseClassEnableVector']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS0 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass0']
_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS0.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS1 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass1']
_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS1.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS2 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass2']
_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS2.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS3 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass3']
_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS3.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS4 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass4']
_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS4.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS5 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass5']
_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS5.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS6 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass6']
_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS6.nested_types_by_name['Choice']
_PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7Counter']
_PATTERNFLOWPFCPAUSEPAUSECLASS7 = DESCRIPTOR.message_types_by_name['PatternFlowPfcPausePauseClass7']
_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE = _PATTERNFLOWPFCPAUSEPAUSECLASS7.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSEDSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDstCounter']
_PATTERNFLOWETHERNETPAUSEDST = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseDst']
_PATTERNFLOWETHERNETPAUSEDST_CHOICE = _PATTERNFLOWETHERNETPAUSEDST.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSESRCCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrcCounter']
_PATTERNFLOWETHERNETPAUSESRC = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseSrc']
_PATTERNFLOWETHERNETPAUSESRC_CHOICE = _PATTERNFLOWETHERNETPAUSESRC.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherTypeCounter']
_PATTERNFLOWETHERNETPAUSEETHERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseEtherType']
_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE = _PATTERNFLOWETHERNETPAUSEETHERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCodeCounter']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseControlOpCode']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE.nested_types_by_name['Choice']
_PATTERNFLOWETHERNETPAUSETIMECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTimeCounter']
_PATTERNFLOWETHERNETPAUSETIME = DESCRIPTOR.message_types_by_name['PatternFlowEthernetPauseTime']
_PATTERNFLOWETHERNETPAUSETIME_CHOICE = _PATTERNFLOWETHERNETPAUSETIME.nested_types_by_name['Choice']
_PATTERNFLOWTCPSRCPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPortCounter']
_PATTERNFLOWTCPSRCPORT = DESCRIPTOR.message_types_by_name['PatternFlowTcpSrcPort']
_PATTERNFLOWTCPSRCPORT_CHOICE = _PATTERNFLOWTCPSRCPORT.nested_types_by_name['Choice']
_PATTERNFLOWTCPDSTPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPortCounter']
_PATTERNFLOWTCPDSTPORT = DESCRIPTOR.message_types_by_name['PatternFlowTcpDstPort']
_PATTERNFLOWTCPDSTPORT_CHOICE = _PATTERNFLOWTCPDSTPORT.nested_types_by_name['Choice']
_PATTERNFLOWTCPSEQNUMCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNumCounter']
_PATTERNFLOWTCPSEQNUM = DESCRIPTOR.message_types_by_name['PatternFlowTcpSeqNum']
_PATTERNFLOWTCPSEQNUM_CHOICE = _PATTERNFLOWTCPSEQNUM.nested_types_by_name['Choice']
_PATTERNFLOWTCPACKNUMCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNumCounter']
_PATTERNFLOWTCPACKNUM = DESCRIPTOR.message_types_by_name['PatternFlowTcpAckNum']
_PATTERNFLOWTCPACKNUM_CHOICE = _PATTERNFLOWTCPACKNUM.nested_types_by_name['Choice']
_PATTERNFLOWTCPDATAOFFSETCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffsetCounter']
_PATTERNFLOWTCPDATAOFFSET = DESCRIPTOR.message_types_by_name['PatternFlowTcpDataOffset']
_PATTERNFLOWTCPDATAOFFSET_CHOICE = _PATTERNFLOWTCPDATAOFFSET.nested_types_by_name['Choice']
_PATTERNFLOWTCPECNNSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNsCounter']
_PATTERNFLOWTCPECNNS = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnNs']
_PATTERNFLOWTCPECNNS_CHOICE = _PATTERNFLOWTCPECNNS.nested_types_by_name['Choice']
_PATTERNFLOWTCPECNCWRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwrCounter']
_PATTERNFLOWTCPECNCWR = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnCwr']
_PATTERNFLOWTCPECNCWR_CHOICE = _PATTERNFLOWTCPECNCWR.nested_types_by_name['Choice']
_PATTERNFLOWTCPECNECHOCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEchoCounter']
_PATTERNFLOWTCPECNECHO = DESCRIPTOR.message_types_by_name['PatternFlowTcpEcnEcho']
_PATTERNFLOWTCPECNECHO_CHOICE = _PATTERNFLOWTCPECNECHO.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLURGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrgCounter']
_PATTERNFLOWTCPCTLURG = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlUrg']
_PATTERNFLOWTCPCTLURG_CHOICE = _PATTERNFLOWTCPCTLURG.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLACKCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAckCounter']
_PATTERNFLOWTCPCTLACK = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlAck']
_PATTERNFLOWTCPCTLACK_CHOICE = _PATTERNFLOWTCPCTLACK.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLPSHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPshCounter']
_PATTERNFLOWTCPCTLPSH = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlPsh']
_PATTERNFLOWTCPCTLPSH_CHOICE = _PATTERNFLOWTCPCTLPSH.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLRSTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRstCounter']
_PATTERNFLOWTCPCTLRST = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlRst']
_PATTERNFLOWTCPCTLRST_CHOICE = _PATTERNFLOWTCPCTLRST.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLSYNCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSynCounter']
_PATTERNFLOWTCPCTLSYN = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlSyn']
_PATTERNFLOWTCPCTLSYN_CHOICE = _PATTERNFLOWTCPCTLSYN.nested_types_by_name['Choice']
_PATTERNFLOWTCPCTLFINCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFinCounter']
_PATTERNFLOWTCPCTLFIN = DESCRIPTOR.message_types_by_name['PatternFlowTcpCtlFin']
_PATTERNFLOWTCPCTLFIN_CHOICE = _PATTERNFLOWTCPCTLFIN.nested_types_by_name['Choice']
_PATTERNFLOWTCPWINDOWCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowTcpWindowCounter']
_PATTERNFLOWTCPWINDOW = DESCRIPTOR.message_types_by_name['PatternFlowTcpWindow']
_PATTERNFLOWTCPWINDOW_CHOICE = _PATTERNFLOWTCPWINDOW.nested_types_by_name['Choice']
_PATTERNFLOWUDPSRCPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPortCounter']
_PATTERNFLOWUDPSRCPORT = DESCRIPTOR.message_types_by_name['PatternFlowUdpSrcPort']
_PATTERNFLOWUDPSRCPORT_CHOICE = _PATTERNFLOWUDPSRCPORT.nested_types_by_name['Choice']
_PATTERNFLOWUDPDSTPORTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPortCounter']
_PATTERNFLOWUDPDSTPORT = DESCRIPTOR.message_types_by_name['PatternFlowUdpDstPort']
_PATTERNFLOWUDPDSTPORT_CHOICE = _PATTERNFLOWUDPDSTPORT.nested_types_by_name['Choice']
_PATTERNFLOWUDPLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowUdpLengthCounter']
_PATTERNFLOWUDPLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowUdpLength']
_PATTERNFLOWUDPLENGTH_CHOICE = _PATTERNFLOWUDPLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWUDPCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowUdpChecksum']
_PATTERNFLOWUDPCHECKSUM_CHOICE = _PATTERNFLOWUDPCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWUDPCHECKSUM_GENERATED = _PATTERNFLOWUDPCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWGRECHECKSUMPRESENTCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresentCounter']
_PATTERNFLOWGRECHECKSUMPRESENT = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksumPresent']
_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE = _PATTERNFLOWGRECHECKSUMPRESENT.nested_types_by_name['Choice']
_PATTERNFLOWGRERESERVED0COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0Counter']
_PATTERNFLOWGRERESERVED0 = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved0']
_PATTERNFLOWGRERESERVED0_CHOICE = _PATTERNFLOWGRERESERVED0.nested_types_by_name['Choice']
_PATTERNFLOWGREVERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreVersionCounter']
_PATTERNFLOWGREVERSION = DESCRIPTOR.message_types_by_name['PatternFlowGreVersion']
_PATTERNFLOWGREVERSION_CHOICE = _PATTERNFLOWGREVERSION.nested_types_by_name['Choice']
_PATTERNFLOWGREPROTOCOLCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreProtocolCounter']
_PATTERNFLOWGREPROTOCOL = DESCRIPTOR.message_types_by_name['PatternFlowGreProtocol']
_PATTERNFLOWGREPROTOCOL_CHOICE = _PATTERNFLOWGREPROTOCOL.nested_types_by_name['Choice']
_PATTERNFLOWGRECHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowGreChecksum']
_PATTERNFLOWGRECHECKSUM_CHOICE = _PATTERNFLOWGRECHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWGRECHECKSUM_GENERATED = _PATTERNFLOWGRECHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWGRERESERVED1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1Counter']
_PATTERNFLOWGRERESERVED1 = DESCRIPTOR.message_types_by_name['PatternFlowGreReserved1']
_PATTERNFLOWGRERESERVED1_CHOICE = _PATTERNFLOWGRERESERVED1.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1VersionCounter']
_PATTERNFLOWGTPV1VERSION = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Version']
_PATTERNFLOWGTPV1VERSION_CHOICE = _PATTERNFLOWGTPV1VERSION.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolTypeCounter']
_PATTERNFLOWGTPV1PROTOCOLTYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ProtocolType']
_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE = _PATTERNFLOWGTPV1PROTOCOLTYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1RESERVEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1ReservedCounter']
_PATTERNFLOWGTPV1RESERVED = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Reserved']
_PATTERNFLOWGTPV1RESERVED_CHOICE = _PATTERNFLOWGTPV1RESERVED.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1EFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlagCounter']
_PATTERNFLOWGTPV1EFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1EFlag']
_PATTERNFLOWGTPV1EFLAG_CHOICE = _PATTERNFLOWGTPV1EFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1SFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlagCounter']
_PATTERNFLOWGTPV1SFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SFlag']
_PATTERNFLOWGTPV1SFLAG_CHOICE = _PATTERNFLOWGTPV1SFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1PNFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlagCounter']
_PATTERNFLOWGTPV1PNFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1PnFlag']
_PATTERNFLOWGTPV1PNFLAG_CHOICE = _PATTERNFLOWGTPV1PNFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1MESSAGETYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageTypeCounter']
_PATTERNFLOWGTPV1MESSAGETYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageType']
_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE = _PATTERNFLOWGTPV1MESSAGETYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLengthCounter']
_PATTERNFLOWGTPV1MESSAGELENGTH = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1MessageLength']
_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE = _PATTERNFLOWGTPV1MESSAGELENGTH.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1TEIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1TeidCounter']
_PATTERNFLOWGTPV1TEID = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1Teid']
_PATTERNFLOWGTPV1TEID_CHOICE = _PATTERNFLOWGTPV1TEID.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumberCounter']
_PATTERNFLOWGTPV1SQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1SquenceNumber']
_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE = _PATTERNFLOWGTPV1SQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1NPDUNUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumberCounter']
_PATTERNFLOWGTPV1NPDUNUMBER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NPduNumber']
_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE = _PATTERNFLOWGTPV1NPDUNUMBER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderTypeCounter']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv1NextExtensionHeaderType']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLengthCounter']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionExtensionLength']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContentsCounter']
_PATTERNFLOWGTPEXTENSIONCONTENTS = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionContents']
_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE = _PATTERNFLOWGTPEXTENSIONCONTENTS.nested_types_by_name['Choice']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeaderCounter']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER = DESCRIPTOR.message_types_by_name['PatternFlowGtpExtensionNextExtensionHeader']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2VersionCounter']
_PATTERNFLOWGTPV2VERSION = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Version']
_PATTERNFLOWGTPV2VERSION_CHOICE = _PATTERNFLOWGTPV2VERSION.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlagCounter']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2PiggybackingFlag']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2TEIDFLAGCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlagCounter']
_PATTERNFLOWGTPV2TEIDFLAG = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidFlag']
_PATTERNFLOWGTPV2TEIDFLAG_CHOICE = _PATTERNFLOWGTPV2TEIDFLAG.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2SPARE1COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1Counter']
_PATTERNFLOWGTPV2SPARE1 = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare1']
_PATTERNFLOWGTPV2SPARE1_CHOICE = _PATTERNFLOWGTPV2SPARE1.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2MESSAGETYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageTypeCounter']
_PATTERNFLOWGTPV2MESSAGETYPE = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageType']
_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE = _PATTERNFLOWGTPV2MESSAGETYPE.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLengthCounter']
_PATTERNFLOWGTPV2MESSAGELENGTH = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2MessageLength']
_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE = _PATTERNFLOWGTPV2MESSAGELENGTH.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2TEIDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2TeidCounter']
_PATTERNFLOWGTPV2TEID = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Teid']
_PATTERNFLOWGTPV2TEID_CHOICE = _PATTERNFLOWGTPV2TEID.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumberCounter']
_PATTERNFLOWGTPV2SEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2SequenceNumber']
_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE = _PATTERNFLOWGTPV2SEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWGTPV2SPARE2COUNTER = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2Counter']
_PATTERNFLOWGTPV2SPARE2 = DESCRIPTOR.message_types_by_name['PatternFlowGtpv2Spare2']
_PATTERNFLOWGTPV2SPARE2_CHOICE = _PATTERNFLOWGTPV2SPARE2.nested_types_by_name['Choice']
_PATTERNFLOWARPHARDWARETYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareTypeCounter']
_PATTERNFLOWARPHARDWARETYPE = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareType']
_PATTERNFLOWARPHARDWARETYPE_CHOICE = _PATTERNFLOWARPHARDWARETYPE.nested_types_by_name['Choice']
_PATTERNFLOWARPPROTOCOLTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolTypeCounter']
_PATTERNFLOWARPPROTOCOLTYPE = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolType']
_PATTERNFLOWARPPROTOCOLTYPE_CHOICE = _PATTERNFLOWARPPROTOCOLTYPE.nested_types_by_name['Choice']
_PATTERNFLOWARPHARDWARELENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLengthCounter']
_PATTERNFLOWARPHARDWARELENGTH = DESCRIPTOR.message_types_by_name['PatternFlowArpHardwareLength']
_PATTERNFLOWARPHARDWARELENGTH_CHOICE = _PATTERNFLOWARPHARDWARELENGTH.nested_types_by_name['Choice']
_PATTERNFLOWARPPROTOCOLLENGTHCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLengthCounter']
_PATTERNFLOWARPPROTOCOLLENGTH = DESCRIPTOR.message_types_by_name['PatternFlowArpProtocolLength']
_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE = _PATTERNFLOWARPPROTOCOLLENGTH.nested_types_by_name['Choice']
_PATTERNFLOWARPOPERATIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpOperationCounter']
_PATTERNFLOWARPOPERATION = DESCRIPTOR.message_types_by_name['PatternFlowArpOperation']
_PATTERNFLOWARPOPERATION_CHOICE = _PATTERNFLOWARPOPERATION.nested_types_by_name['Choice']
_PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddrCounter']
_PATTERNFLOWARPSENDERHARDWAREADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderHardwareAddr']
_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE = _PATTERNFLOWARPSENDERHARDWAREADDR.nested_types_by_name['Choice']
_PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddrCounter']
_PATTERNFLOWARPSENDERPROTOCOLADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpSenderProtocolAddr']
_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE = _PATTERNFLOWARPSENDERPROTOCOLADDR.nested_types_by_name['Choice']
_PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddrCounter']
_PATTERNFLOWARPTARGETHARDWAREADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetHardwareAddr']
_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE = _PATTERNFLOWARPTARGETHARDWAREADDR.nested_types_by_name['Choice']
_PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddrCounter']
_PATTERNFLOWARPTARGETPROTOCOLADDR = DESCRIPTOR.message_types_by_name['PatternFlowArpTargetProtocolAddr']
_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE = _PATTERNFLOWARPTARGETPROTOCOLADDR.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoTypeCounter']
_PATTERNFLOWICMPECHOTYPE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoType']
_PATTERNFLOWICMPECHOTYPE_CHOICE = _PATTERNFLOWICMPECHOTYPE.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCodeCounter']
_PATTERNFLOWICMPECHOCODE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoCode']
_PATTERNFLOWICMPECHOCODE_CHOICE = _PATTERNFLOWICMPECHOCODE.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoChecksum']
_PATTERNFLOWICMPECHOCHECKSUM_CHOICE = _PATTERNFLOWICMPECHOCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOCHECKSUM_GENERATED = _PATTERNFLOWICMPECHOCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWICMPECHOIDENTIFIERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifierCounter']
_PATTERNFLOWICMPECHOIDENTIFIER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoIdentifier']
_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE = _PATTERNFLOWICMPECHOIDENTIFIER.nested_types_by_name['Choice']
_PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumberCounter']
_PATTERNFLOWICMPECHOSEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpEchoSequenceNumber']
_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE = _PATTERNFLOWICMPECHOSEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWICMPCOMMONCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpCommonChecksum']
_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE = _PATTERNFLOWICMPCOMMONCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED = _PATTERNFLOWICMPCOMMONCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifierCounter']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsIdentifier']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER.nested_types_by_name['Choice']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumberCounter']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpNextFieldsSequenceNumber']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoTypeCounter']
_PATTERNFLOWICMPV6ECHOTYPE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoType']
_PATTERNFLOWICMPV6ECHOTYPE_CHOICE = _PATTERNFLOWICMPV6ECHOTYPE.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOCODECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCodeCounter']
_PATTERNFLOWICMPV6ECHOCODE = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoCode']
_PATTERNFLOWICMPV6ECHOCODE_CHOICE = _PATTERNFLOWICMPV6ECHOCODE.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifierCounter']
_PATTERNFLOWICMPV6ECHOIDENTIFIER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoIdentifier']
_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE = _PATTERNFLOWICMPV6ECHOIDENTIFIER.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumberCounter']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoSequenceNumber']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6EchoChecksum']
_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE = _PATTERNFLOWICMPV6ECHOCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED = _PATTERNFLOWICMPV6ECHOCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWICMPV6COMMONCHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIcmpv6CommonChecksum']
_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE = _PATTERNFLOWICMPV6COMMONCHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED = _PATTERNFLOWICMPV6COMMONCHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWPPPADDRESSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPppAddressCounter']
_PATTERNFLOWPPPADDRESS = DESCRIPTOR.message_types_by_name['PatternFlowPppAddress']
_PATTERNFLOWPPPADDRESS_CHOICE = _PATTERNFLOWPPPADDRESS.nested_types_by_name['Choice']
_PATTERNFLOWPPPCONTROLCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPppControlCounter']
_PATTERNFLOWPPPCONTROL = DESCRIPTOR.message_types_by_name['PatternFlowPppControl']
_PATTERNFLOWPPPCONTROL_CHOICE = _PATTERNFLOWPPPCONTROL.nested_types_by_name['Choice']
_PATTERNFLOWPPPPROTOCOLTYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolTypeCounter']
_PATTERNFLOWPPPPROTOCOLTYPE = DESCRIPTOR.message_types_by_name['PatternFlowPppProtocolType']
_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE = _PATTERNFLOWPPPPROTOCOLTYPE.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1VERSIONCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1VersionCounter']
_PATTERNFLOWIGMPV1VERSION = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Version']
_PATTERNFLOWIGMPV1VERSION_CHOICE = _PATTERNFLOWIGMPV1VERSION.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1TYPECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1TypeCounter']
_PATTERNFLOWIGMPV1TYPE = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Type']
_PATTERNFLOWIGMPV1TYPE_CHOICE = _PATTERNFLOWIGMPV1TYPE.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1UNUSEDCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1UnusedCounter']
_PATTERNFLOWIGMPV1UNUSED = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Unused']
_PATTERNFLOWIGMPV1UNUSED_CHOICE = _PATTERNFLOWIGMPV1UNUSED.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1CHECKSUM = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1Checksum']
_PATTERNFLOWIGMPV1CHECKSUM_CHOICE = _PATTERNFLOWIGMPV1CHECKSUM.nested_types_by_name['Choice']
_PATTERNFLOWIGMPV1CHECKSUM_GENERATED = _PATTERNFLOWIGMPV1CHECKSUM.nested_types_by_name['Generated']
_PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddressCounter']
_PATTERNFLOWIGMPV1GROUPADDRESS = DESCRIPTOR.message_types_by_name['PatternFlowIgmpv1GroupAddress']
_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE = _PATTERNFLOWIGMPV1GROUPADDRESS.nested_types_by_name['Choice']
_PATTERNFLOWMPLSLABELCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsLabelCounter']
_PATTERNFLOWMPLSLABEL = DESCRIPTOR.message_types_by_name['PatternFlowMplsLabel']
_PATTERNFLOWMPLSLABEL_CHOICE = _PATTERNFLOWMPLSLABEL.nested_types_by_name['Choice']
_PATTERNFLOWMPLSTRAFFICCLASSCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsTrafficClassCounter']
_PATTERNFLOWMPLSTRAFFICCLASS = DESCRIPTOR.message_types_by_name['PatternFlowMplsTrafficClass']
_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE = _PATTERNFLOWMPLSTRAFFICCLASS.nested_types_by_name['Choice']
_PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsBottomOfStackCounter']
_PATTERNFLOWMPLSBOTTOMOFSTACK = DESCRIPTOR.message_types_by_name['PatternFlowMplsBottomOfStack']
_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE = _PATTERNFLOWMPLSBOTTOMOFSTACK.nested_types_by_name['Choice']
_PATTERNFLOWMPLSTIMETOLIVECOUNTER = DESCRIPTOR.message_types_by_name['PatternFlowMplsTimeToLiveCounter']
_PATTERNFLOWMPLSTIMETOLIVE = DESCRIPTOR.message_types_by_name['PatternFlowMplsTimeToLive']
_PATTERNFLOWMPLSTIMETOLIVE_CHOICE = _PATTERNFLOWMPLSTIMETOLIVE.nested_types_by_name['Choice']
_SUCCESS = DESCRIPTOR.message_types_by_name['Success']
_BADREQUEST = DESCRIPTOR.message_types_by_name['BadRequest']
_INTERNALSERVERERROR = DESCRIPTOR.message_types_by_name['InternalServerError']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_SETTRANSMITSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetTransmitStateRequest']
_SETTRANSMITSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetTransmitStateResponse']
_SETLINKSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetLinkStateRequest']
_SETLINKSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetLinkStateResponse']
_SETCAPTURESTATEREQUEST = DESCRIPTOR.message_types_by_name['SetCaptureStateRequest']
_SETCAPTURESTATERESPONSE = DESCRIPTOR.message_types_by_name['SetCaptureStateResponse']
_UPDATEFLOWSREQUEST = DESCRIPTOR.message_types_by_name['UpdateFlowsRequest']
_UPDATEFLOWSRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFlowsResponse']
_SETROUTESTATEREQUEST = DESCRIPTOR.message_types_by_name['SetRouteStateRequest']
_SETROUTESTATERESPONSE = DESCRIPTOR.message_types_by_name['SetRouteStateResponse']
_SENDPINGREQUEST = DESCRIPTOR.message_types_by_name['SendPingRequest']
_SENDPINGRESPONSE = DESCRIPTOR.message_types_by_name['SendPingResponse']
_SETPROTOCOLSTATEREQUEST = DESCRIPTOR.message_types_by_name['SetProtocolStateRequest']
_SETPROTOCOLSTATERESPONSE = DESCRIPTOR.message_types_by_name['SetProtocolStateResponse']
_GETMETRICSREQUEST = DESCRIPTOR.message_types_by_name['GetMetricsRequest']
_GETMETRICSRESPONSE = DESCRIPTOR.message_types_by_name['GetMetricsResponse']
_GETSTATESREQUEST = DESCRIPTOR.message_types_by_name['GetStatesRequest']
_GETSTATESRESPONSE = DESCRIPTOR.message_types_by_name['GetStatesResponse']
_GETCAPTUREREQUEST = DESCRIPTOR.message_types_by_name['GetCaptureRequest']
_GETCAPTURERESPONSE = DESCRIPTOR.message_types_by_name['GetCaptureResponse']
_LAGPROTOCOL_CHOICE_ENUM = _LAGPROTOCOL_CHOICE.enum_types_by_name['Enum']
_LAGLACP_ACTORACTIVITY_ENUM = _LAGLACP_ACTORACTIVITY.enum_types_by_name['Enum']
_DEVICEVLAN_TPID_ENUM = _DEVICEVLAN_TPID.enum_types_by_name['Enum']
_LAYER1_SPEED_ENUM = _LAYER1_SPEED.enum_types_by_name['Enum']
_LAYER1_MEDIA_ENUM = _LAYER1_MEDIA.enum_types_by_name['Enum']
_LAYER1FLOWCONTROL_CHOICE_ENUM = _LAYER1FLOWCONTROL_CHOICE.enum_types_by_name['Enum']
_CAPTURE_FORMAT_ENUM = _CAPTURE_FORMAT.enum_types_by_name['Enum']
_CAPTUREFILTER_CHOICE_ENUM = _CAPTUREFILTER_CHOICE.enum_types_by_name['Enum']
_ISISINTERFACE_NETWORKTYPE_ENUM = _ISISINTERFACE_NETWORKTYPE.enum_types_by_name['Enum']
_ISISINTERFACE_LEVELTYPE_ENUM = _ISISINTERFACE_LEVELTYPE.enum_types_by_name['Enum']
_ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM = _ISISINTERFACEAUTHENTICATION_AUTHTYPE.enum_types_by_name['Enum']
_ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM = _ISISAUTHENTICATIONBASE_AUTHTYPE.enum_types_by_name['Enum']
_ISISV4ROUTERANGE_ORIGINTYPE_ENUM = _ISISV4ROUTERANGE_ORIGINTYPE.enum_types_by_name['Enum']
_ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM = _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_ISISV6ROUTERANGE_ORIGINTYPE_ENUM = _ISISV6ROUTERANGE_ORIGINTYPE.enum_types_by_name['Enum']
_ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM = _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE.enum_types_by_name['Enum']
_BGPV4PEER_ASTYPE_ENUM = _BGPV4PEER_ASTYPE.enum_types_by_name['Enum']
_BGPV4PEER_ASNUMBERWIDTH_ENUM = _BGPV4PEER_ASNUMBERWIDTH.enum_types_by_name['Enum']
_BGPV4ROUTERANGE_NEXTHOPMODE_ENUM = _BGPV4ROUTERANGE_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM = _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPROUTEADVANCED_ORIGIN_ENUM = _BGPROUTEADVANCED_ORIGIN.enum_types_by_name['Enum']
_BGPCOMMUNITY_TYPE_ENUM = _BGPCOMMUNITY_TYPE.enum_types_by_name['Enum']
_BGPASPATH_ASSETMODE_ENUM = _BGPASPATH_ASSETMODE.enum_types_by_name['Enum']
_BGPASPATHSEGMENT_TYPE_ENUM = _BGPASPATHSEGMENT_TYPE.enum_types_by_name['Enum']
_BGPV6ROUTERANGE_NEXTHOPMODE_ENUM = _BGPV6ROUTERANGE_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM = _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPSRTEV4POLICY_NEXTHOPMODE_ENUM = _BGPSRTEV4POLICY_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM = _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPEXTCOMMUNITY_TYPE_ENUM = _BGPEXTCOMMUNITY_TYPE.enum_types_by_name['Enum']
_BGPEXTCOMMUNITY_SUBTYPE_ENUM = _BGPEXTCOMMUNITY_SUBTYPE.enum_types_by_name['Enum']
_BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM = _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY.enum_types_by_name['Enum']
_BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM = _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE.enum_types_by_name['Enum']
_BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM = _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY.enum_types_by_name['Enum']
_BGPSRTESEGMENT_SEGMENTTYPE_ENUM = _BGPSRTESEGMENT_SEGMENTTYPE.enum_types_by_name['Enum']
_BGPSRTEV6POLICY_NEXTHOPMODE_ENUM = _BGPSRTEV6POLICY_NEXTHOPMODE.enum_types_by_name['Enum']
_BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM = _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE.enum_types_by_name['Enum']
_BGPV6PEER_ASTYPE_ENUM = _BGPV6PEER_ASTYPE.enum_types_by_name['Enum']
_BGPV6PEER_ASNUMBERWIDTH_ENUM = _BGPV6PEER_ASNUMBERWIDTH.enum_types_by_name['Enum']
_FLOWTXRX_CHOICE_ENUM = _FLOWTXRX_CHOICE.enum_types_by_name['Enum']
_FLOWROUTER_MODE_ENUM = _FLOWROUTER_MODE.enum_types_by_name['Enum']
_FLOWHEADER_CHOICE_ENUM = _FLOWHEADER_CHOICE.enum_types_by_name['Enum']
_FLOWIPV4PRIORITY_CHOICE_ENUM = _FLOWIPV4PRIORITY_CHOICE.enum_types_by_name['Enum']
_FLOWICMP_CHOICE_ENUM = _FLOWICMP_CHOICE.enum_types_by_name['Enum']
_FLOWICMPV6_CHOICE_ENUM = _FLOWICMPV6_CHOICE.enum_types_by_name['Enum']
_FLOWSIZE_CHOICE_ENUM = _FLOWSIZE_CHOICE.enum_types_by_name['Enum']
_FLOWRATE_CHOICE_ENUM = _FLOWRATE_CHOICE.enum_types_by_name['Enum']
_FLOWDURATION_CHOICE_ENUM = _FLOWDURATION_CHOICE.enum_types_by_name['Enum']
_FLOWDELAY_CHOICE_ENUM = _FLOWDELAY_CHOICE.enum_types_by_name['Enum']
_FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM = _FLOWDURATIONINTERBURSTGAP_CHOICE.enum_types_by_name['Enum']
_FLOWLATENCYMETRICS_MODE_ENUM = _FLOWLATENCYMETRICS_MODE.enum_types_by_name['Enum']
_EVENTREQUEST_TYPE_ENUM = _EVENTREQUEST_TYPE.enum_types_by_name['Enum']
_LINKSTATE_STATE_ENUM = _LINKSTATE_STATE.enum_types_by_name['Enum']
_TRANSMITSTATE_STATE_ENUM = _TRANSMITSTATE_STATE.enum_types_by_name['Enum']
_CAPTURESTATE_STATE_ENUM = _CAPTURESTATE_STATE.enum_types_by_name['Enum']
_FLOWSUPDATE_PROPERTYNAMES_ENUM = _FLOWSUPDATE_PROPERTYNAMES.enum_types_by_name['Enum']
_ROUTESTATE_STATE_ENUM = _ROUTESTATE_STATE.enum_types_by_name['Enum']
_PROTOCOLSTATE_STATE_ENUM = _PROTOCOLSTATE_STATE.enum_types_by_name['Enum']
_PING_CHOICE_ENUM = _PING_CHOICE.enum_types_by_name['Enum']
_RESPONSE_RESULT_ENUM = _RESPONSE_RESULT.enum_types_by_name['Enum']
_METRICSREQUEST_CHOICE_ENUM = _METRICSREQUEST_CHOICE.enum_types_by_name['Enum']
_METRICSRESPONSE_CHOICE_ENUM = _METRICSRESPONSE_CHOICE.enum_types_by_name['Enum']
_PORTMETRICSREQUEST_COLUMNNAMES_ENUM = _PORTMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_PORTMETRIC_LINK_ENUM = _PORTMETRIC_LINK.enum_types_by_name['Enum']
_PORTMETRIC_CAPTURE_ENUM = _PORTMETRIC_CAPTURE.enum_types_by_name['Enum']
_FLOWMETRICSREQUEST_METRICNAMES_ENUM = _FLOWMETRICSREQUEST_METRICNAMES.enum_types_by_name['Enum']
_FLOWMETRICGROUPREQUEST_CHOICE_ENUM = _FLOWMETRICGROUPREQUEST_CHOICE.enum_types_by_name['Enum']
_FLOWMETRIC_TRANSMIT_ENUM = _FLOWMETRIC_TRANSMIT.enum_types_by_name['Enum']
_BGPV4METRICSREQUEST_COLUMNNAMES_ENUM = _BGPV4METRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_BGPV4METRIC_SESSIONSTATE_ENUM = _BGPV4METRIC_SESSIONSTATE.enum_types_by_name['Enum']
_BGPV6METRICSREQUEST_COLUMNNAMES_ENUM = _BGPV6METRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_BGPV6METRIC_SESSIONSTATE_ENUM = _BGPV6METRIC_SESSIONSTATE.enum_types_by_name['Enum']
_ISISMETRICSREQUEST_COLUMNNAMES_ENUM = _ISISMETRICSREQUEST_COLUMNNAMES.enum_types_by_name['Enum']
_STATESREQUEST_CHOICE_ENUM = _STATESREQUEST_CHOICE.enum_types_by_name['Enum']
_STATESRESPONSE_CHOICE_ENUM = _STATESRESPONSE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETDST_CHOICE_ENUM = _PATTERNFLOWETHERNETDST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETSRC_CHOICE_ENUM = _PATTERNFLOWETHERNETSRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM = _PATTERNFLOWETHERNETETHERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM = _PATTERNFLOWETHERNETPFCQUEUE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANPRIORITY_CHOICE_ENUM = _PATTERNFLOWVLANPRIORITY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANCFI_CHOICE_ENUM = _PATTERNFLOWVLANCFI_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANID_CHOICE_ENUM = _PATTERNFLOWVLANID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVLANTPID_CHOICE_ENUM = _PATTERNFLOWVLANTPID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANFLAGS_CHOICE_ENUM = _PATTERNFLOWVXLANFLAGS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM = _PATTERNFLOWVXLANRESERVED0_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANVNI_CHOICE_ENUM = _PATTERNFLOWVXLANVNI_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM = _PATTERNFLOWVXLANRESERVED1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4VERSION_CHOICE_ENUM = _PATTERNFLOWIPV4VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM = _PATTERNFLOWIPV4HEADERLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM = _PATTERNFLOWIPV4TOTALLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM = _PATTERNFLOWIPV4IDENTIFICATION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4RESERVED_CHOICE_ENUM = _PATTERNFLOWIPV4RESERVED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM = _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM = _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM = _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM = _PATTERNFLOWIPV4TIMETOLIVE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM = _PATTERNFLOWIPV4PROTOCOL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM = _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM = _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWIPV4SRC_CHOICE_ENUM = _PATTERNFLOWIPV4SRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DST_CHOICE_ENUM = _PATTERNFLOWIPV4DST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM = _PATTERNFLOWIPV4PRIORITYRAW_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM = _PATTERNFLOWIPV4DSCPPHB_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM = _PATTERNFLOWIPV4DSCPECN_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM = _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM = _PATTERNFLOWIPV4TOSDELAY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM = _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM = _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM = _PATTERNFLOWIPV4TOSMONETARY_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM = _PATTERNFLOWIPV4TOSUNUSED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6VERSION_CHOICE_ENUM = _PATTERNFLOWIPV6VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM = _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM = _PATTERNFLOWIPV6FLOWLABEL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM = _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM = _PATTERNFLOWIPV6NEXTHEADER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM = _PATTERNFLOWIPV6HOPLIMIT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6SRC_CHOICE_ENUM = _PATTERNFLOWIPV6SRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIPV6DST_CHOICE_ENUM = _PATTERNFLOWIPV6DST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEDST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM = _PATTERNFLOWPFCPAUSESRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM = _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM = _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM = _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSEDST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSESRC_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM = _PATTERNFLOWETHERNETPAUSETIME_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPSRCPORT_CHOICE_ENUM = _PATTERNFLOWTCPSRCPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPDSTPORT_CHOICE_ENUM = _PATTERNFLOWTCPDSTPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPSEQNUM_CHOICE_ENUM = _PATTERNFLOWTCPSEQNUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPACKNUM_CHOICE_ENUM = _PATTERNFLOWTCPACKNUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM = _PATTERNFLOWTCPDATAOFFSET_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPECNNS_CHOICE_ENUM = _PATTERNFLOWTCPECNNS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPECNCWR_CHOICE_ENUM = _PATTERNFLOWTCPECNCWR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPECNECHO_CHOICE_ENUM = _PATTERNFLOWTCPECNECHO_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLURG_CHOICE_ENUM = _PATTERNFLOWTCPCTLURG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLACK_CHOICE_ENUM = _PATTERNFLOWTCPCTLACK_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLPSH_CHOICE_ENUM = _PATTERNFLOWTCPCTLPSH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLRST_CHOICE_ENUM = _PATTERNFLOWTCPCTLRST_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLSYN_CHOICE_ENUM = _PATTERNFLOWTCPCTLSYN_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPCTLFIN_CHOICE_ENUM = _PATTERNFLOWTCPCTLFIN_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWTCPWINDOW_CHOICE_ENUM = _PATTERNFLOWTCPWINDOW_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPSRCPORT_CHOICE_ENUM = _PATTERNFLOWUDPSRCPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPDSTPORT_CHOICE_ENUM = _PATTERNFLOWUDPDSTPORT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPLENGTH_CHOICE_ENUM = _PATTERNFLOWUDPLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM = _PATTERNFLOWUDPCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM = _PATTERNFLOWUDPCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM = _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGRERESERVED0_CHOICE_ENUM = _PATTERNFLOWGRERESERVED0_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGREVERSION_CHOICE_ENUM = _PATTERNFLOWGREVERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGREPROTOCOL_CHOICE_ENUM = _PATTERNFLOWGREPROTOCOL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGRECHECKSUM_CHOICE_ENUM = _PATTERNFLOWGRECHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGRECHECKSUM_GENERATED_ENUM = _PATTERNFLOWGRECHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWGRERESERVED1_CHOICE_ENUM = _PATTERNFLOWGRERESERVED1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1VERSION_CHOICE_ENUM = _PATTERNFLOWGTPV1VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM = _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM = _PATTERNFLOWGTPV1RESERVED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV1EFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV1SFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV1PNFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM = _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM = _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1TEID_CHOICE_ENUM = _PATTERNFLOWGTPV1TEID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM = _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM = _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM = _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM = _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM = _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2VERSION_CHOICE_ENUM = _PATTERNFLOWGTPV2VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM = _PATTERNFLOWGTPV2TEIDFLAG_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM = _PATTERNFLOWGTPV2SPARE1_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM = _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM = _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2TEID_CHOICE_ENUM = _PATTERNFLOWGTPV2TEID_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM = _PATTERNFLOWGTPV2SPARE2_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM = _PATTERNFLOWARPHARDWARETYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM = _PATTERNFLOWARPPROTOCOLTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM = _PATTERNFLOWARPHARDWARELENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM = _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPOPERATION_CHOICE_ENUM = _PATTERNFLOWARPOPERATION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM = _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM = _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM = _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM = _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM = _PATTERNFLOWICMPECHOTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOCODE_CHOICE_ENUM = _PATTERNFLOWICMPECHOCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPECHOCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPECHOCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM = _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM = _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOCODE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM = _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM = _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWPPPADDRESS_CHOICE_ENUM = _PATTERNFLOWPPPADDRESS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPPPCONTROL_CHOICE_ENUM = _PATTERNFLOWPPPCONTROL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM = _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM = _PATTERNFLOWIGMPV1VERSION_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM = _PATTERNFLOWIGMPV1TYPE_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM = _PATTERNFLOWIGMPV1UNUSED_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM = _PATTERNFLOWIGMPV1CHECKSUM_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM = _PATTERNFLOWIGMPV1CHECKSUM_GENERATED.enum_types_by_name['Enum']
_PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM = _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSLABEL_CHOICE_ENUM = _PATTERNFLOWMPLSLABEL_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM = _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM = _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE.enum_types_by_name['Enum']
_PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM = _PATTERNFLOWMPLSTIMETOLIVE_CHOICE.enum_types_by_name['Enum']
Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Config)
  })
_sym_db.RegisterMessage(Config)

ConfigOptions = _reflection.GeneratedProtocolMessageType('ConfigOptions', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ConfigOptions)
  })
_sym_db.RegisterMessage(ConfigOptions)

Port = _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {
  'DESCRIPTOR' : _PORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Port)
  })
_sym_db.RegisterMessage(Port)

PortOptions = _reflection.GeneratedProtocolMessageType('PortOptions', (_message.Message,), {
  'DESCRIPTOR' : _PORTOPTIONS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortOptions)
  })
_sym_db.RegisterMessage(PortOptions)

Lag = _reflection.GeneratedProtocolMessageType('Lag', (_message.Message,), {
  'DESCRIPTOR' : _LAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Lag)
  })
_sym_db.RegisterMessage(Lag)

LagPort = _reflection.GeneratedProtocolMessageType('LagPort', (_message.Message,), {
  'DESCRIPTOR' : _LAGPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagPort)
  })
_sym_db.RegisterMessage(LagPort)

LagProtocol = _reflection.GeneratedProtocolMessageType('LagProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LAGPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _LAGPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagProtocol)
  })
_sym_db.RegisterMessage(LagProtocol)
_sym_db.RegisterMessage(LagProtocol.Choice)

LagStatic = _reflection.GeneratedProtocolMessageType('LagStatic', (_message.Message,), {
  'DESCRIPTOR' : _LAGSTATIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagStatic)
  })
_sym_db.RegisterMessage(LagStatic)

LagLacp = _reflection.GeneratedProtocolMessageType('LagLacp', (_message.Message,), {

  'ActorActivity' : _reflection.GeneratedProtocolMessageType('ActorActivity', (_message.Message,), {
    'DESCRIPTOR' : _LAGLACP_ACTORACTIVITY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LagLacp.ActorActivity)
    })
  ,
  'DESCRIPTOR' : _LAGLACP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LagLacp)
  })
_sym_db.RegisterMessage(LagLacp)
_sym_db.RegisterMessage(LagLacp.ActorActivity)

DeviceEthernetBase = _reflection.GeneratedProtocolMessageType('DeviceEthernetBase', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEETHERNETBASE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceEthernetBase)
  })
_sym_db.RegisterMessage(DeviceEthernetBase)

DeviceEthernet = _reflection.GeneratedProtocolMessageType('DeviceEthernet', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceEthernet)
  })
_sym_db.RegisterMessage(DeviceEthernet)

DeviceVlan = _reflection.GeneratedProtocolMessageType('DeviceVlan', (_message.Message,), {

  'Tpid' : _reflection.GeneratedProtocolMessageType('Tpid', (_message.Message,), {
    'DESCRIPTOR' : _DEVICEVLAN_TPID,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.DeviceVlan.Tpid)
    })
  ,
  'DESCRIPTOR' : _DEVICEVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceVlan)
  })
_sym_db.RegisterMessage(DeviceVlan)
_sym_db.RegisterMessage(DeviceVlan.Tpid)

DeviceIpv4 = _reflection.GeneratedProtocolMessageType('DeviceIpv4', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4)
  })
_sym_db.RegisterMessage(DeviceIpv4)

DeviceIpv4Loopback = _reflection.GeneratedProtocolMessageType('DeviceIpv4Loopback', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV4LOOPBACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv4Loopback)
  })
_sym_db.RegisterMessage(DeviceIpv4Loopback)

DeviceIpv6 = _reflection.GeneratedProtocolMessageType('DeviceIpv6', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6)
  })
_sym_db.RegisterMessage(DeviceIpv6)

DeviceIpv6Loopback = _reflection.GeneratedProtocolMessageType('DeviceIpv6Loopback', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIPV6LOOPBACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIpv6Loopback)
  })
_sym_db.RegisterMessage(DeviceIpv6Loopback)

Layer1 = _reflection.GeneratedProtocolMessageType('Layer1', (_message.Message,), {

  'Speed' : _reflection.GeneratedProtocolMessageType('Speed', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1_SPEED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1.Speed)
    })
  ,

  'Media' : _reflection.GeneratedProtocolMessageType('Media', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1_MEDIA,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1.Media)
    })
  ,
  'DESCRIPTOR' : _LAYER1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1)
  })
_sym_db.RegisterMessage(Layer1)
_sym_db.RegisterMessage(Layer1.Speed)
_sym_db.RegisterMessage(Layer1.Media)

Layer1AutoNegotiation = _reflection.GeneratedProtocolMessageType('Layer1AutoNegotiation', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1AUTONEGOTIATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1AutoNegotiation)
  })
_sym_db.RegisterMessage(Layer1AutoNegotiation)

Layer1FlowControl = _reflection.GeneratedProtocolMessageType('Layer1FlowControl', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _LAYER1FLOWCONTROL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Layer1FlowControl.Choice)
    })
  ,
  'DESCRIPTOR' : _LAYER1FLOWCONTROL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1FlowControl)
  })
_sym_db.RegisterMessage(Layer1FlowControl)
_sym_db.RegisterMessage(Layer1FlowControl.Choice)

Layer1Ieee8023x = _reflection.GeneratedProtocolMessageType('Layer1Ieee8023x', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1IEEE8023X,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1Ieee8023x)
  })
_sym_db.RegisterMessage(Layer1Ieee8023x)

Layer1Ieee8021qbb = _reflection.GeneratedProtocolMessageType('Layer1Ieee8021qbb', (_message.Message,), {
  'DESCRIPTOR' : _LAYER1IEEE8021QBB,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Layer1Ieee8021qbb)
  })
_sym_db.RegisterMessage(Layer1Ieee8021qbb)

Capture = _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), {

  'Format' : _reflection.GeneratedProtocolMessageType('Format', (_message.Message,), {
    'DESCRIPTOR' : _CAPTURE_FORMAT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Capture.Format)
    })
  ,
  'DESCRIPTOR' : _CAPTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Capture)
  })
_sym_db.RegisterMessage(Capture)
_sym_db.RegisterMessage(Capture.Format)

CaptureFilter = _reflection.GeneratedProtocolMessageType('CaptureFilter', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _CAPTUREFILTER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.CaptureFilter.Choice)
    })
  ,
  'DESCRIPTOR' : _CAPTUREFILTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureFilter)
  })
_sym_db.RegisterMessage(CaptureFilter)
_sym_db.RegisterMessage(CaptureFilter.Choice)

CaptureCustom = _reflection.GeneratedProtocolMessageType('CaptureCustom', (_message.Message,), {
  'DESCRIPTOR' : _CAPTURECUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureCustom)
  })
_sym_db.RegisterMessage(CaptureCustom)

CaptureField = _reflection.GeneratedProtocolMessageType('CaptureField', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREFIELD,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureField)
  })
_sym_db.RegisterMessage(CaptureField)

CaptureEthernet = _reflection.GeneratedProtocolMessageType('CaptureEthernet', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureEthernet)
  })
_sym_db.RegisterMessage(CaptureEthernet)

CaptureVlan = _reflection.GeneratedProtocolMessageType('CaptureVlan', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureVlan)
  })
_sym_db.RegisterMessage(CaptureVlan)

CaptureIpv4 = _reflection.GeneratedProtocolMessageType('CaptureIpv4', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureIpv4)
  })
_sym_db.RegisterMessage(CaptureIpv4)

CaptureIpv6 = _reflection.GeneratedProtocolMessageType('CaptureIpv6', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureIpv6)
  })
_sym_db.RegisterMessage(CaptureIpv6)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Device)
  })
_sym_db.RegisterMessage(Device)

DeviceIsisRouter = _reflection.GeneratedProtocolMessageType('DeviceIsisRouter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISISROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIsisRouter)
  })
_sym_db.RegisterMessage(DeviceIsisRouter)

DeviceIsisMultiInstance = _reflection.GeneratedProtocolMessageType('DeviceIsisMultiInstance', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISISMULTIINSTANCE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceIsisMultiInstance)
  })
_sym_db.RegisterMessage(DeviceIsisMultiInstance)

IsisInterface = _reflection.GeneratedProtocolMessageType('IsisInterface', (_message.Message,), {

  'NetworkType' : _reflection.GeneratedProtocolMessageType('NetworkType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACE_NETWORKTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterface.NetworkType)
    })
  ,

  'LevelType' : _reflection.GeneratedProtocolMessageType('LevelType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACE_LEVELTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterface.LevelType)
    })
  ,
  'DESCRIPTOR' : _ISISINTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterface)
  })
_sym_db.RegisterMessage(IsisInterface)
_sym_db.RegisterMessage(IsisInterface.NetworkType)
_sym_db.RegisterMessage(IsisInterface.LevelType)

IsisInterfaceLevel = _reflection.GeneratedProtocolMessageType('IsisInterfaceLevel', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACELEVEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceLevel)
  })
_sym_db.RegisterMessage(IsisInterfaceLevel)

IsisMT = _reflection.GeneratedProtocolMessageType('IsisMT', (_message.Message,), {
  'DESCRIPTOR' : _ISISMT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMT)
  })
_sym_db.RegisterMessage(IsisMT)

LinkStateTE = _reflection.GeneratedProtocolMessageType('LinkStateTE', (_message.Message,), {
  'DESCRIPTOR' : _LINKSTATETE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkStateTE)
  })
_sym_db.RegisterMessage(LinkStateTE)

LinkStatepriorityBandwidths = _reflection.GeneratedProtocolMessageType('LinkStatepriorityBandwidths', (_message.Message,), {
  'DESCRIPTOR' : _LINKSTATEPRIORITYBANDWIDTHS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkStatepriorityBandwidths)
  })
_sym_db.RegisterMessage(LinkStatepriorityBandwidths)

IsisInterfaceAuthentication = _reflection.GeneratedProtocolMessageType('IsisInterfaceAuthentication', (_message.Message,), {

  'AuthType' : _reflection.GeneratedProtocolMessageType('AuthType', (_message.Message,), {
    'DESCRIPTOR' : _ISISINTERFACEAUTHENTICATION_AUTHTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAuthentication.AuthType)
    })
  ,
  'DESCRIPTOR' : _ISISINTERFACEAUTHENTICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAuthentication)
  })
_sym_db.RegisterMessage(IsisInterfaceAuthentication)
_sym_db.RegisterMessage(IsisInterfaceAuthentication.AuthType)

IsisInterfaceAdvanced = _reflection.GeneratedProtocolMessageType('IsisInterfaceAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACEADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceAdvanced)
  })
_sym_db.RegisterMessage(IsisInterfaceAdvanced)

IsisInterfaceLinkProtection = _reflection.GeneratedProtocolMessageType('IsisInterfaceLinkProtection', (_message.Message,), {
  'DESCRIPTOR' : _ISISINTERFACELINKPROTECTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisInterfaceLinkProtection)
  })
_sym_db.RegisterMessage(IsisInterfaceLinkProtection)

IsisBasic = _reflection.GeneratedProtocolMessageType('IsisBasic', (_message.Message,), {
  'DESCRIPTOR' : _ISISBASIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisBasic)
  })
_sym_db.RegisterMessage(IsisBasic)

IsisAdvanced = _reflection.GeneratedProtocolMessageType('IsisAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _ISISADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAdvanced)
  })
_sym_db.RegisterMessage(IsisAdvanced)

IsisAuthentication = _reflection.GeneratedProtocolMessageType('IsisAuthentication', (_message.Message,), {
  'DESCRIPTOR' : _ISISAUTHENTICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAuthentication)
  })
_sym_db.RegisterMessage(IsisAuthentication)

IsisAuthenticationBase = _reflection.GeneratedProtocolMessageType('IsisAuthenticationBase', (_message.Message,), {

  'AuthType' : _reflection.GeneratedProtocolMessageType('AuthType', (_message.Message,), {
    'DESCRIPTOR' : _ISISAUTHENTICATIONBASE_AUTHTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisAuthenticationBase.AuthType)
    })
  ,
  'DESCRIPTOR' : _ISISAUTHENTICATIONBASE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisAuthenticationBase)
  })
_sym_db.RegisterMessage(IsisAuthenticationBase)
_sym_db.RegisterMessage(IsisAuthenticationBase.AuthType)

IsisV4RouteRange = _reflection.GeneratedProtocolMessageType('IsisV4RouteRange', (_message.Message,), {

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV4ROUTERANGE_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange.OriginType)
    })
  ,

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISV4ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisV4RouteRange)
  })
_sym_db.RegisterMessage(IsisV4RouteRange)
_sym_db.RegisterMessage(IsisV4RouteRange.OriginType)
_sym_db.RegisterMessage(IsisV4RouteRange.RedistributionType)

V4RouteAddress = _reflection.GeneratedProtocolMessageType('V4RouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _V4ROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.V4RouteAddress)
  })
_sym_db.RegisterMessage(V4RouteAddress)

V6RouteAddress = _reflection.GeneratedProtocolMessageType('V6RouteAddress', (_message.Message,), {
  'DESCRIPTOR' : _V6ROUTEADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.V6RouteAddress)
  })
_sym_db.RegisterMessage(V6RouteAddress)

IsisV6RouteRange = _reflection.GeneratedProtocolMessageType('IsisV6RouteRange', (_message.Message,), {

  'OriginType' : _reflection.GeneratedProtocolMessageType('OriginType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV6ROUTERANGE_ORIGINTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange.OriginType)
    })
  ,

  'RedistributionType' : _reflection.GeneratedProtocolMessageType('RedistributionType', (_message.Message,), {
    'DESCRIPTOR' : _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange.RedistributionType)
    })
  ,
  'DESCRIPTOR' : _ISISV6ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisV6RouteRange)
  })
_sym_db.RegisterMessage(IsisV6RouteRange)
_sym_db.RegisterMessage(IsisV6RouteRange.OriginType)
_sym_db.RegisterMessage(IsisV6RouteRange.RedistributionType)

DeviceBgpRouter = _reflection.GeneratedProtocolMessageType('DeviceBgpRouter', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEBGPROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.DeviceBgpRouter)
  })
_sym_db.RegisterMessage(DeviceBgpRouter)

BgpV4Peer = _reflection.GeneratedProtocolMessageType('BgpV4Peer', (_message.Message,), {

  'AsType' : _reflection.GeneratedProtocolMessageType('AsType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4PEER_ASTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4Peer.AsType)
    })
  ,

  'AsNumberWidth' : _reflection.GeneratedProtocolMessageType('AsNumberWidth', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4PEER_ASNUMBERWIDTH,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4Peer.AsNumberWidth)
    })
  ,
  'DESCRIPTOR' : _BGPV4PEER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4Peer)
  })
_sym_db.RegisterMessage(BgpV4Peer)
_sym_db.RegisterMessage(BgpV4Peer.AsType)
_sym_db.RegisterMessage(BgpV4Peer.AsNumberWidth)

BgpV4Interface = _reflection.GeneratedProtocolMessageType('BgpV4Interface', (_message.Message,), {
  'DESCRIPTOR' : _BGPV4INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4Interface)
  })
_sym_db.RegisterMessage(BgpV4Interface)

BgpAdvanced = _reflection.GeneratedProtocolMessageType('BgpAdvanced', (_message.Message,), {
  'DESCRIPTOR' : _BGPADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAdvanced)
  })
_sym_db.RegisterMessage(BgpAdvanced)

BgpCapability = _reflection.GeneratedProtocolMessageType('BgpCapability', (_message.Message,), {
  'DESCRIPTOR' : _BGPCAPABILITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCapability)
  })
_sym_db.RegisterMessage(BgpCapability)

BgpV4RouteRange = _reflection.GeneratedProtocolMessageType('BgpV4RouteRange', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ROUTERANGE_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPV4ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV4RouteRange)
  })
_sym_db.RegisterMessage(BgpV4RouteRange)
_sym_db.RegisterMessage(BgpV4RouteRange.NextHopMode)
_sym_db.RegisterMessage(BgpV4RouteRange.NextHopAddressType)

BgpRouteAdvanced = _reflection.GeneratedProtocolMessageType('BgpRouteAdvanced', (_message.Message,), {

  'Origin' : _reflection.GeneratedProtocolMessageType('Origin', (_message.Message,), {
    'DESCRIPTOR' : _BGPROUTEADVANCED_ORIGIN,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpRouteAdvanced.Origin)
    })
  ,
  'DESCRIPTOR' : _BGPROUTEADVANCED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpRouteAdvanced)
  })
_sym_db.RegisterMessage(BgpRouteAdvanced)
_sym_db.RegisterMessage(BgpRouteAdvanced.Origin)

BgpCommunity = _reflection.GeneratedProtocolMessageType('BgpCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpCommunity.Type)
    })
  ,
  'DESCRIPTOR' : _BGPCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpCommunity)
  })
_sym_db.RegisterMessage(BgpCommunity)
_sym_db.RegisterMessage(BgpCommunity.Type)

BgpAsPath = _reflection.GeneratedProtocolMessageType('BgpAsPath', (_message.Message,), {

  'AsSetMode' : _reflection.GeneratedProtocolMessageType('AsSetMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPASPATH_ASSETMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpAsPath.AsSetMode)
    })
  ,
  'DESCRIPTOR' : _BGPASPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAsPath)
  })
_sym_db.RegisterMessage(BgpAsPath)
_sym_db.RegisterMessage(BgpAsPath.AsSetMode)

BgpAsPathSegment = _reflection.GeneratedProtocolMessageType('BgpAsPathSegment', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPASPATHSEGMENT_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpAsPathSegment.Type)
    })
  ,
  'DESCRIPTOR' : _BGPASPATHSEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAsPathSegment)
  })
_sym_db.RegisterMessage(BgpAsPathSegment)
_sym_db.RegisterMessage(BgpAsPathSegment.Type)

BgpAddPath = _reflection.GeneratedProtocolMessageType('BgpAddPath', (_message.Message,), {
  'DESCRIPTOR' : _BGPADDPATH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpAddPath)
  })
_sym_db.RegisterMessage(BgpAddPath)

BgpV6RouteRange = _reflection.GeneratedProtocolMessageType('BgpV6RouteRange', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ROUTERANGE_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPV6ROUTERANGE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6RouteRange)
  })
_sym_db.RegisterMessage(BgpV6RouteRange)
_sym_db.RegisterMessage(BgpV6RouteRange.NextHopMode)
_sym_db.RegisterMessage(BgpV6RouteRange.NextHopAddressType)

BgpSrteV4Policy = _reflection.GeneratedProtocolMessageType('BgpSrteV4Policy', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV4POLICY_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEV4POLICY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV4Policy)
  })
_sym_db.RegisterMessage(BgpSrteV4Policy)
_sym_db.RegisterMessage(BgpSrteV4Policy.NextHopMode)
_sym_db.RegisterMessage(BgpSrteV4Policy.NextHopAddressType)

BgpExtCommunity = _reflection.GeneratedProtocolMessageType('BgpExtCommunity', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _BGPEXTCOMMUNITY_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity.Type)
    })
  ,

  'Subtype' : _reflection.GeneratedProtocolMessageType('Subtype', (_message.Message,), {
    'DESCRIPTOR' : _BGPEXTCOMMUNITY_SUBTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity.Subtype)
    })
  ,
  'DESCRIPTOR' : _BGPEXTCOMMUNITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpExtCommunity)
  })
_sym_db.RegisterMessage(BgpExtCommunity)
_sym_db.RegisterMessage(BgpExtCommunity.Type)
_sym_db.RegisterMessage(BgpExtCommunity.Subtype)

BgpSrteV4TunnelTlv = _reflection.GeneratedProtocolMessageType('BgpSrteV4TunnelTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEV4TUNNELTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV4TunnelTlv)
  })
_sym_db.RegisterMessage(BgpSrteV4TunnelTlv)

BgpSrteRemoteEndpointSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteRemoteEndpointSubTlv', (_message.Message,), {

  'AddressFamily' : _reflection.GeneratedProtocolMessageType('AddressFamily', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteRemoteEndpointSubTlv.AddressFamily)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEREMOTEENDPOINTSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteRemoteEndpointSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteRemoteEndpointSubTlv)
_sym_db.RegisterMessage(BgpSrteRemoteEndpointSubTlv.AddressFamily)

BgpSrteColorSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteColorSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTECOLORSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteColorSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteColorSubTlv)

BgpSrteBindingSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteBindingSubTlv', (_message.Message,), {

  'BindingSidType' : _reflection.GeneratedProtocolMessageType('BindingSidType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteBindingSubTlv.BindingSidType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEBINDINGSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteBindingSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteBindingSubTlv)
_sym_db.RegisterMessage(BgpSrteBindingSubTlv.BindingSidType)

BgpSrtePreferenceSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePreferenceSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPREFERENCESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePreferenceSubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePreferenceSubTlv)

BgpSrtePolicyPrioritySubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePolicyPrioritySubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPOLICYPRIORITYSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePolicyPrioritySubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePolicyPrioritySubTlv)

BgpSrtePolicyNameSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrtePolicyNameSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEPOLICYNAMESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrtePolicyNameSubTlv)
  })
_sym_db.RegisterMessage(BgpSrtePolicyNameSubTlv)

BgpSrteExplicitNullLabelPolicySubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteExplicitNullLabelPolicySubTlv', (_message.Message,), {

  'ExplicitNullLabelPolicy' : _reflection.GeneratedProtocolMessageType('ExplicitNullLabelPolicy', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteExplicitNullLabelPolicySubTlv)
  })
_sym_db.RegisterMessage(BgpSrteExplicitNullLabelPolicySubTlv)
_sym_db.RegisterMessage(BgpSrteExplicitNullLabelPolicySubTlv.ExplicitNullLabelPolicy)

BgpSrteSegmentList = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentList', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTLIST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentList)
  })
_sym_db.RegisterMessage(BgpSrteSegmentList)

BgpSrteSegment = _reflection.GeneratedProtocolMessageType('BgpSrteSegment', (_message.Message,), {

  'SegmentType' : _reflection.GeneratedProtocolMessageType('SegmentType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTESEGMENT_SEGMENTTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteSegment.SegmentType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTESEGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegment)
  })
_sym_db.RegisterMessage(BgpSrteSegment)
_sym_db.RegisterMessage(BgpSrteSegment.SegmentType)

BgpSrteSrMplsSid = _reflection.GeneratedProtocolMessageType('BgpSrteSrMplsSid', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESRMPLSSID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSrMplsSid)
  })
_sym_db.RegisterMessage(BgpSrteSrMplsSid)

BgpSrteSRv6SIDEndpointBehaviorAndStructure = _reflection.GeneratedProtocolMessageType('BgpSrteSRv6SIDEndpointBehaviorAndStructure', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSRv6SIDEndpointBehaviorAndStructure)
  })
_sym_db.RegisterMessage(BgpSrteSRv6SIDEndpointBehaviorAndStructure)

BgpSrteSegmentATypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentATypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTATYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentATypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentATypeSubTlv)

BgpSrteSegmentBTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentBTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTBTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentBTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentBTypeSubTlv)

BgpSrteSegmentCTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentCTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTCTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentCTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentCTypeSubTlv)

BgpSrteSegmentDTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentDTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTDTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentDTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentDTypeSubTlv)

BgpSrteSegmentETypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentETypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTETYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentETypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentETypeSubTlv)

BgpSrteSegmentFTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentFTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTFTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentFTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentFTypeSubTlv)

BgpSrteSegmentGTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentGTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTGTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentGTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentGTypeSubTlv)

BgpSrteSegmentHTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentHTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTHTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentHTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentHTypeSubTlv)

BgpSrteSegmentITypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentITypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTITYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentITypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentITypeSubTlv)

BgpSrteSegmentJTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentJTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTJTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentJTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentJTypeSubTlv)

BgpSrteSegmentKTypeSubTlv = _reflection.GeneratedProtocolMessageType('BgpSrteSegmentKTypeSubTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTESEGMENTKTYPESUBTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteSegmentKTypeSubTlv)
  })
_sym_db.RegisterMessage(BgpSrteSegmentKTypeSubTlv)

BgpSrteV6Policy = _reflection.GeneratedProtocolMessageType('BgpSrteV6Policy', (_message.Message,), {

  'NextHopMode' : _reflection.GeneratedProtocolMessageType('NextHopMode', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV6POLICY_NEXTHOPMODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy.NextHopMode)
    })
  ,

  'NextHopAddressType' : _reflection.GeneratedProtocolMessageType('NextHopAddressType', (_message.Message,), {
    'DESCRIPTOR' : _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy.NextHopAddressType)
    })
  ,
  'DESCRIPTOR' : _BGPSRTEV6POLICY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV6Policy)
  })
_sym_db.RegisterMessage(BgpSrteV6Policy)
_sym_db.RegisterMessage(BgpSrteV6Policy.NextHopMode)
_sym_db.RegisterMessage(BgpSrteV6Policy.NextHopAddressType)

BgpSrteV6TunnelTlv = _reflection.GeneratedProtocolMessageType('BgpSrteV6TunnelTlv', (_message.Message,), {
  'DESCRIPTOR' : _BGPSRTEV6TUNNELTLV,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpSrteV6TunnelTlv)
  })
_sym_db.RegisterMessage(BgpSrteV6TunnelTlv)

BgpV6Peer = _reflection.GeneratedProtocolMessageType('BgpV6Peer', (_message.Message,), {

  'AsType' : _reflection.GeneratedProtocolMessageType('AsType', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6PEER_ASTYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6Peer.AsType)
    })
  ,

  'AsNumberWidth' : _reflection.GeneratedProtocolMessageType('AsNumberWidth', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6PEER_ASNUMBERWIDTH,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.BgpV6Peer.AsNumberWidth)
    })
  ,
  'DESCRIPTOR' : _BGPV6PEER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6Peer)
  })
_sym_db.RegisterMessage(BgpV6Peer)
_sym_db.RegisterMessage(BgpV6Peer.AsType)
_sym_db.RegisterMessage(BgpV6Peer.AsNumberWidth)

BgpV6Interface = _reflection.GeneratedProtocolMessageType('BgpV6Interface', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6INTERFACE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6Interface)
  })
_sym_db.RegisterMessage(BgpV6Interface)

BgpV6SegmentRouting = _reflection.GeneratedProtocolMessageType('BgpV6SegmentRouting', (_message.Message,), {
  'DESCRIPTOR' : _BGPV6SEGMENTROUTING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BgpV6SegmentRouting)
  })
_sym_db.RegisterMessage(BgpV6SegmentRouting)

Flow = _reflection.GeneratedProtocolMessageType('Flow', (_message.Message,), {
  'DESCRIPTOR' : _FLOW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Flow)
  })
_sym_db.RegisterMessage(Flow)

FlowTxRx = _reflection.GeneratedProtocolMessageType('FlowTxRx', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWTXRX_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowTxRx.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWTXRX,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTxRx)
  })
_sym_db.RegisterMessage(FlowTxRx)
_sym_db.RegisterMessage(FlowTxRx.Choice)

FlowPort = _reflection.GeneratedProtocolMessageType('FlowPort', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPort)
  })
_sym_db.RegisterMessage(FlowPort)

FlowRouter = _reflection.GeneratedProtocolMessageType('FlowRouter', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FLOWROUTER_MODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRouter.Mode)
    })
  ,
  'DESCRIPTOR' : _FLOWROUTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRouter)
  })
_sym_db.RegisterMessage(FlowRouter)
_sym_db.RegisterMessage(FlowRouter.Mode)

FlowHeader = _reflection.GeneratedProtocolMessageType('FlowHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowHeader)
  })
_sym_db.RegisterMessage(FlowHeader)
_sym_db.RegisterMessage(FlowHeader.Choice)

FlowCustom = _reflection.GeneratedProtocolMessageType('FlowCustom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCUSTOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowCustom)
  })
_sym_db.RegisterMessage(FlowCustom)

FlowEthernet = _reflection.GeneratedProtocolMessageType('FlowEthernet', (_message.Message,), {
  'DESCRIPTOR' : _FLOWETHERNET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowEthernet)
  })
_sym_db.RegisterMessage(FlowEthernet)

FlowVlan = _reflection.GeneratedProtocolMessageType('FlowVlan', (_message.Message,), {
  'DESCRIPTOR' : _FLOWVLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowVlan)
  })
_sym_db.RegisterMessage(FlowVlan)

FlowVxlan = _reflection.GeneratedProtocolMessageType('FlowVxlan', (_message.Message,), {
  'DESCRIPTOR' : _FLOWVXLAN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowVxlan)
  })
_sym_db.RegisterMessage(FlowVxlan)

FlowIpv4 = _reflection.GeneratedProtocolMessageType('FlowIpv4', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4)
  })
_sym_db.RegisterMessage(FlowIpv4)

FlowIpv4Priority = _reflection.GeneratedProtocolMessageType('FlowIpv4Priority', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWIPV4PRIORITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIpv4Priority.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWIPV4PRIORITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Priority)
  })
_sym_db.RegisterMessage(FlowIpv4Priority)
_sym_db.RegisterMessage(FlowIpv4Priority.Choice)

FlowIpv4Dscp = _reflection.GeneratedProtocolMessageType('FlowIpv4Dscp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4DSCP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Dscp)
  })
_sym_db.RegisterMessage(FlowIpv4Dscp)

FlowIpv4Tos = _reflection.GeneratedProtocolMessageType('FlowIpv4Tos', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV4TOS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv4Tos)
  })
_sym_db.RegisterMessage(FlowIpv4Tos)

FlowIpv6 = _reflection.GeneratedProtocolMessageType('FlowIpv6', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIpv6)
  })
_sym_db.RegisterMessage(FlowIpv6)

FlowPfcPause = _reflection.GeneratedProtocolMessageType('FlowPfcPause', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPFCPAUSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPfcPause)
  })
_sym_db.RegisterMessage(FlowPfcPause)

FlowEthernetPause = _reflection.GeneratedProtocolMessageType('FlowEthernetPause', (_message.Message,), {
  'DESCRIPTOR' : _FLOWETHERNETPAUSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowEthernetPause)
  })
_sym_db.RegisterMessage(FlowEthernetPause)

FlowTcp = _reflection.GeneratedProtocolMessageType('FlowTcp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWTCP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowTcp)
  })
_sym_db.RegisterMessage(FlowTcp)

FlowUdp = _reflection.GeneratedProtocolMessageType('FlowUdp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWUDP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowUdp)
  })
_sym_db.RegisterMessage(FlowUdp)

FlowGre = _reflection.GeneratedProtocolMessageType('FlowGre', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGRE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGre)
  })
_sym_db.RegisterMessage(FlowGre)

FlowGtpv1 = _reflection.GeneratedProtocolMessageType('FlowGtpv1', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPV1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpv1)
  })
_sym_db.RegisterMessage(FlowGtpv1)

FlowGtpExtension = _reflection.GeneratedProtocolMessageType('FlowGtpExtension', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPEXTENSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpExtension)
  })
_sym_db.RegisterMessage(FlowGtpExtension)

FlowGtpv2 = _reflection.GeneratedProtocolMessageType('FlowGtpv2', (_message.Message,), {
  'DESCRIPTOR' : _FLOWGTPV2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowGtpv2)
  })
_sym_db.RegisterMessage(FlowGtpv2)

FlowArp = _reflection.GeneratedProtocolMessageType('FlowArp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWARP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowArp)
  })
_sym_db.RegisterMessage(FlowArp)

FlowIcmp = _reflection.GeneratedProtocolMessageType('FlowIcmp', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWICMP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIcmp.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWICMP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmp)
  })
_sym_db.RegisterMessage(FlowIcmp)
_sym_db.RegisterMessage(FlowIcmp.Choice)

FlowIcmpEcho = _reflection.GeneratedProtocolMessageType('FlowIcmpEcho', (_message.Message,), {
  'DESCRIPTOR' : _FLOWICMPECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpEcho)
  })
_sym_db.RegisterMessage(FlowIcmpEcho)

FlowIcmpv6 = _reflection.GeneratedProtocolMessageType('FlowIcmpv6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWICMPV6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWICMPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6)
  })
_sym_db.RegisterMessage(FlowIcmpv6)
_sym_db.RegisterMessage(FlowIcmpv6.Choice)

FlowIcmpv6Echo = _reflection.GeneratedProtocolMessageType('FlowIcmpv6Echo', (_message.Message,), {
  'DESCRIPTOR' : _FLOWICMPV6ECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIcmpv6Echo)
  })
_sym_db.RegisterMessage(FlowIcmpv6Echo)

FlowPpp = _reflection.GeneratedProtocolMessageType('FlowPpp', (_message.Message,), {
  'DESCRIPTOR' : _FLOWPPP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowPpp)
  })
_sym_db.RegisterMessage(FlowPpp)

FlowIgmpv1 = _reflection.GeneratedProtocolMessageType('FlowIgmpv1', (_message.Message,), {
  'DESCRIPTOR' : _FLOWIGMPV1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowIgmpv1)
  })
_sym_db.RegisterMessage(FlowIgmpv1)

FlowMpls = _reflection.GeneratedProtocolMessageType('FlowMpls', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMPLS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMpls)
  })
_sym_db.RegisterMessage(FlowMpls)

FlowSize = _reflection.GeneratedProtocolMessageType('FlowSize', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSIZE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowSize.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWSIZE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSize)
  })
_sym_db.RegisterMessage(FlowSize)
_sym_db.RegisterMessage(FlowSize.Choice)

FlowSizeIncrement = _reflection.GeneratedProtocolMessageType('FlowSizeIncrement', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZEINCREMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeIncrement)
  })
_sym_db.RegisterMessage(FlowSizeIncrement)

FlowSizeRandom = _reflection.GeneratedProtocolMessageType('FlowSizeRandom', (_message.Message,), {
  'DESCRIPTOR' : _FLOWSIZERANDOM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowSizeRandom)
  })
_sym_db.RegisterMessage(FlowSizeRandom)

FlowRate = _reflection.GeneratedProtocolMessageType('FlowRate', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWRATE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowRate.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWRATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowRate)
  })
_sym_db.RegisterMessage(FlowRate)
_sym_db.RegisterMessage(FlowRate.Choice)

FlowDuration = _reflection.GeneratedProtocolMessageType('FlowDuration', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDURATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDuration.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDURATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDuration)
  })
_sym_db.RegisterMessage(FlowDuration)
_sym_db.RegisterMessage(FlowDuration.Choice)

FlowContinuous = _reflection.GeneratedProtocolMessageType('FlowContinuous', (_message.Message,), {
  'DESCRIPTOR' : _FLOWCONTINUOUS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowContinuous)
  })
_sym_db.RegisterMessage(FlowContinuous)

FlowDelay = _reflection.GeneratedProtocolMessageType('FlowDelay', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDELAY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDelay.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDELAY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDelay)
  })
_sym_db.RegisterMessage(FlowDelay)
_sym_db.RegisterMessage(FlowDelay.Choice)

FlowFixedPackets = _reflection.GeneratedProtocolMessageType('FlowFixedPackets', (_message.Message,), {
  'DESCRIPTOR' : _FLOWFIXEDPACKETS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowFixedPackets)
  })
_sym_db.RegisterMessage(FlowFixedPackets)

FlowFixedSeconds = _reflection.GeneratedProtocolMessageType('FlowFixedSeconds', (_message.Message,), {
  'DESCRIPTOR' : _FLOWFIXEDSECONDS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowFixedSeconds)
  })
_sym_db.RegisterMessage(FlowFixedSeconds)

FlowBurst = _reflection.GeneratedProtocolMessageType('FlowBurst', (_message.Message,), {
  'DESCRIPTOR' : _FLOWBURST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowBurst)
  })
_sym_db.RegisterMessage(FlowBurst)

FlowDurationInterBurstGap = _reflection.GeneratedProtocolMessageType('FlowDurationInterBurstGap', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWDURATIONINTERBURSTGAP_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowDurationInterBurstGap.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWDURATIONINTERBURSTGAP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowDurationInterBurstGap)
  })
_sym_db.RegisterMessage(FlowDurationInterBurstGap)
_sym_db.RegisterMessage(FlowDurationInterBurstGap.Choice)

FlowMetrics = _reflection.GeneratedProtocolMessageType('FlowMetrics', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetrics)
  })
_sym_db.RegisterMessage(FlowMetrics)

FlowLatencyMetrics = _reflection.GeneratedProtocolMessageType('FlowLatencyMetrics', (_message.Message,), {

  'Mode' : _reflection.GeneratedProtocolMessageType('Mode', (_message.Message,), {
    'DESCRIPTOR' : _FLOWLATENCYMETRICS_MODE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowLatencyMetrics.Mode)
    })
  ,
  'DESCRIPTOR' : _FLOWLATENCYMETRICS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowLatencyMetrics)
  })
_sym_db.RegisterMessage(FlowLatencyMetrics)
_sym_db.RegisterMessage(FlowLatencyMetrics.Mode)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Event)
  })
_sym_db.RegisterMessage(Event)

EventRxRateThreshold = _reflection.GeneratedProtocolMessageType('EventRxRateThreshold', (_message.Message,), {
  'DESCRIPTOR' : _EVENTRXRATETHRESHOLD,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRxRateThreshold)
  })
_sym_db.RegisterMessage(EventRxRateThreshold)

EventLink = _reflection.GeneratedProtocolMessageType('EventLink', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLINK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventLink)
  })
_sym_db.RegisterMessage(EventLink)

EventRouteAdvertiseWithdraw = _reflection.GeneratedProtocolMessageType('EventRouteAdvertiseWithdraw', (_message.Message,), {
  'DESCRIPTOR' : _EVENTROUTEADVERTISEWITHDRAW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRouteAdvertiseWithdraw)
  })
_sym_db.RegisterMessage(EventRouteAdvertiseWithdraw)

EventRequest = _reflection.GeneratedProtocolMessageType('EventRequest', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _EVENTREQUEST_TYPE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.EventRequest.Type)
    })
  ,
  'DESCRIPTOR' : _EVENTREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventRequest)
  })
_sym_db.RegisterMessage(EventRequest)
_sym_db.RegisterMessage(EventRequest.Type)

EventSubscription = _reflection.GeneratedProtocolMessageType('EventSubscription', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSUBSCRIPTION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.EventSubscription)
  })
_sym_db.RegisterMessage(EventSubscription)

ResponseError = _reflection.GeneratedProtocolMessageType('ResponseError', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResponseError)
  })
_sym_db.RegisterMessage(ResponseError)

ResponseWarning = _reflection.GeneratedProtocolMessageType('ResponseWarning', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSEWARNING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ResponseWarning)
  })
_sym_db.RegisterMessage(ResponseWarning)

LinkState = _reflection.GeneratedProtocolMessageType('LinkState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _LINKSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.LinkState.State)
    })
  ,
  'DESCRIPTOR' : _LINKSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.LinkState)
  })
_sym_db.RegisterMessage(LinkState)
_sym_db.RegisterMessage(LinkState.State)

TransmitState = _reflection.GeneratedProtocolMessageType('TransmitState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _TRANSMITSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.TransmitState.State)
    })
  ,
  'DESCRIPTOR' : _TRANSMITSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.TransmitState)
  })
_sym_db.RegisterMessage(TransmitState)
_sym_db.RegisterMessage(TransmitState.State)

CaptureState = _reflection.GeneratedProtocolMessageType('CaptureState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _CAPTURESTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.CaptureState.State)
    })
  ,
  'DESCRIPTOR' : _CAPTURESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureState)
  })
_sym_db.RegisterMessage(CaptureState)
_sym_db.RegisterMessage(CaptureState.State)

FlowsUpdate = _reflection.GeneratedProtocolMessageType('FlowsUpdate', (_message.Message,), {

  'PropertyNames' : _reflection.GeneratedProtocolMessageType('PropertyNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWSUPDATE_PROPERTYNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowsUpdate.PropertyNames)
    })
  ,
  'DESCRIPTOR' : _FLOWSUPDATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowsUpdate)
  })
_sym_db.RegisterMessage(FlowsUpdate)
_sym_db.RegisterMessage(FlowsUpdate.PropertyNames)

RouteState = _reflection.GeneratedProtocolMessageType('RouteState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _ROUTESTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.RouteState.State)
    })
  ,
  'DESCRIPTOR' : _ROUTESTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.RouteState)
  })
_sym_db.RegisterMessage(RouteState)
_sym_db.RegisterMessage(RouteState.State)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

ProtocolState = _reflection.GeneratedProtocolMessageType('ProtocolState', (_message.Message,), {

  'State' : _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
    'DESCRIPTOR' : _PROTOCOLSTATE_STATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.ProtocolState.State)
    })
  ,
  'DESCRIPTOR' : _PROTOCOLSTATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.ProtocolState)
  })
_sym_db.RegisterMessage(ProtocolState)
_sym_db.RegisterMessage(ProtocolState.State)

Ping = _reflection.GeneratedProtocolMessageType('Ping', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PING_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Ping.Choice)
    })
  ,
  'DESCRIPTOR' : _PING,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Ping)
  })
_sym_db.RegisterMessage(Ping)
_sym_db.RegisterMessage(Ping.Choice)

PingIpv4 = _reflection.GeneratedProtocolMessageType('PingIpv4', (_message.Message,), {
  'DESCRIPTOR' : _PINGIPV4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingIpv4)
  })
_sym_db.RegisterMessage(PingIpv4)

PingIpv6 = _reflection.GeneratedProtocolMessageType('PingIpv6', (_message.Message,), {
  'DESCRIPTOR' : _PINGIPV6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingIpv6)
  })
_sym_db.RegisterMessage(PingIpv6)

PingResponse = _reflection.GeneratedProtocolMessageType('PingResponse', (_message.Message,), {
  'DESCRIPTOR' : _PINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PingResponse)
  })
_sym_db.RegisterMessage(PingResponse)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {

  'Result' : _reflection.GeneratedProtocolMessageType('Result', (_message.Message,), {
    'DESCRIPTOR' : _RESPONSE_RESULT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Response.Result)
    })
  ,
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Response)
  })
_sym_db.RegisterMessage(Response)
_sym_db.RegisterMessage(Response.Result)

MetricsRequest = _reflection.GeneratedProtocolMessageType('MetricsRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _METRICSREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.MetricsRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricsRequest)
  })
_sym_db.RegisterMessage(MetricsRequest)
_sym_db.RegisterMessage(MetricsRequest.Choice)

MetricsResponse = _reflection.GeneratedProtocolMessageType('MetricsResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _METRICSRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.MetricsResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _METRICSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricsResponse)
  })
_sym_db.RegisterMessage(MetricsResponse)
_sym_db.RegisterMessage(MetricsResponse.Choice)

PortMetricsRequest = _reflection.GeneratedProtocolMessageType('PortMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _PORTMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortMetricsRequest)
  })
_sym_db.RegisterMessage(PortMetricsRequest)
_sym_db.RegisterMessage(PortMetricsRequest.ColumnNames)

PortMetric = _reflection.GeneratedProtocolMessageType('PortMetric', (_message.Message,), {

  'Link' : _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_LINK,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Link)
    })
  ,

  'Capture' : _reflection.GeneratedProtocolMessageType('Capture', (_message.Message,), {
    'DESCRIPTOR' : _PORTMETRIC_CAPTURE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PortMetric.Capture)
    })
  ,
  'DESCRIPTOR' : _PORTMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PortMetric)
  })
_sym_db.RegisterMessage(PortMetric)
_sym_db.RegisterMessage(PortMetric.Link)
_sym_db.RegisterMessage(PortMetric.Capture)

FlowMetricsRequest = _reflection.GeneratedProtocolMessageType('FlowMetricsRequest', (_message.Message,), {

  'MetricNames' : _reflection.GeneratedProtocolMessageType('MetricNames', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRICSREQUEST_METRICNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetricsRequest.MetricNames)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricsRequest)
  })
_sym_db.RegisterMessage(FlowMetricsRequest)
_sym_db.RegisterMessage(FlowMetricsRequest.MetricNames)

FlowMetricGroupRequest = _reflection.GeneratedProtocolMessageType('FlowMetricGroupRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRICGROUPREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetricGroupRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRICGROUPREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricGroupRequest)
  })
_sym_db.RegisterMessage(FlowMetricGroupRequest)
_sym_db.RegisterMessage(FlowMetricGroupRequest.Choice)

FlowMetric = _reflection.GeneratedProtocolMessageType('FlowMetric', (_message.Message,), {

  'Transmit' : _reflection.GeneratedProtocolMessageType('Transmit', (_message.Message,), {
    'DESCRIPTOR' : _FLOWMETRIC_TRANSMIT,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.FlowMetric.Transmit)
    })
  ,
  'DESCRIPTOR' : _FLOWMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetric)
  })
_sym_db.RegisterMessage(FlowMetric)
_sym_db.RegisterMessage(FlowMetric.Transmit)

FlowMetricGroup = _reflection.GeneratedProtocolMessageType('FlowMetricGroup', (_message.Message,), {
  'DESCRIPTOR' : _FLOWMETRICGROUP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.FlowMetricGroup)
  })
_sym_db.RegisterMessage(FlowMetricGroup)

MetricTimestamp = _reflection.GeneratedProtocolMessageType('MetricTimestamp', (_message.Message,), {
  'DESCRIPTOR' : _METRICTIMESTAMP,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricTimestamp)
  })
_sym_db.RegisterMessage(MetricTimestamp)

MetricLatency = _reflection.GeneratedProtocolMessageType('MetricLatency', (_message.Message,), {
  'DESCRIPTOR' : _METRICLATENCY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.MetricLatency)
  })
_sym_db.RegisterMessage(MetricLatency)

Bgpv4MetricsRequest = _reflection.GeneratedProtocolMessageType('Bgpv4MetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4MetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _BGPV4METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv4MetricsRequest)
  })
_sym_db.RegisterMessage(Bgpv4MetricsRequest)
_sym_db.RegisterMessage(Bgpv4MetricsRequest.ColumnNames)

Bgpv4Metric = _reflection.GeneratedProtocolMessageType('Bgpv4Metric', (_message.Message,), {

  'SessionState' : _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV4METRIC_SESSIONSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric.SessionState)
    })
  ,
  'DESCRIPTOR' : _BGPV4METRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv4Metric)
  })
_sym_db.RegisterMessage(Bgpv4Metric)
_sym_db.RegisterMessage(Bgpv4Metric.SessionState)

Bgpv6MetricsRequest = _reflection.GeneratedProtocolMessageType('Bgpv6MetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6MetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _BGPV6METRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv6MetricsRequest)
  })
_sym_db.RegisterMessage(Bgpv6MetricsRequest)
_sym_db.RegisterMessage(Bgpv6MetricsRequest.ColumnNames)

Bgpv6Metric = _reflection.GeneratedProtocolMessageType('Bgpv6Metric', (_message.Message,), {

  'SessionState' : _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
    'DESCRIPTOR' : _BGPV6METRIC_SESSIONSTATE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric.SessionState)
    })
  ,
  'DESCRIPTOR' : _BGPV6METRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Bgpv6Metric)
  })
_sym_db.RegisterMessage(Bgpv6Metric)
_sym_db.RegisterMessage(Bgpv6Metric.SessionState)

IsisMetricsRequest = _reflection.GeneratedProtocolMessageType('IsisMetricsRequest', (_message.Message,), {

  'ColumnNames' : _reflection.GeneratedProtocolMessageType('ColumnNames', (_message.Message,), {
    'DESCRIPTOR' : _ISISMETRICSREQUEST_COLUMNNAMES,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.IsisMetricsRequest.ColumnNames)
    })
  ,
  'DESCRIPTOR' : _ISISMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMetricsRequest)
  })
_sym_db.RegisterMessage(IsisMetricsRequest)
_sym_db.RegisterMessage(IsisMetricsRequest.ColumnNames)

IsisMetric = _reflection.GeneratedProtocolMessageType('IsisMetric', (_message.Message,), {
  'DESCRIPTOR' : _ISISMETRIC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.IsisMetric)
  })
_sym_db.RegisterMessage(IsisMetric)

StatesRequest = _reflection.GeneratedProtocolMessageType('StatesRequest', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATESREQUEST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatesRequest.Choice)
    })
  ,
  'DESCRIPTOR' : _STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatesRequest)
  })
_sym_db.RegisterMessage(StatesRequest)
_sym_db.RegisterMessage(StatesRequest.Choice)

StatesResponse = _reflection.GeneratedProtocolMessageType('StatesResponse', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _STATESRESPONSE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.StatesResponse.Choice)
    })
  ,
  'DESCRIPTOR' : _STATESRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.StatesResponse)
  })
_sym_db.RegisterMessage(StatesResponse)
_sym_db.RegisterMessage(StatesResponse.Choice)

Neighborsv4StatesRequest = _reflection.GeneratedProtocolMessageType('Neighborsv4StatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV4STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv4StatesRequest)
  })
_sym_db.RegisterMessage(Neighborsv4StatesRequest)

Neighborsv4State = _reflection.GeneratedProtocolMessageType('Neighborsv4State', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV4STATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv4State)
  })
_sym_db.RegisterMessage(Neighborsv4State)

Neighborsv6StatesRequest = _reflection.GeneratedProtocolMessageType('Neighborsv6StatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV6STATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv6StatesRequest)
  })
_sym_db.RegisterMessage(Neighborsv6StatesRequest)

Neighborsv6State = _reflection.GeneratedProtocolMessageType('Neighborsv6State', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORSV6STATE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Neighborsv6State)
  })
_sym_db.RegisterMessage(Neighborsv6State)

CaptureRequest = _reflection.GeneratedProtocolMessageType('CaptureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CAPTUREREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.CaptureRequest)
  })
_sym_db.RegisterMessage(CaptureRequest)

PatternFlowEthernetDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDstCounter)

PatternFlowEthernetDst = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetDst)
  })
_sym_db.RegisterMessage(PatternFlowEthernetDst)
_sym_db.RegisterMessage(PatternFlowEthernetDst.Choice)

PatternFlowEthernetSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrcCounter)

PatternFlowEthernetSrc = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETSRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETSRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetSrc)
  })
_sym_db.RegisterMessage(PatternFlowEthernetSrc)
_sym_db.RegisterMessage(PatternFlowEthernetSrc.Choice)

PatternFlowEthernetEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherTypeCounter)

PatternFlowEthernetEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetEtherType)
  })
_sym_db.RegisterMessage(PatternFlowEthernetEtherType)
_sym_db.RegisterMessage(PatternFlowEthernetEtherType.Choice)

PatternFlowEthernetPfcQueueCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueueCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueueCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueueCounter)

PatternFlowEthernetPfcQueue = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPfcQueue', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueue.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPFCQUEUE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPfcQueue)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueue)
_sym_db.RegisterMessage(PatternFlowEthernetPfcQueue.Choice)

PatternFlowVlanPriorityCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriorityCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriorityCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriorityCounter)

PatternFlowVlanPriority = _reflection.GeneratedProtocolMessageType('PatternFlowVlanPriority', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriority.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANPRIORITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanPriority)
  })
_sym_db.RegisterMessage(PatternFlowVlanPriority)
_sym_db.RegisterMessage(PatternFlowVlanPriority.Choice)

PatternFlowVlanCfiCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfiCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANCFICOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfiCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfiCounter)

PatternFlowVlanCfi = _reflection.GeneratedProtocolMessageType('PatternFlowVlanCfi', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANCFI_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfi.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANCFI,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanCfi)
  })
_sym_db.RegisterMessage(PatternFlowVlanCfi)
_sym_db.RegisterMessage(PatternFlowVlanCfi.Choice)

PatternFlowVlanIdCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanIdCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanIdCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanIdCounter)

PatternFlowVlanId = _reflection.GeneratedProtocolMessageType('PatternFlowVlanId', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanId.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanId)
  })
_sym_db.RegisterMessage(PatternFlowVlanId)
_sym_db.RegisterMessage(PatternFlowVlanId.Choice)

PatternFlowVlanTpidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVLANTPIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpidCounter)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpidCounter)

PatternFlowVlanTpid = _reflection.GeneratedProtocolMessageType('PatternFlowVlanTpid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVLANTPID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVLANTPID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVlanTpid)
  })
_sym_db.RegisterMessage(PatternFlowVlanTpid)
_sym_db.RegisterMessage(PatternFlowVlanTpid.Choice)

PatternFlowVxlanFlagsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlagsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlagsCounter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlagsCounter)

PatternFlowVxlanFlags = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanFlags', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlags.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANFLAGS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanFlags)
  })
_sym_db.RegisterMessage(PatternFlowVxlanFlags)
_sym_db.RegisterMessage(PatternFlowVxlanFlags.Choice)

PatternFlowVxlanReserved0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0Counter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0Counter)

PatternFlowVxlanReserved0 = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved0)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved0)
_sym_db.RegisterMessage(PatternFlowVxlanReserved0.Choice)

PatternFlowVxlanVniCounter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVniCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNICOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVniCounter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVniCounter)

PatternFlowVxlanVni = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanVni', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANVNI_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVni.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANVNI,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanVni)
  })
_sym_db.RegisterMessage(PatternFlowVxlanVni)
_sym_db.RegisterMessage(PatternFlowVxlanVni.Choice)

PatternFlowVxlanReserved1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1Counter)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1Counter)

PatternFlowVxlanReserved1 = _reflection.GeneratedProtocolMessageType('PatternFlowVxlanReserved1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWVXLANRESERVED1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowVxlanReserved1)
  })
_sym_db.RegisterMessage(PatternFlowVxlanReserved1)
_sym_db.RegisterMessage(PatternFlowVxlanReserved1.Choice)

PatternFlowIpv4VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4VersionCounter)

PatternFlowIpv4Version = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Version)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Version)
_sym_db.RegisterMessage(PatternFlowIpv4Version.Choice)

PatternFlowIpv4HeaderLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLengthCounter)

PatternFlowIpv4HeaderLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderLength.Choice)

PatternFlowIpv4TotalLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLengthCounter)

PatternFlowIpv4TotalLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TotalLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOTALLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TotalLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength)
_sym_db.RegisterMessage(PatternFlowIpv4TotalLength.Choice)

PatternFlowIpv4IdentificationCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4IdentificationCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4IdentificationCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4IdentificationCounter)

PatternFlowIpv4Identification = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Identification', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Identification.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4IDENTIFICATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Identification)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Identification)
_sym_db.RegisterMessage(PatternFlowIpv4Identification.Choice)

PatternFlowIpv4ReservedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ReservedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ReservedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ReservedCounter)

PatternFlowIpv4Reserved = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Reserved', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Reserved.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4RESERVED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Reserved)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Reserved)
_sym_db.RegisterMessage(PatternFlowIpv4Reserved.Choice)

PatternFlowIpv4DontFragmentCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragmentCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragmentCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragmentCounter)

PatternFlowIpv4DontFragment = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DontFragment', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragment.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DONTFRAGMENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DontFragment)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DontFragment)
_sym_db.RegisterMessage(PatternFlowIpv4DontFragment.Choice)

PatternFlowIpv4MoreFragmentsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragmentsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragmentsCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragmentsCounter)

PatternFlowIpv4MoreFragments = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4MoreFragments', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragments.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4MOREFRAGMENTS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4MoreFragments)
  })
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragments)
_sym_db.RegisterMessage(PatternFlowIpv4MoreFragments.Choice)

PatternFlowIpv4FragmentOffsetCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffsetCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffsetCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffsetCounter)

PatternFlowIpv4FragmentOffset = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4FragmentOffset', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffset.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4FRAGMENTOFFSET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4FragmentOffset)
  })
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffset)
_sym_db.RegisterMessage(PatternFlowIpv4FragmentOffset.Choice)

PatternFlowIpv4TimeToLiveCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLiveCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLiveCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLiveCounter)

PatternFlowIpv4TimeToLive = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TimeToLive', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLive.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TIMETOLIVE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TimeToLive)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLive)
_sym_db.RegisterMessage(PatternFlowIpv4TimeToLive.Choice)

PatternFlowIpv4ProtocolCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4ProtocolCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4ProtocolCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4ProtocolCounter)

PatternFlowIpv4Protocol = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Protocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4PROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Protocol)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Protocol)
_sym_db.RegisterMessage(PatternFlowIpv4Protocol.Choice)

PatternFlowIpv4HeaderChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4HeaderChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4HEADERCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4HeaderChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIpv4HeaderChecksum.Generated)

PatternFlowIpv4SrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4SrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4SrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4SrcCounter)

PatternFlowIpv4Src = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Src', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4SRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Src.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4SRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Src)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Src)
_sym_db.RegisterMessage(PatternFlowIpv4Src.Choice)

PatternFlowIpv4DstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DstCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DstCounter)

PatternFlowIpv4Dst = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4Dst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Dst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4Dst)
  })
_sym_db.RegisterMessage(PatternFlowIpv4Dst)
_sym_db.RegisterMessage(PatternFlowIpv4Dst.Choice)

PatternFlowIpv4PriorityRawCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRawCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAWCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRawCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRawCounter)

PatternFlowIpv4PriorityRaw = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4PriorityRaw', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAW_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRaw.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4PRIORITYRAW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4PriorityRaw)
  })
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRaw)
_sym_db.RegisterMessage(PatternFlowIpv4PriorityRaw.Choice)

PatternFlowIpv4DscpPhbCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhbCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHBCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhbCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhbCounter)

PatternFlowIpv4DscpPhb = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpPhb', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHB_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhb.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPPHB,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpPhb)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhb)
_sym_db.RegisterMessage(PatternFlowIpv4DscpPhb.Choice)

PatternFlowIpv4DscpEcnCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcnCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECNCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcnCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcnCounter)

PatternFlowIpv4DscpEcn = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4DscpEcn', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcn.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4DSCPECN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4DscpEcn)
  })
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcn)
_sym_db.RegisterMessage(PatternFlowIpv4DscpEcn.Choice)

PatternFlowIpv4TosPrecedenceCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedenceCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedenceCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedenceCounter)

PatternFlowIpv4TosPrecedence = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosPrecedence', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedence.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSPRECEDENCE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosPrecedence)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedence)
_sym_db.RegisterMessage(PatternFlowIpv4TosPrecedence.Choice)

PatternFlowIpv4TosDelayCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelayCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelayCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelayCounter)

PatternFlowIpv4TosDelay = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosDelay', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelay.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSDELAY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosDelay)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosDelay)
_sym_db.RegisterMessage(PatternFlowIpv4TosDelay.Choice)

PatternFlowIpv4TosThroughputCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughputCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughputCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughputCounter)

PatternFlowIpv4TosThroughput = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosThroughput', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughput.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSTHROUGHPUT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosThroughput)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughput)
_sym_db.RegisterMessage(PatternFlowIpv4TosThroughput.Choice)

PatternFlowIpv4TosReliabilityCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliabilityCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliabilityCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliabilityCounter)

PatternFlowIpv4TosReliability = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosReliability', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliability.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSRELIABILITY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosReliability)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosReliability)
_sym_db.RegisterMessage(PatternFlowIpv4TosReliability.Choice)

PatternFlowIpv4TosMonetaryCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetaryCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARYCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetaryCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetaryCounter)

PatternFlowIpv4TosMonetary = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosMonetary', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARY_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetary.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSMONETARY,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosMonetary)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetary)
_sym_db.RegisterMessage(PatternFlowIpv4TosMonetary.Choice)

PatternFlowIpv4TosUnusedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnusedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnusedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnusedCounter)

PatternFlowIpv4TosUnused = _reflection.GeneratedProtocolMessageType('PatternFlowIpv4TosUnused', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnused.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV4TOSUNUSED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv4TosUnused)
  })
_sym_db.RegisterMessage(PatternFlowIpv4TosUnused)
_sym_db.RegisterMessage(PatternFlowIpv4TosUnused.Choice)

PatternFlowIpv6VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6VersionCounter)

PatternFlowIpv6Version = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Version)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Version)
_sym_db.RegisterMessage(PatternFlowIpv6Version.Choice)

PatternFlowIpv6TrafficClassCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClassCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClassCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClassCounter)

PatternFlowIpv6TrafficClass = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6TrafficClass', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClass.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6TRAFFICCLASS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6TrafficClass)
  })
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClass)
_sym_db.RegisterMessage(PatternFlowIpv6TrafficClass.Choice)

PatternFlowIpv6FlowLabelCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabelCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABELCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabelCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabelCounter)

PatternFlowIpv6FlowLabel = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6FlowLabel', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABEL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabel.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6FLOWLABEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6FlowLabel)
  })
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabel)
_sym_db.RegisterMessage(PatternFlowIpv6FlowLabel.Choice)

PatternFlowIpv6PayloadLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLengthCounter)

PatternFlowIpv6PayloadLength = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6PayloadLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6PAYLOADLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6PayloadLength)
  })
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength)
_sym_db.RegisterMessage(PatternFlowIpv6PayloadLength.Choice)

PatternFlowIpv6NextHeaderCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeaderCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeaderCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeaderCounter)

PatternFlowIpv6NextHeader = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6NextHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6NEXTHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6NextHeader)
  })
_sym_db.RegisterMessage(PatternFlowIpv6NextHeader)
_sym_db.RegisterMessage(PatternFlowIpv6NextHeader.Choice)

PatternFlowIpv6HopLimitCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimitCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMITCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimitCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimitCounter)

PatternFlowIpv6HopLimit = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6HopLimit', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMIT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimit.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6HOPLIMIT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6HopLimit)
  })
_sym_db.RegisterMessage(PatternFlowIpv6HopLimit)
_sym_db.RegisterMessage(PatternFlowIpv6HopLimit.Choice)

PatternFlowIpv6SrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6SrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6SrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6SrcCounter)

PatternFlowIpv6Src = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Src', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6SRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Src.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6SRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Src)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Src)
_sym_db.RegisterMessage(PatternFlowIpv6Src.Choice)

PatternFlowIpv6DstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6DstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIPV6DSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6DstCounter)
  })
_sym_db.RegisterMessage(PatternFlowIpv6DstCounter)

PatternFlowIpv6Dst = _reflection.GeneratedProtocolMessageType('PatternFlowIpv6Dst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIPV6DST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Dst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIPV6DST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIpv6Dst)
  })
_sym_db.RegisterMessage(PatternFlowIpv6Dst)
_sym_db.RegisterMessage(PatternFlowIpv6Dst.Choice)

PatternFlowPfcPauseDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDstCounter)

PatternFlowPfcPauseDst = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseDst)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseDst)
_sym_db.RegisterMessage(PatternFlowPfcPauseDst.Choice)

PatternFlowPfcPauseSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrcCounter)

PatternFlowPfcPauseSrc = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSESRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseSrc)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseSrc)
_sym_db.RegisterMessage(PatternFlowPfcPauseSrc.Choice)

PatternFlowPfcPauseEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherTypeCounter)

PatternFlowPfcPauseEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseEtherType)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherType)
_sym_db.RegisterMessage(PatternFlowPfcPauseEtherType.Choice)

PatternFlowPfcPauseControlOpCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCodeCounter)

PatternFlowPfcPauseControlOpCode = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseControlOpCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECONTROLOPCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseControlOpCode)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCode)
_sym_db.RegisterMessage(PatternFlowPfcPauseControlOpCode.Choice)

PatternFlowPfcPauseClassEnableVectorCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVectorCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVectorCounter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVectorCounter)

PatternFlowPfcPauseClassEnableVector = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPauseClassEnableVector', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVector.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPauseClassEnableVector)
  })
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVector)
_sym_db.RegisterMessage(PatternFlowPfcPauseClassEnableVector.Choice)

PatternFlowPfcPausePauseClass0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0Counter)

PatternFlowPfcPausePauseClass0 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass0)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass0.Choice)

PatternFlowPfcPausePauseClass1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1Counter)

PatternFlowPfcPausePauseClass1 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass1)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass1.Choice)

PatternFlowPfcPausePauseClass2Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2Counter)

PatternFlowPfcPausePauseClass2 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass2', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass2)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass2.Choice)

PatternFlowPfcPausePauseClass3Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3Counter)

PatternFlowPfcPausePauseClass3 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass3', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS3,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass3)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass3.Choice)

PatternFlowPfcPausePauseClass4Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4Counter)

PatternFlowPfcPausePauseClass4 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass4', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS4,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass4)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass4.Choice)

PatternFlowPfcPausePauseClass5Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5Counter)

PatternFlowPfcPausePauseClass5 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass5', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS5,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass5)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass5.Choice)

PatternFlowPfcPausePauseClass6Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6Counter)

PatternFlowPfcPausePauseClass6 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass6', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS6,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass6)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass6.Choice)

PatternFlowPfcPausePauseClass7Counter = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7Counter)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7Counter)

PatternFlowPfcPausePauseClass7 = _reflection.GeneratedProtocolMessageType('PatternFlowPfcPausePauseClass7', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPFCPAUSEPAUSECLASS7,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPfcPausePauseClass7)
  })
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7)
_sym_db.RegisterMessage(PatternFlowPfcPausePauseClass7.Choice)

PatternFlowEthernetPauseDstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDstCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDstCounter)

PatternFlowEthernetPauseDst = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseDst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEDST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseDst)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseDst)
_sym_db.RegisterMessage(PatternFlowEthernetPauseDst.Choice)

PatternFlowEthernetPauseSrcCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrcCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRCCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrcCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrcCounter)

PatternFlowEthernetPauseSrc = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseSrc', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRC_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrc.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSESRC,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseSrc)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrc)
_sym_db.RegisterMessage(PatternFlowEthernetPauseSrc.Choice)

PatternFlowEthernetPauseEtherTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherTypeCounter)

PatternFlowEthernetPauseEtherType = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseEtherType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSEETHERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseEtherType)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherType)
_sym_db.RegisterMessage(PatternFlowEthernetPauseEtherType.Choice)

PatternFlowEthernetPauseControlOpCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCodeCounter)

PatternFlowEthernetPauseControlOpCode = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseControlOpCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSECONTROLOPCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseControlOpCode)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCode)
_sym_db.RegisterMessage(PatternFlowEthernetPauseControlOpCode.Choice)

PatternFlowEthernetPauseTimeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTimeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIMECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTimeCounter)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTimeCounter)

PatternFlowEthernetPauseTime = _reflection.GeneratedProtocolMessageType('PatternFlowEthernetPauseTime', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIME_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTime.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWETHERNETPAUSETIME,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowEthernetPauseTime)
  })
_sym_db.RegisterMessage(PatternFlowEthernetPauseTime)
_sym_db.RegisterMessage(PatternFlowEthernetPauseTime.Choice)

PatternFlowTcpSrcPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPortCounter)

PatternFlowTcpSrcPort = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSrcPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPSRCPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSrcPort)
  })
_sym_db.RegisterMessage(PatternFlowTcpSrcPort)
_sym_db.RegisterMessage(PatternFlowTcpSrcPort.Choice)

PatternFlowTcpDstPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPortCounter)

PatternFlowTcpDstPort = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDstPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPDSTPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDstPort)
  })
_sym_db.RegisterMessage(PatternFlowTcpDstPort)
_sym_db.RegisterMessage(PatternFlowTcpDstPort.Choice)

PatternFlowTcpSeqNumCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNumCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUMCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNumCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNumCounter)

PatternFlowTcpSeqNum = _reflection.GeneratedProtocolMessageType('PatternFlowTcpSeqNum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNum.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPSEQNUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpSeqNum)
  })
_sym_db.RegisterMessage(PatternFlowTcpSeqNum)
_sym_db.RegisterMessage(PatternFlowTcpSeqNum.Choice)

PatternFlowTcpAckNumCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNumCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUMCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNumCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNumCounter)

PatternFlowTcpAckNum = _reflection.GeneratedProtocolMessageType('PatternFlowTcpAckNum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPACKNUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNum.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPACKNUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpAckNum)
  })
_sym_db.RegisterMessage(PatternFlowTcpAckNum)
_sym_db.RegisterMessage(PatternFlowTcpAckNum.Choice)

PatternFlowTcpDataOffsetCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffsetCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSETCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffsetCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffsetCounter)

PatternFlowTcpDataOffset = _reflection.GeneratedProtocolMessageType('PatternFlowTcpDataOffset', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSET_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffset.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPDATAOFFSET,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpDataOffset)
  })
_sym_db.RegisterMessage(PatternFlowTcpDataOffset)
_sym_db.RegisterMessage(PatternFlowTcpDataOffset.Choice)

PatternFlowTcpEcnNsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNsCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNsCounter)

PatternFlowTcpEcnNs = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnNs', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNNS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNs.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNNS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnNs)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnNs)
_sym_db.RegisterMessage(PatternFlowTcpEcnNs.Choice)

PatternFlowTcpEcnCwrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwrCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwrCounter)

PatternFlowTcpEcnCwr = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnCwr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNCWR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNCWR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnCwr)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnCwr)
_sym_db.RegisterMessage(PatternFlowTcpEcnCwr.Choice)

PatternFlowTcpEcnEchoCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEchoCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHOCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEchoCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEchoCounter)

PatternFlowTcpEcnEcho = _reflection.GeneratedProtocolMessageType('PatternFlowTcpEcnEcho', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPECNECHO_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEcho.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPECNECHO,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpEcnEcho)
  })
_sym_db.RegisterMessage(PatternFlowTcpEcnEcho)
_sym_db.RegisterMessage(PatternFlowTcpEcnEcho.Choice)

PatternFlowTcpCtlUrgCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrgCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrgCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrgCounter)

PatternFlowTcpCtlUrg = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlUrg', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLURG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrg.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLURG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlUrg)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlUrg)
_sym_db.RegisterMessage(PatternFlowTcpCtlUrg.Choice)

PatternFlowTcpCtlAckCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAckCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACKCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAckCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAckCounter)

PatternFlowTcpCtlAck = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlAck', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLACK_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAck.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlAck)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlAck)
_sym_db.RegisterMessage(PatternFlowTcpCtlAck.Choice)

PatternFlowTcpCtlPshCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPshCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPshCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPshCounter)

PatternFlowTcpCtlPsh = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlPsh', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPsh.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLPSH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlPsh)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlPsh)
_sym_db.RegisterMessage(PatternFlowTcpCtlPsh.Choice)

PatternFlowTcpCtlRstCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRstCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRSTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRstCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRstCounter)

PatternFlowTcpCtlRst = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlRst', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLRST_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRst.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLRST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlRst)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlRst)
_sym_db.RegisterMessage(PatternFlowTcpCtlRst.Choice)

PatternFlowTcpCtlSynCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSynCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYNCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSynCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSynCounter)

PatternFlowTcpCtlSyn = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlSyn', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSyn.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLSYN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlSyn)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlSyn)
_sym_db.RegisterMessage(PatternFlowTcpCtlSyn.Choice)

PatternFlowTcpCtlFinCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFinCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFINCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFinCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFinCounter)

PatternFlowTcpCtlFin = _reflection.GeneratedProtocolMessageType('PatternFlowTcpCtlFin', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPCTLFIN_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFin.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPCTLFIN,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpCtlFin)
  })
_sym_db.RegisterMessage(PatternFlowTcpCtlFin)
_sym_db.RegisterMessage(PatternFlowTcpCtlFin.Choice)

PatternFlowTcpWindowCounter = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindowCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOWCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindowCounter)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindowCounter)

PatternFlowTcpWindow = _reflection.GeneratedProtocolMessageType('PatternFlowTcpWindow', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWTCPWINDOW_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindow.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWTCPWINDOW,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowTcpWindow)
  })
_sym_db.RegisterMessage(PatternFlowTcpWindow)
_sym_db.RegisterMessage(PatternFlowTcpWindow.Choice)

PatternFlowUdpSrcPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPortCounter)

PatternFlowUdpSrcPort = _reflection.GeneratedProtocolMessageType('PatternFlowUdpSrcPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPSRCPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpSrcPort)
  })
_sym_db.RegisterMessage(PatternFlowUdpSrcPort)
_sym_db.RegisterMessage(PatternFlowUdpSrcPort.Choice)

PatternFlowUdpDstPortCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPortCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPortCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPortCounter)

PatternFlowUdpDstPort = _reflection.GeneratedProtocolMessageType('PatternFlowUdpDstPort', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPort.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPDSTPORT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpDstPort)
  })
_sym_db.RegisterMessage(PatternFlowUdpDstPort)
_sym_db.RegisterMessage(PatternFlowUdpDstPort.Choice)

PatternFlowUdpLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowUdpLengthCounter)

PatternFlowUdpLength = _reflection.GeneratedProtocolMessageType('PatternFlowUdpLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpLength)
  })
_sym_db.RegisterMessage(PatternFlowUdpLength)
_sym_db.RegisterMessage(PatternFlowUdpLength.Choice)

PatternFlowUdpChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowUdpChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWUDPCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowUdpChecksum)
  })
_sym_db.RegisterMessage(PatternFlowUdpChecksum)
_sym_db.RegisterMessage(PatternFlowUdpChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowUdpChecksum.Generated)

PatternFlowGreChecksumPresentCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresentCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresentCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresentCounter)

PatternFlowGreChecksumPresent = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksumPresent', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresent.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUMPRESENT,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksumPresent)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksumPresent)
_sym_db.RegisterMessage(PatternFlowGreChecksumPresent.Choice)

PatternFlowGreReserved0Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0Counter)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0Counter)

PatternFlowGreReserved0 = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved0', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED0,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved0)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved0)
_sym_db.RegisterMessage(PatternFlowGreReserved0.Choice)

PatternFlowGreVersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREVERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreVersionCounter)

PatternFlowGreVersion = _reflection.GeneratedProtocolMessageType('PatternFlowGreVersion', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGREVERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersion.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGREVERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreVersion)
  })
_sym_db.RegisterMessage(PatternFlowGreVersion)
_sym_db.RegisterMessage(PatternFlowGreVersion.Choice)

PatternFlowGreProtocolCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocolCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocolCounter)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocolCounter)

PatternFlowGreProtocol = _reflection.GeneratedProtocolMessageType('PatternFlowGreProtocol', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocol.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGREPROTOCOL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreProtocol)
  })
_sym_db.RegisterMessage(PatternFlowGreProtocol)
_sym_db.RegisterMessage(PatternFlowGreProtocol.Choice)

PatternFlowGreChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowGreChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRECHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreChecksum)
  })
_sym_db.RegisterMessage(PatternFlowGreChecksum)
_sym_db.RegisterMessage(PatternFlowGreChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowGreChecksum.Generated)

PatternFlowGreReserved1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1Counter)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1Counter)

PatternFlowGreReserved1 = _reflection.GeneratedProtocolMessageType('PatternFlowGreReserved1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGRERESERVED1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGreReserved1)
  })
_sym_db.RegisterMessage(PatternFlowGreReserved1)
_sym_db.RegisterMessage(PatternFlowGreReserved1.Choice)

PatternFlowGtpv1VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1VersionCounter)

PatternFlowGtpv1Version = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Version)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Version)
_sym_db.RegisterMessage(PatternFlowGtpv1Version.Choice)

PatternFlowGtpv1ProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolTypeCounter)

PatternFlowGtpv1ProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolType)
_sym_db.RegisterMessage(PatternFlowGtpv1ProtocolType.Choice)

PatternFlowGtpv1ReservedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1ReservedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1ReservedCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1ReservedCounter)

PatternFlowGtpv1Reserved = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Reserved', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Reserved.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1RESERVED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Reserved)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Reserved)
_sym_db.RegisterMessage(PatternFlowGtpv1Reserved.Choice)

PatternFlowGtpv1EFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlagCounter)

PatternFlowGtpv1EFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1EFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1EFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1EFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1EFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1EFlag.Choice)

PatternFlowGtpv1SFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlagCounter)

PatternFlowGtpv1SFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1SFlag.Choice)

PatternFlowGtpv1PnFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlagCounter)

PatternFlowGtpv1PnFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1PnFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1PNFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1PnFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlag)
_sym_db.RegisterMessage(PatternFlowGtpv1PnFlag.Choice)

PatternFlowGtpv1MessageTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageTypeCounter)

PatternFlowGtpv1MessageType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageType)
_sym_db.RegisterMessage(PatternFlowGtpv1MessageType.Choice)

PatternFlowGtpv1MessageLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLengthCounter)

PatternFlowGtpv1MessageLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1MessageLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1MESSAGELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1MessageLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLength)
_sym_db.RegisterMessage(PatternFlowGtpv1MessageLength.Choice)

PatternFlowGtpv1TeidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1TeidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1TeidCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1TeidCounter)

PatternFlowGtpv1Teid = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1Teid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1TEID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Teid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1TEID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1Teid)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1Teid)
_sym_db.RegisterMessage(PatternFlowGtpv1Teid.Choice)

PatternFlowGtpv1SquenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumberCounter)

PatternFlowGtpv1SquenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1SquenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1SQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1SquenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumber)
_sym_db.RegisterMessage(PatternFlowGtpv1SquenceNumber.Choice)

PatternFlowGtpv1NPduNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumberCounter)

PatternFlowGtpv1NPduNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NPduNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NPDUNUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NPduNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumber)
_sym_db.RegisterMessage(PatternFlowGtpv1NPduNumber.Choice)

PatternFlowGtpv1NextExtensionHeaderTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderTypeCounter)

PatternFlowGtpv1NextExtensionHeaderType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv1NextExtensionHeaderType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv1NextExtensionHeaderType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderType)
_sym_db.RegisterMessage(PatternFlowGtpv1NextExtensionHeaderType.Choice)

PatternFlowGtpExtensionExtensionLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLengthCounter)

PatternFlowGtpExtensionExtensionLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionExtensionLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionExtensionLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLength)
_sym_db.RegisterMessage(PatternFlowGtpExtensionExtensionLength.Choice)

PatternFlowGtpExtensionContentsCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContentsCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContentsCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContentsCounter)

PatternFlowGtpExtensionContents = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionContents', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContents.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONCONTENTS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionContents)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionContents)
_sym_db.RegisterMessage(PatternFlowGtpExtensionContents.Choice)

PatternFlowGtpExtensionNextExtensionHeaderCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeaderCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeaderCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeaderCounter)

PatternFlowGtpExtensionNextExtensionHeader = _reflection.GeneratedProtocolMessageType('PatternFlowGtpExtensionNextExtensionHeader', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeader.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpExtensionNextExtensionHeader)
  })
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeader)
_sym_db.RegisterMessage(PatternFlowGtpExtensionNextExtensionHeader.Choice)

PatternFlowGtpv2VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2VersionCounter)

PatternFlowGtpv2Version = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Version)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Version)
_sym_db.RegisterMessage(PatternFlowGtpv2Version.Choice)

PatternFlowGtpv2PiggybackingFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlagCounter)

PatternFlowGtpv2PiggybackingFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2PiggybackingFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2PIGGYBACKINGFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2PiggybackingFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlag)
_sym_db.RegisterMessage(PatternFlowGtpv2PiggybackingFlag.Choice)

PatternFlowGtpv2TeidFlagCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlagCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAGCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlagCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlagCounter)

PatternFlowGtpv2TeidFlag = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidFlag', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAG_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlag.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDFLAG,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidFlag)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlag)
_sym_db.RegisterMessage(PatternFlowGtpv2TeidFlag.Choice)

PatternFlowGtpv2Spare1Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1Counter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1Counter)

PatternFlowGtpv2Spare1 = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare1', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE1,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare1)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1)
_sym_db.RegisterMessage(PatternFlowGtpv2Spare1.Choice)

PatternFlowGtpv2MessageTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageTypeCounter)

PatternFlowGtpv2MessageType = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageType)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageType)
_sym_db.RegisterMessage(PatternFlowGtpv2MessageType.Choice)

PatternFlowGtpv2MessageLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLengthCounter)

PatternFlowGtpv2MessageLength = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2MessageLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2MESSAGELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2MessageLength)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLength)
_sym_db.RegisterMessage(PatternFlowGtpv2MessageLength.Choice)

PatternFlowGtpv2TeidCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2TeidCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEIDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2TeidCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2TeidCounter)

PatternFlowGtpv2Teid = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Teid', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2TEID_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Teid.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2TEID,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Teid)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Teid)
_sym_db.RegisterMessage(PatternFlowGtpv2Teid.Choice)

PatternFlowGtpv2SequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumberCounter)

PatternFlowGtpv2SequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2SequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2SequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumber)
_sym_db.RegisterMessage(PatternFlowGtpv2SequenceNumber.Choice)

PatternFlowGtpv2Spare2Counter = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2Counter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2COUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2Counter)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2Counter)

PatternFlowGtpv2Spare2 = _reflection.GeneratedProtocolMessageType('PatternFlowGtpv2Spare2', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWGTPV2SPARE2,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowGtpv2Spare2)
  })
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2)
_sym_db.RegisterMessage(PatternFlowGtpv2Spare2.Choice)

PatternFlowArpHardwareTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareTypeCounter)

PatternFlowArpHardwareType = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARETYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareType)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareType)
_sym_db.RegisterMessage(PatternFlowArpHardwareType.Choice)

PatternFlowArpProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolTypeCounter)

PatternFlowArpProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolType)
_sym_db.RegisterMessage(PatternFlowArpProtocolType.Choice)

PatternFlowArpHardwareLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLengthCounter)

PatternFlowArpHardwareLength = _reflection.GeneratedProtocolMessageType('PatternFlowArpHardwareLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPHARDWARELENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpHardwareLength)
  })
_sym_db.RegisterMessage(PatternFlowArpHardwareLength)
_sym_db.RegisterMessage(PatternFlowArpHardwareLength.Choice)

PatternFlowArpProtocolLengthCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLengthCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLengthCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLengthCounter)

PatternFlowArpProtocolLength = _reflection.GeneratedProtocolMessageType('PatternFlowArpProtocolLength', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLength.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPPROTOCOLLENGTH,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpProtocolLength)
  })
_sym_db.RegisterMessage(PatternFlowArpProtocolLength)
_sym_db.RegisterMessage(PatternFlowArpProtocolLength.Choice)

PatternFlowArpOperationCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperationCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperationCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpOperationCounter)

PatternFlowArpOperation = _reflection.GeneratedProtocolMessageType('PatternFlowArpOperation', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPOPERATION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperation.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPOPERATION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpOperation)
  })
_sym_db.RegisterMessage(PatternFlowArpOperation)
_sym_db.RegisterMessage(PatternFlowArpOperation.Choice)

PatternFlowArpSenderHardwareAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddrCounter)

PatternFlowArpSenderHardwareAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderHardwareAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERHARDWAREADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderHardwareAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddr)
_sym_db.RegisterMessage(PatternFlowArpSenderHardwareAddr.Choice)

PatternFlowArpSenderProtocolAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddrCounter)

PatternFlowArpSenderProtocolAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpSenderProtocolAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPSENDERPROTOCOLADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpSenderProtocolAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddr)
_sym_db.RegisterMessage(PatternFlowArpSenderProtocolAddr.Choice)

PatternFlowArpTargetHardwareAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddrCounter)

PatternFlowArpTargetHardwareAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetHardwareAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETHARDWAREADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetHardwareAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddr)
_sym_db.RegisterMessage(PatternFlowArpTargetHardwareAddr.Choice)

PatternFlowArpTargetProtocolAddrCounter = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddrCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddrCounter)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddrCounter)

PatternFlowArpTargetProtocolAddr = _reflection.GeneratedProtocolMessageType('PatternFlowArpTargetProtocolAddr', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddr.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWARPTARGETPROTOCOLADDR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowArpTargetProtocolAddr)
  })
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddr)
_sym_db.RegisterMessage(PatternFlowArpTargetProtocolAddr.Choice)

PatternFlowIcmpEchoTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoTypeCounter)

PatternFlowIcmpEchoType = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoType)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoType)
_sym_db.RegisterMessage(PatternFlowIcmpEchoType.Choice)

PatternFlowIcmpEchoCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCodeCounter)

PatternFlowIcmpEchoCode = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoCode)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoCode)
_sym_db.RegisterMessage(PatternFlowIcmpEchoCode.Choice)

PatternFlowIcmpEchoChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpEchoChecksum.Generated)

PatternFlowIcmpEchoIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifierCounter)

PatternFlowIcmpEchoIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpEchoIdentifier.Choice)

PatternFlowIcmpEchoSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumberCounter)

PatternFlowIcmpEchoSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpEchoSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPECHOSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpEchoSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpEchoSequenceNumber.Choice)

PatternFlowIcmpCommonChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpCommonChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPCOMMONCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpCommonChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpCommonChecksum.Generated)

PatternFlowIcmpNextFieldsIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifierCounter)

PatternFlowIcmpNextFieldsIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsIdentifier.Choice)

PatternFlowIcmpNextFieldsSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumberCounter)

PatternFlowIcmpNextFieldsSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpNextFieldsSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpNextFieldsSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpNextFieldsSequenceNumber.Choice)

PatternFlowIcmpv6EchoTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoTypeCounter)

PatternFlowIcmpv6EchoType = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoType)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoType)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoType.Choice)

PatternFlowIcmpv6EchoCodeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCodeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCodeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCodeCounter)

PatternFlowIcmpv6EchoCode = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoCode', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCode.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCODE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoCode)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCode)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoCode.Choice)

PatternFlowIcmpv6EchoIdentifierCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifierCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifierCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifierCounter)

PatternFlowIcmpv6EchoIdentifier = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoIdentifier', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifier.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOIDENTIFIER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoIdentifier)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifier)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoIdentifier.Choice)

PatternFlowIcmpv6EchoSequenceNumberCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumberCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumberCounter)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumberCounter)

PatternFlowIcmpv6EchoSequenceNumber = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoSequenceNumber', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumber.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoSequenceNumber)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumber)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoSequenceNumber.Choice)

PatternFlowIcmpv6EchoChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6EchoChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6ECHOCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6EchoChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpv6EchoChecksum.Generated)

PatternFlowIcmpv6CommonChecksum = _reflection.GeneratedProtocolMessageType('PatternFlowIcmpv6CommonChecksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWICMPV6COMMONCHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIcmpv6CommonChecksum)
  })
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum)
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum.Choice)
_sym_db.RegisterMessage(PatternFlowIcmpv6CommonChecksum.Generated)

PatternFlowPppAddressCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddressCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddressCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppAddressCounter)

PatternFlowPppAddress = _reflection.GeneratedProtocolMessageType('PatternFlowPppAddress', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPADDRESS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddress.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppAddress)
  })
_sym_db.RegisterMessage(PatternFlowPppAddress)
_sym_db.RegisterMessage(PatternFlowPppAddress.Choice)

PatternFlowPppControlCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppControlCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROLCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControlCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppControlCounter)

PatternFlowPppControl = _reflection.GeneratedProtocolMessageType('PatternFlowPppControl', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPCONTROL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControl.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPCONTROL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppControl)
  })
_sym_db.RegisterMessage(PatternFlowPppControl)
_sym_db.RegisterMessage(PatternFlowPppControl.Choice)

PatternFlowPppProtocolTypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolTypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolTypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolTypeCounter)

PatternFlowPppProtocolType = _reflection.GeneratedProtocolMessageType('PatternFlowPppProtocolType', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWPPPPROTOCOLTYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowPppProtocolType)
  })
_sym_db.RegisterMessage(PatternFlowPppProtocolType)
_sym_db.RegisterMessage(PatternFlowPppProtocolType.Choice)

PatternFlowIgmpv1VersionCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1VersionCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSIONCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1VersionCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1VersionCounter)

PatternFlowIgmpv1Version = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Version', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSION_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Version.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1VERSION,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Version)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Version)
_sym_db.RegisterMessage(PatternFlowIgmpv1Version.Choice)

PatternFlowIgmpv1TypeCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1TypeCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1TypeCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1TypeCounter)

PatternFlowIgmpv1Type = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Type', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Type.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1TYPE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Type)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Type)
_sym_db.RegisterMessage(PatternFlowIgmpv1Type.Choice)

PatternFlowIgmpv1UnusedCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1UnusedCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSEDCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1UnusedCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1UnusedCounter)

PatternFlowIgmpv1Unused = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Unused', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSED_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Unused.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1UNUSED,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Unused)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Unused)
_sym_db.RegisterMessage(PatternFlowIgmpv1Unused.Choice)

PatternFlowIgmpv1Checksum = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1Checksum', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum.Choice)
    })
  ,

  'Generated' : _reflection.GeneratedProtocolMessageType('Generated', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM_GENERATED,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum.Generated)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1CHECKSUM,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1Checksum)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum)
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum.Choice)
_sym_db.RegisterMessage(PatternFlowIgmpv1Checksum.Generated)

PatternFlowIgmpv1GroupAddressCounter = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddressCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddressCounter)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddressCounter)

PatternFlowIgmpv1GroupAddress = _reflection.GeneratedProtocolMessageType('PatternFlowIgmpv1GroupAddress', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddress.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWIGMPV1GROUPADDRESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowIgmpv1GroupAddress)
  })
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddress)
_sym_db.RegisterMessage(PatternFlowIgmpv1GroupAddress.Choice)

PatternFlowMplsLabelCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsLabelCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSLABELCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabelCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsLabelCounter)

PatternFlowMplsLabel = _reflection.GeneratedProtocolMessageType('PatternFlowMplsLabel', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSLABEL_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabel.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSLABEL,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsLabel)
  })
_sym_db.RegisterMessage(PatternFlowMplsLabel)
_sym_db.RegisterMessage(PatternFlowMplsLabel.Choice)

PatternFlowMplsTrafficClassCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTrafficClassCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASSCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClassCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsTrafficClassCounter)

PatternFlowMplsTrafficClass = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTrafficClass', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClass.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSTRAFFICCLASS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTrafficClass)
  })
_sym_db.RegisterMessage(PatternFlowMplsTrafficClass)
_sym_db.RegisterMessage(PatternFlowMplsTrafficClass.Choice)

PatternFlowMplsBottomOfStackCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsBottomOfStackCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStackCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStackCounter)

PatternFlowMplsBottomOfStack = _reflection.GeneratedProtocolMessageType('PatternFlowMplsBottomOfStack', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStack.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSBOTTOMOFSTACK,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsBottomOfStack)
  })
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStack)
_sym_db.RegisterMessage(PatternFlowMplsBottomOfStack.Choice)

PatternFlowMplsTimeToLiveCounter = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTimeToLiveCounter', (_message.Message,), {
  'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVECOUNTER,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLiveCounter)
  })
_sym_db.RegisterMessage(PatternFlowMplsTimeToLiveCounter)

PatternFlowMplsTimeToLive = _reflection.GeneratedProtocolMessageType('PatternFlowMplsTimeToLive', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVE_CHOICE,
    '__module__' : 'otg_pb2'
    # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLive.Choice)
    })
  ,
  'DESCRIPTOR' : _PATTERNFLOWMPLSTIMETOLIVE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.PatternFlowMplsTimeToLive)
  })
_sym_db.RegisterMessage(PatternFlowMplsTimeToLive)
_sym_db.RegisterMessage(PatternFlowMplsTimeToLive.Choice)

Success = _reflection.GeneratedProtocolMessageType('Success', (_message.Message,), {
  'DESCRIPTOR' : _SUCCESS,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.Success)
  })
_sym_db.RegisterMessage(Success)

BadRequest = _reflection.GeneratedProtocolMessageType('BadRequest', (_message.Message,), {
  'DESCRIPTOR' : _BADREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.BadRequest)
  })
_sym_db.RegisterMessage(BadRequest)

InternalServerError = _reflection.GeneratedProtocolMessageType('InternalServerError', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALSERVERERROR,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.InternalServerError)
  })
_sym_db.RegisterMessage(InternalServerError)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

SetTransmitStateRequest = _reflection.GeneratedProtocolMessageType('SetTransmitStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETTRANSMITSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetTransmitStateRequest)
  })
_sym_db.RegisterMessage(SetTransmitStateRequest)

SetTransmitStateResponse = _reflection.GeneratedProtocolMessageType('SetTransmitStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETTRANSMITSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetTransmitStateResponse)
  })
_sym_db.RegisterMessage(SetTransmitStateResponse)

SetLinkStateRequest = _reflection.GeneratedProtocolMessageType('SetLinkStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLINKSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetLinkStateRequest)
  })
_sym_db.RegisterMessage(SetLinkStateRequest)

SetLinkStateResponse = _reflection.GeneratedProtocolMessageType('SetLinkStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETLINKSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetLinkStateResponse)
  })
_sym_db.RegisterMessage(SetLinkStateResponse)

SetCaptureStateRequest = _reflection.GeneratedProtocolMessageType('SetCaptureStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCAPTURESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetCaptureStateRequest)
  })
_sym_db.RegisterMessage(SetCaptureStateRequest)

SetCaptureStateResponse = _reflection.GeneratedProtocolMessageType('SetCaptureStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCAPTURESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetCaptureStateResponse)
  })
_sym_db.RegisterMessage(SetCaptureStateResponse)

UpdateFlowsRequest = _reflection.GeneratedProtocolMessageType('UpdateFlowsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFLOWSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateFlowsRequest)
  })
_sym_db.RegisterMessage(UpdateFlowsRequest)

UpdateFlowsResponse = _reflection.GeneratedProtocolMessageType('UpdateFlowsResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFLOWSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.UpdateFlowsResponse)
  })
_sym_db.RegisterMessage(UpdateFlowsResponse)

SetRouteStateRequest = _reflection.GeneratedProtocolMessageType('SetRouteStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETROUTESTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetRouteStateRequest)
  })
_sym_db.RegisterMessage(SetRouteStateRequest)

SetRouteStateResponse = _reflection.GeneratedProtocolMessageType('SetRouteStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETROUTESTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetRouteStateResponse)
  })
_sym_db.RegisterMessage(SetRouteStateResponse)

SendPingRequest = _reflection.GeneratedProtocolMessageType('SendPingRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDPINGREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SendPingRequest)
  })
_sym_db.RegisterMessage(SendPingRequest)

SendPingResponse = _reflection.GeneratedProtocolMessageType('SendPingResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDPINGRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SendPingResponse)
  })
_sym_db.RegisterMessage(SendPingResponse)

SetProtocolStateRequest = _reflection.GeneratedProtocolMessageType('SetProtocolStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPROTOCOLSTATEREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetProtocolStateRequest)
  })
_sym_db.RegisterMessage(SetProtocolStateRequest)

SetProtocolStateResponse = _reflection.GeneratedProtocolMessageType('SetProtocolStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETPROTOCOLSTATERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.SetProtocolStateResponse)
  })
_sym_db.RegisterMessage(SetProtocolStateResponse)

GetMetricsRequest = _reflection.GeneratedProtocolMessageType('GetMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetMetricsRequest)
  })
_sym_db.RegisterMessage(GetMetricsRequest)

GetMetricsResponse = _reflection.GeneratedProtocolMessageType('GetMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetMetricsResponse)
  })
_sym_db.RegisterMessage(GetMetricsResponse)

GetStatesRequest = _reflection.GeneratedProtocolMessageType('GetStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATESREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetStatesRequest)
  })
_sym_db.RegisterMessage(GetStatesRequest)

GetStatesResponse = _reflection.GeneratedProtocolMessageType('GetStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATESRESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetStatesResponse)
  })
_sym_db.RegisterMessage(GetStatesResponse)

GetCaptureRequest = _reflection.GeneratedProtocolMessageType('GetCaptureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCAPTUREREQUEST,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetCaptureRequest)
  })
_sym_db.RegisterMessage(GetCaptureRequest)

GetCaptureResponse = _reflection.GeneratedProtocolMessageType('GetCaptureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCAPTURERESPONSE,
  '__module__' : 'otg_pb2'
  # @@protoc_insertion_point(class_scope:otg.GetCaptureResponse)
  })
_sym_db.RegisterMessage(GetCaptureResponse)

_OPENAPI = DESCRIPTOR.services_by_name['Openapi']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CONFIG._serialized_start=82
  _CONFIG._serialized_end=355
  _CONFIGOPTIONS._serialized_start=357
  _CONFIGOPTIONS._serialized_end=434
  _PORT._serialized_start=436
  _PORT._serialized_end=492
  _PORTOPTIONS._serialized_start=494
  _PORTOPTIONS._serialized_end=565
  _LAG._serialized_start=567
  _LAG._serialized_end=615
  _LAGPORT._serialized_start=617
  _LAGPORT._serialized_end=724
  _LAGPROTOCOL._serialized_start=727
  _LAGPROTOCOL._serialized_end=949
  _LAGPROTOCOL_CHOICE._serialized_start=863
  _LAGPROTOCOL_CHOICE._serialized_end=918
  _LAGPROTOCOL_CHOICE_ENUM._serialized_start=873
  _LAGPROTOCOL_CHOICE_ENUM._serialized_end=918
  _LAGSTATIC._serialized_start=951
  _LAGSTATIC._serialized_end=994
  _LAGLACP._serialized_start=997
  _LAGLACP._serialized_end=1542
  _LAGLACP_ACTORACTIVITY._serialized_start=1299
  _LAGLACP_ACTORACTIVITY._serialized_end=1364
  _LAGLACP_ACTORACTIVITY_ENUM._serialized_start=1316
  _LAGLACP_ACTORACTIVITY_ENUM._serialized_end=1364
  _DEVICEETHERNETBASE._serialized_start=1544
  _DEVICEETHERNETBASE._serialized_end=1649
  _DEVICEETHERNET._serialized_start=1652
  _DEVICEETHERNET._serialized_end=1854
  _DEVICEVLAN._serialized_start=1857
  _DEVICEVLAN._serialized_end=2086
  _DEVICEVLAN_TPID._serialized_start=1971
  _DEVICEVLAN_TPID._serialized_end=2057
  _DEVICEVLAN_TPID_ENUM._serialized_start=1979
  _DEVICEVLAN_TPID_ENUM._serialized_end=2057
  _DEVICEIPV4._serialized_start=2088
  _DEVICEIPV4._serialized_end=2180
  _DEVICEIPV4LOOPBACK._serialized_start=2182
  _DEVICEIPV4LOOPBACK._serialized_end=2268
  _DEVICEIPV6._serialized_start=2270
  _DEVICEIPV6._serialized_end=2362
  _DEVICEIPV6LOOPBACK._serialized_start=2364
  _DEVICEIPV6LOOPBACK._serialized_end=2450
  _LAYER1._serialized_start=2453
  _LAYER1._serialized_end=3273
  _LAYER1_SPEED._serialized_start=2803
  _LAYER1_SPEED._serialized_end=3080
  _LAYER1_SPEED_ENUM._serialized_start=2813
  _LAYER1_SPEED_ENUM._serialized_end=3080
  _LAYER1_MEDIA._serialized_start=3082
  _LAYER1_MEDIA._serialized_end=3148
  _LAYER1_MEDIA_ENUM._serialized_start=3091
  _LAYER1_MEDIA_ENUM._serialized_end=3148
  _LAYER1AUTONEGOTIATION._serialized_start=3276
  _LAYER1AUTONEGOTIATION._serialized_end=3679
  _LAYER1FLOWCONTROL._serialized_start=3682
  _LAYER1FLOWCONTROL._serialized_end=4026
  _LAYER1FLOWCONTROL_CHOICE._serialized_start=3891
  _LAYER1FLOWCONTROL_CHOICE._serialized_end=3960
  _LAYER1FLOWCONTROL_CHOICE_ENUM._serialized_start=3901
  _LAYER1FLOWCONTROL_CHOICE_ENUM._serialized_end=3960
  _LAYER1IEEE8023X._serialized_start=4028
  _LAYER1IEEE8023X._serialized_end=4045
  _LAYER1IEEE8021QBB._serialized_start=4048
  _LAYER1IEEE8021QBB._serialized_end=4441
  _CAPTURE._serialized_start=4444
  _CAPTURE._serialized_end=4719
  _CAPTURE_FORMAT._serialized_start=4623
  _CAPTURE_FORMAT._serialized_end=4678
  _CAPTURE_FORMAT_ENUM._serialized_start=4633
  _CAPTURE_FORMAT_ENUM._serialized_end=4678
  _CAPTUREFILTER._serialized_start=4722
  _CAPTUREFILTER._serialized_end=5140
  _CAPTUREFILTER_CHOICE._serialized_start=4989
  _CAPTUREFILTER_CHOICE._serialized_end=5078
  _CAPTUREFILTER_CHOICE_ENUM._serialized_start=4999
  _CAPTUREFILTER_CHOICE_ENUM._serialized_end=5078
  _CAPTURECUSTOM._serialized_start=5143
  _CAPTURECUSTOM._serialized_end=5320
  _CAPTUREFIELD._serialized_start=5322
  _CAPTUREFIELD._serialized_end=5426
  _CAPTUREETHERNET._serialized_start=5429
  _CAPTUREETHERNET._serialized_end=5652
  _CAPTUREVLAN._serialized_start=5655
  _CAPTUREVLAN._serialized_end=5866
  _CAPTUREIPV4._serialized_start=5869
  _CAPTUREIPV4._serialized_end=6718
  _CAPTUREIPV6._serialized_start=6721
  _CAPTUREIPV6._serialized_end=7186
  _DEVICE._serialized_start=7189
  _DEVICE._serialized_end=7448
  _DEVICEISISROUTER._serialized_start=7451
  _DEVICEISISROUTER._serialized_end=7860
  _DEVICEISISMULTIINSTANCE._serialized_start=7862
  _DEVICEISISMULTIINSTANCE._serialized_end=7928
  _ISISINTERFACE._serialized_start=7931
  _ISISINTERFACE._serialized_end=8793
  _ISISINTERFACE_NETWORKTYPE._serialized_start=8514
  _ISISINTERFACE_NETWORKTYPE._serialized_end=8587
  _ISISINTERFACE_NETWORKTYPE_ENUM._serialized_start=8529
  _ISISINTERFACE_NETWORKTYPE_ENUM._serialized_end=8587
  _ISISINTERFACE_LEVELTYPE._serialized_start=8589
  _ISISINTERFACE_LEVELTYPE._serialized_end=8666
  _ISISINTERFACE_LEVELTYPE_ENUM._serialized_start=8602
  _ISISINTERFACE_LEVELTYPE_ENUM._serialized_end=8666
  _ISISINTERFACELEVEL._serialized_start=8796
  _ISISINTERFACELEVEL._serialized_end=8946
  _ISISMT._serialized_start=8948
  _ISISMT._serialized_end=9028
  _LINKSTATETE._serialized_start=9031
  _LINKSTATETE._serialized_end=9352
  _LINKSTATEPRIORITYBANDWIDTHS._serialized_start=9355
  _LINKSTATEPRIORITYBANDWIDTHS._serialized_end=9592
  _ISISINTERFACEAUTHENTICATION._serialized_start=9595
  _ISISINTERFACEAUTHENTICATION._serialized_end=9813
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE._serialized_start=9734
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE._serialized_end=9792
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM._serialized_start=9746
  _ISISINTERFACEAUTHENTICATION_AUTHTYPE_ENUM._serialized_end=9792
  _ISISINTERFACEADVANCED._serialized_start=9816
  _ISISINTERFACEADVANCED._serialized_end=10085
  _ISISINTERFACELINKPROTECTION._serialized_start=10088
  _ISISINTERFACELINKPROTECTION._serialized_end=10465
  _ISISBASIC._serialized_start=10468
  _ISISBASIC._serialized_end=10625
  _ISISADVANCED._serialized_start=10628
  _ISISADVANCED._serialized_end=11150
  _ISISAUTHENTICATION._serialized_start=11153
  _ISISAUTHENTICATION._serialized_end=11367
  _ISISAUTHENTICATIONBASE._serialized_start=11370
  _ISISAUTHENTICATIONBASE._serialized_end=11578
  _ISISAUTHENTICATIONBASE_AUTHTYPE._serialized_start=9734
  _ISISAUTHENTICATIONBASE_AUTHTYPE._serialized_end=9792
  _ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM._serialized_start=9746
  _ISISAUTHENTICATIONBASE_AUTHTYPE_ENUM._serialized_end=9792
  _ISISV4ROUTERANGE._serialized_start=11581
  _ISISV4ROUTERANGE._serialized_end=12167
  _ISISV4ROUTERANGE_ORIGINTYPE._serialized_start=11924
  _ISISV4ROUTERANGE_ORIGINTYPE._serialized_end=11989
  _ISISV4ROUTERANGE_ORIGINTYPE_ENUM._serialized_start=11938
  _ISISV4ROUTERANGE_ORIGINTYPE_ENUM._serialized_end=11989
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE._serialized_start=11991
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE._serialized_end=12054
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_start=12013
  _ISISV4ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_end=12054
  _V4ROUTEADDRESS._serialized_start=12169
  _V4ROUTEADDRESS._serialized_end=12292
  _V6ROUTEADDRESS._serialized_start=12294
  _V6ROUTEADDRESS._serialized_end=12417
  _ISISV6ROUTERANGE._serialized_start=12420
  _ISISV6ROUTERANGE._serialized_end=13006
  _ISISV6ROUTERANGE_ORIGINTYPE._serialized_start=11924
  _ISISV6ROUTERANGE_ORIGINTYPE._serialized_end=11989
  _ISISV6ROUTERANGE_ORIGINTYPE_ENUM._serialized_start=11938
  _ISISV6ROUTERANGE_ORIGINTYPE_ENUM._serialized_end=11989
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE._serialized_start=11991
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE._serialized_end=12054
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_start=12013
  _ISISV6ROUTERANGE_REDISTRIBUTIONTYPE_ENUM._serialized_end=12054
  _DEVICEBGPROUTER._serialized_start=13009
  _DEVICEBGPROUTER._serialized_end=13137
  _BGPV4PEER._serialized_start=13140
  _BGPV4PEER._serialized_end=13744
  _BGPV4PEER_ASTYPE._serialized_start=13582
  _BGPV4PEER_ASTYPE._serialized_end=13635
  _BGPV4PEER_ASTYPE_ENUM._serialized_start=13592
  _BGPV4PEER_ASTYPE_ENUM._serialized_end=13635
  _BGPV4PEER_ASNUMBERWIDTH._serialized_start=13637
  _BGPV4PEER_ASNUMBERWIDTH._serialized_end=13696
  _BGPV4PEER_ASNUMBERWIDTH_ENUM._serialized_start=13654
  _BGPV4PEER_ASNUMBERWIDTH_ENUM._serialized_end=13696
  _BGPV4INTERFACE._serialized_start=13746
  _BGPV4INTERFACE._serialized_end=13812
  _BGPADVANCED._serialized_start=13815
  _BGPADVANCED._serialized_end=14070
  _BGPCAPABILITY._serialized_start=14073
  _BGPCAPABILITY._serialized_end=15370
  _BGPV4ROUTERANGE._serialized_start=15373
  _BGPV4ROUTERANGE._serialized_end=16096
  _BGPV4ROUTERANGE_NEXTHOPMODE._serialized_start=15831
  _BGPV4ROUTERANGE_NEXTHOPMODE._serialized_end=15895
  _BGPV4ROUTERANGE_NEXTHOPMODE_ENUM._serialized_start=15846
  _BGPV4ROUTERANGE_NEXTHOPMODE_ENUM._serialized_end=15895
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_start=15897
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_end=15962
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_start=15919
  _BGPV4ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_end=15962
  _BGPROUTEADVANCED._serialized_start=16099
  _BGPROUTEADVANCED._serialized_end=16305
  _BGPROUTEADVANCED_ORIGIN._serialized_start=16214
  _BGPROUTEADVANCED_ORIGIN._serialized_end=16265
  _BGPROUTEADVANCED_ORIGIN_ENUM._serialized_start=16224
  _BGPROUTEADVANCED_ORIGIN_ENUM._serialized_end=16265
  _BGPCOMMUNITY._serialized_start=16308
  _BGPCOMMUNITY._serialized_end=16600
  _BGPCOMMUNITY_TYPE._serialized_start=16421
  _BGPCOMMUNITY_TYPE._serialized_end=16563
  _BGPCOMMUNITY_TYPE_ENUM._serialized_start=16430
  _BGPCOMMUNITY_TYPE_ENUM._serialized_end=16563
  _BGPASPATH._serialized_start=16603
  _BGPASPATH._serialized_end=16921
  _BGPASPATH_ASSETMODE._serialized_start=16715
  _BGPASPATH_ASSETMODE._serialized_end=16905
  _BGPASPATH_ASSETMODE_ENUM._serialized_start=16729
  _BGPASPATH_ASSETMODE_ENUM._serialized_end=16905
  _BGPASPATHSEGMENT._serialized_start=16924
  _BGPASPATHSEGMENT._serialized_end=17118
  _BGPASPATHSEGMENT_TYPE._serialized_start=17016
  _BGPASPATHSEGMENT_TYPE._serialized_end=17109
  _BGPASPATHSEGMENT_TYPE_ENUM._serialized_start=17024
  _BGPASPATHSEGMENT_TYPE_ENUM._serialized_end=17109
  _BGPADDPATH._serialized_start=17120
  _BGPADDPATH._serialized_end=17166
  _BGPV6ROUTERANGE._serialized_start=17169
  _BGPV6ROUTERANGE._serialized_end=17892
  _BGPV6ROUTERANGE_NEXTHOPMODE._serialized_start=15831
  _BGPV6ROUTERANGE_NEXTHOPMODE._serialized_end=15895
  _BGPV6ROUTERANGE_NEXTHOPMODE_ENUM._serialized_start=15846
  _BGPV6ROUTERANGE_NEXTHOPMODE_ENUM._serialized_end=15895
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_start=15897
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE._serialized_end=15962
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_start=15919
  _BGPV6ROUTERANGE_NEXTHOPADDRESSTYPE_ENUM._serialized_end=15962
  _BGPSRTEV4POLICY._serialized_start=17895
  _BGPSRTEV4POLICY._serialized_end=18802
  _BGPSRTEV4POLICY_NEXTHOPMODE._serialized_start=15831
  _BGPSRTEV4POLICY_NEXTHOPMODE._serialized_end=15895
  _BGPSRTEV4POLICY_NEXTHOPMODE_ENUM._serialized_start=15846
  _BGPSRTEV4POLICY_NEXTHOPMODE_ENUM._serialized_end=15895
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE._serialized_start=15897
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE._serialized_end=15962
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_start=15919
  _BGPSRTEV4POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_end=15962
  _BGPEXTCOMMUNITY._serialized_start=18805
  _BGPEXTCOMMUNITY._serialized_end=19310
  _BGPEXTCOMMUNITY_TYPE._serialized_start=18953
  _BGPEXTCOMMUNITY_TYPE._serialized_end=19141
  _BGPEXTCOMMUNITY_TYPE_ENUM._serialized_start=18962
  _BGPEXTCOMMUNITY_TYPE_ENUM._serialized_end=19141
  _BGPEXTCOMMUNITY_SUBTYPE._serialized_start=19144
  _BGPEXTCOMMUNITY_SUBTYPE._serialized_end=19279
  _BGPEXTCOMMUNITY_SUBTYPE_ENUM._serialized_start=19155
  _BGPEXTCOMMUNITY_SUBTYPE_ENUM._serialized_end=19279
  _BGPSRTEV4TUNNELTLV._serialized_start=19313
  _BGPSRTEV4TUNNELTLV._serialized_end=20080
  _BGPSRTEREMOTEENDPOINTSUBTLV._serialized_start=20083
  _BGPSRTEREMOTEENDPOINTSUBTLV._serialized_end=20401
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY._serialized_start=20274
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY._serialized_end=20334
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM._serialized_start=15919
  _BGPSRTEREMOTEENDPOINTSUBTLV_ADDRESSFAMILY_ENUM._serialized_end=15962
  _BGPSRTECOLORSUBTLV._serialized_start=20403
  _BGPSRTECOLORSUBTLV._serialized_end=20453
  _BGPSRTEBINDINGSUBTLV._serialized_start=20456
  _BGPSRTEBINDINGSUBTLV._serialized_end=20818
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE._serialized_start=20652
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE._serialized_end=20743
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM._serialized_start=20670
  _BGPSRTEBINDINGSUBTLV_BINDINGSIDTYPE_ENUM._serialized_end=20743
  _BGPSRTEPREFERENCESUBTLV._serialized_start=20820
  _BGPSRTEPREFERENCESUBTLV._serialized_end=20885
  _BGPSRTEPOLICYPRIORITYSUBTLV._serialized_start=20887
  _BGPSRTEPOLICYPRIORITYSUBTLV._serialized_end=20966
  _BGPSRTEPOLICYNAMESUBTLV._serialized_start=20968
  _BGPSRTEPOLICYNAMESUBTLV._serialized_end=21035
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV._serialized_start=21038
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV._serialized_end=21380
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY._serialized_start=21192
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY._serialized_end=21349
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM._serialized_start=21220
  _BGPSRTEEXPLICITNULLLABELPOLICYSUBTLV_EXPLICITNULLLABELPOLICY_ENUM._serialized_end=21349
  _BGPSRTESEGMENTLIST._serialized_start=21383
  _BGPSRTESEGMENTLIST._serialized_end=21520
  _BGPSRTESEGMENT._serialized_start=21523
  _BGPSRTESEGMENT._serialized_end=22523
  _BGPSRTESEGMENT_SEGMENTTYPE._serialized_start=22220
  _BGPSRTESEGMENT_SEGMENTTYPE._serialized_end=22391
  _BGPSRTESEGMENT_SEGMENTTYPE_ENUM._serialized_start=22236
  _BGPSRTESEGMENT_SEGMENTTYPE_ENUM._serialized_end=22391
  _BGPSRTESRMPLSSID._serialized_start=22526
  _BGPSRTESRMPLSSID._serialized_end=22654
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE._serialized_start=22657
  _BGPSRTESRV6SIDENDPOINTBEHAVIORANDSTRUCTURE._serialized_end=22859
  _BGPSRTESEGMENTATYPESUBTLV._serialized_start=22862
  _BGPSRTESEGMENTATYPESUBTLV._serialized_end=23029
  _BGPSRTESEGMENTBTYPESUBTLV._serialized_start=23032
  _BGPSRTESEGMENTBTYPESUBTLV._serialized_end=23228
  _BGPSRTESEGMENTCTYPESUBTLV._serialized_start=23231
  _BGPSRTESEGMENTCTYPESUBTLV._serialized_end=23424
  _BGPSRTESEGMENTDTYPESUBTLV._serialized_start=23427
  _BGPSRTESEGMENTDTYPESUBTLV._serialized_end=23620
  _BGPSRTESEGMENTETYPESUBTLV._serialized_start=23623
  _BGPSRTESEGMENTETYPESUBTLV._serialized_end=23828
  _BGPSRTESEGMENTFTYPESUBTLV._serialized_start=23831
  _BGPSRTESEGMENTFTYPESUBTLV._serialized_end=24010
  _BGPSRTESEGMENTGTYPESUBTLV._serialized_start=24013
  _BGPSRTESEGMENTGTYPESUBTLV._serialized_end=24316
  _BGPSRTESEGMENTHTYPESUBTLV._serialized_start=24319
  _BGPSRTESEGMENTHTYPESUBTLV._serialized_end=24498
  _BGPSRTESEGMENTITYPESUBTLV._serialized_start=24501
  _BGPSRTESEGMENTITYPESUBTLV._serialized_end=24742
  _BGPSRTESEGMENTJTYPESUBTLV._serialized_start=24745
  _BGPSRTESEGMENTJTYPESUBTLV._serialized_end=25184
  _BGPSRTESEGMENTKTYPESUBTLV._serialized_start=25187
  _BGPSRTESEGMENTKTYPESUBTLV._serialized_end=25502
  _BGPSRTEV6POLICY._serialized_start=25505
  _BGPSRTEV6POLICY._serialized_end=26411
  _BGPSRTEV6POLICY_NEXTHOPMODE._serialized_start=15831
  _BGPSRTEV6POLICY_NEXTHOPMODE._serialized_end=15895
  _BGPSRTEV6POLICY_NEXTHOPMODE_ENUM._serialized_start=15846
  _BGPSRTEV6POLICY_NEXTHOPMODE_ENUM._serialized_end=15895
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE._serialized_start=15897
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE._serialized_end=15962
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_start=15919
  _BGPSRTEV6POLICY_NEXTHOPADDRESSTYPE_ENUM._serialized_end=15962
  _BGPSRTEV6TUNNELTLV._serialized_start=26414
  _BGPSRTEV6TUNNELTLV._serialized_end=27181
  _BGPV6PEER._serialized_start=27184
  _BGPV6PEER._serialized_end=27864
  _BGPV6PEER_ASTYPE._serialized_start=13582
  _BGPV6PEER_ASTYPE._serialized_end=13635
  _BGPV6PEER_ASTYPE_ENUM._serialized_start=13592
  _BGPV6PEER_ASTYPE_ENUM._serialized_end=13635
  _BGPV6PEER_ASNUMBERWIDTH._serialized_start=13637
  _BGPV6PEER_ASNUMBERWIDTH._serialized_end=13696
  _BGPV6PEER_ASNUMBERWIDTH_ENUM._serialized_start=13654
  _BGPV6PEER_ASNUMBERWIDTH_ENUM._serialized_end=13696
  _BGPV6INTERFACE._serialized_start=27866
  _BGPV6INTERFACE._serialized_end=27932
  _BGPV6SEGMENTROUTING._serialized_start=27935
  _BGPV6SEGMENTROUTING._serialized_end=28432
  _FLOW._serialized_start=28435
  _FLOW._serialized_end=28711
  _FLOWTXRX._serialized_start=28714
  _FLOWTXRX._serialized_end=28932
  _FLOWTXRX_CHOICE._serialized_start=28846
  _FLOWTXRX_CHOICE._serialized_end=28901
  _FLOWTXRX_CHOICE_ENUM._serialized_start=28856
  _FLOWTXRX_CHOICE_ENUM._serialized_end=28901
  _FLOWPORT._serialized_start=28934
  _FLOWPORT._serialized_end=28995
  _FLOWROUTER._serialized_start=28998
  _FLOWROUTER._serialized_end=29160
  _FLOWROUTER_MODE._serialized_start=29094
  _FLOWROUTER_MODE._serialized_end=29151
  _FLOWROUTER_MODE_ENUM._serialized_start=29102
  _FLOWROUTER_MODE_ENUM._serialized_end=29151
  _FLOWHEADER._serialized_start=29163
  _FLOWHEADER._serialized_end=30364
  _FLOWHEADER_CHOICE._serialized_start=29916
  _FLOWHEADER_CHOICE._serialized_end=30161
  _FLOWHEADER_CHOICE_ENUM._serialized_start=29927
  _FLOWHEADER_CHOICE_ENUM._serialized_end=30161
  _FLOWCUSTOM._serialized_start=30366
  _FLOWCUSTOM._serialized_end=30393
  _FLOWETHERNET._serialized_start=30396
  _FLOWETHERNET._serialized_end=30667
  _FLOWVLAN._serialized_start=30670
  _FLOWVLAN._serialized_end=30899
  _FLOWVXLAN._serialized_start=30902
  _FLOWVXLAN._serialized_end=31163
  _FLOWIPV4._serialized_start=31166
  _FLOWIPV4._serialized_end=32184
  _FLOWIPV4PRIORITY._serialized_start=32187
  _FLOWIPV4PRIORITY._serialized_end=32485
  _FLOWIPV4PRIORITY_CHOICE._serialized_start=32388
  _FLOWIPV4PRIORITY_CHOICE._serialized_end=32449
  _FLOWIPV4PRIORITY_CHOICE_ENUM._serialized_start=32398
  _FLOWIPV4PRIORITY_CHOICE_ENUM._serialized_end=32449
  _FLOWIPV4DSCP._serialized_start=32487
  _FLOWIPV4DSCP._serialized_end=32611
  _FLOWIPV4TOS._serialized_start=32614
  _FLOWIPV4TOS._serialized_end=33047
  _FLOWIPV6._serialized_start=33050
  _FLOWIPV6._serialized_end=33601
  _FLOWPFCPAUSE._serialized_start=33604
  _FLOWPFCPAUSE._serialized_end=34657
  _FLOWETHERNETPAUSE._serialized_start=34660
  _FLOWETHERNETPAUSE._serialized_end=35036
  _FLOWTCP._serialized_start=35039
  _FLOWTCP._serialized_end=35979
  _FLOWUDP._serialized_start=35982
  _FLOWUDP._serialized_end=36243
  _FLOWGRE._serialized_start=36246
  _FLOWGRE._serialized_end=36671
  _FLOWGTPV1._serialized_start=36674
  _FLOWGTPV1._serialized_end=37626
  _FLOWGTPEXTENSION._serialized_start=37629
  _FLOWGTPEXTENSION._serialized_end=37929
  _FLOWGTPV2._serialized_start=37932
  _FLOWGTPV2._serialized_end=38595
  _FLOWARP._serialized_start=38598
  _FLOWARP._serialized_end=39399
  _FLOWICMP._serialized_start=39402
  _FLOWICMP._serialized_end=39563
  _FLOWICMP_CHOICE._serialized_start=39500
  _FLOWICMP_CHOICE._serialized_end=39543
  _FLOWICMP_CHOICE_ENUM._serialized_start=39510
  _FLOWICMP_CHOICE_ENUM._serialized_end=39543
  _FLOWICMPECHO._serialized_start=39566
  _FLOWICMPECHO._serialized_end=39932
  _FLOWICMPV6._serialized_start=39935
  _FLOWICMPV6._serialized_end=40102
  _FLOWICMPV6_CHOICE._serialized_start=39500
  _FLOWICMPV6_CHOICE._serialized_end=39543
  _FLOWICMPV6_CHOICE_ENUM._serialized_start=39510
  _FLOWICMPV6_CHOICE_ENUM._serialized_end=39543
  _FLOWICMPV6ECHO._serialized_start=40105
  _FLOWICMPV6ECHO._serialized_end=40483
  _FLOWPPP._serialized_start=40486
  _FLOWPPP._serialized_end=40698
  _FLOWIGMPV1._serialized_start=40701
  _FLOWIGMPV1._serialized_end=41046
  _FLOWMPLS._serialized_start=41049
  _FLOWMPLS._serialized_end=41357
  _FLOWSIZE._serialized_start=41360
  _FLOWSIZE._serialized_end=41647
  _FLOWSIZE_CHOICE._serialized_start=41530
  _FLOWSIZE_CHOICE._serialized_end=41601
  _FLOWSIZE_CHOICE_ENUM._serialized_start=41540
  _FLOWSIZE_CHOICE_ENUM._serialized_end=41601
  _FLOWSIZEINCREMENT._serialized_start=41649
  _FLOWSIZEINCREMENT._serialized_end=41752
  _FLOWSIZERANDOM._serialized_start=41754
  _FLOWSIZERANDOM._serialized_end=41822
  _FLOWRATE._serialized_start=41825
  _FLOWRATE._serialized_end=42169
  _FLOWRATE_CHOICE._serialized_start=42003
  _FLOWRATE_CHOICE._serialized_end=42100
  _FLOWRATE_CHOICE_ENUM._serialized_start=42013
  _FLOWRATE_CHOICE_ENUM._serialized_end=42100
  _FLOWDURATION._serialized_start=42172
  _FLOWDURATION._serialized_end=42594
  _FLOWDURATION_CHOICE._serialized_start=42424
  _FLOWDURATION_CHOICE._serialized_end=42522
  _FLOWDURATION_CHOICE_ENUM._serialized_start=42434
  _FLOWDURATION_CHOICE_ENUM._serialized_end=42522
  _FLOWCONTINUOUS._serialized_start=42596
  _FLOWCONTINUOUS._serialized_end=42684
  _FLOWDELAY._serialized_start=42687
  _FLOWDELAY._serialized_end=42955
  _FLOWDELAY_CHOICE._serialized_start=42822
  _FLOWDELAY_CHOICE._serialized_end=42901
  _FLOWDELAY_CHOICE_ENUM._serialized_start=42832
  _FLOWDELAY_CHOICE_ENUM._serialized_end=42901
  _FLOWFIXEDPACKETS._serialized_start=42957
  _FLOWFIXEDPACKETS._serialized_end=43081
  _FLOWFIXEDSECONDS._serialized_start=43083
  _FLOWFIXEDSECONDS._serialized_end=43207
  _FLOWBURST._serialized_start=43210
  _FLOWBURST._serialized_end=43395
  _FLOWDURATIONINTERBURSTGAP._serialized_start=43398
  _FLOWDURATIONINTERBURSTGAP._serialized_end=43698
  _FLOWDURATIONINTERBURSTGAP_CHOICE._serialized_start=42822
  _FLOWDURATIONINTERBURSTGAP_CHOICE._serialized_end=42901
  _FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM._serialized_start=42832
  _FLOWDURATIONINTERBURSTGAP_CHOICE_ENUM._serialized_end=42901
  _FLOWMETRICS._serialized_start=43701
  _FLOWMETRICS._serialized_end=43873
  _FLOWLATENCYMETRICS._serialized_start=43876
  _FLOWLATENCYMETRICS._serialized_end=44060
  _FLOWLATENCYMETRICS_MODE._serialized_start=43973
  _FLOWLATENCYMETRICS_MODE._serialized_end=44040
  _FLOWLATENCYMETRICS_MODE_ENUM._serialized_start=43981
  _FLOWLATENCYMETRICS_MODE_ENUM._serialized_end=44040
  _EVENT._serialized_start=44063
  _EVENT._serialized_end=44329
  _EVENTRXRATETHRESHOLD._serialized_start=44331
  _EVENTRXRATETHRESHOLD._serialized_end=44423
  _EVENTLINK._serialized_start=44425
  _EVENTLINK._serialized_end=44468
  _EVENTROUTEADVERTISEWITHDRAW._serialized_start=44470
  _EVENTROUTEADVERTISEWITHDRAW._serialized_end=44531
  _EVENTREQUEST._serialized_start=44534
  _EVENTREQUEST._serialized_end=44779
  _EVENTREQUEST_TYPE._serialized_start=44610
  _EVENTREQUEST_TYPE._serialized_end=44779
  _EVENTREQUEST_TYPE_ENUM._serialized_start=44619
  _EVENTREQUEST_TYPE_ENUM._serialized_end=44779
  _EVENTSUBSCRIPTION._serialized_start=44781
  _EVENTSUBSCRIPTION._serialized_end=44893
  _RESPONSEERROR._serialized_start=44895
  _RESPONSEERROR._serialized_end=44926
  _RESPONSEWARNING._serialized_start=44928
  _RESPONSEWARNING._serialized_end=44963
  _LINKSTATE._serialized_start=44965
  _LINKSTATE._serialized_end=45090
  _LINKSTATE_STATE._serialized_start=45040
  _LINKSTATE_STATE._serialized_end=45090
  _LINKSTATE_STATE_ENUM._serialized_start=12013
  _LINKSTATE_STATE_ENUM._serialized_end=12054
  _TRANSMITSTATE._serialized_start=45093
  _TRANSMITSTATE._serialized_end=45240
  _TRANSMITSTATE_STATE._serialized_start=45176
  _TRANSMITSTATE_STATE._serialized_end=45240
  _TRANSMITSTATE_STATE_ENUM._serialized_start=45185
  _TRANSMITSTATE_STATE_ENUM._serialized_end=45240
  _CAPTURESTATE._serialized_start=45243
  _CAPTURESTATE._serialized_end=45377
  _CAPTURESTATE_STATE._serialized_start=45324
  _CAPTURESTATE_STATE._serialized_end=45377
  _CAPTURESTATE_STATE_ENUM._serialized_start=45185
  _CAPTURESTATE_STATE_ENUM._serialized_end=45229
  _FLOWSUPDATE._serialized_start=45380
  _FLOWSUPDATE._serialized_end=45542
  _FLOWSUPDATE_PROPERTYNAMES._serialized_start=45482
  _FLOWSUPDATE_PROPERTYNAMES._serialized_end=45542
  _FLOWSUPDATE_PROPERTYNAMES_ENUM._serialized_start=45499
  _FLOWSUPDATE_PROPERTYNAMES_ENUM._serialized_end=45542
  _ROUTESTATE._serialized_start=45545
  _ROUTESTATE._serialized_end=45678
  _ROUTESTATE_STATE._serialized_start=45617
  _ROUTESTATE_STATE._serialized_end=45678
  _ROUTESTATE_STATE_ENUM._serialized_start=45626
  _ROUTESTATE_STATE_ENUM._serialized_end=45678
  _PINGREQUEST._serialized_start=45680
  _PINGREQUEST._serialized_end=45723
  _PROTOCOLSTATE._serialized_start=45725
  _PROTOCOLSTATE._serialized_end=45841
  _PROTOCOLSTATE_STATE._serialized_start=45324
  _PROTOCOLSTATE_STATE._serialized_end=45377
  _PROTOCOLSTATE_STATE_ENUM._serialized_start=45185
  _PROTOCOLSTATE_STATE_ENUM._serialized_end=45229
  _PING._serialized_start=45844
  _PING._serialized_end=46046
  _PING_CHOICE._serialized_start=45964
  _PING_CHOICE._serialized_end=46017
  _PING_CHOICE_ENUM._serialized_start=15919
  _PING_CHOICE_ENUM._serialized_end=15962
  _PINGIPV4._serialized_start=46048
  _PINGIPV4._serialized_end=46126
  _PINGIPV6._serialized_start=46128
  _PINGIPV6._serialized_end=46206
  _PINGRESPONSE._serialized_start=46208
  _PINGRESPONSE._serialized_end=46256
  _RESPONSE._serialized_start=46259
  _RESPONSE._serialized_end=46457
  _RESPONSE_RESULT._serialized_start=46363
  _RESPONSE_RESULT._serialized_end=46422
  _RESPONSE_RESULT_ENUM._serialized_start=46373
  _RESPONSE_RESULT_ENUM._serialized_end=46422
  _METRICSREQUEST._serialized_start=46460
  _METRICSREQUEST._serialized_end=46899
  _METRICSREQUEST_CHOICE._serialized_start=46756
  _METRICSREQUEST_CHOICE._serialized_end=46841
  _METRICSREQUEST_CHOICE_ENUM._serialized_start=46766
  _METRICSREQUEST_CHOICE_ENUM._serialized_end=46841
  _METRICSRESPONSE._serialized_start=46902
  _METRICSRESPONSE._serialized_end=47311
  _METRICSRESPONSE_CHOICE._serialized_start=47175
  _METRICSRESPONSE_CHOICE._serialized_end=47300
  _METRICSRESPONSE_CHOICE_ENUM._serialized_start=47185
  _METRICSRESPONSE_CHOICE_ENUM._serialized_end=47300
  _PORTMETRICSREQUEST._serialized_start=47314
  _PORTMETRICSREQUEST._serialized_end=47647
  _PORTMETRICSREQUEST_COLUMNNAMES._serialized_start=47421
  _PORTMETRICSREQUEST_COLUMNNAMES._serialized_end=47647
  _PORTMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=47437
  _PORTMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=47647
  _PORTMETRIC._serialized_start=47650
  _PORTMETRIC._serialized_end=48294
  _PORTMETRIC_LINK._serialized_start=48012
  _PORTMETRIC_LINK._serialized_end=48061
  _PORTMETRIC_LINK_ENUM._serialized_start=12013
  _PORTMETRIC_LINK_ENUM._serialized_end=12054
  _PORTMETRIC_CAPTURE._serialized_start=48063
  _PORTMETRIC_CAPTURE._serialized_end=48123
  _PORTMETRIC_CAPTURE_ENUM._serialized_start=48074
  _PORTMETRIC_CAPTURE_ENUM._serialized_end=48123
  _FLOWMETRICSREQUEST._serialized_start=48297
  _FLOWMETRICSREQUEST._serialized_end=48630
  _FLOWMETRICSREQUEST_METRICNAMES._serialized_start=48461
  _FLOWMETRICSREQUEST_METRICNAMES._serialized_end=48612
  _FLOWMETRICSREQUEST_METRICNAMES_ENUM._serialized_start=48477
  _FLOWMETRICSREQUEST_METRICNAMES_ENUM._serialized_end=48612
  _FLOWMETRICGROUPREQUEST._serialized_start=48633
  _FLOWMETRICGROUPREQUEST._serialized_end=48823
  _FLOWMETRICGROUPREQUEST_CHOICE._serialized_start=48754
  _FLOWMETRICGROUPREQUEST_CHOICE._serialized_end=48812
  _FLOWMETRICGROUPREQUEST_CHOICE_ENUM._serialized_start=48764
  _FLOWMETRICGROUPREQUEST_CHOICE_ENUM._serialized_end=48812
  _FLOWMETRIC._serialized_start=48826
  _FLOWMETRIC._serialized_end=49509
  _FLOWMETRIC_TRANSMIT._serialized_start=49262
  _FLOWMETRIC_TRANSMIT._serialized_end=49335
  _FLOWMETRIC_TRANSMIT_ENUM._serialized_start=49274
  _FLOWMETRIC_TRANSMIT_ENUM._serialized_end=49335
  _FLOWMETRICGROUP._serialized_start=49511
  _FLOWMETRICGROUP._serialized_end=49586
  _METRICTIMESTAMP._serialized_start=49588
  _METRICTIMESTAMP._serialized_end=49715
  _METRICLATENCY._serialized_start=49718
  _METRICLATENCY._serialized_end=49853
  _BGPV4METRICSREQUEST._serialized_start=49856
  _BGPV4METRICSREQUEST._serialized_end=50321
  _BGPV4METRICSREQUEST_COLUMNNAMES._serialized_start=49965
  _BGPV4METRICSREQUEST_COLUMNNAMES._serialized_end=50321
  _BGPV4METRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=49981
  _BGPV4METRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=50321
  _BGPV4METRIC._serialized_start=50324
  _BGPV4METRIC._serialized_end=51206
  _BGPV4METRIC_SESSIONSTATE._serialized_start=50837
  _BGPV4METRIC_SESSIONSTATE._serialized_end=50894
  _BGPV4METRIC_SESSIONSTATE_ENUM._serialized_start=12013
  _BGPV4METRIC_SESSIONSTATE_ENUM._serialized_end=12054
  _BGPV6METRICSREQUEST._serialized_start=51209
  _BGPV6METRICSREQUEST._serialized_end=51674
  _BGPV6METRICSREQUEST_COLUMNNAMES._serialized_start=49965
  _BGPV6METRICSREQUEST_COLUMNNAMES._serialized_end=50321
  _BGPV6METRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=49981
  _BGPV6METRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=50321
  _BGPV6METRIC._serialized_start=51677
  _BGPV6METRIC._serialized_end=52559
  _BGPV6METRIC_SESSIONSTATE._serialized_start=50837
  _BGPV6METRIC_SESSIONSTATE._serialized_end=50894
  _BGPV6METRIC_SESSIONSTATE_ENUM._serialized_start=12013
  _BGPV6METRIC_SESSIONSTATE_ENUM._serialized_end=12054
  _ISISMETRICSREQUEST._serialized_start=52562
  _ISISMETRICSREQUEST._serialized_end=53348
  _ISISMETRICSREQUEST_COLUMNNAMES._serialized_start=52671
  _ISISMETRICSREQUEST_COLUMNNAMES._serialized_end=53348
  _ISISMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_start=52687
  _ISISMETRICSREQUEST_COLUMNNAMES_ENUM._serialized_end=53348
  _ISISMETRIC._serialized_start=53351
  _ISISMETRIC._serialized_end=54875
  _STATESREQUEST._serialized_start=54878
  _STATESREQUEST._serialized_end=55190
  _STATESREQUEST_CHOICE._serialized_start=55068
  _STATESREQUEST_CHOICE._serialized_end=55141
  _STATESREQUEST_CHOICE_ENUM._serialized_start=55078
  _STATESREQUEST_CHOICE_ENUM._serialized_end=55141
  _STATESRESPONSE._serialized_start=55193
  _STATESRESPONSE._serialized_end=55443
  _STATESRESPONSE_CHOICE._serialized_start=55068
  _STATESRESPONSE_CHOICE._serialized_end=55141
  _STATESRESPONSE_CHOICE_ENUM._serialized_start=55078
  _STATESRESPONSE_CHOICE_ENUM._serialized_end=55141
  _NEIGHBORSV4STATESREQUEST._serialized_start=55445
  _NEIGHBORSV4STATESREQUEST._serialized_end=55495
  _NEIGHBORSV4STATE._serialized_start=55497
  _NEIGHBORSV4STATE._serialized_end=55616
  _NEIGHBORSV6STATESREQUEST._serialized_start=55618
  _NEIGHBORSV6STATESREQUEST._serialized_end=55668
  _NEIGHBORSV6STATE._serialized_start=55670
  _NEIGHBORSV6STATE._serialized_end=55789
  _CAPTUREREQUEST._serialized_start=55791
  _CAPTUREREQUEST._serialized_end=55826
  _PATTERNFLOWETHERNETDSTCOUNTER._serialized_start=55828
  _PATTERNFLOWETHERNETDSTCOUNTER._serialized_end=55947
  _PATTERNFLOWETHERNETDST._serialized_start=55950
  _PATTERNFLOWETHERNETDST._serialized_end=56411
  _PATTERNFLOWETHERNETDST_CHOICE._serialized_start=56240
  _PATTERNFLOWETHERNETDST_CHOICE._serialized_end=56336
  _PATTERNFLOWETHERNETDST_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWETHERNETDST_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWETHERNETSRCCOUNTER._serialized_start=56413
  _PATTERNFLOWETHERNETSRCCOUNTER._serialized_end=56532
  _PATTERNFLOWETHERNETSRC._serialized_start=56535
  _PATTERNFLOWETHERNETSRC._serialized_end=56958
  _PATTERNFLOWETHERNETSRC_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETSRC_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETSRC_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETSRC_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWETHERNETETHERTYPECOUNTER._serialized_start=56960
  _PATTERNFLOWETHERNETETHERTYPECOUNTER._serialized_end=57085
  _PATTERNFLOWETHERNETETHERTYPE._serialized_start=57088
  _PATTERNFLOWETHERNETETHERTYPE._serialized_end=57573
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE._serialized_start=56240
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE._serialized_end=56336
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWETHERNETETHERTYPE_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER._serialized_start=57575
  _PATTERNFLOWETHERNETPFCQUEUECOUNTER._serialized_end=57699
  _PATTERNFLOWETHERNETPFCQUEUE._serialized_start=57702
  _PATTERNFLOWETHERNETPFCQUEUE._serialized_end=58145
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETPFCQUEUE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVLANPRIORITYCOUNTER._serialized_start=58147
  _PATTERNFLOWVLANPRIORITYCOUNTER._serialized_end=58267
  _PATTERNFLOWVLANPRIORITY._serialized_start=58270
  _PATTERNFLOWVLANPRIORITY._serialized_end=58697
  _PATTERNFLOWVLANPRIORITY_CHOICE._serialized_start=56806
  _PATTERNFLOWVLANPRIORITY_CHOICE._serialized_end=56892
  _PATTERNFLOWVLANPRIORITY_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVLANPRIORITY_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVLANCFICOUNTER._serialized_start=58699
  _PATTERNFLOWVLANCFICOUNTER._serialized_end=58814
  _PATTERNFLOWVLANCFI._serialized_start=58817
  _PATTERNFLOWVLANCFI._serialized_end=59224
  _PATTERNFLOWVLANCFI_CHOICE._serialized_start=56806
  _PATTERNFLOWVLANCFI_CHOICE._serialized_end=56892
  _PATTERNFLOWVLANCFI_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVLANCFI_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVLANIDCOUNTER._serialized_start=59226
  _PATTERNFLOWVLANIDCOUNTER._serialized_end=59340
  _PATTERNFLOWVLANID._serialized_start=59343
  _PATTERNFLOWVLANID._serialized_end=59746
  _PATTERNFLOWVLANID_CHOICE._serialized_start=56806
  _PATTERNFLOWVLANID_CHOICE._serialized_end=56892
  _PATTERNFLOWVLANID_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVLANID_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVLANTPIDCOUNTER._serialized_start=59748
  _PATTERNFLOWVLANTPIDCOUNTER._serialized_end=59864
  _PATTERNFLOWVLANTPID._serialized_start=59867
  _PATTERNFLOWVLANTPID._serialized_end=60278
  _PATTERNFLOWVLANTPID_CHOICE._serialized_start=56806
  _PATTERNFLOWVLANTPID_CHOICE._serialized_end=56892
  _PATTERNFLOWVLANTPID_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVLANTPID_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVXLANFLAGSCOUNTER._serialized_start=60280
  _PATTERNFLOWVXLANFLAGSCOUNTER._serialized_end=60398
  _PATTERNFLOWVXLANFLAGS._serialized_start=60401
  _PATTERNFLOWVXLANFLAGS._serialized_end=60820
  _PATTERNFLOWVXLANFLAGS_CHOICE._serialized_start=56806
  _PATTERNFLOWVXLANFLAGS_CHOICE._serialized_end=56892
  _PATTERNFLOWVXLANFLAGS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVXLANFLAGS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVXLANRESERVED0COUNTER._serialized_start=60822
  _PATTERNFLOWVXLANRESERVED0COUNTER._serialized_end=60944
  _PATTERNFLOWVXLANRESERVED0._serialized_start=60947
  _PATTERNFLOWVXLANRESERVED0._serialized_end=61382
  _PATTERNFLOWVXLANRESERVED0_CHOICE._serialized_start=56806
  _PATTERNFLOWVXLANRESERVED0_CHOICE._serialized_end=56892
  _PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVXLANRESERVED0_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVXLANVNICOUNTER._serialized_start=61384
  _PATTERNFLOWVXLANVNICOUNTER._serialized_end=61500
  _PATTERNFLOWVXLANVNI._serialized_start=61503
  _PATTERNFLOWVXLANVNI._serialized_end=61914
  _PATTERNFLOWVXLANVNI_CHOICE._serialized_start=56806
  _PATTERNFLOWVXLANVNI_CHOICE._serialized_end=56892
  _PATTERNFLOWVXLANVNI_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVXLANVNI_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWVXLANRESERVED1COUNTER._serialized_start=61916
  _PATTERNFLOWVXLANRESERVED1COUNTER._serialized_end=62038
  _PATTERNFLOWVXLANRESERVED1._serialized_start=62041
  _PATTERNFLOWVXLANRESERVED1._serialized_end=62476
  _PATTERNFLOWVXLANRESERVED1_CHOICE._serialized_start=56806
  _PATTERNFLOWVXLANRESERVED1_CHOICE._serialized_end=56892
  _PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWVXLANRESERVED1_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4VERSIONCOUNTER._serialized_start=62478
  _PATTERNFLOWIPV4VERSIONCOUNTER._serialized_end=62597
  _PATTERNFLOWIPV4VERSION._serialized_start=62600
  _PATTERNFLOWIPV4VERSION._serialized_end=63023
  _PATTERNFLOWIPV4VERSION_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4VERSION_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4VERSION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4VERSION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER._serialized_start=63025
  _PATTERNFLOWIPV4HEADERLENGTHCOUNTER._serialized_end=63149
  _PATTERNFLOWIPV4HEADERLENGTH._serialized_start=63152
  _PATTERNFLOWIPV4HEADERLENGTH._serialized_end=63633
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE._serialized_start=56240
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE._serialized_end=56336
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWIPV4HEADERLENGTH_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER._serialized_start=63635
  _PATTERNFLOWIPV4TOTALLENGTHCOUNTER._serialized_end=63758
  _PATTERNFLOWIPV4TOTALLENGTH._serialized_start=63761
  _PATTERNFLOWIPV4TOTALLENGTH._serialized_end=64238
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE._serialized_start=56240
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE._serialized_end=56336
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWIPV4TOTALLENGTH_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER._serialized_start=64240
  _PATTERNFLOWIPV4IDENTIFICATIONCOUNTER._serialized_end=64366
  _PATTERNFLOWIPV4IDENTIFICATION._serialized_start=64369
  _PATTERNFLOWIPV4IDENTIFICATION._serialized_end=64820
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4IDENTIFICATION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4RESERVEDCOUNTER._serialized_start=64822
  _PATTERNFLOWIPV4RESERVEDCOUNTER._serialized_end=64942
  _PATTERNFLOWIPV4RESERVED._serialized_start=64945
  _PATTERNFLOWIPV4RESERVED._serialized_end=65372
  _PATTERNFLOWIPV4RESERVED_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4RESERVED_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4RESERVED_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4RESERVED_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER._serialized_start=65374
  _PATTERNFLOWIPV4DONTFRAGMENTCOUNTER._serialized_end=65498
  _PATTERNFLOWIPV4DONTFRAGMENT._serialized_start=65501
  _PATTERNFLOWIPV4DONTFRAGMENT._serialized_end=65944
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4DONTFRAGMENT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER._serialized_start=65946
  _PATTERNFLOWIPV4MOREFRAGMENTSCOUNTER._serialized_end=66071
  _PATTERNFLOWIPV4MOREFRAGMENTS._serialized_start=66074
  _PATTERNFLOWIPV4MOREFRAGMENTS._serialized_end=66521
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4MOREFRAGMENTS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER._serialized_start=66523
  _PATTERNFLOWIPV4FRAGMENTOFFSETCOUNTER._serialized_end=66649
  _PATTERNFLOWIPV4FRAGMENTOFFSET._serialized_start=66652
  _PATTERNFLOWIPV4FRAGMENTOFFSET._serialized_end=67103
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4FRAGMENTOFFSET_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER._serialized_start=67105
  _PATTERNFLOWIPV4TIMETOLIVECOUNTER._serialized_end=67227
  _PATTERNFLOWIPV4TIMETOLIVE._serialized_start=67230
  _PATTERNFLOWIPV4TIMETOLIVE._serialized_end=67665
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TIMETOLIVE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4PROTOCOLCOUNTER._serialized_start=67667
  _PATTERNFLOWIPV4PROTOCOLCOUNTER._serialized_end=67787
  _PATTERNFLOWIPV4PROTOCOL._serialized_start=67790
  _PATTERNFLOWIPV4PROTOCOL._serialized_end=68255
  _PATTERNFLOWIPV4PROTOCOL_CHOICE._serialized_start=56240
  _PATTERNFLOWIPV4PROTOCOL_CHOICE._serialized_end=56336
  _PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWIPV4PROTOCOL_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWIPV4HEADERCHECKSUM._serialized_start=68258
  _PATTERNFLOWIPV4HEADERCHECKSUM._serialized_end=68609
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWIPV4HEADERCHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWIPV4HEADERCHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWIPV4SRCCOUNTER._serialized_start=68611
  _PATTERNFLOWIPV4SRCCOUNTER._serialized_end=68726
  _PATTERNFLOWIPV4SRC._serialized_start=68729
  _PATTERNFLOWIPV4SRC._serialized_end=69136
  _PATTERNFLOWIPV4SRC_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4SRC_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4SRC_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4SRC_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4DSTCOUNTER._serialized_start=69138
  _PATTERNFLOWIPV4DSTCOUNTER._serialized_end=69253
  _PATTERNFLOWIPV4DST._serialized_start=69256
  _PATTERNFLOWIPV4DST._serialized_end=69663
  _PATTERNFLOWIPV4DST_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4DST_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4DST_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4DST_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER._serialized_start=69665
  _PATTERNFLOWIPV4PRIORITYRAWCOUNTER._serialized_end=69788
  _PATTERNFLOWIPV4PRIORITYRAW._serialized_start=69791
  _PATTERNFLOWIPV4PRIORITYRAW._serialized_end=70230
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4PRIORITYRAW_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4DSCPPHBCOUNTER._serialized_start=70232
  _PATTERNFLOWIPV4DSCPPHBCOUNTER._serialized_end=70351
  _PATTERNFLOWIPV4DSCPPHB._serialized_start=70354
  _PATTERNFLOWIPV4DSCPPHB._serialized_end=70777
  _PATTERNFLOWIPV4DSCPPHB_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4DSCPPHB_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4DSCPPHB_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4DSCPECNCOUNTER._serialized_start=70779
  _PATTERNFLOWIPV4DSCPECNCOUNTER._serialized_end=70898
  _PATTERNFLOWIPV4DSCPECN._serialized_start=70901
  _PATTERNFLOWIPV4DSCPECN._serialized_end=71324
  _PATTERNFLOWIPV4DSCPECN_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4DSCPECN_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4DSCPECN_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER._serialized_start=71326
  _PATTERNFLOWIPV4TOSPRECEDENCECOUNTER._serialized_end=71451
  _PATTERNFLOWIPV4TOSPRECEDENCE._serialized_start=71454
  _PATTERNFLOWIPV4TOSPRECEDENCE._serialized_end=71901
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TOSPRECEDENCE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TOSDELAYCOUNTER._serialized_start=71903
  _PATTERNFLOWIPV4TOSDELAYCOUNTER._serialized_end=72023
  _PATTERNFLOWIPV4TOSDELAY._serialized_start=72026
  _PATTERNFLOWIPV4TOSDELAY._serialized_end=72453
  _PATTERNFLOWIPV4TOSDELAY_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TOSDELAY_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TOSDELAY_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER._serialized_start=72455
  _PATTERNFLOWIPV4TOSTHROUGHPUTCOUNTER._serialized_end=72580
  _PATTERNFLOWIPV4TOSTHROUGHPUT._serialized_start=72583
  _PATTERNFLOWIPV4TOSTHROUGHPUT._serialized_end=73030
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TOSTHROUGHPUT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER._serialized_start=73032
  _PATTERNFLOWIPV4TOSRELIABILITYCOUNTER._serialized_end=73158
  _PATTERNFLOWIPV4TOSRELIABILITY._serialized_start=73161
  _PATTERNFLOWIPV4TOSRELIABILITY._serialized_end=73612
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TOSRELIABILITY_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER._serialized_start=73614
  _PATTERNFLOWIPV4TOSMONETARYCOUNTER._serialized_end=73737
  _PATTERNFLOWIPV4TOSMONETARY._serialized_start=73740
  _PATTERNFLOWIPV4TOSMONETARY._serialized_end=74179
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TOSMONETARY_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER._serialized_start=74181
  _PATTERNFLOWIPV4TOSUNUSEDCOUNTER._serialized_end=74302
  _PATTERNFLOWIPV4TOSUNUSED._serialized_start=74305
  _PATTERNFLOWIPV4TOSUNUSED._serialized_end=74736
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV4TOSUNUSED_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6VERSIONCOUNTER._serialized_start=74738
  _PATTERNFLOWIPV6VERSIONCOUNTER._serialized_end=74857
  _PATTERNFLOWIPV6VERSION._serialized_start=74860
  _PATTERNFLOWIPV6VERSION._serialized_end=75283
  _PATTERNFLOWIPV6VERSION_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6VERSION_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6VERSION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6VERSION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER._serialized_start=75285
  _PATTERNFLOWIPV6TRAFFICCLASSCOUNTER._serialized_end=75409
  _PATTERNFLOWIPV6TRAFFICCLASS._serialized_start=75412
  _PATTERNFLOWIPV6TRAFFICCLASS._serialized_end=75855
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6TRAFFICCLASS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6FLOWLABELCOUNTER._serialized_start=75857
  _PATTERNFLOWIPV6FLOWLABELCOUNTER._serialized_end=75978
  _PATTERNFLOWIPV6FLOWLABEL._serialized_start=75981
  _PATTERNFLOWIPV6FLOWLABEL._serialized_end=76412
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6FLOWLABEL_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER._serialized_start=76414
  _PATTERNFLOWIPV6PAYLOADLENGTHCOUNTER._serialized_end=76539
  _PATTERNFLOWIPV6PAYLOADLENGTH._serialized_start=76542
  _PATTERNFLOWIPV6PAYLOADLENGTH._serialized_end=77027
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE._serialized_start=56240
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE._serialized_end=56336
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWIPV6PAYLOADLENGTH_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER._serialized_start=77029
  _PATTERNFLOWIPV6NEXTHEADERCOUNTER._serialized_end=77151
  _PATTERNFLOWIPV6NEXTHEADER._serialized_start=77154
  _PATTERNFLOWIPV6NEXTHEADER._serialized_end=77589
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6NEXTHEADER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6HOPLIMITCOUNTER._serialized_start=77591
  _PATTERNFLOWIPV6HOPLIMITCOUNTER._serialized_end=77711
  _PATTERNFLOWIPV6HOPLIMIT._serialized_start=77714
  _PATTERNFLOWIPV6HOPLIMIT._serialized_end=78141
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6HOPLIMIT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6SRCCOUNTER._serialized_start=78143
  _PATTERNFLOWIPV6SRCCOUNTER._serialized_end=78258
  _PATTERNFLOWIPV6SRC._serialized_start=78261
  _PATTERNFLOWIPV6SRC._serialized_end=78668
  _PATTERNFLOWIPV6SRC_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6SRC_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6SRC_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6SRC_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIPV6DSTCOUNTER._serialized_start=78670
  _PATTERNFLOWIPV6DSTCOUNTER._serialized_end=78785
  _PATTERNFLOWIPV6DST._serialized_start=78788
  _PATTERNFLOWIPV6DST._serialized_end=79195
  _PATTERNFLOWIPV6DST_CHOICE._serialized_start=56806
  _PATTERNFLOWIPV6DST_CHOICE._serialized_end=56892
  _PATTERNFLOWIPV6DST_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIPV6DST_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEDSTCOUNTER._serialized_start=79197
  _PATTERNFLOWPFCPAUSEDSTCOUNTER._serialized_end=79316
  _PATTERNFLOWPFCPAUSEDST._serialized_start=79319
  _PATTERNFLOWPFCPAUSEDST._serialized_end=79742
  _PATTERNFLOWPFCPAUSEDST_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEDST_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEDST_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSESRCCOUNTER._serialized_start=79744
  _PATTERNFLOWPFCPAUSESRCCOUNTER._serialized_end=79863
  _PATTERNFLOWPFCPAUSESRC._serialized_start=79866
  _PATTERNFLOWPFCPAUSESRC._serialized_end=80289
  _PATTERNFLOWPFCPAUSESRC_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSESRC_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSESRC_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER._serialized_start=80291
  _PATTERNFLOWPFCPAUSEETHERTYPECOUNTER._serialized_end=80416
  _PATTERNFLOWPFCPAUSEETHERTYPE._serialized_start=80419
  _PATTERNFLOWPFCPAUSEETHERTYPE._serialized_end=80866
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEETHERTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER._serialized_start=80869
  _PATTERNFLOWPFCPAUSECONTROLOPCODECOUNTER._serialized_end=80998
  _PATTERNFLOWPFCPAUSECONTROLOPCODE._serialized_start=81001
  _PATTERNFLOWPFCPAUSECONTROLOPCODE._serialized_end=81464
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER._serialized_start=81467
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTORCOUNTER._serialized_end=81600
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR._serialized_start=81603
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR._serialized_end=82082
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSECLASSENABLEVECTOR_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER._serialized_start=82084
  _PATTERNFLOWPFCPAUSEPAUSECLASS0COUNTER._serialized_end=82211
  _PATTERNFLOWPFCPAUSEPAUSECLASS0._serialized_start=82214
  _PATTERNFLOWPFCPAUSEPAUSECLASS0._serialized_end=82669
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS0_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER._serialized_start=82671
  _PATTERNFLOWPFCPAUSEPAUSECLASS1COUNTER._serialized_end=82798
  _PATTERNFLOWPFCPAUSEPAUSECLASS1._serialized_start=82801
  _PATTERNFLOWPFCPAUSEPAUSECLASS1._serialized_end=83256
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS1_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER._serialized_start=83258
  _PATTERNFLOWPFCPAUSEPAUSECLASS2COUNTER._serialized_end=83385
  _PATTERNFLOWPFCPAUSEPAUSECLASS2._serialized_start=83388
  _PATTERNFLOWPFCPAUSEPAUSECLASS2._serialized_end=83843
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS2_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER._serialized_start=83845
  _PATTERNFLOWPFCPAUSEPAUSECLASS3COUNTER._serialized_end=83972
  _PATTERNFLOWPFCPAUSEPAUSECLASS3._serialized_start=83975
  _PATTERNFLOWPFCPAUSEPAUSECLASS3._serialized_end=84430
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS3_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER._serialized_start=84432
  _PATTERNFLOWPFCPAUSEPAUSECLASS4COUNTER._serialized_end=84559
  _PATTERNFLOWPFCPAUSEPAUSECLASS4._serialized_start=84562
  _PATTERNFLOWPFCPAUSEPAUSECLASS4._serialized_end=85017
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS4_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER._serialized_start=85019
  _PATTERNFLOWPFCPAUSEPAUSECLASS5COUNTER._serialized_end=85146
  _PATTERNFLOWPFCPAUSEPAUSECLASS5._serialized_start=85149
  _PATTERNFLOWPFCPAUSEPAUSECLASS5._serialized_end=85604
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS5_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER._serialized_start=85606
  _PATTERNFLOWPFCPAUSEPAUSECLASS6COUNTER._serialized_end=85733
  _PATTERNFLOWPFCPAUSEPAUSECLASS6._serialized_start=85736
  _PATTERNFLOWPFCPAUSEPAUSECLASS6._serialized_end=86191
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS6_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER._serialized_start=86193
  _PATTERNFLOWPFCPAUSEPAUSECLASS7COUNTER._serialized_end=86320
  _PATTERNFLOWPFCPAUSEPAUSECLASS7._serialized_start=86323
  _PATTERNFLOWPFCPAUSEPAUSECLASS7._serialized_end=86778
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE._serialized_start=56806
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE._serialized_end=56892
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPFCPAUSEPAUSECLASS7_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER._serialized_start=86780
  _PATTERNFLOWETHERNETPAUSEDSTCOUNTER._serialized_end=86904
  _PATTERNFLOWETHERNETPAUSEDST._serialized_start=86907
  _PATTERNFLOWETHERNETPAUSEDST._serialized_end=87350
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETPAUSEDST_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER._serialized_start=87352
  _PATTERNFLOWETHERNETPAUSESRCCOUNTER._serialized_end=87476
  _PATTERNFLOWETHERNETPAUSESRC._serialized_start=87479
  _PATTERNFLOWETHERNETPAUSESRC._serialized_end=87922
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETPAUSESRC_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER._serialized_start=87925
  _PATTERNFLOWETHERNETPAUSEETHERTYPECOUNTER._serialized_end=88055
  _PATTERNFLOWETHERNETPAUSEETHERTYPE._serialized_start=88058
  _PATTERNFLOWETHERNETPAUSEETHERTYPE._serialized_end=88525
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETPAUSEETHERTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER._serialized_start=88528
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODECOUNTER._serialized_end=88662
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE._serialized_start=88665
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE._serialized_end=89148
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETPAUSECONTROLOPCODE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER._serialized_start=89150
  _PATTERNFLOWETHERNETPAUSETIMECOUNTER._serialized_end=89275
  _PATTERNFLOWETHERNETPAUSETIME._serialized_start=89278
  _PATTERNFLOWETHERNETPAUSETIME._serialized_end=89725
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE._serialized_start=56806
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE._serialized_end=56892
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWETHERNETPAUSETIME_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPSRCPORTCOUNTER._serialized_start=89727
  _PATTERNFLOWTCPSRCPORTCOUNTER._serialized_end=89845
  _PATTERNFLOWTCPSRCPORT._serialized_start=89848
  _PATTERNFLOWTCPSRCPORT._serialized_end=90267
  _PATTERNFLOWTCPSRCPORT_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPSRCPORT_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPSRCPORT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPSRCPORT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPDSTPORTCOUNTER._serialized_start=90269
  _PATTERNFLOWTCPDSTPORTCOUNTER._serialized_end=90387
  _PATTERNFLOWTCPDSTPORT._serialized_start=90390
  _PATTERNFLOWTCPDSTPORT._serialized_end=90809
  _PATTERNFLOWTCPDSTPORT_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPDSTPORT_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPDSTPORT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPDSTPORT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPSEQNUMCOUNTER._serialized_start=90811
  _PATTERNFLOWTCPSEQNUMCOUNTER._serialized_end=90928
  _PATTERNFLOWTCPSEQNUM._serialized_start=90931
  _PATTERNFLOWTCPSEQNUM._serialized_end=91346
  _PATTERNFLOWTCPSEQNUM_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPSEQNUM_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPSEQNUM_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPSEQNUM_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPACKNUMCOUNTER._serialized_start=91348
  _PATTERNFLOWTCPACKNUMCOUNTER._serialized_end=91465
  _PATTERNFLOWTCPACKNUM._serialized_start=91468
  _PATTERNFLOWTCPACKNUM._serialized_end=91883
  _PATTERNFLOWTCPACKNUM_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPACKNUM_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPACKNUM_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPACKNUM_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPDATAOFFSETCOUNTER._serialized_start=91885
  _PATTERNFLOWTCPDATAOFFSETCOUNTER._serialized_end=92006
  _PATTERNFLOWTCPDATAOFFSET._serialized_start=92009
  _PATTERNFLOWTCPDATAOFFSET._serialized_end=92440
  _PATTERNFLOWTCPDATAOFFSET_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPDATAOFFSET_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPDATAOFFSET_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPECNNSCOUNTER._serialized_start=92442
  _PATTERNFLOWTCPECNNSCOUNTER._serialized_end=92558
  _PATTERNFLOWTCPECNNS._serialized_start=92561
  _PATTERNFLOWTCPECNNS._serialized_end=92972
  _PATTERNFLOWTCPECNNS_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPECNNS_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPECNNS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPECNNS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPECNCWRCOUNTER._serialized_start=92974
  _PATTERNFLOWTCPECNCWRCOUNTER._serialized_end=93091
  _PATTERNFLOWTCPECNCWR._serialized_start=93094
  _PATTERNFLOWTCPECNCWR._serialized_end=93509
  _PATTERNFLOWTCPECNCWR_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPECNCWR_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPECNCWR_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPECNCWR_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPECNECHOCOUNTER._serialized_start=93511
  _PATTERNFLOWTCPECNECHOCOUNTER._serialized_end=93629
  _PATTERNFLOWTCPECNECHO._serialized_start=93632
  _PATTERNFLOWTCPECNECHO._serialized_end=94051
  _PATTERNFLOWTCPECNECHO_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPECNECHO_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPECNECHO_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPECNECHO_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPCTLURGCOUNTER._serialized_start=94053
  _PATTERNFLOWTCPCTLURGCOUNTER._serialized_end=94170
  _PATTERNFLOWTCPCTLURG._serialized_start=94173
  _PATTERNFLOWTCPCTLURG._serialized_end=94588
  _PATTERNFLOWTCPCTLURG_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPCTLURG_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPCTLURG_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPCTLURG_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPCTLACKCOUNTER._serialized_start=94590
  _PATTERNFLOWTCPCTLACKCOUNTER._serialized_end=94707
  _PATTERNFLOWTCPCTLACK._serialized_start=94710
  _PATTERNFLOWTCPCTLACK._serialized_end=95125
  _PATTERNFLOWTCPCTLACK_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPCTLACK_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPCTLACK_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPCTLACK_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPCTLPSHCOUNTER._serialized_start=95127
  _PATTERNFLOWTCPCTLPSHCOUNTER._serialized_end=95244
  _PATTERNFLOWTCPCTLPSH._serialized_start=95247
  _PATTERNFLOWTCPCTLPSH._serialized_end=95662
  _PATTERNFLOWTCPCTLPSH_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPCTLPSH_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPCTLPSH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPCTLPSH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPCTLRSTCOUNTER._serialized_start=95664
  _PATTERNFLOWTCPCTLRSTCOUNTER._serialized_end=95781
  _PATTERNFLOWTCPCTLRST._serialized_start=95784
  _PATTERNFLOWTCPCTLRST._serialized_end=96199
  _PATTERNFLOWTCPCTLRST_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPCTLRST_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPCTLRST_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPCTLRST_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPCTLSYNCOUNTER._serialized_start=96201
  _PATTERNFLOWTCPCTLSYNCOUNTER._serialized_end=96318
  _PATTERNFLOWTCPCTLSYN._serialized_start=96321
  _PATTERNFLOWTCPCTLSYN._serialized_end=96736
  _PATTERNFLOWTCPCTLSYN_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPCTLSYN_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPCTLSYN_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPCTLSYN_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPCTLFINCOUNTER._serialized_start=96738
  _PATTERNFLOWTCPCTLFINCOUNTER._serialized_end=96855
  _PATTERNFLOWTCPCTLFIN._serialized_start=96858
  _PATTERNFLOWTCPCTLFIN._serialized_end=97273
  _PATTERNFLOWTCPCTLFIN_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPCTLFIN_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPCTLFIN_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPCTLFIN_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWTCPWINDOWCOUNTER._serialized_start=97275
  _PATTERNFLOWTCPWINDOWCOUNTER._serialized_end=97392
  _PATTERNFLOWTCPWINDOW._serialized_start=97395
  _PATTERNFLOWTCPWINDOW._serialized_end=97810
  _PATTERNFLOWTCPWINDOW_CHOICE._serialized_start=56806
  _PATTERNFLOWTCPWINDOW_CHOICE._serialized_end=56892
  _PATTERNFLOWTCPWINDOW_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWTCPWINDOW_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWUDPSRCPORTCOUNTER._serialized_start=97812
  _PATTERNFLOWUDPSRCPORTCOUNTER._serialized_end=97930
  _PATTERNFLOWUDPSRCPORT._serialized_start=97933
  _PATTERNFLOWUDPSRCPORT._serialized_end=98352
  _PATTERNFLOWUDPSRCPORT_CHOICE._serialized_start=56806
  _PATTERNFLOWUDPSRCPORT_CHOICE._serialized_end=56892
  _PATTERNFLOWUDPSRCPORT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWUDPSRCPORT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWUDPDSTPORTCOUNTER._serialized_start=98354
  _PATTERNFLOWUDPDSTPORTCOUNTER._serialized_end=98472
  _PATTERNFLOWUDPDSTPORT._serialized_start=98475
  _PATTERNFLOWUDPDSTPORT._serialized_end=98894
  _PATTERNFLOWUDPDSTPORT_CHOICE._serialized_start=56806
  _PATTERNFLOWUDPDSTPORT_CHOICE._serialized_end=56892
  _PATTERNFLOWUDPDSTPORT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWUDPDSTPORT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWUDPLENGTHCOUNTER._serialized_start=98896
  _PATTERNFLOWUDPLENGTHCOUNTER._serialized_end=99013
  _PATTERNFLOWUDPLENGTH._serialized_start=99016
  _PATTERNFLOWUDPLENGTH._serialized_end=99431
  _PATTERNFLOWUDPLENGTH_CHOICE._serialized_start=56806
  _PATTERNFLOWUDPLENGTH_CHOICE._serialized_end=56892
  _PATTERNFLOWUDPLENGTH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWUDPLENGTH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWUDPCHECKSUM._serialized_start=99434
  _PATTERNFLOWUDPCHECKSUM._serialized_end=99764
  _PATTERNFLOWUDPCHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWUDPCHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWUDPCHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWUDPCHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWUDPCHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWUDPCHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER._serialized_start=99766
  _PATTERNFLOWGRECHECKSUMPRESENTCOUNTER._serialized_end=99892
  _PATTERNFLOWGRECHECKSUMPRESENT._serialized_start=99895
  _PATTERNFLOWGRECHECKSUMPRESENT._serialized_end=100346
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE._serialized_start=56806
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE._serialized_end=56892
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGRECHECKSUMPRESENT_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGRERESERVED0COUNTER._serialized_start=100348
  _PATTERNFLOWGRERESERVED0COUNTER._serialized_end=100468
  _PATTERNFLOWGRERESERVED0._serialized_start=100471
  _PATTERNFLOWGRERESERVED0._serialized_end=100898
  _PATTERNFLOWGRERESERVED0_CHOICE._serialized_start=56806
  _PATTERNFLOWGRERESERVED0_CHOICE._serialized_end=56892
  _PATTERNFLOWGRERESERVED0_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGRERESERVED0_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGREVERSIONCOUNTER._serialized_start=100900
  _PATTERNFLOWGREVERSIONCOUNTER._serialized_end=101018
  _PATTERNFLOWGREVERSION._serialized_start=101021
  _PATTERNFLOWGREVERSION._serialized_end=101440
  _PATTERNFLOWGREVERSION_CHOICE._serialized_start=56806
  _PATTERNFLOWGREVERSION_CHOICE._serialized_end=56892
  _PATTERNFLOWGREVERSION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGREVERSION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGREPROTOCOLCOUNTER._serialized_start=101442
  _PATTERNFLOWGREPROTOCOLCOUNTER._serialized_end=101561
  _PATTERNFLOWGREPROTOCOL._serialized_start=101564
  _PATTERNFLOWGREPROTOCOL._serialized_end=101987
  _PATTERNFLOWGREPROTOCOL_CHOICE._serialized_start=56806
  _PATTERNFLOWGREPROTOCOL_CHOICE._serialized_end=56892
  _PATTERNFLOWGREPROTOCOL_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGREPROTOCOL_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGRECHECKSUM._serialized_start=101990
  _PATTERNFLOWGRECHECKSUM._serialized_end=102320
  _PATTERNFLOWGRECHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWGRECHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWGRECHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWGRECHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWGRECHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWGRECHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWGRECHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWGRECHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWGRERESERVED1COUNTER._serialized_start=102322
  _PATTERNFLOWGRERESERVED1COUNTER._serialized_end=102442
  _PATTERNFLOWGRERESERVED1._serialized_start=102445
  _PATTERNFLOWGRERESERVED1._serialized_end=102872
  _PATTERNFLOWGRERESERVED1_CHOICE._serialized_start=56806
  _PATTERNFLOWGRERESERVED1_CHOICE._serialized_end=56892
  _PATTERNFLOWGRERESERVED1_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGRERESERVED1_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1VERSIONCOUNTER._serialized_start=102874
  _PATTERNFLOWGTPV1VERSIONCOUNTER._serialized_end=102994
  _PATTERNFLOWGTPV1VERSION._serialized_start=102997
  _PATTERNFLOWGTPV1VERSION._serialized_end=103424
  _PATTERNFLOWGTPV1VERSION_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1VERSION_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1VERSION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1VERSION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER._serialized_start=103426
  _PATTERNFLOWGTPV1PROTOCOLTYPECOUNTER._serialized_end=103551
  _PATTERNFLOWGTPV1PROTOCOLTYPE._serialized_start=103554
  _PATTERNFLOWGTPV1PROTOCOLTYPE._serialized_end=104001
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1PROTOCOLTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1RESERVEDCOUNTER._serialized_start=104003
  _PATTERNFLOWGTPV1RESERVEDCOUNTER._serialized_end=104124
  _PATTERNFLOWGTPV1RESERVED._serialized_start=104127
  _PATTERNFLOWGTPV1RESERVED._serialized_end=104558
  _PATTERNFLOWGTPV1RESERVED_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1RESERVED_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1RESERVED_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1EFLAGCOUNTER._serialized_start=104560
  _PATTERNFLOWGTPV1EFLAGCOUNTER._serialized_end=104678
  _PATTERNFLOWGTPV1EFLAG._serialized_start=104681
  _PATTERNFLOWGTPV1EFLAG._serialized_end=105100
  _PATTERNFLOWGTPV1EFLAG_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1EFLAG_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1EFLAG_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1SFLAGCOUNTER._serialized_start=105102
  _PATTERNFLOWGTPV1SFLAGCOUNTER._serialized_end=105220
  _PATTERNFLOWGTPV1SFLAG._serialized_start=105223
  _PATTERNFLOWGTPV1SFLAG._serialized_end=105642
  _PATTERNFLOWGTPV1SFLAG_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1SFLAG_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1SFLAG_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1PNFLAGCOUNTER._serialized_start=105644
  _PATTERNFLOWGTPV1PNFLAGCOUNTER._serialized_end=105763
  _PATTERNFLOWGTPV1PNFLAG._serialized_start=105766
  _PATTERNFLOWGTPV1PNFLAG._serialized_end=106189
  _PATTERNFLOWGTPV1PNFLAG_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1PNFLAG_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1PNFLAG_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER._serialized_start=106191
  _PATTERNFLOWGTPV1MESSAGETYPECOUNTER._serialized_end=106315
  _PATTERNFLOWGTPV1MESSAGETYPE._serialized_start=106318
  _PATTERNFLOWGTPV1MESSAGETYPE._serialized_end=106761
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1MESSAGETYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER._serialized_start=106763
  _PATTERNFLOWGTPV1MESSAGELENGTHCOUNTER._serialized_end=106889
  _PATTERNFLOWGTPV1MESSAGELENGTH._serialized_start=106892
  _PATTERNFLOWGTPV1MESSAGELENGTH._serialized_end=107343
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1MESSAGELENGTH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1TEIDCOUNTER._serialized_start=107345
  _PATTERNFLOWGTPV1TEIDCOUNTER._serialized_end=107462
  _PATTERNFLOWGTPV1TEID._serialized_start=107465
  _PATTERNFLOWGTPV1TEID._serialized_end=107880
  _PATTERNFLOWGTPV1TEID_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1TEID_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1TEID_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1TEID_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER._serialized_start=107882
  _PATTERNFLOWGTPV1SQUENCENUMBERCOUNTER._serialized_end=108008
  _PATTERNFLOWGTPV1SQUENCENUMBER._serialized_start=108011
  _PATTERNFLOWGTPV1SQUENCENUMBER._serialized_end=108462
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1SQUENCENUMBER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER._serialized_start=108464
  _PATTERNFLOWGTPV1NPDUNUMBERCOUNTER._serialized_end=108587
  _PATTERNFLOWGTPV1NPDUNUMBER._serialized_start=108590
  _PATTERNFLOWGTPV1NPDUNUMBER._serialized_end=109029
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1NPDUNUMBER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER._serialized_start=109032
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPECOUNTER._serialized_end=109168
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE._serialized_start=109171
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE._serialized_end=109662
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV1NEXTEXTENSIONHEADERTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER._serialized_start=109665
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTHCOUNTER._serialized_end=109800
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH._serialized_start=109803
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH._serialized_end=110290
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPEXTENSIONEXTENSIONLENGTH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER._serialized_start=110293
  _PATTERNFLOWGTPEXTENSIONCONTENTSCOUNTER._serialized_end=110421
  _PATTERNFLOWGTPEXTENSIONCONTENTS._serialized_start=110424
  _PATTERNFLOWGTPEXTENSIONCONTENTS._serialized_end=110883
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPEXTENSIONCONTENTS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER._serialized_start=110886
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADERCOUNTER._serialized_end=111025
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER._serialized_start=111028
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER._serialized_end=111531
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPEXTENSIONNEXTEXTENSIONHEADER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2VERSIONCOUNTER._serialized_start=111533
  _PATTERNFLOWGTPV2VERSIONCOUNTER._serialized_end=111653
  _PATTERNFLOWGTPV2VERSION._serialized_start=111656
  _PATTERNFLOWGTPV2VERSION._serialized_end=112083
  _PATTERNFLOWGTPV2VERSION_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2VERSION_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2VERSION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2VERSION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER._serialized_start=112086
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAGCOUNTER._serialized_end=112215
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG._serialized_start=112218
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG._serialized_end=112681
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2PIGGYBACKINGFLAG_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER._serialized_start=112683
  _PATTERNFLOWGTPV2TEIDFLAGCOUNTER._serialized_end=112804
  _PATTERNFLOWGTPV2TEIDFLAG._serialized_start=112807
  _PATTERNFLOWGTPV2TEIDFLAG._serialized_end=113238
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2TEIDFLAG_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2SPARE1COUNTER._serialized_start=113240
  _PATTERNFLOWGTPV2SPARE1COUNTER._serialized_end=113359
  _PATTERNFLOWGTPV2SPARE1._serialized_start=113362
  _PATTERNFLOWGTPV2SPARE1._serialized_end=113785
  _PATTERNFLOWGTPV2SPARE1_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2SPARE1_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2SPARE1_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER._serialized_start=113787
  _PATTERNFLOWGTPV2MESSAGETYPECOUNTER._serialized_end=113911
  _PATTERNFLOWGTPV2MESSAGETYPE._serialized_start=113914
  _PATTERNFLOWGTPV2MESSAGETYPE._serialized_end=114357
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2MESSAGETYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER._serialized_start=114359
  _PATTERNFLOWGTPV2MESSAGELENGTHCOUNTER._serialized_end=114485
  _PATTERNFLOWGTPV2MESSAGELENGTH._serialized_start=114488
  _PATTERNFLOWGTPV2MESSAGELENGTH._serialized_end=114939
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2MESSAGELENGTH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2TEIDCOUNTER._serialized_start=114941
  _PATTERNFLOWGTPV2TEIDCOUNTER._serialized_end=115058
  _PATTERNFLOWGTPV2TEID._serialized_start=115061
  _PATTERNFLOWGTPV2TEID._serialized_end=115476
  _PATTERNFLOWGTPV2TEID_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2TEID_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2TEID_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2TEID_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER._serialized_start=115478
  _PATTERNFLOWGTPV2SEQUENCENUMBERCOUNTER._serialized_end=115605
  _PATTERNFLOWGTPV2SEQUENCENUMBER._serialized_start=115608
  _PATTERNFLOWGTPV2SEQUENCENUMBER._serialized_end=116063
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2SEQUENCENUMBER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWGTPV2SPARE2COUNTER._serialized_start=116065
  _PATTERNFLOWGTPV2SPARE2COUNTER._serialized_end=116184
  _PATTERNFLOWGTPV2SPARE2._serialized_start=116187
  _PATTERNFLOWGTPV2SPARE2._serialized_end=116610
  _PATTERNFLOWGTPV2SPARE2_CHOICE._serialized_start=56806
  _PATTERNFLOWGTPV2SPARE2_CHOICE._serialized_end=56892
  _PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWGTPV2SPARE2_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPHARDWARETYPECOUNTER._serialized_start=116612
  _PATTERNFLOWARPHARDWARETYPECOUNTER._serialized_end=116735
  _PATTERNFLOWARPHARDWARETYPE._serialized_start=116738
  _PATTERNFLOWARPHARDWARETYPE._serialized_end=117177
  _PATTERNFLOWARPHARDWARETYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWARPHARDWARETYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPHARDWARETYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER._serialized_start=117179
  _PATTERNFLOWARPPROTOCOLTYPECOUNTER._serialized_end=117302
  _PATTERNFLOWARPPROTOCOLTYPE._serialized_start=117305
  _PATTERNFLOWARPPROTOCOLTYPE._serialized_end=117744
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPPROTOCOLTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER._serialized_start=117746
  _PATTERNFLOWARPHARDWARELENGTHCOUNTER._serialized_end=117871
  _PATTERNFLOWARPHARDWARELENGTH._serialized_start=117874
  _PATTERNFLOWARPHARDWARELENGTH._serialized_end=118321
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE._serialized_start=56806
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE._serialized_end=56892
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPHARDWARELENGTH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER._serialized_start=118323
  _PATTERNFLOWARPPROTOCOLLENGTHCOUNTER._serialized_end=118448
  _PATTERNFLOWARPPROTOCOLLENGTH._serialized_start=118451
  _PATTERNFLOWARPPROTOCOLLENGTH._serialized_end=118898
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE._serialized_start=56806
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE._serialized_end=56892
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPPROTOCOLLENGTH_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPOPERATIONCOUNTER._serialized_start=118900
  _PATTERNFLOWARPOPERATIONCOUNTER._serialized_end=119020
  _PATTERNFLOWARPOPERATION._serialized_start=119023
  _PATTERNFLOWARPOPERATION._serialized_end=119450
  _PATTERNFLOWARPOPERATION_CHOICE._serialized_start=56806
  _PATTERNFLOWARPOPERATION_CHOICE._serialized_end=56892
  _PATTERNFLOWARPOPERATION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPOPERATION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER._serialized_start=119453
  _PATTERNFLOWARPSENDERHARDWAREADDRCOUNTER._serialized_end=119582
  _PATTERNFLOWARPSENDERHARDWAREADDR._serialized_start=119585
  _PATTERNFLOWARPSENDERHARDWAREADDR._serialized_end=120048
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE._serialized_start=56806
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE._serialized_end=56892
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPSENDERHARDWAREADDR_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER._serialized_start=120051
  _PATTERNFLOWARPSENDERPROTOCOLADDRCOUNTER._serialized_end=120180
  _PATTERNFLOWARPSENDERPROTOCOLADDR._serialized_start=120183
  _PATTERNFLOWARPSENDERPROTOCOLADDR._serialized_end=120646
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE._serialized_start=56806
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE._serialized_end=56892
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPSENDERPROTOCOLADDR_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER._serialized_start=120649
  _PATTERNFLOWARPTARGETHARDWAREADDRCOUNTER._serialized_end=120778
  _PATTERNFLOWARPTARGETHARDWAREADDR._serialized_start=120781
  _PATTERNFLOWARPTARGETHARDWAREADDR._serialized_end=121244
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE._serialized_start=56806
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE._serialized_end=56892
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPTARGETHARDWAREADDR_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER._serialized_start=121247
  _PATTERNFLOWARPTARGETPROTOCOLADDRCOUNTER._serialized_end=121376
  _PATTERNFLOWARPTARGETPROTOCOLADDR._serialized_start=121379
  _PATTERNFLOWARPTARGETPROTOCOLADDR._serialized_end=121842
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE._serialized_start=56806
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE._serialized_end=56892
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWARPTARGETPROTOCOLADDR_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPECHOTYPECOUNTER._serialized_start=121844
  _PATTERNFLOWICMPECHOTYPECOUNTER._serialized_end=121964
  _PATTERNFLOWICMPECHOTYPE._serialized_start=121967
  _PATTERNFLOWICMPECHOTYPE._serialized_end=122394
  _PATTERNFLOWICMPECHOTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPECHOTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPECHOTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPECHOCODECOUNTER._serialized_start=122396
  _PATTERNFLOWICMPECHOCODECOUNTER._serialized_end=122516
  _PATTERNFLOWICMPECHOCODE._serialized_start=122519
  _PATTERNFLOWICMPECHOCODE._serialized_end=122946
  _PATTERNFLOWICMPECHOCODE_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPECHOCODE_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPECHOCODE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPECHOCODE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPECHOCHECKSUM._serialized_start=122949
  _PATTERNFLOWICMPECHOCHECKSUM._serialized_end=123294
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWICMPECHOCHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWICMPECHOCHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER._serialized_start=123296
  _PATTERNFLOWICMPECHOIDENTIFIERCOUNTER._serialized_end=123422
  _PATTERNFLOWICMPECHOIDENTIFIER._serialized_start=123425
  _PATTERNFLOWICMPECHOIDENTIFIER._serialized_end=123876
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPECHOIDENTIFIER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER._serialized_start=123879
  _PATTERNFLOWICMPECHOSEQUENCENUMBERCOUNTER._serialized_end=124009
  _PATTERNFLOWICMPECHOSEQUENCENUMBER._serialized_start=124012
  _PATTERNFLOWICMPECHOSEQUENCENUMBER._serialized_end=124479
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPCOMMONCHECKSUM._serialized_start=124482
  _PATTERNFLOWICMPCOMMONCHECKSUM._serialized_end=124833
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWICMPCOMMONCHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWICMPCOMMONCHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER._serialized_start=124836
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIERCOUNTER._serialized_end=124968
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER._serialized_start=124971
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER._serialized_end=125446
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPNEXTFIELDSIDENTIFIER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER._serialized_start=125449
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBERCOUNTER._serialized_end=125585
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER._serialized_start=125588
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER._serialized_end=126079
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPNEXTFIELDSSEQUENCENUMBER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER._serialized_start=126081
  _PATTERNFLOWICMPV6ECHOTYPECOUNTER._serialized_end=126203
  _PATTERNFLOWICMPV6ECHOTYPE._serialized_start=126206
  _PATTERNFLOWICMPV6ECHOTYPE._serialized_end=126641
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPV6ECHOTYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOCODECOUNTER._serialized_start=126643
  _PATTERNFLOWICMPV6ECHOCODECOUNTER._serialized_end=126765
  _PATTERNFLOWICMPV6ECHOCODE._serialized_start=126768
  _PATTERNFLOWICMPV6ECHOCODE._serialized_end=127203
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPV6ECHOCODE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER._serialized_start=127206
  _PATTERNFLOWICMPV6ECHOIDENTIFIERCOUNTER._serialized_end=127334
  _PATTERNFLOWICMPV6ECHOIDENTIFIER._serialized_start=127337
  _PATTERNFLOWICMPV6ECHOIDENTIFIER._serialized_end=127796
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPV6ECHOIDENTIFIER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER._serialized_start=127799
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBERCOUNTER._serialized_end=127931
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER._serialized_start=127934
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER._serialized_end=128409
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE._serialized_start=56806
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWICMPV6ECHOSEQUENCENUMBER_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWICMPV6ECHOCHECKSUM._serialized_start=128412
  _PATTERNFLOWICMPV6ECHOCHECKSUM._serialized_end=128763
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWICMPV6ECHOCHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWICMPV6ECHOCHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWICMPV6COMMONCHECKSUM._serialized_start=128766
  _PATTERNFLOWICMPV6COMMONCHECKSUM._serialized_end=129123
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWICMPV6COMMONCHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWICMPV6COMMONCHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWPPPADDRESSCOUNTER._serialized_start=129125
  _PATTERNFLOWPPPADDRESSCOUNTER._serialized_end=129243
  _PATTERNFLOWPPPADDRESS._serialized_start=129246
  _PATTERNFLOWPPPADDRESS._serialized_end=129665
  _PATTERNFLOWPPPADDRESS_CHOICE._serialized_start=56806
  _PATTERNFLOWPPPADDRESS_CHOICE._serialized_end=56892
  _PATTERNFLOWPPPADDRESS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPPPADDRESS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPPPCONTROLCOUNTER._serialized_start=129667
  _PATTERNFLOWPPPCONTROLCOUNTER._serialized_end=129785
  _PATTERNFLOWPPPCONTROL._serialized_start=129788
  _PATTERNFLOWPPPCONTROL._serialized_end=130207
  _PATTERNFLOWPPPCONTROL_CHOICE._serialized_start=56806
  _PATTERNFLOWPPPCONTROL_CHOICE._serialized_end=56892
  _PATTERNFLOWPPPCONTROL_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWPPPCONTROL_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER._serialized_start=130209
  _PATTERNFLOWPPPPROTOCOLTYPECOUNTER._serialized_end=130332
  _PATTERNFLOWPPPPROTOCOLTYPE._serialized_start=130335
  _PATTERNFLOWPPPPROTOCOLTYPE._serialized_end=130812
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE._serialized_start=56240
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE._serialized_end=56336
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWPPPPROTOCOLTYPE_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWIGMPV1VERSIONCOUNTER._serialized_start=130814
  _PATTERNFLOWIGMPV1VERSIONCOUNTER._serialized_end=130935
  _PATTERNFLOWIGMPV1VERSION._serialized_start=130938
  _PATTERNFLOWIGMPV1VERSION._serialized_end=131369
  _PATTERNFLOWIGMPV1VERSION_CHOICE._serialized_start=56806
  _PATTERNFLOWIGMPV1VERSION_CHOICE._serialized_end=56892
  _PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIGMPV1VERSION_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIGMPV1TYPECOUNTER._serialized_start=131371
  _PATTERNFLOWIGMPV1TYPECOUNTER._serialized_end=131489
  _PATTERNFLOWIGMPV1TYPE._serialized_start=131492
  _PATTERNFLOWIGMPV1TYPE._serialized_end=131911
  _PATTERNFLOWIGMPV1TYPE_CHOICE._serialized_start=56806
  _PATTERNFLOWIGMPV1TYPE_CHOICE._serialized_end=56892
  _PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIGMPV1TYPE_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER._serialized_start=131913
  _PATTERNFLOWIGMPV1UNUSEDCOUNTER._serialized_end=132033
  _PATTERNFLOWIGMPV1UNUSED._serialized_start=132036
  _PATTERNFLOWIGMPV1UNUSED._serialized_end=132463
  _PATTERNFLOWIGMPV1UNUSED_CHOICE._serialized_start=56806
  _PATTERNFLOWIGMPV1UNUSED_CHOICE._serialized_end=56892
  _PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIGMPV1UNUSED_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWIGMPV1CHECKSUM._serialized_start=132466
  _PATTERNFLOWIGMPV1CHECKSUM._serialized_end=132805
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE._serialized_start=68456
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE._serialized_end=68516
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM._serialized_start=68466
  _PATTERNFLOWIGMPV1CHECKSUM_CHOICE_ENUM._serialized_end=68516
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED._serialized_start=68518
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED._serialized_end=68573
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM._serialized_start=68531
  _PATTERNFLOWIGMPV1CHECKSUM_GENERATED_ENUM._serialized_end=68573
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER._serialized_start=132807
  _PATTERNFLOWIGMPV1GROUPADDRESSCOUNTER._serialized_end=132933
  _PATTERNFLOWIGMPV1GROUPADDRESS._serialized_start=132936
  _PATTERNFLOWIGMPV1GROUPADDRESS._serialized_end=133387
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE._serialized_start=56806
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE._serialized_end=56892
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWIGMPV1GROUPADDRESS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWMPLSLABELCOUNTER._serialized_start=133389
  _PATTERNFLOWMPLSLABELCOUNTER._serialized_end=133506
  _PATTERNFLOWMPLSLABEL._serialized_start=133509
  _PATTERNFLOWMPLSLABEL._serialized_end=133962
  _PATTERNFLOWMPLSLABEL_CHOICE._serialized_start=56240
  _PATTERNFLOWMPLSLABEL_CHOICE._serialized_end=56336
  _PATTERNFLOWMPLSLABEL_CHOICE_ENUM._serialized_start=56250
  _PATTERNFLOWMPLSLABEL_CHOICE_ENUM._serialized_end=56336
  _PATTERNFLOWMPLSTRAFFICCLASSCOUNTER._serialized_start=133964
  _PATTERNFLOWMPLSTRAFFICCLASSCOUNTER._serialized_end=134088
  _PATTERNFLOWMPLSTRAFFICCLASS._serialized_start=134091
  _PATTERNFLOWMPLSTRAFFICCLASS._serialized_end=134534
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE._serialized_start=56806
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE._serialized_end=56892
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWMPLSTRAFFICCLASS_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER._serialized_start=134536
  _PATTERNFLOWMPLSBOTTOMOFSTACKCOUNTER._serialized_end=134661
  _PATTERNFLOWMPLSBOTTOMOFSTACK._serialized_start=134664
  _PATTERNFLOWMPLSBOTTOMOFSTACK._serialized_end=135111
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE._serialized_start=56806
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE._serialized_end=56892
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWMPLSBOTTOMOFSTACK_CHOICE_ENUM._serialized_end=56892
  _PATTERNFLOWMPLSTIMETOLIVECOUNTER._serialized_start=135113
  _PATTERNFLOWMPLSTIMETOLIVECOUNTER._serialized_end=135235
  _PATTERNFLOWMPLSTIMETOLIVE._serialized_start=135238
  _PATTERNFLOWMPLSTIMETOLIVE._serialized_end=135673
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE._serialized_start=56806
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE._serialized_end=56892
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM._serialized_start=56816
  _PATTERNFLOWMPLSTIMETOLIVE_CHOICE_ENUM._serialized_end=56892
  _SUCCESS._serialized_start=135675
  _SUCCESS._serialized_end=135732
  _BADREQUEST._serialized_start=135734
  _BADREQUEST._serialized_end=135790
  _INTERNALSERVERERROR._serialized_start=135792
  _INTERNALSERVERERROR._serialized_end=135857
  _SETCONFIGREQUEST._serialized_start=135859
  _SETCONFIGREQUEST._serialized_end=135906
  _SETCONFIGRESPONSE._serialized_start=135909
  _SETCONFIGRESPONSE._serialized_end=136140
  _GETCONFIGRESPONSE._serialized_start=136143
  _GETCONFIGRESPONSE._serialized_end=136365
  _SETTRANSMITSTATEREQUEST._serialized_start=136367
  _SETTRANSMITSTATEREQUEST._serialized_end=136436
  _SETTRANSMITSTATERESPONSE._serialized_start=136439
  _SETTRANSMITSTATERESPONSE._serialized_end=136677
  _SETLINKSTATEREQUEST._serialized_start=136679
  _SETLINKSTATEREQUEST._serialized_end=136736
  _SETLINKSTATERESPONSE._serialized_start=136739
  _SETLINKSTATERESPONSE._serialized_end=136973
  _SETCAPTURESTATEREQUEST._serialized_start=136975
  _SETCAPTURESTATEREQUEST._serialized_end=137041
  _SETCAPTURESTATERESPONSE._serialized_start=137044
  _SETCAPTURESTATERESPONSE._serialized_end=137281
  _UPDATEFLOWSREQUEST._serialized_start=137283
  _UPDATEFLOWSREQUEST._serialized_end=137343
  _UPDATEFLOWSRESPONSE._serialized_start=137346
  _UPDATEFLOWSRESPONSE._serialized_end=137570
  _SETROUTESTATEREQUEST._serialized_start=137572
  _SETROUTESTATEREQUEST._serialized_end=137632
  _SETROUTESTATERESPONSE._serialized_start=137635
  _SETROUTESTATERESPONSE._serialized_end=137870
  _SENDPINGREQUEST._serialized_start=137872
  _SENDPINGREQUEST._serialized_end=137929
  _SENDPINGRESPONSE._serialized_start=137932
  _SENDPINGRESPONSE._serialized_end=138159
  _SETPROTOCOLSTATEREQUEST._serialized_start=138161
  _SETPROTOCOLSTATEREQUEST._serialized_end=138230
  _SETPROTOCOLSTATERESPONSE._serialized_start=138233
  _SETPROTOCOLSTATERESPONSE._serialized_end=138471
  _GETMETRICSREQUEST._serialized_start=138473
  _GETMETRICSREQUEST._serialized_end=138538
  _GETMETRICSRESPONSE._serialized_start=138541
  _GETMETRICSRESPONSE._serialized_end=138773
  _GETSTATESREQUEST._serialized_start=138775
  _GETSTATESREQUEST._serialized_end=138837
  _GETSTATESRESPONSE._serialized_start=138840
  _GETSTATESRESPONSE._serialized_end=139070
  _GETCAPTUREREQUEST._serialized_start=139072
  _GETCAPTUREREQUEST._serialized_end=139137
  _GETCAPTURERESPONSE._serialized_start=139140
  _GETCAPTURERESPONSE._serialized_end=139350
  _OPENAPI._serialized_start=139353
  _OPENAPI._serialized_end=140173
# @@protoc_insertion_point(module_scope)
